# DO NOT EDIT this file, it is automatically generated.
#
# This file is only used as a code completion helper
# for editors, it is not used at runtime.
from __future__ import annotations
from typing import TypeAlias, Annotated
from enum import Enum, IntFlag
from wayland.baseobject import WaylandEvent
new_id: TypeAlias = int
fd: TypeAlias = int

class wl_display:
    """
    Core global object

    The core global object.  This is a special singleton object.  It
    is used for internal Wayland protocol features.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        Global error values

        These errors are global and can be emitted in response to any
        server request.
        """

        invalid_object: int
        """Server couldn't find object"""

        invalid_method: int
        """Method doesn't exist on the specified interface or malformed request"""

        no_memory: int
        """Server is out of memory"""

        implementation: int
        """Implementation error in compositor"""



    def sync(self) -> wl_callback:
        """
        Asynchronous roundtrip

        The sync request asks the server to emit the 'done' event
        on the returned wl_callback object.  Since requests are
        handled in-order and events are delivered in-order, this can
        be used as a barrier to ensure all previous requests and the
        resulting events have been handled.

        The object returned by this request will be destroyed by the
        compositor after the callback is fired and as such the client must not
        attempt to use it after that point.

        The callback_data passed in the callback is undefined and should be ignored.

        Returns:
            wl_callback: The created object
        """

        ...

    def get_registry(self) -> wl_registry:
        """
        Get global registry object

        This request creates a registry object that allows the client
        to list and bind the global objects available from the
        compositor.

        It should be noted that the server side resources consumed in
        response to a get_registry request can only be released when the
        client disconnects, not when the client side proxy is destroyed.
        Therefore, clients should invoke get_registry as infrequently as
        possible to avoid wasting memory.

        Returns:
            wl_registry: The created object
        """

        ...

    def on_error(self, object_id: object, code: int, message: str) -> None:
        """
        Fatal error event.

        Override to handle [`wayland.wl_display.events.error`][].
        """

        ...

    def on_delete_id(self, id: int) -> None:
        """
        Acknowledge object id deletion.

        Override to handle [`wayland.wl_display.events.delete_id`][].
        """

        ...


    def dispatch(self) -> None:
        """
        Call `dispatch` to dispatch incoming Wayland events to your
        event handlers.

        This is a blocking call. It is not return until some events
        have been dispatched.
        """

        ...

    def dispatch_pending(self) -> bool:
        """
        Call `dispatch_pending` to dispatch any pending Wayland events to your
        event handlers.

        This is a non-blocking call. It returns as soon as any pending
        events have been dispatched. If there are no pending events it
        returns immediately.

        Returns:
            bool: True if any events were dispatched, otherwise False
        """

        ...

    def dispatch_timeout(self, timeout: float) -> None:
        """
        Call `dispatch_timeout` to dispatch incoming Wayland events
        to your event handlers.

        This is a blocking call. It returns either when some events
        have been dispatched or when the wait time specified by
        `timeout` has been exceeded.

        Examples:
            Wait for 1/50th of a second for events and return

            ```python
            had_events = wayland.wl_display.dispatch_timeout(1/50)
            ```

        Args:
            timeout: the maximum time to wait for events in seconds.

        Returns:
            bool: True if any events were dispatched, otherwise False
        """
        ...


    class events(WaylandEvent):
        def error(self, object_id: object, code: int, message: str) -> None:
            """
            Fatal error event

            The error event is sent out when a fatal (non-recoverable)
            error has occurred.  The object_id argument is the object
            where the error occurred, most often in response to a request
            to that object.  The code identifies the error and is defined
            by the object interface.  As such, each interface defines its
            own set of error codes.  The message is a brief description
            of the error, for (debugging) convenience.

            Args:
                object_id: Object where the error occurred
                code: Error code
                message: Error description
            """

            ...

        def delete_id(self, id: int) -> None:
            """
            Acknowledge object id deletion

            This event is used internally by the object ID management
            logic. When a client deletes an object that it had created,
            the server will send this event to acknowledge that it has
            seen the delete request. When the client receives this event,
            it will know that it can safely reuse the object ID.

            Args:
                id: Deleted object id
            """

            ...

class wl_registry:
    """
    Global registry object

    The singleton global registry object.  The server has a number of
    global objects that are available to all clients.  These objects
    typically represent an actual object in the server (for example,
    an input device) or they are singleton objects that provide
    extension functionality.

    When a client creates a registry object, the registry object
    will emit a global event for each global currently in the
    registry.  Globals come and go as a result of device or
    monitor hotplugs, reconfiguration or other events, and the
    registry will send out global and global_remove events to
    keep the client up to date with the changes.  To mark the end
    of the initial burst of events, the client can use the
    wl_display.sync request immediately after calling
    wl_display.get_registry.

    A client can bind to a global object by using the bind
    request.  This creates a client-side handle that lets the object
    emit events to the client and lets the client invoke requests on
    the object.
    """
    object_id = 0
    version = 1


    def bind(self, name: int, interface: str, version: int, id: new_id) -> None:
        """
        Bind an object to the display

        Binds a new, client-created object to the server using the
        specified name as the identifier.

        Args:
            name: Unique numeric name of the object
            id: Bounded object
        """

        ...

    def on_global_(self, name: int, interface: str, version: int) -> None:
        """
        Announce global object.

        Override to handle [`wayland.wl_registry.events.global_`][].
        """

        ...

    def on_global_remove(self, name: int) -> None:
        """
        Announce removal of global object.

        Override to handle [`wayland.wl_registry.events.global_remove`][].
        """

        ...

    class events(WaylandEvent):
        def global_(self, name: int, interface: str, version: int) -> None:
            """
            Announce global object

            Notify the client of global objects.

            The event notifies the client that a global object with
            the given name is now available, and it implements the
            given version of the given interface.

            Args:
                name: Numeric name of the global object
                interface: Interface implemented by the object
                version: Interface version
            """

            ...

        def global_remove(self, name: int) -> None:
            """
            Announce removal of global object

            Notify the client of removed global objects.

            This event notifies the client that the global identified
            by name is no longer available.  If the client bound to
            the global using the bind request, the client should now
            destroy that object.

            The object remains valid and requests to the object will be
            ignored until the client destroys it, to avoid races between
            the global going away and a client sending a request to it.

            Args:
                name: Numeric name of the global object
            """

            ...

class wl_callback:
    """
    Callback object

    Clients can handle the 'done' event to get notified when
    the related request is done.

    Note, because wl_callback objects are created from multiple independent
    factory interfaces, the wl_callback interface is frozen at version 1.
    """
    object_id = 0
    version = 1



    def on_done(self, callback_data: int) -> None:
        """
        Done event.

        Override to handle [`wayland.wl_callback.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def done(self, callback_data: int) -> None:
            """
            Done event

            Notify the client when the related request is done.

            Args:
                callback_data: Request-specific data for the callback
            """

            ...

class wl_compositor:
    """
    The compositor singleton

    A compositor.  This object is a singleton global.  The
    compositor is in charge of combining the contents of multiple
    surfaces into one displayable output.
    """
    object_id = 0
    version = 6


    def create_surface(self) -> wl_surface:
        """
        Create new surface

        Ask the compositor to create a new surface.

        Returns:
            wl_surface: The created object
        """

        ...

    def create_region(self) -> wl_region:
        """
        Create new region

        Ask the compositor to create a new region.

        Returns:
            wl_region: The created object
        """

        ...

class wl_shm_pool:
    """
    A shared memory pool

    The wl_shm_pool object encapsulates a piece of memory shared
    between the compositor and client.  Through the wl_shm_pool
    object, the client can allocate shared memory wl_buffer objects.
    All objects created through the same pool share the same
    underlying mapped memory. Reusing the mapped memory avoids the
    setup/teardown overhead and is useful when interactively resizing
    a surface or for many small buffers.
    """
    object_id = 0
    version = 2


    def create_buffer(self, offset: int, width: int, height: int, stride: int, format: wl_shm.format) -> wl_buffer:
        """
        Create a buffer from the pool

        Create a wl_buffer object from the pool.

        The buffer is created offset bytes into the pool and has
        width and height as specified.  The stride argument specifies
        the number of bytes from the beginning of one row to the beginning
        of the next.  The format is the pixel format of the buffer and
        must be one of those advertised through the wl_shm.format event.

        A buffer will keep a reference to the pool it was created from
        so it is valid to destroy the pool immediately after creating
        a buffer from it.

        Args:
            offset: Buffer byte offset within the pool
            width: Buffer width, in pixels
            height: Buffer height, in pixels
            stride: Number of bytes from the beginning of one row to the beginning of the next row
            format: Buffer pixel format

        Returns:
            wl_buffer: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the pool

        Destroy the shared memory pool.

        The mmapped memory will be released when all
        buffers that have been created from this pool
        are gone.
        """

        ...

    def resize(self, size: int) -> None:
        """
        Change the size of the pool mapping

        This request will cause the server to remap the backing memory
        for the pool from the file descriptor passed when the pool was
        created, but using the new size.  This request can only be
        used to make the pool bigger.

        This request only changes the amount of bytes that are mmapped
        by the server and does not touch the file corresponding to the
        file descriptor passed at creation time. It is the client's
        responsibility to ensure that the file is at least as big as
        the new pool size.

        Args:
            size: New size of the pool, in bytes
        """

        ...

class wl_shm:
    """
    Shared memory support

    A singleton global object that provides support for shared
    memory.

    Clients can create wl_shm_pool objects using the create_pool
    request.

    On binding the wl_shm object one or more format events
    are emitted to inform clients about the valid pixel formats
    that can be used for buffers.
    """
    object_id = 0
    version = 2

    class error(Enum):
        """
        `wl_shm` error values

        These errors can be emitted in response to wl_shm requests.
        """

        invalid_format: int
        """Buffer format is not known"""

        invalid_stride: int
        """Invalid size or stride during pool or buffer creation"""

        invalid_fd: int
        """Mmapping the file descriptor failed"""



    class format(Enum):
        """
        Pixel formats

        This describes the memory layout of an individual pixel.

        All renderers should support argb8888 and xrgb8888 but any other
        formats are optional and may not be supported by the particular
        renderer in use.

        The drm format codes match the macros defined in drm_fourcc.h, except
        argb8888 and xrgb8888. The formats actually supported by the compositor
        will be reported by the format event.

        For all wl_shm formats and unless specified in another protocol
        extension, pre-multiplied alpha is used for pixel values.
        """

        argb8888: int
        """32-bit argb format, [31:0] a:r:g:b 8:8:8:8 little endian"""

        xrgb8888: int
        """32-bit rgb format, [31:0] x:r:g:b 8:8:8:8 little endian"""

        c8: int
        """8-bit color index format, [7:0] c"""

        rgb332: int
        """8-bit rgb format, [7:0] r:g:b 3:3:2"""

        bgr233: int
        """8-bit bgr format, [7:0] b:g:r 2:3:3"""

        xrgb4444: int
        """16-bit xrgb format, [15:0] x:r:g:b 4:4:4:4 little endian"""

        xbgr4444: int
        """16-bit xbgr format, [15:0] x:b:g:r 4:4:4:4 little endian"""

        rgbx4444: int
        """16-bit rgbx format, [15:0] r:g:b:x 4:4:4:4 little endian"""

        bgrx4444: int
        """16-bit bgrx format, [15:0] b:g:r:x 4:4:4:4 little endian"""

        argb4444: int
        """16-bit argb format, [15:0] a:r:g:b 4:4:4:4 little endian"""

        abgr4444: int
        """16-bit abgr format, [15:0] a:b:g:r 4:4:4:4 little endian"""

        rgba4444: int
        """16-bit rbga format, [15:0] r:g:b:a 4:4:4:4 little endian"""

        bgra4444: int
        """16-bit bgra format, [15:0] b:g:r:a 4:4:4:4 little endian"""

        xrgb1555: int
        """16-bit xrgb format, [15:0] x:r:g:b 1:5:5:5 little endian"""

        xbgr1555: int
        """16-bit xbgr 1555 format, [15:0] x:b:g:r 1:5:5:5 little endian"""

        rgbx5551: int
        """16-bit rgbx 5551 format, [15:0] r:g:b:x 5:5:5:1 little endian"""

        bgrx5551: int
        """16-bit bgrx 5551 format, [15:0] b:g:r:x 5:5:5:1 little endian"""

        argb1555: int
        """16-bit argb 1555 format, [15:0] a:r:g:b 1:5:5:5 little endian"""

        abgr1555: int
        """16-bit abgr 1555 format, [15:0] a:b:g:r 1:5:5:5 little endian"""

        rgba5551: int
        """16-bit rgba 5551 format, [15:0] r:g:b:a 5:5:5:1 little endian"""

        bgra5551: int
        """16-bit bgra 5551 format, [15:0] b:g:r:a 5:5:5:1 little endian"""

        rgb565: int
        """16-bit rgb 565 format, [15:0] r:g:b 5:6:5 little endian"""

        bgr565: int
        """16-bit bgr 565 format, [15:0] b:g:r 5:6:5 little endian"""

        rgb888: int
        """24-bit rgb format, [23:0] r:g:b little endian"""

        bgr888: int
        """24-bit bgr format, [23:0] b:g:r little endian"""

        xbgr8888: int
        """32-bit xbgr format, [31:0] x:b:g:r 8:8:8:8 little endian"""

        rgbx8888: int
        """32-bit rgbx format, [31:0] r:g:b:x 8:8:8:8 little endian"""

        bgrx8888: int
        """32-bit bgrx format, [31:0] b:g:r:x 8:8:8:8 little endian"""

        abgr8888: int
        """32-bit abgr format, [31:0] a:b:g:r 8:8:8:8 little endian"""

        rgba8888: int
        """32-bit rgba format, [31:0] r:g:b:a 8:8:8:8 little endian"""

        bgra8888: int
        """32-bit bgra format, [31:0] b:g:r:a 8:8:8:8 little endian"""

        xrgb2101010: int
        """32-bit xrgb format, [31:0] x:r:g:b 2:10:10:10 little endian"""

        xbgr2101010: int
        """32-bit xbgr format, [31:0] x:b:g:r 2:10:10:10 little endian"""

        rgbx1010102: int
        """32-bit rgbx format, [31:0] r:g:b:x 10:10:10:2 little endian"""

        bgrx1010102: int
        """32-bit bgrx format, [31:0] b:g:r:x 10:10:10:2 little endian"""

        argb2101010: int
        """32-bit argb format, [31:0] a:r:g:b 2:10:10:10 little endian"""

        abgr2101010: int
        """32-bit abgr format, [31:0] a:b:g:r 2:10:10:10 little endian"""

        rgba1010102: int
        """32-bit rgba format, [31:0] r:g:b:a 10:10:10:2 little endian"""

        bgra1010102: int
        """32-bit bgra format, [31:0] b:g:r:a 10:10:10:2 little endian"""

        yuyv: int
        """Packed ycbcr format, [31:0] cr0:y1:cb0:y0 8:8:8:8 little endian"""

        yvyu: int
        """Packed ycbcr format, [31:0] cb0:y1:cr0:y0 8:8:8:8 little endian"""

        uyvy: int
        """Packed ycbcr format, [31:0] y1:cr0:y0:cb0 8:8:8:8 little endian"""

        vyuy: int
        """Packed ycbcr format, [31:0] y1:cb0:y0:cr0 8:8:8:8 little endian"""

        ayuv: int
        """Packed aycbcr format, [31:0] a:y:cb:cr 8:8:8:8 little endian"""

        nv12: int
        """2 plane ycbcr cr:cb format, 2x2 subsampled cr:cb plane"""

        nv21: int
        """2 plane ycbcr cb:cr format, 2x2 subsampled cb:cr plane"""

        nv16: int
        """2 plane ycbcr cr:cb format, 2x1 subsampled cr:cb plane"""

        nv61: int
        """2 plane ycbcr cb:cr format, 2x1 subsampled cb:cr plane"""

        yuv410: int
        """3 plane ycbcr format, 4x4 subsampled cb (1) and cr (2) planes"""

        yvu410: int
        """3 plane ycbcr format, 4x4 subsampled cr (1) and cb (2) planes"""

        yuv411: int
        """3 plane ycbcr format, 4x1 subsampled cb (1) and cr (2) planes"""

        yvu411: int
        """3 plane ycbcr format, 4x1 subsampled cr (1) and cb (2) planes"""

        yuv420: int
        """3 plane ycbcr format, 2x2 subsampled cb (1) and cr (2) planes"""

        yvu420: int
        """3 plane ycbcr format, 2x2 subsampled cr (1) and cb (2) planes"""

        yuv422: int
        """3 plane ycbcr format, 2x1 subsampled cb (1) and cr (2) planes"""

        yvu422: int
        """3 plane ycbcr format, 2x1 subsampled cr (1) and cb (2) planes"""

        yuv444: int
        """3 plane ycbcr format, non-subsampled cb (1) and cr (2) planes"""

        yvu444: int
        """3 plane ycbcr format, non-subsampled cr (1) and cb (2) planes"""

        r8: int
        """[7:0] r"""

        r16: int
        """[15:0] r little endian"""

        rg88: int
        """[15:0] r:g 8:8 little endian"""

        gr88: int
        """[15:0] g:r 8:8 little endian"""

        rg1616: int
        """[31:0] r:g 16:16 little endian"""

        gr1616: int
        """[31:0] g:r 16:16 little endian"""

        xrgb16161616f: int
        """[63:0] x:r:g:b 16:16:16:16 little endian"""

        xbgr16161616f: int
        """[63:0] x:b:g:r 16:16:16:16 little endian"""

        argb16161616f: int
        """[63:0] a:r:g:b 16:16:16:16 little endian"""

        abgr16161616f: int
        """[63:0] a:b:g:r 16:16:16:16 little endian"""

        xyuv8888: int
        """[31:0] x:y:cb:cr 8:8:8:8 little endian"""

        vuy888: int
        """[23:0] cr:cb:y 8:8:8 little endian"""

        vuy101010: int
        """Y followed by u then v, 10:10:10. non-linear modifier only"""

        y210: int
        """[63:0] cr0:0:y1:0:cb0:0:y0:0 10:6:10:6:10:6:10:6 little endian per 2 y pixels"""

        y212: int
        """[63:0] cr0:0:y1:0:cb0:0:y0:0 12:4:12:4:12:4:12:4 little endian per 2 y pixels"""

        y216: int
        """[63:0] cr0:y1:cb0:y0 16:16:16:16 little endian per 2 y pixels"""

        y410: int
        """[31:0] a:cr:y:cb 2:10:10:10 little endian"""

        y412: int
        """[63:0] a:0:cr:0:y:0:cb:0 12:4:12:4:12:4:12:4 little endian"""

        y416: int
        """[63:0] a:cr:y:cb 16:16:16:16 little endian"""

        xvyu2101010: int
        """[31:0] x:cr:y:cb 2:10:10:10 little endian"""

        xvyu12_16161616: int
        """[63:0] x:0:cr:0:y:0:cb:0 12:4:12:4:12:4:12:4 little endian"""

        xvyu16161616: int
        """[63:0] x:cr:y:cb 16:16:16:16 little endian"""

        y0l0: int
        """[63:0]   a3:a2:y3:0:cr0:0:y2:0:a1:a0:y1:0:cb0:0:y0:0  1:1:8:2:8:2:8:2:1:1:8:2:8:2:8:2 little endian"""

        x0l0: int
        """[63:0]   x3:x2:y3:0:cr0:0:y2:0:x1:x0:y1:0:cb0:0:y0:0  1:1:8:2:8:2:8:2:1:1:8:2:8:2:8:2 little endian"""

        y0l2: int
        """[63:0]   a3:a2:y3:cr0:y2:a1:a0:y1:cb0:y0  1:1:10:10:10:1:1:10:10:10 little endian"""

        x0l2: int
        """[63:0]   x3:x2:y3:cr0:y2:x1:x0:y1:cb0:y0  1:1:10:10:10:1:1:10:10:10 little endian"""

        yuv420_8bit: int
        yuv420_10bit: int
        xrgb8888_a8: int
        xbgr8888_a8: int
        rgbx8888_a8: int
        bgrx8888_a8: int
        rgb888_a8: int
        bgr888_a8: int
        rgb565_a8: int
        bgr565_a8: int
        nv24: int
        """Non-subsampled cr:cb plane"""

        nv42: int
        """Non-subsampled cb:cr plane"""

        p210: int
        """2x1 subsampled cr:cb plane, 10 bit per channel"""

        p010: int
        """2x2 subsampled cr:cb plane 10 bits per channel"""

        p012: int
        """2x2 subsampled cr:cb plane 12 bits per channel"""

        p016: int
        """2x2 subsampled cr:cb plane 16 bits per channel"""

        axbxgxrx106106106106: int
        """[63:0] a:x:b:x:g:x:r:x 10:6:10:6:10:6:10:6 little endian"""

        nv15: int
        """2x2 subsampled cr:cb plane"""

        q410: int
        q401: int
        xrgb16161616: int
        """[63:0] x:r:g:b 16:16:16:16 little endian"""

        xbgr16161616: int
        """[63:0] x:b:g:r 16:16:16:16 little endian"""

        argb16161616: int
        """[63:0] a:r:g:b 16:16:16:16 little endian"""

        abgr16161616: int
        """[63:0] a:b:g:r 16:16:16:16 little endian"""

        c1: int
        """[7:0] c0:c1:c2:c3:c4:c5:c6:c7 1:1:1:1:1:1:1:1 eight pixels/byte"""

        c2: int
        """[7:0] c0:c1:c2:c3 2:2:2:2 four pixels/byte"""

        c4: int
        """[7:0] c0:c1 4:4 two pixels/byte"""

        d1: int
        """[7:0] d0:d1:d2:d3:d4:d5:d6:d7 1:1:1:1:1:1:1:1 eight pixels/byte"""

        d2: int
        """[7:0] d0:d1:d2:d3 2:2:2:2 four pixels/byte"""

        d4: int
        """[7:0] d0:d1 4:4 two pixels/byte"""

        d8: int
        """[7:0] d"""

        r1: int
        """[7:0] r0:r1:r2:r3:r4:r5:r6:r7 1:1:1:1:1:1:1:1 eight pixels/byte"""

        r2: int
        """[7:0] r0:r1:r2:r3 2:2:2:2 four pixels/byte"""

        r4: int
        """[7:0] r0:r1 4:4 two pixels/byte"""

        r10: int
        """[15:0] x:r 6:10 little endian"""

        r12: int
        """[15:0] x:r 4:12 little endian"""

        avuy8888: int
        """[31:0] a:cr:cb:y 8:8:8:8 little endian"""

        xvuy8888: int
        """[31:0] x:cr:cb:y 8:8:8:8 little endian"""

        p030: int
        """2x2 subsampled cr:cb plane 10 bits per channel packed"""



    def create_pool(self, fd: fd, size: int) -> wl_shm_pool:
        """
        Create a shm pool

        Create a new wl_shm_pool object.

        The pool can be used to create shared memory based buffer
        objects.  The server will mmap size bytes of the passed file
        descriptor, to use as backing memory for the pool.

        Args:
            fd: File descriptor for the pool
            size: Pool size, in bytes

        Returns:
            wl_shm_pool: The created object
        """

        ...

    def release(self) -> None:
        """
        Release the shm object

        Using this request a client can tell the server that it is not going to
        use the shm object anymore.

        Objects created via this interface remain unaffected.
        """

        ...

    def on_format(self, format: wl_shm.format) -> None:
        """
        Pixel format description.

        Override to handle [`wayland.wl_shm.events.format`][].
        """

        ...

    class events(WaylandEvent):
        def format(self, format: wl_shm.format) -> None:
            """
            Pixel format description

            Informs the client about a valid pixel format that
            can be used for buffers. Known formats include
            argb8888 and xrgb8888.

            Args:
                format: Buffer pixel format
            """

            ...

class wl_buffer:
    """
    Content for a `wl_surface`

    A buffer provides the content for a wl_surface. Buffers are
    created through factory interfaces such as wl_shm, wp_linux_buffer_params
    (from the linux-dmabuf protocol extension) or similar. It has a width and
    a height and can be attached to a wl_surface, but the mechanism by which a
    client provides and updates the contents is defined by the buffer factory
    interface.

    Color channels are assumed to be electrical rather than optical (in other
    words, encoded with a transfer function) unless otherwise specified. If
    the buffer uses a format that has an alpha channel, the alpha channel is
    assumed to be premultiplied into the electrical color channel values
    (after transfer function encoding) unless otherwise specified.

    Note, because wl_buffer objects are created from multiple independent
    factory interfaces, the wl_buffer interface is frozen at version 1.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy a buffer

        Destroy a buffer. If and how you need to release the backing
        storage is defined by the buffer factory interface.

        For possible side-effects to a surface, see wl_surface.attach.
        """

        ...

    def on_release(self) -> None:
        """
        Compositor releases buffer.

        Override to handle [`wayland.wl_buffer.events.release`][].
        """

        ...

    class events(WaylandEvent):
        def release(self) -> None:
            """
            Compositor releases buffer

            Sent when this wl_buffer is no longer used by the compositor.

            For more information on when release events may or may not be sent,
            and what consequences it has, please see the description of
            wl_surface.attach.

            If a client receives a release event before the frame callback
            requested in the same wl_surface.commit that attaches this
            wl_buffer to a surface, then the client is immediately free to
            reuse the buffer and its backing storage, and does not need a
            second buffer for the next surface content update. Typically
            this is possible, when the compositor maintains a copy of the
            wl_surface contents, e.g. as a GL texture. This is an important
            optimization for GL(ES) compositors with wl_shm clients.
            """

            ...

class wl_data_offer:
    """
    Offer to transfer data

    A wl_data_offer represents a piece of data offered for transfer
    by another client (the source client).  It is used by the
    copy-and-paste and drag-and-drop mechanisms.  The offer
    describes the different mime types that the data can be
    converted to and provides the mechanism for transferring the
    data directly from the source client.
    """
    object_id = 0
    version = 3

    class error(Enum):
        invalid_finish: int
        """Finish request was called untimely"""

        invalid_action_mask: int
        """Action mask contains invalid values"""

        invalid_action: int
        """Action argument has an invalid value"""

        invalid_offer: int
        """Offer doesn't accept this request"""



    def accept(self, serial: int, mime_type: str) -> None:
        """
        Accept one of the offered mime types

        Indicate that the client can accept the given mime type, or
        NULL for not accepted.

        For objects of version 2 or older, this request is used by the
        client to give feedback whether the client can receive the given
        mime type, or NULL if none is accepted; the feedback does not
        determine whether the drag-and-drop operation succeeds or not.

        For objects of version 3 or newer, this request determines the
        final result of the drag-and-drop operation. If the end result
        is that no mime types were accepted, the drag-and-drop operation
        will be cancelled and the corresponding drag source will receive
        wl_data_source.cancelled. Clients may still use this event in
        conjunction with wl_data_source.action for feedback.

        Args:
            serial: Serial number of the accept request
            mime_type: Mime type accepted by the client
        """

        ...

    def receive(self, mime_type: str, fd: fd) -> None:
        """
        Request that the data is transferred

        To transfer the offered data, the client issues this request
        and indicates the mime type it wants to receive.  The transfer
        happens through the passed file descriptor (typically created
        with the pipe system call).  The source client writes the data
        in the mime type representation requested and then closes the
        file descriptor.

        The receiving client reads from the read end of the pipe until
        EOF and then closes its end, at which point the transfer is
        complete.

        This request may happen multiple times for different mime types,
        both before and after wl_data_device.drop. Drag-and-drop destination
        clients may preemptively fetch data or examine it more closely to
        determine acceptance.

        Args:
            mime_type: Mime type desired by receiver
            fd: File descriptor for data transfer
        """

        ...

    def destroy(self) -> None:
        """
        Destroy data offer

        Destroy the data offer.
        """

        ...

    def finish(self) -> None:
        """
        The offer will no longer be used

        Notifies the compositor that the drag destination successfully
        finished the drag-and-drop operation.

        Upon receiving this request, the compositor will emit
        wl_data_source.dnd_finished on the drag source client.

        It is a client error to perform other requests than
        wl_data_offer.destroy after this one. It is also an error to perform
        this request after a NULL mime type has been set in
        wl_data_offer.accept or no action was received through
        wl_data_offer.action.

        If wl_data_offer.finish request is received for a non drag and drop
        operation, the invalid_finish protocol error is raised.
        """

        ...

    def set_actions(self, dnd_actions: wl_data_device_manager.dnd_action, preferred_action: wl_data_device_manager.dnd_action) -> None:
        """
        Set the available/preferred drag-and-drop actions

        Sets the actions that the destination side client supports for
        this operation. This request may trigger the emission of
        wl_data_source.action and wl_data_offer.action events if the compositor
        needs to change the selected action.

        This request can be called multiple times throughout the
        drag-and-drop operation, typically in response to wl_data_device.enter
        or wl_data_device.motion events.

        This request determines the final result of the drag-and-drop
        operation. If the end result is that no action is accepted,
        the drag source will receive wl_data_source.cancelled.

        The dnd_actions argument must contain only values expressed in the
        wl_data_device_manager.dnd_actions enum, and the preferred_action
        argument must only contain one of those values set, otherwise it
        will result in a protocol error.

        While managing an "ask" action, the destination drag-and-drop client
        may perform further wl_data_offer.receive requests, and is expected
        to perform one last wl_data_offer.set_actions request with a preferred
        action other than "ask" (and optionally wl_data_offer.accept) before
        requesting wl_data_offer.finish, in order to convey the action selected
        by the user. If the preferred action is not in the
        wl_data_offer.source_actions mask, an error will be raised.

        If the "ask" action is dismissed (e.g. user cancellation), the client
        is expected to perform wl_data_offer.destroy right away.

        This request can only be made on drag-and-drop offers, a protocol error
        will be raised otherwise.

        Args:
            dnd_actions: Actions supported by the destination client
            preferred_action: Action preferred by the destination client
        """

        ...

    def on_offer(self, mime_type: str) -> None:
        """
        Advertise offered mime type.

        Override to handle [`wayland.wl_data_offer.events.offer`][].
        """

        ...

    def on_source_actions(self, source_actions: wl_data_device_manager.dnd_action) -> None:
        """
        Notify the source-side available actions.

        Override to handle [`wayland.wl_data_offer.events.source_actions`][].
        """

        ...

    def on_action(self, dnd_action: wl_data_device_manager.dnd_action) -> None:
        """
        Notify the selected action.

        Override to handle [`wayland.wl_data_offer.events.action`][].
        """

        ...

    class events(WaylandEvent):
        def offer(self, mime_type: str) -> None:
            """
            Advertise offered mime type

            Sent immediately after creating the wl_data_offer object.  One
            event per offered mime type.

            Args:
                mime_type: Offered mime type
            """

            ...

        def source_actions(self, source_actions: wl_data_device_manager.dnd_action) -> None:
            """
            Notify the source-side available actions

            This event indicates the actions offered by the data source. It
            will be sent immediately after creating the wl_data_offer object,
            or anytime the source side changes its offered actions through
            wl_data_source.set_actions.

            Args:
                source_actions: Actions offered by the data source
            """

            ...

        def action(self, dnd_action: wl_data_device_manager.dnd_action) -> None:
            """
            Notify the selected action

            This event indicates the action selected by the compositor after
            matching the source/destination side actions. Only one action (or
            none) will be offered here.

            This event can be emitted multiple times during the drag-and-drop
            operation in response to destination side action changes through
            wl_data_offer.set_actions.

            This event will no longer be emitted after wl_data_device.drop
            happened on the drag-and-drop destination, the client must
            honor the last action received, or the last preferred one set
            through wl_data_offer.set_actions when handling an "ask" action.

            Compositors may also change the selected action on the fly, mainly
            in response to keyboard modifier changes during the drag-and-drop
            operation.

            The most recent action received is always the valid one. Prior to
            receiving wl_data_device.drop, the chosen action may change (e.g.
            due to keyboard modifiers being pressed). At the time of receiving
            wl_data_device.drop the drag-and-drop destination must honor the
            last action received.

            Action changes may still happen after wl_data_device.drop,
            especially on "ask" actions, where the drag-and-drop destination
            may choose another action afterwards. Action changes happening
            at this stage are always the result of inter-client negotiation, the
            compositor shall no longer be able to induce a different action.

            Upon "ask" actions, it is expected that the drag-and-drop destination
            may potentially choose a different action and/or mime type,
            based on wl_data_offer.source_actions and finally chosen by the
            user (e.g. popping up a menu with the available options). The
            final wl_data_offer.set_actions and wl_data_offer.accept requests
            must happen before the call to wl_data_offer.finish.

            Args:
                dnd_action: Action selected by the compositor
            """

            ...

class wl_data_source:
    """
    Offer to transfer data

    The wl_data_source object is the source side of a wl_data_offer.
    It is created by the source client in a data transfer and
    provides a way to describe the offered data and a way to respond
    to requests to transfer the data.
    """
    object_id = 0
    version = 3

    class error(Enum):
        invalid_action_mask: int
        """Action mask contains invalid values"""

        invalid_source: int
        """Source doesn't accept this request"""



    def offer(self, mime_type: str) -> None:
        """
        Add an offered mime type

        This request adds a mime type to the set of mime types
        advertised to targets.  Can be called several times to offer
        multiple types.

        Args:
            mime_type: Mime type offered by the data source
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the data source

        Destroy the data source.
        """

        ...

    def set_actions(self, dnd_actions: wl_data_device_manager.dnd_action) -> None:
        """
        Set the available drag-and-drop actions

        Sets the actions that the source side client supports for this
        operation. This request may trigger wl_data_source.action and
        wl_data_offer.action events if the compositor needs to change the
        selected action.

        The dnd_actions argument must contain only values expressed in the
        wl_data_device_manager.dnd_actions enum, otherwise it will result
        in a protocol error.

        This request must be made once only, and can only be made on sources
        used in drag-and-drop, so it must be performed before
        wl_data_device.start_drag. Attempting to use the source other than
        for drag-and-drop will raise a protocol error.

        Args:
            dnd_actions: Actions supported by the data source
        """

        ...

    def on_target(self, mime_type: str) -> None:
        """
        A target accepts an offered mime type.

        Override to handle [`wayland.wl_data_source.events.target`][].
        """

        ...

    def on_send(self, mime_type: str, fd: fd) -> None:
        """
        Send the data.

        Override to handle [`wayland.wl_data_source.events.send`][].
        """

        ...

    def on_cancelled(self) -> None:
        """
        Selection was cancelled.

        Override to handle [`wayland.wl_data_source.events.cancelled`][].
        """

        ...

    def on_dnd_drop_performed(self) -> None:
        """
        The drag-and-drop operation physically finished.

        Override to handle [`wayland.wl_data_source.events.dnd_drop_performed`][].
        """

        ...

    def on_dnd_finished(self) -> None:
        """
        The drag-and-drop operation concluded.

        Override to handle [`wayland.wl_data_source.events.dnd_finished`][].
        """

        ...

    def on_action(self, dnd_action: wl_data_device_manager.dnd_action) -> None:
        """
        Notify the selected action.

        Override to handle [`wayland.wl_data_source.events.action`][].
        """

        ...

    class events(WaylandEvent):
        def target(self, mime_type: str) -> None:
            """
            A target accepts an offered mime type

            Sent when a target accepts pointer_focus or motion events.  If
            a target does not accept any of the offered types, type is NULL.

            Used for feedback during drag-and-drop.

            Args:
                mime_type: Mime type accepted by the target
            """

            ...

        def send(self, mime_type: str, fd: fd) -> None:
            """
            Send the data

            Request for data from the client.  Send the data as the
            specified mime type over the passed file descriptor, then
            close it.

            Args:
                mime_type: Mime type for the data
                fd: File descriptor for the data
            """

            ...

        def cancelled(self) -> None:
            """
            Selection was cancelled

            This data source is no longer valid. There are several reasons why
            this could happen:

            - The data source has been replaced by another data source.
            - The drag-and-drop operation was performed, but the drop destination
              did not accept any of the mime types offered through
              wl_data_source.target.
            - The drag-and-drop operation was performed, but the drop destination
              did not select any of the actions present in the mask offered through
              wl_data_source.action.
            - The drag-and-drop operation was performed but didn't happen over a
              surface.
            - The compositor cancelled the drag-and-drop operation (e.g. compositor
              dependent timeouts to avoid stale drag-and-drop transfers).

            The client should clean up and destroy this data source.

            For objects of version 2 or older, wl_data_source.cancelled will
            only be emitted if the data source was replaced by another data
            source.
            """

            ...

        def dnd_drop_performed(self) -> None:
            """
            The drag-and-drop operation physically finished

            The user performed the drop action. This event does not indicate
            acceptance, wl_data_source.cancelled may still be emitted afterwards
            if the drop destination does not accept any mime type.

            However, this event might however not be received if the compositor
            cancelled the drag-and-drop operation before this event could happen.

            Note that the data_source may still be used in the future and should
            not be destroyed here.
            """

            ...

        def dnd_finished(self) -> None:
            """
            The drag-and-drop operation concluded

            The drop destination finished interoperating with this data
            source, so the client is now free to destroy this data source and
            free all associated data.

            If the action used to perform the operation was "move", the
            source can now delete the transferred data.
            """

            ...

        def action(self, dnd_action: wl_data_device_manager.dnd_action) -> None:
            """
            Notify the selected action

            This event indicates the action selected by the compositor after
            matching the source/destination side actions. Only one action (or
            none) will be offered here.

            This event can be emitted multiple times during the drag-and-drop
            operation, mainly in response to destination side changes through
            wl_data_offer.set_actions, and as the data device enters/leaves
            surfaces.

            It is only possible to receive this event after
            wl_data_source.dnd_drop_performed if the drag-and-drop operation
            ended in an "ask" action, in which case the final wl_data_source.action
            event will happen immediately before wl_data_source.dnd_finished.

            Compositors may also change the selected action on the fly, mainly
            in response to keyboard modifier changes during the drag-and-drop
            operation.

            The most recent action received is always the valid one. The chosen
            action may change alongside negotiation (e.g. an "ask" action can turn
            into a "move" operation), so the effects of the final action must
            always be applied in wl_data_offer.dnd_finished.

            Clients can trigger cursor surface changes from this point, so
            they reflect the current action.

            Args:
                dnd_action: Action selected by the compositor
            """

            ...

class wl_data_device:
    """
    Data transfer device

    There is one wl_data_device per seat which can be obtained
    from the global wl_data_device_manager singleton.

    A wl_data_device provides access to inter-client data transfer
    mechanisms such as copy-and-paste and drag-and-drop.
    """
    object_id = 0
    version = 3

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""

        used_source: int
        """Source has already been used"""



    def start_drag(self, source: wl_data_source, origin: wl_surface, icon: wl_surface, serial: int) -> None:
        """
        Start drag-and-drop operation

        This request asks the compositor to start a drag-and-drop
        operation on behalf of the client.

        The source argument is the data source that provides the data
        for the eventual data transfer. If source is NULL, enter, leave
        and motion events are sent only to the client that initiated the
        drag and the client is expected to handle the data passing
        internally. If source is destroyed, the drag-and-drop session will be
        cancelled.

        The origin surface is the surface where the drag originates and
        the client must have an active implicit grab that matches the
        serial.

        The icon surface is an optional (can be NULL) surface that
        provides an icon to be moved around with the cursor.  Initially,
        the top-left corner of the icon surface is placed at the cursor
        hotspot, but subsequent wl_surface.offset requests can move the
        relative position. Attach requests must be confirmed with
        wl_surface.commit as usual. The icon surface is given the role of
        a drag-and-drop icon. If the icon surface already has another role,
        it raises a protocol error.

        The input region is ignored for wl_surfaces with the role of a
        drag-and-drop icon.

        The given source may not be used in any further set_selection or
        start_drag requests. Attempting to reuse a previously-used source
        may send a used_source error.

        Args:
            source: Data source for the eventual transfer
            origin: Surface where the drag originates
            icon: Drag-and-drop icon surface
            serial: Serial number of the implicit grab on the origin
        """

        ...

    def set_selection(self, source: wl_data_source, serial: int) -> None:
        """
        Copy data to the selection

        This request asks the compositor to set the selection
        to the data from the source on behalf of the client.

        To unset the selection, set the source to NULL.

        The given source may not be used in any further set_selection or
        start_drag requests. Attempting to reuse a previously-used source
        may send a used_source error.

        Args:
            source: Data source for the selection
            serial: Serial number of the event that triggered this request
        """

        ...

    def release(self) -> None:
        """
        Destroy data device

        This request destroys the data device.
        """

        ...

    def on_data_offer(self, id: wl_data_offer) -> None:
        """
        Introduce a new `wl_data_offer`.

        Override to handle [`wayland.wl_data_device.events.data_offer`][].
        """

        ...

    def on_enter(self, serial: int, surface: wl_surface, x: float, y: float, id: wl_data_offer) -> None:
        """
        Initiate drag-and-drop session.

        Override to handle [`wayland.wl_data_device.events.enter`][].
        """

        ...

    def on_leave(self) -> None:
        """
        End drag-and-drop session.

        Override to handle [`wayland.wl_data_device.events.leave`][].
        """

        ...

    def on_motion(self, time: int, x: float, y: float) -> None:
        """
        Drag-and-drop session motion.

        Override to handle [`wayland.wl_data_device.events.motion`][].
        """

        ...

    def on_drop(self) -> None:
        """
        End drag-and-drop session successfully.

        Override to handle [`wayland.wl_data_device.events.drop`][].
        """

        ...

    def on_selection(self, id: wl_data_offer) -> None:
        """
        Advertise new selection.

        Override to handle [`wayland.wl_data_device.events.selection`][].
        """

        ...

    class events(WaylandEvent):
        def data_offer(self, id: wl_data_offer) -> None:
            """
            Introduce a new `wl_data_offer`

            The data_offer event introduces a new wl_data_offer object,
            which will subsequently be used in either the
            data_device.enter event (for drag-and-drop) or the
            data_device.selection event (for selections).  Immediately
            following the data_device.data_offer event, the new data_offer
            object will send out data_offer.offer events to describe the
            mime types it offers.

            Args:
                id: The new `data_offer` object
            """

            ...

        def enter(self, serial: int, surface: wl_surface, x: float, y: float, id: wl_data_offer) -> None:
            """
            Initiate drag-and-drop session

            This event is sent when an active drag-and-drop pointer enters
            a surface owned by the client.  The position of the pointer at
            enter time is provided by the x and y arguments, in surface-local
            coordinates.

            Args:
                serial: Serial number of the enter event
                surface: Client surface entered
                x: Surface-local x coordinate
                y: Surface-local y coordinate
                id: Source `data_offer` object
            """

            ...

        def leave(self) -> None:
            """
            End drag-and-drop session

            This event is sent when the drag-and-drop pointer leaves the
            surface and the session ends.  The client must destroy the
            wl_data_offer introduced at enter time at this point.
            """

            ...

        def motion(self, time: int, x: float, y: float) -> None:
            """
            Drag-and-drop session motion

            This event is sent when the drag-and-drop pointer moves within
            the currently focused surface. The new position of the pointer
            is provided by the x and y arguments, in surface-local
            coordinates.

            Args:
                time: Timestamp with millisecond granularity
                x: Surface-local x coordinate
                y: Surface-local y coordinate
            """

            ...

        def drop(self) -> None:
            """
            End drag-and-drop session successfully

            The event is sent when a drag-and-drop operation is ended
            because the implicit grab is removed.

            The drag-and-drop destination is expected to honor the last action
            received through wl_data_offer.action, if the resulting action is
            "copy" or "move", the destination can still perform
            wl_data_offer.receive requests, and is expected to end all
            transfers with a wl_data_offer.finish request.

            If the resulting action is "ask", the action will not be considered
            final. The drag-and-drop destination is expected to perform one last
            wl_data_offer.set_actions request, or wl_data_offer.destroy in order
            to cancel the operation.
            """

            ...

        def selection(self, id: wl_data_offer) -> None:
            """
            Advertise new selection

            The selection event is sent out to notify the client of a new
            wl_data_offer for the selection for this device.  The
            data_device.data_offer and the data_offer.offer events are
            sent out immediately before this event to introduce the data
            offer object.  The selection event is sent to a client
            immediately before receiving keyboard focus and when a new
            selection is set while the client has keyboard focus.  The
            data_offer is valid until a new data_offer or NULL is received
            or until the client loses keyboard focus.  Switching surface with
            keyboard focus within the same client doesn't mean a new selection
            will be sent.  The client must destroy the previous selection
            data_offer, if any, upon receiving this event.

            Args:
                id: Selection `data_offer` object
            """

            ...

class wl_data_device_manager:
    """
    Data transfer interface

    The wl_data_device_manager is a singleton global object that
    provides access to inter-client data transfer mechanisms such as
    copy-and-paste and drag-and-drop.  These mechanisms are tied to
    a wl_seat and this interface lets a client get a wl_data_device
    corresponding to a wl_seat.

    Depending on the version bound, the objects created from the bound
    wl_data_device_manager object will have different requirements for
    functioning properly. See wl_data_source.set_actions,
    wl_data_offer.accept and wl_data_offer.finish for details.
    """
    object_id = 0
    version = 3

    class dnd_action(IntFlag):
        """
        Drag and drop actions

        This is a bitmask of the available/preferred actions in a
        drag-and-drop operation.

        In the compositor, the selected action is a result of matching the
        actions offered by the source and destination sides.  "action" events
        with a "none" action will be sent to both source and destination if
        there is no match. All further checks will effectively happen on
        (source actions ∩ destination actions).

        In addition, compositors may also pick different actions in
        reaction to key modifiers being pressed. One common design that
        is used in major toolkits (and the behavior recommended for
        compositors) is:

        - If no modifiers are pressed, the first match (in bit order)
          will be used.
        - Pressing Shift selects "move", if enabled in the mask.
        - Pressing Control selects "copy", if enabled in the mask.

        Behavior beyond that is considered implementation-dependent.
        Compositors may for example bind other modifiers (like Alt/Meta)
        or drags initiated with other buttons than BTN_LEFT to specific
        actions (e.g. "ask").
        """

        none: int
        """No action"""

        copy: int
        """Copy action"""

        move: int
        """Move action"""

        ask: int
        """Ask action"""



    def create_data_source(self) -> wl_data_source:
        """
        Create a new data source

        Create a new data source.

        Returns:
            wl_data_source: The created object
        """

        ...

    def get_data_device(self, seat: wl_seat) -> wl_data_device:
        """
        Create a new data device

        Create a new data device for a given seat.

        Args:
            seat: Seat associated with the data device

        Returns:
            wl_data_device: The created object
        """

        ...

class wl_shell:
    """
    Create desktop-style surfaces

    This interface is implemented by servers that provide
    desktop-style user interfaces.

    It allows clients to associate a wl_shell_surface with
    a basic surface.

    Note! This protocol is deprecated and not intended for production use.
    For desktop-style user interfaces, use xdg_shell. Compositors and clients
    should not implement this interface.
    """
    object_id = 0
    version = 1

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""



    def get_shell_surface(self, surface: wl_surface) -> wl_shell_surface:
        """
        Create a shell surface from a surface

        Create a shell surface for an existing surface. This gives
        the wl_surface the role of a shell surface. If the wl_surface
        already has another role, it raises a protocol error.

        Only one shell surface can be associated with a given surface.

        Args:
            surface: Surface to be given the shell surface role

        Returns:
            wl_shell_surface: The created object
        """

        ...

class wl_shell_surface:
    """
    Desktop-style metadata interface

    An interface that may be implemented by a wl_surface, for
    implementations that provide a desktop-style user interface.

    It provides requests to treat surfaces like toplevel, fullscreen
    or popup windows, move, resize or maximize them, associate
    metadata like title and class, etc.

    On the server side the object is automatically destroyed when
    the related wl_surface is destroyed. On the client side,
    wl_shell_surface_destroy() must be called before destroying
    the wl_surface object.
    """
    object_id = 0
    version = 1

    class resize(IntFlag):
        """
        Edge values for resizing

        These values are used to indicate which edge of a surface
        is being dragged in a resize operation. The server may
        use this information to adapt its behavior, e.g. choose
        an appropriate cursor image.
        """

        none: int
        """No edge"""

        top: int
        """Top edge"""

        bottom: int
        """Bottom edge"""

        left: int
        """Left edge"""

        top_left: int
        """Top and left edges"""

        bottom_left: int
        """Bottom and left edges"""

        right: int
        """Right edge"""

        top_right: int
        """Top and right edges"""

        bottom_right: int
        """Bottom and right edges"""



    class transient(IntFlag):
        """
        Details of transient behaviour

        These flags specify details of the expected behaviour
        of transient surfaces. Used in the set_transient request.
        """

        inactive: int
        """Do not set keyboard focus"""



    class fullscreen_method(Enum):
        """
        Different method to set the surface fullscreen

        Hints to indicate to the compositor how to deal with a conflict
        between the dimensions of the surface and the dimensions of the
        output. The compositor is free to ignore this parameter.
        """

        default: int
        """No preference, apply default policy"""

        scale: int
        """Scale, preserve the surface's aspect ratio and center on output"""

        driver: int
        """Switch output mode to the smallest mode that can fit the surface, add black borders to compensate size mismatch"""

        fill: int
        """No upscaling, center on output and add black borders to compensate size mismatch"""



    def pong(self, serial: int) -> None:
        """
        Respond to a ping event

        A client must respond to a ping event with a pong request or
        the client may be deemed unresponsive.

        Args:
            serial: Serial number of the ping event
        """

        ...

    def move(self, seat: wl_seat, serial: int) -> None:
        """
        Start an interactive move

        Start a pointer-driven move of the surface.

        This request must be used in response to a button press event.
        The server may ignore move requests depending on the state of
        the surface (e.g. fullscreen or maximized).

        Args:
            seat: Seat whose pointer is used
            serial: Serial number of the implicit grab on the pointer
        """

        ...

    def resize(self, seat: wl_seat, serial: int, edges: wl_shell_surface.resize) -> None:
        """
        Start an interactive resize

        Start a pointer-driven resizing of the surface.

        This request must be used in response to a button press event.
        The server may ignore resize requests depending on the state of
        the surface (e.g. fullscreen or maximized).

        Args:
            seat: Seat whose pointer is used
            serial: Serial number of the implicit grab on the pointer
            edges: Which edge or corner is being dragged
        """

        ...

    def set_toplevel(self) -> None:
        """
        Make the surface a toplevel surface

        Map the surface as a toplevel surface.

        A toplevel surface is not fullscreen, maximized or transient.
        """

        ...

    def set_transient(self, parent: wl_surface, x: int, y: int, flags: wl_shell_surface.transient) -> None:
        """
        Make the surface a transient surface

        Map the surface relative to an existing surface.

        The x and y arguments specify the location of the upper left
        corner of the surface relative to the upper left corner of the
        parent surface, in surface-local coordinates.

        The flags argument controls details of the transient behaviour.

        Args:
            parent: Parent surface
            x: Surface-local x coordinate
            y: Surface-local y coordinate
            flags: Transient surface behavior
        """

        ...

    def set_fullscreen(self, method: wl_shell_surface.fullscreen_method, framerate: int, output: wl_output) -> None:
        """
        Make the surface a fullscreen surface

        Map the surface as a fullscreen surface.

        If an output parameter is given then the surface will be made
        fullscreen on that output. If the client does not specify the
        output then the compositor will apply its policy - usually
        choosing the output on which the surface has the biggest surface
        area.

        The client may specify a method to resolve a size conflict
        between the output size and the surface size - this is provided
        through the method parameter.

        The framerate parameter is used only when the method is set
        to "driver", to indicate the preferred framerate. A value of 0
        indicates that the client does not care about framerate.  The
        framerate is specified in mHz, that is framerate of 60000 is 60Hz.

        A method of "scale" or "driver" implies a scaling operation of
        the surface, either via a direct scaling operation or a change of
        the output mode. This will override any kind of output scaling, so
        that mapping a surface with a buffer size equal to the mode can
        fill the screen independent of buffer_scale.

        A method of "fill" means we don't scale up the buffer, however
        any output scale is applied. This means that you may run into
        an edge case where the application maps a buffer with the same
        size of the output mode but buffer_scale 1 (thus making a
        surface larger than the output). In this case it is allowed to
        downscale the results to fit the screen.

        The compositor must reply to this request with a configure event
        with the dimensions for the output on which the surface will
        be made fullscreen.

        Args:
            method: Method for resolving size conflict
            framerate: Framerate in mhz
            output: Output on which the surface is to be fullscreen
        """

        ...

    def set_popup(self, seat: wl_seat, serial: int, parent: wl_surface, x: int, y: int, flags: wl_shell_surface.transient) -> None:
        """
        Make the surface a popup surface

        Map the surface as a popup.

        A popup surface is a transient surface with an added pointer
        grab.

        An existing implicit grab will be changed to owner-events mode,
        and the popup grab will continue after the implicit grab ends
        (i.e. releasing the mouse button does not cause the popup to
        be unmapped).

        The popup grab continues until the window is destroyed or a
        mouse button is pressed in any other client's window. A click
        in any of the client's surfaces is reported as normal, however,
        clicks in other clients' surfaces will be discarded and trigger
        the callback.

        The x and y arguments specify the location of the upper left
        corner of the surface relative to the upper left corner of the
        parent surface, in surface-local coordinates.

        Args:
            seat: Seat whose pointer is used
            serial: Serial number of the implicit grab on the pointer
            parent: Parent surface
            x: Surface-local x coordinate
            y: Surface-local y coordinate
            flags: Transient surface behavior
        """

        ...

    def set_maximized(self, output: wl_output) -> None:
        """
        Make the surface a maximized surface

        Map the surface as a maximized surface.

        If an output parameter is given then the surface will be
        maximized on that output. If the client does not specify the
        output then the compositor will apply its policy - usually
        choosing the output on which the surface has the biggest surface
        area.

        The compositor will reply with a configure event telling
        the expected new surface size. The operation is completed
        on the next buffer attach to this surface.

        A maximized surface typically fills the entire output it is
        bound to, except for desktop elements such as panels. This is
        the main difference between a maximized shell surface and a
        fullscreen shell surface.

        The details depend on the compositor implementation.

        Args:
            output: Output on which the surface is to be maximized
        """

        ...

    def set_title(self, title: str) -> None:
        """
        Set surface title

        Set a short title for the surface.

        This string may be used to identify the surface in a task bar,
        window list, or other user interface elements provided by the
        compositor.

        The string must be encoded in UTF-8.

        Args:
            title: Surface title
        """

        ...

    def set_class(self, class_: str) -> None:
        """
        Set surface class

        Set a class for the surface.

        The surface class identifies the general class of applications
        to which the surface belongs. A common convention is to use the
        file name (or the full path if it is a non-standard location) of
        the application's .desktop file as the class.

        Args:
            class_: Surface class
        """

        ...

    def on_ping(self, serial: int) -> None:
        """
        Ping client.

        Override to handle [`wayland.wl_shell_surface.events.ping`][].
        """

        ...

    def on_configure(self, edges: wl_shell_surface.resize, width: int, height: int) -> None:
        """
        Suggest resize.

        Override to handle [`wayland.wl_shell_surface.events.configure`][].
        """

        ...

    def on_popup_done(self) -> None:
        """
        Popup interaction is done.

        Override to handle [`wayland.wl_shell_surface.events.popup_done`][].
        """

        ...

    class events(WaylandEvent):
        def ping(self, serial: int) -> None:
            """
            Ping client

            Ping a client to check if it is receiving events and sending
            requests. A client is expected to reply with a pong request.

            Args:
                serial: Serial number of the ping
            """

            ...

        def configure(self, edges: wl_shell_surface.resize, width: int, height: int) -> None:
            """
            Suggest resize

            The configure event asks the client to resize its surface.

            The size is a hint, in the sense that the client is free to
            ignore it if it doesn't resize, pick a smaller size (to
            satisfy aspect ratio or resize in steps of NxM pixels).

            The edges parameter provides a hint about how the surface
            was resized. The client may use this information to decide
            how to adjust its content to the new size (e.g. a scrolling
            area might adjust its content position to leave the viewable
            content unmoved).

            The client is free to dismiss all but the last configure
            event it received.

            The width and height arguments specify the size of the window
            in surface-local coordinates.

            Args:
                edges: How the surface was resized
                width: New width of the surface
                height: New height of the surface
            """

            ...

        def popup_done(self) -> None:
            """
            Popup interaction is done

            The popup_done event is sent out when a popup grab is broken,
            that is, when the user clicks a surface that doesn't belong
            to the client owning the popup surface.
            """

            ...

class wl_surface:
    """
    An onscreen surface

    A surface is a rectangular area that may be displayed on zero
    or more outputs, and shown any number of times at the compositor's
    discretion. They can present wl_buffers, receive user input, and
    define a local coordinate system.

    The size of a surface (and relative positions on it) is described
    in surface-local coordinates, which may differ from the buffer
    coordinates of the pixel content, in case a buffer_transform
    or a buffer_scale is used.

    A surface without a "role" is fairly useless: a compositor does
    not know where, when or how to present it. The role is the
    purpose of a wl_surface. Examples of roles are a cursor for a
    pointer (as set by wl_pointer.set_cursor), a drag icon
    (wl_data_device.start_drag), a sub-surface
    (wl_subcompositor.get_subsurface), and a window as defined by a
    shell protocol (e.g. wl_shell.get_shell_surface).

    A surface can have only one role at a time. Initially a
    wl_surface does not have a role. Once a wl_surface is given a
    role, it is set permanently for the whole lifetime of the
    wl_surface object. Giving the current role again is allowed,
    unless explicitly forbidden by the relevant interface
    specification.

    Surface roles are given by requests in other interfaces such as
    wl_pointer.set_cursor. The request should explicitly mention
    that this request gives a role to a wl_surface. Often, this
    request also creates a new protocol object that represents the
    role and adds additional functionality to wl_surface. When a
    client wants to destroy a wl_surface, they must destroy this role
    object before the wl_surface, otherwise a defunct_role_object error is
    sent.

    Destroying the role object does not remove the role from the
    wl_surface, but it may stop the wl_surface from "playing the role".
    For instance, if a wl_subsurface object is destroyed, the wl_surface
    it was created for will be unmapped and forget its position and
    z-order. It is allowed to create a wl_subsurface for the same
    wl_surface again, but it is not allowed to use the wl_surface as
    a cursor (cursor is a different role than sub-surface, and role
    switching is not allowed).
    """
    object_id = 0
    version = 6

    class error(Enum):
        """
        `wl_surface` error values

        These errors can be emitted in response to wl_surface requests.
        """

        invalid_scale: int
        """Buffer scale value is invalid"""

        invalid_transform: int
        """Buffer transform value is invalid"""

        invalid_size: int
        """Buffer size is invalid"""

        invalid_offset: int
        """Buffer offset is invalid"""

        defunct_role_object: int
        """Surface was destroyed before its role object"""



    def destroy(self) -> None:
        """
        Delete surface

        Deletes the surface and invalidates its object ID.
        """

        ...

    def attach(self, buffer: wl_buffer, x: int, y: int) -> None:
        """
        Set the surface contents

        Set a buffer as the content of this surface.

        The new size of the surface is calculated based on the buffer
        size transformed by the inverse buffer_transform and the
        inverse buffer_scale. This means that at commit time the supplied
        buffer size must be an integer multiple of the buffer_scale. If
        that's not the case, an invalid_size error is sent.

        The x and y arguments specify the location of the new pending
        buffer's upper left corner, relative to the current buffer's upper
        left corner, in surface-local coordinates. In other words, the
        x and y, combined with the new surface size define in which
        directions the surface's size changes. Setting anything other than 0
        as x and y arguments is discouraged, and should instead be replaced
        with using the separate wl_surface.offset request.

        When the bound wl_surface version is 5 or higher, passing any
        non-zero x or y is a protocol violation, and will result in an
        'invalid_offset' error being raised. The x and y arguments are ignored
        and do not change the pending state. To achieve equivalent semantics,
        use wl_surface.offset.

        Surface contents are double-buffered state, see wl_surface.commit.

        The initial surface contents are void; there is no content.
        wl_surface.attach assigns the given wl_buffer as the pending
        wl_buffer. wl_surface.commit makes the pending wl_buffer the new
        surface contents, and the size of the surface becomes the size
        calculated from the wl_buffer, as described above. After commit,
        there is no pending buffer until the next attach.

        Committing a pending wl_buffer allows the compositor to read the
        pixels in the wl_buffer. The compositor may access the pixels at
        any time after the wl_surface.commit request. When the compositor
        will not access the pixels anymore, it will send the
        wl_buffer.release event. Only after receiving wl_buffer.release,
        the client may reuse the wl_buffer. A wl_buffer that has been
        attached and then replaced by another attach instead of committed
        will not receive a release event, and is not used by the
        compositor.

        If a pending wl_buffer has been committed to more than one wl_surface,
        the delivery of wl_buffer.release events becomes undefined. A well
        behaved client should not rely on wl_buffer.release events in this
        case. Alternatively, a client could create multiple wl_buffer objects
        from the same backing storage or use a protocol extension providing
        per-commit release notifications.

        Destroying the wl_buffer after wl_buffer.release does not change
        the surface contents. Destroying the wl_buffer before wl_buffer.release
        is allowed as long as the underlying buffer storage isn't re-used (this
        can happen e.g. on client process termination). However, if the client
        destroys the wl_buffer before receiving the wl_buffer.release event and
        mutates the underlying buffer storage, the surface contents become
        undefined immediately.

        If wl_surface.attach is sent with a NULL wl_buffer, the
        following wl_surface.commit will remove the surface content.

        If a pending wl_buffer has been destroyed, the result is not specified.
        Many compositors are known to remove the surface content on the following
        wl_surface.commit, but this behaviour is not universal. Clients seeking to
        maximise compatibility should not destroy pending buffers and should
        ensure that they explicitly remove content from surfaces, even after
        destroying buffers.

        Args:
            buffer: Buffer of surface contents
            x: Surface-local x coordinate
            y: Surface-local y coordinate
        """

        ...

    def damage(self, x: int, y: int, width: int, height: int) -> None:
        """
        Mark part of the surface damaged

        This request is used to describe the regions where the pending
        buffer is different from the current surface contents, and where
        the surface therefore needs to be repainted. The compositor
        ignores the parts of the damage that fall outside of the surface.

        Damage is double-buffered state, see wl_surface.commit.

        The damage rectangle is specified in surface-local coordinates,
        where x and y specify the upper left corner of the damage rectangle.

        The initial value for pending damage is empty: no damage.
        wl_surface.damage adds pending damage: the new pending damage
        is the union of old pending damage and the given rectangle.

        wl_surface.commit assigns pending damage as the current damage,
        and clears pending damage. The server will clear the current
        damage as it repaints the surface.

        Note! New clients should not use this request. Instead damage can be
        posted with wl_surface.damage_buffer which uses buffer coordinates
        instead of surface coordinates.

        Args:
            x: Surface-local x coordinate
            y: Surface-local y coordinate
            width: Width of damage rectangle
            height: Height of damage rectangle
        """

        ...

    def frame(self) -> wl_callback:
        """
        Request a frame throttling hint

        Request a notification when it is a good time to start drawing a new
        frame, by creating a frame callback. This is useful for throttling
        redrawing operations, and driving animations.

        When a client is animating on a wl_surface, it can use the 'frame'
        request to get notified when it is a good time to draw and commit the
        next frame of animation. If the client commits an update earlier than
        that, it is likely that some updates will not make it to the display,
        and the client is wasting resources by drawing too often.

        The frame request will take effect on the next wl_surface.commit.
        The notification will only be posted for one frame unless
        requested again. For a wl_surface, the notifications are posted in
        the order the frame requests were committed.

        The server must send the notifications so that a client
        will not send excessive updates, while still allowing
        the highest possible update rate for clients that wait for the reply
        before drawing again. The server should give some time for the client
        to draw and commit after sending the frame callback events to let it
        hit the next output refresh.

        A server should avoid signaling the frame callbacks if the
        surface is not visible in any way, e.g. the surface is off-screen,
        or completely obscured by other opaque surfaces.

        The object returned by this request will be destroyed by the
        compositor after the callback is fired and as such the client must not
        attempt to use it after that point.

        The callback_data passed in the callback is the current time, in
        milliseconds, with an undefined base.

        Returns:
            wl_callback: The created object
        """

        ...

    def set_opaque_region(self, region: wl_region) -> None:
        """
        Set opaque region

        This request sets the region of the surface that contains
        opaque content.

        The opaque region is an optimization hint for the compositor
        that lets it optimize the redrawing of content behind opaque
        regions.  Setting an opaque region is not required for correct
        behaviour, but marking transparent content as opaque will result
        in repaint artifacts.

        The opaque region is specified in surface-local coordinates.

        The compositor ignores the parts of the opaque region that fall
        outside of the surface.

        Opaque region is double-buffered state, see wl_surface.commit.

        wl_surface.set_opaque_region changes the pending opaque region.
        wl_surface.commit copies the pending region to the current region.
        Otherwise, the pending and current regions are never changed.

        The initial value for an opaque region is empty. Setting the pending
        opaque region has copy semantics, and the wl_region object can be
        destroyed immediately. A NULL wl_region causes the pending opaque
        region to be set to empty.

        Args:
            region: Opaque region of the surface
        """

        ...

    def set_input_region(self, region: wl_region) -> None:
        """
        Set input region

        This request sets the region of the surface that can receive
        pointer and touch events.

        Input events happening outside of this region will try the next
        surface in the server surface stack. The compositor ignores the
        parts of the input region that fall outside of the surface.

        The input region is specified in surface-local coordinates.

        Input region is double-buffered state, see wl_surface.commit.

        wl_surface.set_input_region changes the pending input region.
        wl_surface.commit copies the pending region to the current region.
        Otherwise the pending and current regions are never changed,
        except cursor and icon surfaces are special cases, see
        wl_pointer.set_cursor and wl_data_device.start_drag.

        The initial value for an input region is infinite. That means the
        whole surface will accept input. Setting the pending input region
        has copy semantics, and the wl_region object can be destroyed
        immediately. A NULL wl_region causes the input region to be set
        to infinite.

        Args:
            region: Input region of the surface
        """

        ...

    def commit(self) -> None:
        """
        Commit pending surface state

        Surface state (input, opaque, and damage regions, attached buffers,
        etc.) is double-buffered. Protocol requests modify the pending state,
        as opposed to the active state in use by the compositor.

        A commit request atomically creates a content update from the pending
        state, even if the pending state has not been touched. The content
        update is placed in a queue until it becomes active. After commit, the
        new pending state is as documented for each related request.

        When the content update is applied, the wl_buffer is applied before all
        other state. This means that all coordinates in double-buffered state
        are relative to the newly attached wl_buffers, except for
        wl_surface.attach itself. If there is no newly attached wl_buffer, the
        coordinates are relative to the previous content update.

        All requests that need a commit to become effective are documented
        to affect double-buffered state.

        Other interfaces may add further double-buffered surface state.
        """

        ...

    def set_buffer_transform(self, transform: wl_output.transform) -> None:
        """
        Sets the buffer transformation

        This request sets the transformation that the client has already applied
        to the content of the buffer. The accepted values for the transform
        parameter are the values for wl_output.transform.

        The compositor applies the inverse of this transformation whenever it
        uses the buffer contents.

        Buffer transform is double-buffered state, see wl_surface.commit.

        A newly created surface has its buffer transformation set to normal.

        wl_surface.set_buffer_transform changes the pending buffer
        transformation. wl_surface.commit copies the pending buffer
        transformation to the current one. Otherwise, the pending and current
        values are never changed.

        The purpose of this request is to allow clients to render content
        according to the output transform, thus permitting the compositor to
        use certain optimizations even if the display is rotated. Using
        hardware overlays and scanning out a client buffer for fullscreen
        surfaces are examples of such optimizations. Those optimizations are
        highly dependent on the compositor implementation, so the use of this
        request should be considered on a case-by-case basis.

        Note that if the transform value includes 90 or 270 degree rotation,
        the width of the buffer will become the surface height and the height
        of the buffer will become the surface width.

        If transform is not one of the values from the
        wl_output.transform enum the invalid_transform protocol error
        is raised.

        Args:
            transform: Transform for interpreting buffer contents
        """

        ...

    def set_buffer_scale(self, scale: int) -> None:
        """
        Sets the buffer scaling factor

        This request sets an optional scaling factor on how the compositor
        interprets the contents of the buffer attached to the window.

        Buffer scale is double-buffered state, see wl_surface.commit.

        A newly created surface has its buffer scale set to 1.

        wl_surface.set_buffer_scale changes the pending buffer scale.
        wl_surface.commit copies the pending buffer scale to the current one.
        Otherwise, the pending and current values are never changed.

        The purpose of this request is to allow clients to supply higher
        resolution buffer data for use on high resolution outputs. It is
        intended that you pick the same buffer scale as the scale of the
        output that the surface is displayed on. This means the compositor
        can avoid scaling when rendering the surface on that output.

        Note that if the scale is larger than 1, then you have to attach
        a buffer that is larger (by a factor of scale in each dimension)
        than the desired surface size.

        If scale is not greater than 0 the invalid_scale protocol error is
        raised.

        Args:
            scale: Scale for interpreting buffer contents
        """

        ...

    def damage_buffer(self, x: int, y: int, width: int, height: int) -> None:
        """
        Mark part of the surface damaged using buffer coordinates

        This request is used to describe the regions where the pending
        buffer is different from the current surface contents, and where
        the surface therefore needs to be repainted. The compositor
        ignores the parts of the damage that fall outside of the surface.

        Damage is double-buffered state, see wl_surface.commit.

        The damage rectangle is specified in buffer coordinates,
        where x and y specify the upper left corner of the damage rectangle.

        The initial value for pending damage is empty: no damage.
        wl_surface.damage_buffer adds pending damage: the new pending
        damage is the union of old pending damage and the given rectangle.

        wl_surface.commit assigns pending damage as the current damage,
        and clears pending damage. The server will clear the current
        damage as it repaints the surface.

        This request differs from wl_surface.damage in only one way - it
        takes damage in buffer coordinates instead of surface-local
        coordinates. While this generally is more intuitive than surface
        coordinates, it is especially desirable when using wp_viewport
        or when a drawing library (like EGL) is unaware of buffer scale
        and buffer transform.

        Note: Because buffer transformation changes and damage requests may
        be interleaved in the protocol stream, it is impossible to determine
        the actual mapping between surface and buffer damage until
        wl_surface.commit time. Therefore, compositors wishing to take both
        kinds of damage into account will have to accumulate damage from the
        two requests separately and only transform from one to the other
        after receiving the wl_surface.commit.

        Args:
            x: Buffer-local x coordinate
            y: Buffer-local y coordinate
            width: Width of damage rectangle
            height: Height of damage rectangle
        """

        ...

    def offset(self, x: int, y: int) -> None:
        """
        Set the surface contents offset

        The x and y arguments specify the location of the new pending
        buffer's upper left corner, relative to the current buffer's upper
        left corner, in surface-local coordinates. In other words, the
        x and y, combined with the new surface size define in which
        directions the surface's size changes.

        The exact semantics of wl_surface.offset are role-specific. Refer to
        the documentation of specific roles for more information.

        Surface location offset is double-buffered state, see
        wl_surface.commit.

        This request is semantically equivalent to and the replaces the x and y
        arguments in the wl_surface.attach request in wl_surface versions prior
        to 5. See wl_surface.attach for details.

        Args:
            x: Surface-local x coordinate
            y: Surface-local y coordinate
        """

        ...

    def on_enter(self, output: wl_output) -> None:
        """
        Surface enters an output.

        Override to handle [`wayland.wl_surface.events.enter`][].
        """

        ...

    def on_leave(self, output: wl_output) -> None:
        """
        Surface leaves an output.

        Override to handle [`wayland.wl_surface.events.leave`][].
        """

        ...

    def on_preferred_buffer_scale(self, factor: int) -> None:
        """
        Preferred buffer scale for the surface.

        Override to handle [`wayland.wl_surface.events.preferred_buffer_scale`][].
        """

        ...

    def on_preferred_buffer_transform(self, transform: wl_output.transform) -> None:
        """
        Preferred buffer transform for the surface.

        Override to handle [`wayland.wl_surface.events.preferred_buffer_transform`][].
        """

        ...

    class events(WaylandEvent):
        def enter(self, output: wl_output) -> None:
            """
            Surface enters an output

            This is emitted whenever a surface's creation, movement, or resizing
            results in some part of it being within the scanout region of an
            output.

            Note that a surface may be overlapping with zero or more outputs.

            Args:
                output: Output entered by the surface
            """

            ...

        def leave(self, output: wl_output) -> None:
            """
            Surface leaves an output

            This is emitted whenever a surface's creation, movement, or resizing
            results in it no longer having any part of it within the scanout region
            of an output.

            Clients should not use the number of outputs the surface is on for frame
            throttling purposes. The surface might be hidden even if no leave event
            has been sent, and the compositor might expect new surface content
            updates even if no enter event has been sent. The frame event should be
            used instead.

            Args:
                output: Output left by the surface
            """

            ...

        def preferred_buffer_scale(self, factor: int) -> None:
            """
            Preferred buffer scale for the surface

            This event indicates the preferred buffer scale for this surface. It is
            sent whenever the compositor's preference changes.

            Before receiving this event the preferred buffer scale for this surface
            is 1.

            It is intended that scaling aware clients use this event to scale their
            content and use wl_surface.set_buffer_scale to indicate the scale they
            have rendered with. This allows clients to supply a higher detail
            buffer.

            The compositor shall emit a scale value greater than 0.

            Args:
                factor: Preferred scaling factor
            """

            ...

        def preferred_buffer_transform(self, transform: wl_output.transform) -> None:
            """
            Preferred buffer transform for the surface

            This event indicates the preferred buffer transform for this surface.
            It is sent whenever the compositor's preference changes.

            Before receiving this event the preferred buffer transform for this
            surface is normal.

            Applying this transformation to the surface buffer contents and using
            wl_surface.set_buffer_transform might allow the compositor to use the
            surface buffer more efficiently.

            Args:
                transform: Preferred transform
            """

            ...

class wl_seat:
    """
    Group of input devices

    A seat is a group of keyboards, pointer and touch devices. This
    object is published as a global during start up, or when such a
    device is hot plugged.  A seat typically has a pointer and
    maintains a keyboard focus and a pointer focus.
    """
    object_id = 0
    version = 10

    class capability(IntFlag):
        """
        Seat capability bitmask

        This is a bitmask of capabilities this seat has; if a member is
        set, then it is present on the seat.
        """

        pointer: int
        """The seat has pointer devices"""

        keyboard: int
        """The seat has one or more keyboards"""

        touch: int
        """The seat has touch devices"""



    class error(Enum):
        """
        `wl_seat` error values

        These errors can be emitted in response to wl_seat requests.
        """

        missing_capability: int
        """`get_pointer`, `get_keyboard` or `get_touch` called on seat without the matching capability"""



    def get_pointer(self) -> wl_pointer:
        """
        Return pointer object

        The ID provided will be initialized to the wl_pointer interface
        for this seat.

        This request only takes effect if the seat has the pointer
        capability, or has had the pointer capability in the past.
        It is a protocol violation to issue this request on a seat that has
        never had the pointer capability. The missing_capability error will
        be sent in this case.

        Returns:
            wl_pointer: The created object
        """

        ...

    def get_keyboard(self) -> wl_keyboard:
        """
        Return keyboard object

        The ID provided will be initialized to the wl_keyboard interface
        for this seat.

        This request only takes effect if the seat has the keyboard
        capability, or has had the keyboard capability in the past.
        It is a protocol violation to issue this request on a seat that has
        never had the keyboard capability. The missing_capability error will
        be sent in this case.

        Returns:
            wl_keyboard: The created object
        """

        ...

    def get_touch(self) -> wl_touch:
        """
        Return touch object

        The ID provided will be initialized to the wl_touch interface
        for this seat.

        This request only takes effect if the seat has the touch
        capability, or has had the touch capability in the past.
        It is a protocol violation to issue this request on a seat that has
        never had the touch capability. The missing_capability error will
        be sent in this case.

        Returns:
            wl_touch: The created object
        """

        ...

    def release(self) -> None:
        """
        Release the seat object

        Using this request a client can tell the server that it is not going to
        use the seat object anymore.
        """

        ...

    def on_capabilities(self, capabilities: wl_seat.capability) -> None:
        """
        Seat capabilities changed.

        Override to handle [`wayland.wl_seat.events.capabilities`][].
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Unique identifier for this seat.

        Override to handle [`wayland.wl_seat.events.name`][].
        """

        ...

    class events(WaylandEvent):
        def capabilities(self, capabilities: wl_seat.capability) -> None:
            """
            Seat capabilities changed

            This is sent on binding to the seat global or whenever a seat gains
            or loses the pointer, keyboard or touch capabilities.
            The argument is a capability enum containing the complete set of
            capabilities this seat has.

            When the pointer capability is added, a client may create a
            wl_pointer object using the wl_seat.get_pointer request. This object
            will receive pointer events until the capability is removed in the
            future.

            When the pointer capability is removed, a client should destroy the
            wl_pointer objects associated with the seat where the capability was
            removed, using the wl_pointer.release request. No further pointer
            events will be received on these objects.

            In some compositors, if a seat regains the pointer capability and a
            client has a previously obtained wl_pointer object of version 4 or
            less, that object may start sending pointer events again. This
            behavior is considered a misinterpretation of the intended behavior
            and must not be relied upon by the client. wl_pointer objects of
            version 5 or later must not send events if created before the most
            recent event notifying the client of an added pointer capability.

            The above behavior also applies to wl_keyboard and wl_touch with the
            keyboard and touch capabilities, respectively.

            Args:
                capabilities: Capabilities of the seat
            """

            ...

        def name(self, name: str) -> None:
            """
            Unique identifier for this seat

            In a multi-seat configuration the seat name can be used by clients to
            help identify which physical devices the seat represents.

            The seat name is a UTF-8 string with no convention defined for its
            contents. Each name is unique among all wl_seat globals. The name is
            only guaranteed to be unique for the current compositor instance.

            The same seat names are used for all clients. Thus, the name can be
            shared across processes to refer to a specific wl_seat global.

            The name event is sent after binding to the seat global, and should be sent
            before announcing capabilities. This event only sent once per seat object,
            and the name does not change over the lifetime of the wl_seat global.

            Compositors may re-use the same seat name if the wl_seat global is
            destroyed and re-created later.

            Args:
                name: Seat identifier
            """

            ...

class wl_pointer:
    """
    Pointer input device

    The wl_pointer interface represents one or more input devices,
    such as mice, which control the pointer location and pointer_focus
    of a seat.

    The wl_pointer interface generates motion, enter and leave
    events for the surfaces that the pointer is located over,
    and button and axis events for button presses, button releases
    and scrolling.
    """
    object_id = 0
    version = 10

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""



    class button_state(Enum):
        """
        Physical button state

        Describes the physical state of a button that produced the button
        event.
        """

        released: int
        """The button is not pressed"""

        pressed: int
        """The button is pressed"""



    class axis(Enum):
        """
        Axis types

        Describes the axis types of scroll events.
        """

        vertical_scroll: int
        """Vertical axis"""

        horizontal_scroll: int
        """Horizontal axis"""



    class axis_source(Enum):
        """
        Axis source types

        Describes the source types for axis events. This indicates to the
        client how an axis event was physically generated; a client may
        adjust the user interface accordingly. For example, scroll events
        from a "finger" source may be in a smooth coordinate space with
        kinetic scrolling whereas a "wheel" source may be in discrete steps
        of a number of lines.

        The "continuous" axis source is a device generating events in a
        continuous coordinate space, but using something other than a
        finger. One example for this source is button-based scrolling where
        the vertical motion of a device is converted to scroll events while
        a button is held down.

        The "wheel tilt" axis source indicates that the actual device is a
        wheel but the scroll event is not caused by a rotation but a
        (usually sideways) tilt of the wheel.
        """

        wheel: int
        """A physical wheel rotation"""

        finger: int
        """Finger on a touch surface"""

        continuous: int
        """Continuous coordinate space"""

        wheel_tilt: int
        """A physical wheel tilt"""



    class axis_relative_direction(Enum):
        """
        Axis relative direction

        This specifies the direction of the physical motion that caused a
        wl_pointer.axis event, relative to the wl_pointer.axis direction.
        """

        identical: int
        """Physical motion matches axis direction"""

        inverted: int
        """Physical motion is the inverse of the axis direction"""



    def set_cursor(self, serial: int, surface: wl_surface, hotspot_x: int, hotspot_y: int) -> None:
        """
        Set the pointer surface

        Set the pointer surface, i.e., the surface that contains the
        pointer image (cursor). This request gives the surface the role
        of a cursor. If the surface already has another role, it raises
        a protocol error.

        The cursor actually changes only if the pointer
        focus for this device is one of the requesting client's surfaces
        or the surface parameter is the current pointer surface. If
        there was a previous surface set with this request it is
        replaced. If surface is NULL, the pointer image is hidden.

        The parameters hotspot_x and hotspot_y define the position of
        the pointer surface relative to the pointer location. Its
        top-left corner is always at (x, y) - (hotspot_x, hotspot_y),
        where (x, y) are the coordinates of the pointer location, in
        surface-local coordinates.

        On wl_surface.offset requests to the pointer surface, hotspot_x
        and hotspot_y are decremented by the x and y parameters
        passed to the request. The offset must be applied by
        wl_surface.commit as usual.

        The hotspot can also be updated by passing the currently set
        pointer surface to this request with new values for hotspot_x
        and hotspot_y.

        The input region is ignored for wl_surfaces with the role of
        a cursor. When the use as a cursor ends, the wl_surface is
        unmapped.

        The serial parameter must match the latest wl_pointer.enter
        serial number sent to the client. Otherwise the request will be
        ignored.

        Args:
            serial: Serial number of the enter event
            surface: Pointer surface
            hotspot_x: Surface-local x coordinate
            hotspot_y: Surface-local y coordinate
        """

        ...

    def release(self) -> None:
        """
        Release the pointer object

        Using this request a client can tell the server that it is not going to
        use the pointer object anymore.

        This request destroys the pointer proxy object, so clients must not call
        wl_pointer_destroy() after using this request.
        """

        ...

    def on_enter(self, serial: int, surface: wl_surface, surface_x: float, surface_y: float) -> None:
        """
        Enter event.

        Override to handle [`wayland.wl_pointer.events.enter`][].
        """

        ...

    def on_leave(self, serial: int, surface: wl_surface) -> None:
        """
        Leave event.

        Override to handle [`wayland.wl_pointer.events.leave`][].
        """

        ...

    def on_motion(self, time: int, surface_x: float, surface_y: float) -> None:
        """
        Pointer motion event.

        Override to handle [`wayland.wl_pointer.events.motion`][].
        """

        ...

    def on_button(self, serial: int, time: int, button: int, state: wl_pointer.button_state) -> None:
        """
        Pointer button event.

        Override to handle [`wayland.wl_pointer.events.button`][].
        """

        ...

    def on_axis(self, time: int, axis: wl_pointer.axis, value: float) -> None:
        """
        Axis event.

        Override to handle [`wayland.wl_pointer.events.axis`][].
        """

        ...

    def on_frame(self) -> None:
        """
        End of a pointer event sequence.

        Override to handle [`wayland.wl_pointer.events.frame`][].
        """

        ...

    def on_axis_source(self, axis_source: wl_pointer.axis_source) -> None:
        """
        Axis source event.

        Override to handle [`wayland.wl_pointer.events.axis_source`][].
        """

        ...

    def on_axis_stop(self, time: int, axis: wl_pointer.axis) -> None:
        """
        Axis stop event.

        Override to handle [`wayland.wl_pointer.events.axis_stop`][].
        """

        ...

    def on_axis_discrete(self, axis: wl_pointer.axis, discrete: int) -> None:
        """
        Axis click event.

        Override to handle [`wayland.wl_pointer.events.axis_discrete`][].
        """

        ...

    def on_axis_value120(self, axis: wl_pointer.axis, value120: int) -> None:
        """
        Axis high-resolution scroll event.

        Override to handle [`wayland.wl_pointer.events.axis_value120`][].
        """

        ...

    def on_axis_relative_direction(self, axis: wl_pointer.axis, direction: wl_pointer.axis_relative_direction) -> None:
        """
        Axis relative physical direction event.

        Override to handle [`wayland.wl_pointer.events.axis_relative_direction`][].
        """

        ...

    class events(WaylandEvent):
        def enter(self, serial: int, surface: wl_surface, surface_x: float, surface_y: float) -> None:
            """
            Enter event

            Notification that this seat's pointer is focused on a certain
            surface.

            When a seat's focus enters a surface, the pointer image
            is undefined and a client should respond to this event by setting
            an appropriate pointer image with the set_cursor request.

            Args:
                serial: Serial number of the enter event
                surface: Surface entered by the pointer
                surface_x: Surface-local x coordinate
                surface_y: Surface-local y coordinate
            """

            ...

        def leave(self, serial: int, surface: wl_surface) -> None:
            """
            Leave event

            Notification that this seat's pointer is no longer focused on
            a certain surface.

            The leave notification is sent before the enter notification
            for the new focus.

            Args:
                serial: Serial number of the leave event
                surface: Surface left by the pointer
            """

            ...

        def motion(self, time: int, surface_x: float, surface_y: float) -> None:
            """
            Pointer motion event

            Notification of pointer location change. The arguments
            surface_x and surface_y are the location relative to the
            focused surface.

            Args:
                time: Timestamp with millisecond granularity
                surface_x: Surface-local x coordinate
                surface_y: Surface-local y coordinate
            """

            ...

        def button(self, serial: int, time: int, button: int, state: wl_pointer.button_state) -> None:
            """
            Pointer button event

            Mouse button click and release notifications.

            The location of the click is given by the last motion or
            enter event.
            The time argument is a timestamp with millisecond
            granularity, with an undefined base.

            The button is a button code as defined in the Linux kernel's
            linux/input-event-codes.h header file, e.g. BTN_LEFT.

            Any 16-bit button code value is reserved for future additions to the
            kernel's event code list. All other button codes above 0xFFFF are
            currently undefined but may be used in future versions of this
            protocol.

            Args:
                serial: Serial number of the button event
                time: Timestamp with millisecond granularity
                button: Button that produced the event
                state: Physical state of the button
            """

            ...

        def axis(self, time: int, axis: wl_pointer.axis, value: float) -> None:
            """
            Axis event

            Scroll and other axis notifications.

            For scroll events (vertical and horizontal scroll axes), the
            value parameter is the length of a vector along the specified
            axis in a coordinate space identical to those of motion events,
            representing a relative movement along the specified axis.

            For devices that support movements non-parallel to axes multiple
            axis events will be emitted.

            When applicable, for example for touch pads, the server can
            choose to emit scroll events where the motion vector is
            equivalent to a motion event vector.

            When applicable, a client can transform its content relative to the
            scroll distance.

            Args:
                time: Timestamp with millisecond granularity
                axis: Axis type
                value: Length of vector in surface-local coordinate space
            """

            ...

        def frame(self) -> None:
            """
            End of a pointer event sequence

            Indicates the end of a set of events that logically belong together.
            A client is expected to accumulate the data in all events within the
            frame before proceeding.

            All wl_pointer events before a wl_pointer.frame event belong
            logically together. For example, in a diagonal scroll motion the
            compositor will send an optional wl_pointer.axis_source event, two
            wl_pointer.axis events (horizontal and vertical) and finally a
            wl_pointer.frame event. The client may use this information to
            calculate a diagonal vector for scrolling.

            When multiple wl_pointer.axis events occur within the same frame,
            the motion vector is the combined motion of all events.
            When a wl_pointer.axis and a wl_pointer.axis_stop event occur within
            the same frame, this indicates that axis movement in one axis has
            stopped but continues in the other axis.
            When multiple wl_pointer.axis_stop events occur within the same
            frame, this indicates that these axes stopped in the same instance.

            A wl_pointer.frame event is sent for every logical event group,
            even if the group only contains a single wl_pointer event.
            Specifically, a client may get a sequence: motion, frame, button,
            frame, axis, frame, axis_stop, frame.

            The wl_pointer.enter and wl_pointer.leave events are logical events
            generated by the compositor and not the hardware. These events are
            also grouped by a wl_pointer.frame. When a pointer moves from one
            surface to another, a compositor should group the
            wl_pointer.leave event within the same wl_pointer.frame.
            However, a client must not rely on wl_pointer.leave and
            wl_pointer.enter being in the same wl_pointer.frame.
            Compositor-specific policies may require the wl_pointer.leave and
            wl_pointer.enter event being split across multiple wl_pointer.frame
            groups.
            """

            ...

        def axis_source(self, axis_source: wl_pointer.axis_source) -> None:
            """
            Axis source event

            Source information for scroll and other axes.

            This event does not occur on its own. It is sent before a
            wl_pointer.frame event and carries the source information for
            all events within that frame.

            The source specifies how this event was generated. If the source is
            wl_pointer.axis_source.finger, a wl_pointer.axis_stop event will be
            sent when the user lifts the finger off the device.

            If the source is wl_pointer.axis_source.wheel,
            wl_pointer.axis_source.wheel_tilt or
            wl_pointer.axis_source.continuous, a wl_pointer.axis_stop event may
            or may not be sent. Whether a compositor sends an axis_stop event
            for these sources is hardware-specific and implementation-dependent;
            clients must not rely on receiving an axis_stop event for these
            scroll sources and should treat scroll sequences from these scroll
            sources as unterminated by default.

            This event is optional. If the source is unknown for a particular
            axis event sequence, no event is sent.
            Only one wl_pointer.axis_source event is permitted per frame.

            The order of wl_pointer.axis_discrete and wl_pointer.axis_source is
            not guaranteed.

            Args:
                axis_source: Source of the axis event
            """

            ...

        def axis_stop(self, time: int, axis: wl_pointer.axis) -> None:
            """
            Axis stop event

            Stop notification for scroll and other axes.

            For some wl_pointer.axis_source types, a wl_pointer.axis_stop event
            is sent to notify a client that the axis sequence has terminated.
            This enables the client to implement kinetic scrolling.
            See the wl_pointer.axis_source documentation for information on when
            this event may be generated.

            Any wl_pointer.axis events with the same axis_source after this
            event should be considered as the start of a new axis motion.

            The timestamp is to be interpreted identical to the timestamp in the
            wl_pointer.axis event. The timestamp value may be the same as a
            preceding wl_pointer.axis event.

            Args:
                time: Timestamp with millisecond granularity
                axis: The axis stopped with this event
            """

            ...

        def axis_discrete(self, axis: wl_pointer.axis, discrete: int) -> None:
            """
            Axis click event

            Discrete step information for scroll and other axes.

            This event carries the axis value of the wl_pointer.axis event in
            discrete steps (e.g. mouse wheel clicks).

            This event is deprecated with wl_pointer version 8 - this event is not
            sent to clients supporting version 8 or later.

            This event does not occur on its own, it is coupled with a
            wl_pointer.axis event that represents this axis value on a
            continuous scale. The protocol guarantees that each axis_discrete
            event is always followed by exactly one axis event with the same
            axis number within the same wl_pointer.frame. Note that the protocol
            allows for other events to occur between the axis_discrete and
            its coupled axis event, including other axis_discrete or axis
            events. A wl_pointer.frame must not contain more than one axis_discrete
            event per axis type.

            This event is optional; continuous scrolling devices
            like two-finger scrolling on touchpads do not have discrete
            steps and do not generate this event.

            The discrete value carries the directional information. e.g. a value
            of -2 is two steps towards the negative direction of this axis.

            The axis number is identical to the axis number in the associated
            axis event.

            The order of wl_pointer.axis_discrete and wl_pointer.axis_source is
            not guaranteed.

            Args:
                axis: Axis type
                discrete: Number of steps
            """

            ...

        def axis_value120(self, axis: wl_pointer.axis, value120: int) -> None:
            """
            Axis high-resolution scroll event

            Discrete high-resolution scroll information.

            This event carries high-resolution wheel scroll information,
            with each multiple of 120 representing one logical scroll step
            (a wheel detent). For example, an axis_value120 of 30 is one quarter of
            a logical scroll step in the positive direction, a value120 of
            -240 are two logical scroll steps in the negative direction within the
            same hardware event.
            Clients that rely on discrete scrolling should accumulate the
            value120 to multiples of 120 before processing the event.

            The value120 must not be zero.

            This event replaces the wl_pointer.axis_discrete event in clients
            supporting wl_pointer version 8 or later.

            Where a wl_pointer.axis_source event occurs in the same
            wl_pointer.frame, the axis source applies to this event.

            The order of wl_pointer.axis_value120 and wl_pointer.axis_source is
            not guaranteed.

            Args:
                axis: Axis type
                value120: Scroll distance as fraction of 120
            """

            ...

        def axis_relative_direction(self, axis: wl_pointer.axis, direction: wl_pointer.axis_relative_direction) -> None:
            """
            Axis relative physical direction event

            Relative directional information of the entity causing the axis
            motion.

            For a wl_pointer.axis event, the wl_pointer.axis_relative_direction
            event specifies the movement direction of the entity causing the
            wl_pointer.axis event. For example:
            - if a user's fingers on a touchpad move down and this
              causes a wl_pointer.axis vertical_scroll down event, the physical
              direction is 'identical'
            - if a user's fingers on a touchpad move down and this causes a
              wl_pointer.axis vertical_scroll up scroll up event ('natural
              scrolling'), the physical direction is 'inverted'.

            A client may use this information to adjust scroll motion of
            components. Specifically, enabling natural scrolling causes the
            content to change direction compared to traditional scrolling.
            Some widgets like volume control sliders should usually match the
            physical direction regardless of whether natural scrolling is
            active. This event enables clients to match the scroll direction of
            a widget to the physical direction.

            This event does not occur on its own, it is coupled with a
            wl_pointer.axis event that represents this axis value.
            The protocol guarantees that each axis_relative_direction event is
            always followed by exactly one axis event with the same
            axis number within the same wl_pointer.frame. Note that the protocol
            allows for other events to occur between the axis_relative_direction
            and its coupled axis event.

            The axis number is identical to the axis number in the associated
            axis event.

            The order of wl_pointer.axis_relative_direction,
            wl_pointer.axis_discrete and wl_pointer.axis_source is not
            guaranteed.

            Args:
                axis: Axis type
                direction: Physical direction relative to axis motion
            """

            ...

class wl_keyboard:
    """
    Keyboard input device

    The wl_keyboard interface represents one or more keyboards
    associated with a seat.

    Each wl_keyboard has the following logical state:

    - an active surface (possibly null),
    - the keys currently logically down,
    - the active modifiers,
    - the active group.

    By default, the active surface is null, the keys currently logically down
    are empty, the active modifiers and the active group are 0.
    """
    object_id = 0
    version = 10

    class keymap_format(Enum):
        """
        Keyboard mapping format

        This specifies the format of the keymap provided to the
        client with the wl_keyboard.keymap event.
        """

        no_keymap: int
        """No keymap; client must understand how to interpret the raw keycode"""

        xkb_v1: int
        """Libxkbcommon compatible, null-terminated string; to determine the xkb keycode, clients must add 8 to the key event keycode"""



    class key_state(Enum):
        """
        Physical key state

        Describes the physical state of a key that produced the key event.

        Since version 10, the key can be in a "repeated" pseudo-state which
        means the same as "pressed", but is used to signal repetition in the
        key event.

        The key may only enter the repeated state after entering the pressed
        state and before entering the released state. This event may be
        generated multiple times while the key is down.
        """

        released: int
        """Key is not pressed"""

        pressed: int
        """Key is pressed"""

        repeated: int
        """Key was repeated"""



    def release(self) -> None:
        """Release the keyboard object"""

        ...

    def on_keymap(self, format: wl_keyboard.keymap_format, fd: fd, size: int) -> None:
        """
        Keyboard mapping.

        Override to handle [`wayland.wl_keyboard.events.keymap`][].
        """

        ...

    def on_enter(self, serial: int, surface: wl_surface, keys: list) -> None:
        """
        Enter event.

        Override to handle [`wayland.wl_keyboard.events.enter`][].
        """

        ...

    def on_leave(self, serial: int, surface: wl_surface) -> None:
        """
        Leave event.

        Override to handle [`wayland.wl_keyboard.events.leave`][].
        """

        ...

    def on_key(self, serial: int, time: int, key: int, state: wl_keyboard.key_state) -> None:
        """
        Key event.

        Override to handle [`wayland.wl_keyboard.events.key`][].
        """

        ...

    def on_modifiers(self, serial: int, mods_depressed: int, mods_latched: int, mods_locked: int, group: int) -> None:
        """
        Modifier and group state.

        Override to handle [`wayland.wl_keyboard.events.modifiers`][].
        """

        ...

    def on_repeat_info(self, rate: int, delay: int) -> None:
        """
        Repeat rate and delay.

        Override to handle [`wayland.wl_keyboard.events.repeat_info`][].
        """

        ...

    class events(WaylandEvent):
        def keymap(self, format: wl_keyboard.keymap_format, fd: fd, size: int) -> None:
            """
            Keyboard mapping

            This event provides a file descriptor to the client which can be
            memory-mapped in read-only mode to provide a keyboard mapping
            description.

            From version 7 onwards, the fd must be mapped with MAP_PRIVATE by
            the recipient, as MAP_SHARED may fail.

            Args:
                format: Keymap format
                fd: Keymap file descriptor
                size: Keymap size, in bytes
            """

            ...

        def enter(self, serial: int, surface: wl_surface, keys: list) -> None:
            """
            Enter event

            Notification that this seat's keyboard focus is on a certain
            surface.

            The compositor must send the wl_keyboard.modifiers event after this
            event.

            In the wl_keyboard logical state, this event sets the active surface to
            the surface argument and the keys currently logically down to the keys
            in the keys argument. The compositor must not send this event if the
            wl_keyboard already had an active surface immediately before this event.

            Clients should not use the list of pressed keys to emulate key-press
            events. The order of keys in the list is unspecified.

            Args:
                serial: Serial number of the enter event
                surface: Surface gaining keyboard focus
                keys: The keys currently logically down
            """

            ...

        def leave(self, serial: int, surface: wl_surface) -> None:
            """
            Leave event

            Notification that this seat's keyboard focus is no longer on
            a certain surface.

            The leave notification is sent before the enter notification
            for the new focus.

            In the wl_keyboard logical state, this event resets all values to their
            defaults. The compositor must not send this event if the active surface
            of the wl_keyboard was not equal to the surface argument immediately
            before this event.

            Args:
                serial: Serial number of the leave event
                surface: Surface that lost keyboard focus
            """

            ...

        def key(self, serial: int, time: int, key: int, state: wl_keyboard.key_state) -> None:
            """
            Key event

            A key was pressed or released.
            The time argument is a timestamp with millisecond
            granularity, with an undefined base.

            The key is a platform-specific key code that can be interpreted
            by feeding it to the keyboard mapping (see the keymap event).

            If this event produces a change in modifiers, then the resulting
            wl_keyboard.modifiers event must be sent after this event.

            In the wl_keyboard logical state, this event adds the key to the keys
            currently logically down (if the state argument is pressed) or removes
            the key from the keys currently logically down (if the state argument is
            released). The compositor must not send this event if the wl_keyboard
            did not have an active surface immediately before this event. The
            compositor must not send this event if state is pressed (resp. released)
            and the key was already logically down (resp. was not logically down)
            immediately before this event.

            Since version 10, compositors may send key events with the "repeated"
            key state when a wl_keyboard.repeat_info event with a rate argument of
            0 has been received. This allows the compositor to take over the
            responsibility of key repetition.

            Args:
                serial: Serial number of the key event
                time: Timestamp with millisecond granularity
                key: Key that produced the event
                state: Physical state of the key
            """

            ...

        def modifiers(self, serial: int, mods_depressed: int, mods_latched: int, mods_locked: int, group: int) -> None:
            """
            Modifier and group state

            Notifies clients that the modifier and/or group state has
            changed, and it should update its local state.

            The compositor may send this event without a surface of the client
            having keyboard focus, for example to tie modifier information to
            pointer focus instead. If a modifier event with pressed modifiers is sent
            without a prior enter event, the client can assume the modifier state is
            valid until it receives the next wl_keyboard.modifiers event. In order to
            reset the modifier state again, the compositor can send a
            wl_keyboard.modifiers event with no pressed modifiers.

            In the wl_keyboard logical state, this event updates the modifiers and
            group.

            Args:
                serial: Serial number of the modifiers event
                mods_depressed: Depressed modifiers
                mods_latched: Latched modifiers
                mods_locked: Locked modifiers
                group: Keyboard layout
            """

            ...

        def repeat_info(self, rate: int, delay: int) -> None:
            """
            Repeat rate and delay

            Informs the client about the keyboard's repeat rate and delay.

            This event is sent as soon as the wl_keyboard object has been created,
            and is guaranteed to be received by the client before any key press
            event.

            Negative values for either rate or delay are illegal. A rate of zero
            will disable any repeating (regardless of the value of delay).

            This event can be sent later on as well with a new value if necessary,
            so clients should continue listening for the event past the creation
            of wl_keyboard.

            Args:
                rate: The rate of repeating keys in characters per second
                delay: Delay in milliseconds since key down until repeating starts
            """

            ...

class wl_touch:
    """
    Touchscreen input device

    The wl_touch interface represents a touchscreen
    associated with a seat.

    Touch interactions can consist of one or more contacts.
    For each contact, a series of events is generated, starting
    with a down event, followed by zero or more motion events,
    and ending with an up event. Events relating to the same
    contact point can be identified by the ID of the sequence.
    """
    object_id = 0
    version = 10


    def release(self) -> None:
        """Release the touch object"""

        ...

    def on_down(self, serial: int, time: int, surface: wl_surface, id: int, x: float, y: float) -> None:
        """
        Touch down event and beginning of a touch sequence.

        Override to handle [`wayland.wl_touch.events.down`][].
        """

        ...

    def on_up(self, serial: int, time: int, id: int) -> None:
        """
        End of a touch event sequence.

        Override to handle [`wayland.wl_touch.events.up`][].
        """

        ...

    def on_motion(self, time: int, id: int, x: float, y: float) -> None:
        """
        Update of touch point coordinates.

        Override to handle [`wayland.wl_touch.events.motion`][].
        """

        ...

    def on_frame(self) -> None:
        """
        End of touch frame event.

        Override to handle [`wayland.wl_touch.events.frame`][].
        """

        ...

    def on_cancel(self) -> None:
        """
        Touch session cancelled.

        Override to handle [`wayland.wl_touch.events.cancel`][].
        """

        ...

    def on_shape(self, id: int, major: float, minor: float) -> None:
        """
        Update shape of touch point.

        Override to handle [`wayland.wl_touch.events.shape`][].
        """

        ...

    def on_orientation(self, id: int, orientation: float) -> None:
        """
        Update orientation of touch point.

        Override to handle [`wayland.wl_touch.events.orientation`][].
        """

        ...

    class events(WaylandEvent):
        def down(self, serial: int, time: int, surface: wl_surface, id: int, x: float, y: float) -> None:
            """
            Touch down event and beginning of a touch sequence

            A new touch point has appeared on the surface. This touch point is
            assigned a unique ID. Future events from this touch point reference
            this ID. The ID ceases to be valid after a touch up event and may be
            reused in the future.

            Args:
                serial: Serial number of the touch down event
                time: Timestamp with millisecond granularity
                surface: Surface touched
                id: The unique id of this touch point
                x: Surface-local x coordinate
                y: Surface-local y coordinate
            """

            ...

        def up(self, serial: int, time: int, id: int) -> None:
            """
            End of a touch event sequence

            The touch point has disappeared. No further events will be sent for
            this touch point and the touch point's ID is released and may be
            reused in a future touch down event.

            Args:
                serial: Serial number of the touch up event
                time: Timestamp with millisecond granularity
                id: The unique id of this touch point
            """

            ...

        def motion(self, time: int, id: int, x: float, y: float) -> None:
            """
            Update of touch point coordinates

            A touch point has changed coordinates.

            Args:
                time: Timestamp with millisecond granularity
                id: The unique id of this touch point
                x: Surface-local x coordinate
                y: Surface-local y coordinate
            """

            ...

        def frame(self) -> None:
            """
            End of touch frame event

            Indicates the end of a set of events that logically belong together.
            A client is expected to accumulate the data in all events within the
            frame before proceeding.

            A wl_touch.frame terminates at least one event but otherwise no
            guarantee is provided about the set of events within a frame. A client
            must assume that any state not updated in a frame is unchanged from the
            previously known state.
            """

            ...

        def cancel(self) -> None:
            """
            Touch session cancelled

            Sent if the compositor decides the touch stream is a global
            gesture. No further events are sent to the clients from that
            particular gesture. Touch cancellation applies to all touch points
            currently active on this client's surface. The client is
            responsible for finalizing the touch points, future touch points on
            this surface may reuse the touch point ID.

            No frame event is required after the cancel event.
            """

            ...

        def shape(self, id: int, major: float, minor: float) -> None:
            """
            Update shape of touch point

            Sent when a touchpoint has changed its shape.

            This event does not occur on its own. It is sent before a
            wl_touch.frame event and carries the new shape information for
            any previously reported, or new touch points of that frame.

            Other events describing the touch point such as wl_touch.down,
            wl_touch.motion or wl_touch.orientation may be sent within the
            same wl_touch.frame. A client should treat these events as a single
            logical touch point update. The order of wl_touch.shape,
            wl_touch.orientation and wl_touch.motion is not guaranteed.
            A wl_touch.down event is guaranteed to occur before the first
            wl_touch.shape event for this touch ID but both events may occur within
            the same wl_touch.frame.

            A touchpoint shape is approximated by an ellipse through the major and
            minor axis length. The major axis length describes the longer diameter
            of the ellipse, while the minor axis length describes the shorter
            diameter. Major and minor are orthogonal and both are specified in
            surface-local coordinates. The center of the ellipse is always at the
            touchpoint location as reported by wl_touch.down or wl_touch.move.

            This event is only sent by the compositor if the touch device supports
            shape reports. The client has to make reasonable assumptions about the
            shape if it did not receive this event.

            Args:
                id: The unique id of this touch point
                major: Length of the major axis in surface-local coordinates
                minor: Length of the minor axis in surface-local coordinates
            """

            ...

        def orientation(self, id: int, orientation: float) -> None:
            """
            Update orientation of touch point

            Sent when a touchpoint has changed its orientation.

            This event does not occur on its own. It is sent before a
            wl_touch.frame event and carries the new shape information for
            any previously reported, or new touch points of that frame.

            Other events describing the touch point such as wl_touch.down,
            wl_touch.motion or wl_touch.shape may be sent within the
            same wl_touch.frame. A client should treat these events as a single
            logical touch point update. The order of wl_touch.shape,
            wl_touch.orientation and wl_touch.motion is not guaranteed.
            A wl_touch.down event is guaranteed to occur before the first
            wl_touch.orientation event for this touch ID but both events may occur
            within the same wl_touch.frame.

            The orientation describes the clockwise angle of a touchpoint's major
            axis to the positive surface y-axis and is normalized to the -180 to
            +180 degree range. The granularity of orientation depends on the touch
            device, some devices only support binary rotation values between 0 and
            90 degrees.

            This event is only sent by the compositor if the touch device supports
            orientation reports.

            Args:
                id: The unique id of this touch point
                orientation: Angle between major axis and positive surface y-axis in degrees
            """

            ...

class wl_output:
    """
    Compositor output region

    An output describes part of the compositor geometry.  The
    compositor works in the 'compositor coordinate system' and an
    output corresponds to a rectangular area in that space that is
    actually visible.  This typically corresponds to a monitor that
    displays part of the compositor space.  This object is published
    as global during start up, or when a monitor is hotplugged.
    """
    object_id = 0
    version = 4

    class subpixel(Enum):
        """
        Subpixel geometry information

        This enumeration describes how the physical
        pixels on an output are laid out.
        """

        unknown: int
        """Unknown geometry"""

        none: int
        """No geometry"""

        horizontal_rgb: int
        """Horizontal rgb"""

        horizontal_bgr: int
        """Horizontal bgr"""

        vertical_rgb: int
        """Vertical rgb"""

        vertical_bgr: int
        """Vertical bgr"""



    class transform(Enum):
        """
        Transformation applied to buffer contents

        This describes transformations that clients and compositors apply to
        buffer contents.

        The flipped values correspond to an initial flip around a
        vertical axis followed by rotation.

        The purpose is mainly to allow clients to render accordingly and
        tell the compositor, so that for fullscreen surfaces, the
        compositor will still be able to scan out directly from client
        surfaces.
        """

        normal: int
        """No transform"""

        transform_90: int
        """90 degrees counter-clockwise"""

        transform_180: int
        """180 degrees counter-clockwise"""

        transform_270: int
        """270 degrees counter-clockwise"""

        flipped: int
        """180 degree flip around a vertical axis"""

        flipped_90: int
        """Flip and rotate 90 degrees counter-clockwise"""

        flipped_180: int
        """Flip and rotate 180 degrees counter-clockwise"""

        flipped_270: int
        """Flip and rotate 270 degrees counter-clockwise"""



    class mode(IntFlag):
        """
        Mode information

        These flags describe properties of an output mode.
        They are used in the flags bitfield of the mode event.
        """

        current: int
        """Indicates this is the current mode"""

        preferred: int
        """Indicates this is the preferred mode"""



    def release(self) -> None:
        """
        Release the output object

        Using this request a client can tell the server that it is not going to
        use the output object anymore.
        """

        ...

    def on_geometry(self, x: int, y: int, physical_width: int, physical_height: int, subpixel: wl_output.subpixel, make: str, model: str, transform: wl_output.transform) -> None:
        """
        Properties of the output.

        Override to handle [`wayland.wl_output.events.geometry`][].
        """

        ...

    def on_mode(self, flags: wl_output.mode, width: int, height: int, refresh: int) -> None:
        """
        Advertise available modes for the output.

        Override to handle [`wayland.wl_output.events.mode`][].
        """

        ...

    def on_done(self) -> None:
        """
        Sent all information about output.

        Override to handle [`wayland.wl_output.events.done`][].
        """

        ...

    def on_scale(self, factor: int) -> None:
        """
        Output scaling properties.

        Override to handle [`wayland.wl_output.events.scale`][].
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Name of this output.

        Override to handle [`wayland.wl_output.events.name`][].
        """

        ...

    def on_description(self, description: str) -> None:
        """
        Human-readable description of this output.

        Override to handle [`wayland.wl_output.events.description`][].
        """

        ...

    class events(WaylandEvent):
        def geometry(self, x: int, y: int, physical_width: int, physical_height: int, subpixel: wl_output.subpixel, make: str, model: str, transform: wl_output.transform) -> None:
            """
            Properties of the output

            The geometry event describes geometric properties of the output.
            The event is sent when binding to the output object and whenever
            any of the properties change.

            The physical size can be set to zero if it doesn't make sense for this
            output (e.g. for projectors or virtual outputs).

            The geometry event will be followed by a done event (starting from
            version 2).

            Clients should use wl_surface.preferred_buffer_transform instead of the
            transform advertised by this event to find the preferred buffer
            transform to use for a surface.

            Note: wl_output only advertises partial information about the output
            position and identification. Some compositors, for instance those not
            implementing a desktop-style output layout or those exposing virtual
            outputs, might fake this information. Instead of using x and y, clients
            should use xdg_output.logical_position. Instead of using make and model,
            clients should use name and description.

            Args:
                x: X position within the global compositor space
                y: Y position within the global compositor space
                physical_width: Width in millimeters of the output
                physical_height: Height in millimeters of the output
                subpixel: Subpixel orientation of the output
                make: Textual description of the manufacturer
                model: Textual description of the model
                transform: Additional transformation applied to buffer contents during presentation
            """

            ...

        def mode(self, flags: wl_output.mode, width: int, height: int, refresh: int) -> None:
            """
            Advertise available modes for the output

            The mode event describes an available mode for the output.

            The event is sent when binding to the output object and there
            will always be one mode, the current mode.  The event is sent
            again if an output changes mode, for the mode that is now
            current.  In other words, the current mode is always the last
            mode that was received with the current flag set.

            Non-current modes are deprecated. A compositor can decide to only
            advertise the current mode and never send other modes. Clients
            should not rely on non-current modes.

            The size of a mode is given in physical hardware units of
            the output device. This is not necessarily the same as
            the output size in the global compositor space. For instance,
            the output may be scaled, as described in wl_output.scale,
            or transformed, as described in wl_output.transform. Clients
            willing to retrieve the output size in the global compositor
            space should use xdg_output.logical_size instead.

            The vertical refresh rate can be set to zero if it doesn't make
            sense for this output (e.g. for virtual outputs).

            The mode event will be followed by a done event (starting from
            version 2).

            Clients should not use the refresh rate to schedule frames. Instead,
            they should use the wl_surface.frame event or the presentation-time
            protocol.

            Note: this information is not always meaningful for all outputs. Some
            compositors, such as those exposing virtual outputs, might fake the
            refresh rate or the size.

            Args:
                flags: Bitfield of mode flags
                width: Width of the mode in hardware units
                height: Height of the mode in hardware units
                refresh: Vertical refresh rate in mhz
            """

            ...

        def done(self) -> None:
            """
            Sent all information about output

            This event is sent after all other properties have been
            sent after binding to the output object and after any
            other property changes done after that. This allows
            changes to the output properties to be seen as
            atomic, even if they happen via multiple events.
            """

            ...

        def scale(self, factor: int) -> None:
            """
            Output scaling properties

            This event contains scaling geometry information
            that is not in the geometry event. It may be sent after
            binding the output object or if the output scale changes
            later. The compositor will emit a non-zero, positive
            value for scale. If it is not sent, the client should
            assume a scale of 1.

            A scale larger than 1 means that the compositor will
            automatically scale surface buffers by this amount
            when rendering. This is used for very high resolution
            displays where applications rendering at the native
            resolution would be too small to be legible.

            Clients should use wl_surface.preferred_buffer_scale
            instead of this event to find the preferred buffer
            scale to use for a surface.

            The scale event will be followed by a done event.

            Args:
                factor: Scaling factor of output
            """

            ...

        def name(self, name: str) -> None:
            """
            Name of this output

            Many compositors will assign user-friendly names to their outputs, show
            them to the user, allow the user to refer to an output, etc. The client
            may wish to know this name as well to offer the user similar behaviors.

            The name is a UTF-8 string with no convention defined for its contents.
            Each name is unique among all wl_output globals. The name is only
            guaranteed to be unique for the compositor instance.

            The same output name is used for all clients for a given wl_output
            global. Thus, the name can be shared across processes to refer to a
            specific wl_output global.

            The name is not guaranteed to be persistent across sessions, thus cannot
            be used to reliably identify an output in e.g. configuration files.

            Examples of names include 'HDMI-A-1', 'WL-1', 'X11-1', etc. However, do
            not assume that the name is a reflection of an underlying DRM connector,
            X11 connection, etc.

            The name event is sent after binding the output object. This event is
            only sent once per output object, and the name does not change over the
            lifetime of the wl_output global.

            Compositors may re-use the same output name if the wl_output global is
            destroyed and re-created later. Compositors should avoid re-using the
            same name if possible.

            The name event will be followed by a done event.

            Args:
                name: Output name
            """

            ...

        def description(self, description: str) -> None:
            """
            Human-readable description of this output

            Many compositors can produce human-readable descriptions of their
            outputs. The client may wish to know this description as well, e.g. for
            output selection purposes.

            The description is a UTF-8 string with no convention defined for its
            contents. The description is not guaranteed to be unique among all
            wl_output globals. Examples might include 'Foocorp 11" Display' or
            'Virtual X11 output via :1'.

            The description event is sent after binding the output object and
            whenever the description changes. The description is optional, and may
            not be sent at all.

            The description event will be followed by a done event.

            Args:
                description: Output description
            """

            ...

class wl_region:
    """
    Region interface

    A region object describes an area.

    Region objects are used to describe the opaque and input
    regions of a surface.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy region

        Destroy the region.  This will invalidate the object ID.
        """

        ...

    def add(self, x: int, y: int, width: int, height: int) -> None:
        """
        Add rectangle to region

        Add the specified rectangle to the region.

        Args:
            x: Region-local x coordinate
            y: Region-local y coordinate
            width: Rectangle width
            height: Rectangle height
        """

        ...

    def subtract(self, x: int, y: int, width: int, height: int) -> None:
        """
        Subtract rectangle from region

        Subtract the specified rectangle from the region.

        Args:
            x: Region-local x coordinate
            y: Region-local y coordinate
            width: Rectangle width
            height: Rectangle height
        """

        ...

class wl_subcompositor:
    """
    Sub-surface compositing

    The global interface exposing sub-surface compositing capabilities.
    A wl_surface, that has sub-surfaces associated, is called the
    parent surface. Sub-surfaces can be arbitrarily nested and create
    a tree of sub-surfaces.

    The root surface in a tree of sub-surfaces is the main
    surface. The main surface cannot be a sub-surface, because
    sub-surfaces must always have a parent.

    A main surface with its sub-surfaces forms a (compound) window.
    For window management purposes, this set of wl_surface objects is
    to be considered as a single window, and it should also behave as
    such.

    The aim of sub-surfaces is to offload some of the compositing work
    within a window from clients to the compositor. A prime example is
    a video player with decorations and video in separate wl_surface
    objects. This should allow the compositor to pass YUV video buffer
    processing to dedicated overlay hardware when possible.
    """
    object_id = 0
    version = 1

    class error(Enum):
        bad_surface: int
        """The to-be sub-surface is invalid"""

        bad_parent: int
        """The to-be sub-surface parent is invalid"""



    def destroy(self) -> None:
        """
        Unbind from the subcompositor interface

        Informs the server that the client will not be using this
        protocol object anymore. This does not affect any other
        objects, wl_subsurface objects included.
        """

        ...

    def get_subsurface(self, surface: wl_surface, parent: wl_surface) -> wl_subsurface:
        """
        Give a surface the role sub-surface

        Create a sub-surface interface for the given surface, and
        associate it with the given parent surface. This turns a
        plain wl_surface into a sub-surface.

        The to-be sub-surface must not already have another role, and it
        must not have an existing wl_subsurface object. Otherwise the
        bad_surface protocol error is raised.

        Adding sub-surfaces to a parent is a double-buffered operation on the
        parent (see wl_surface.commit). The effect of adding a sub-surface
        becomes visible on the next time the state of the parent surface is
        applied.

        The parent surface must not be one of the child surface's descendants,
        and the parent must be different from the child surface, otherwise the
        bad_parent protocol error is raised.

        This request modifies the behaviour of wl_surface.commit request on
        the sub-surface, see the documentation on wl_subsurface interface.

        Args:
            surface: The surface to be turned into a sub-surface
            parent: The parent surface

        Returns:
            wl_subsurface: The created object
        """

        ...

class wl_subsurface:
    """
    Sub-surface interface to a `wl_surface`

    An additional interface to a wl_surface object, which has been
    made a sub-surface. A sub-surface has one parent surface. A
    sub-surface's size and position are not limited to that of the parent.
    Particularly, a sub-surface is not automatically clipped to its
    parent's area.

    A sub-surface becomes mapped, when a non-NULL wl_buffer is applied
    and the parent surface is mapped. The order of which one happens
    first is irrelevant. A sub-surface is hidden if the parent becomes
    hidden, or if a NULL wl_buffer is applied. These rules apply
    recursively through the tree of surfaces.

    The behaviour of a wl_surface.commit request on a sub-surface
    depends on the sub-surface's mode. The possible modes are
    synchronized and desynchronized, see methods
    wl_subsurface.set_sync and wl_subsurface.set_desync. Synchronized
    mode caches the wl_surface state to be applied when the parent's
    state gets applied, and desynchronized mode applies the pending
    wl_surface state directly. A sub-surface is initially in the
    synchronized mode.

    Sub-surfaces also have another kind of state, which is managed by
    wl_subsurface requests, as opposed to wl_surface requests. This
    state includes the sub-surface position relative to the parent
    surface (wl_subsurface.set_position), and the stacking order of
    the parent and its sub-surfaces (wl_subsurface.place_above and
    .place_below). This state is applied when the parent surface's
    wl_surface state is applied, regardless of the sub-surface's mode.
    As the exception, set_sync and set_desync are effective immediately.

    The main surface can be thought to be always in desynchronized mode,
    since it does not have a parent in the sub-surfaces sense.

    Even if a sub-surface is in desynchronized mode, it will behave as
    in synchronized mode, if its parent surface behaves as in
    synchronized mode. This rule is applied recursively throughout the
    tree of surfaces. This means, that one can set a sub-surface into
    synchronized mode, and then assume that all its child and grand-child
    sub-surfaces are synchronized, too, without explicitly setting them.

    Destroying a sub-surface takes effect immediately. If you need to
    synchronize the removal of a sub-surface to the parent surface update,
    unmap the sub-surface first by attaching a NULL wl_buffer, update parent,
    and then destroy the sub-surface.

    If the parent wl_surface object is destroyed, the sub-surface is
    unmapped.

    A sub-surface never has the keyboard focus of any seat.

    The wl_surface.offset request is ignored: clients must use set_position
    instead to move the sub-surface.
    """
    object_id = 0
    version = 1

    class error(Enum):
        bad_surface: int
        """`wl_surface` is not a sibling or the parent"""



    def destroy(self) -> None:
        """
        Remove sub-surface interface

        The sub-surface interface is removed from the wl_surface object
        that was turned into a sub-surface with a
        wl_subcompositor.get_subsurface request. The wl_surface's association
        to the parent is deleted. The wl_surface is unmapped immediately.
        """

        ...

    def set_position(self, x: int, y: int) -> None:
        """
        Reposition the sub-surface

        This schedules a sub-surface position change.
        The sub-surface will be moved so that its origin (top left
        corner pixel) will be at the location x, y of the parent surface
        coordinate system. The coordinates are not restricted to the parent
        surface area. Negative values are allowed.

        The scheduled coordinates will take effect whenever the state of the
        parent surface is applied.

        If more than one set_position request is invoked by the client before
        the commit of the parent surface, the position of a new request always
        replaces the scheduled position from any previous request.

        The initial position is 0, 0.

        Args:
            x: X coordinate in the parent surface
            y: Y coordinate in the parent surface
        """

        ...

    def place_above(self, sibling: wl_surface) -> None:
        """
        Restack the sub-surface

        This sub-surface is taken from the stack, and put back just
        above the reference surface, changing the z-order of the sub-surfaces.
        The reference surface must be one of the sibling surfaces, or the
        parent surface. Using any other surface, including this sub-surface,
        will cause a protocol error.

        The z-order is double-buffered. Requests are handled in order and
        applied immediately to a pending state. The final pending state is
        copied to the active state the next time the state of the parent
        surface is applied.

        A new sub-surface is initially added as the top-most in the stack
        of its siblings and parent.

        Args:
            sibling: The reference surface
        """

        ...

    def place_below(self, sibling: wl_surface) -> None:
        """
        Restack the sub-surface

        The sub-surface is placed just below the reference surface.
        See wl_subsurface.place_above.

        Args:
            sibling: The reference surface
        """

        ...

    def set_sync(self) -> None:
        """
        Set sub-surface to synchronized mode

        Change the commit behaviour of the sub-surface to synchronized
        mode, also described as the parent dependent mode.

        In synchronized mode, wl_surface.commit on a sub-surface will
        accumulate the committed state in a cache, but the state will
        not be applied and hence will not change the compositor output.
        The cached state is applied to the sub-surface immediately after
        the parent surface's state is applied. This ensures atomic
        updates of the parent and all its synchronized sub-surfaces.
        Applying the cached state will invalidate the cache, so further
        parent surface commits do not (re-)apply old state.

        See wl_subsurface for the recursive effect of this mode.
        """

        ...

    def set_desync(self) -> None:
        """
        Set sub-surface to desynchronized mode

        Change the commit behaviour of the sub-surface to desynchronized
        mode, also described as independent or freely running mode.

        In desynchronized mode, wl_surface.commit on a sub-surface will
        apply the pending state directly, without caching, as happens
        normally with a wl_surface. Calling wl_surface.commit on the
        parent surface has no effect on the sub-surface's wl_surface
        state. This mode allows a sub-surface to be updated on its own.

        If cached state exists when wl_surface.commit is called in
        desynchronized mode, the pending state is added to the cached
        state, and applied as a whole. This invalidates the cache.

        Note: even if a sub-surface is set to desynchronized, a parent
        sub-surface may override it to behave as synchronized. For details,
        see wl_subsurface.

        If a surface's parent surface behaves as desynchronized, then
        the cached state is applied on set_desync.
        """

        ...

class wl_fixes:
    """
    Wayland protocol fixes

    This global fixes problems with other core-protocol interfaces that
    cannot be fixed in these interfaces themselves.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """Destroys this object"""

        ...

    def destroy_registry(self, registry: wl_registry) -> None:
        """
        Destroy a `wl_registry`

        This request destroys a wl_registry object.

        The client should no longer use the wl_registry after making this
        request.

        The compositor will emit a wl_display.delete_id event with the object ID
        of the registry and will no longer emit any events on the registry. The
        client should re-use the object ID once it receives the
        wl_display.delete_id event.

        Args:
            registry: The registry to destroy
        """

        ...

class zwp_linux_dmabuf_v1:
    """
    Factory for creating dmabuf-based `wl_buffers`

    This interface offers ways to create generic dmabuf-based wl_buffers.

    For more information about dmabuf, see:
    https://www.kernel.org/doc/html/next/userspace-api/dma-buf-alloc-exchange.html

    Clients can use the get_surface_feedback request to get dmabuf feedback
    for a particular surface. If the client wants to retrieve feedback not
    tied to a surface, they can use the get_default_feedback request.

    The following are required from clients:

    - Clients must ensure that either all data in the dma-buf is
      coherent for all subsequent read access or that coherency is
      correctly handled by the underlying kernel-side dma-buf
      implementation.

    - Don't make any more attachments after sending the buffer to the
      compositor. Making more attachments later increases the risk of
      the compositor not being able to use (re-import) an existing
      dmabuf-based wl_buffer.

    The underlying graphics stack must ensure the following:

    - The dmabuf file descriptors relayed to the server will stay valid
      for the whole lifetime of the wl_buffer. This means the server may
      at any time use those fds to import the dmabuf into any kernel
      sub-system that might accept it.

    However, when the underlying graphics stack fails to deliver the
    promise, because of e.g. a device hot-unplug which raises internal
    errors, after the wl_buffer has been successfully created the
    compositor must not raise protocol errors to the client when dmabuf
    import later fails.

    To create a wl_buffer from one or more dmabufs, a client creates a
    zwp_linux_dmabuf_params_v1 object with a zwp_linux_dmabuf_v1.create_params
    request. All planes required by the intended format are added with
    the 'add' request. Finally, a 'create' or 'create_immed' request is
    issued, which has the following outcome depending on the import success.

    The 'create' request,
    - on success, triggers a 'created' event which provides the final
      wl_buffer to the client.
    - on failure, triggers a 'failed' event to convey that the server
      cannot use the dmabufs received from the client.

    For the 'create_immed' request,
    - on success, the server immediately imports the added dmabufs to
      create a wl_buffer. No event is sent from the server in this case.
    - on failure, the server can choose to either:
      - terminate the client by raising a fatal error.
      - mark the wl_buffer as failed, and send a 'failed' event to the
        client. If the client uses a failed wl_buffer as an argument to any
        request, the behaviour is compositor implementation-defined.

    For all DRM formats and unless specified in another protocol extension,
    pre-multiplied alpha is used for pixel values.

    Unless specified otherwise in another protocol extension, implicit
    synchronization is used. In other words, compositors and clients must
    wait and signal fences implicitly passed via the DMA-BUF's reservation
    mechanism.
    """
    object_id = 0
    version = 5


    def destroy(self) -> None:
        """
        Unbind the factory

        Objects created through this interface, especially wl_buffers, will
        remain valid.
        """

        ...

    def create_params(self) -> zwp_linux_buffer_params_v1:
        """
        Create a temporary object for buffer parameters

        This temporary object is used to collect multiple dmabuf handles into
        a single batch to create a wl_buffer. It can only be used once and
        should be destroyed after a 'created' or 'failed' event has been
        received.

        Returns:
            zwp_linux_buffer_params_v1: The created object
        """

        ...

    def get_default_feedback(self) -> zwp_linux_dmabuf_feedback_v1:
        """
        Get default feedback

        This request creates a new wp_linux_dmabuf_feedback object not bound
        to a particular surface. This object will deliver feedback about dmabuf
        parameters to use if the client doesn't support per-surface feedback
        (see get_surface_feedback).

        Returns:
            zwp_linux_dmabuf_feedback_v1: The created object
        """

        ...

    def get_surface_feedback(self, surface: wl_surface) -> zwp_linux_dmabuf_feedback_v1:
        """
        Get feedback for a surface

        This request creates a new wp_linux_dmabuf_feedback object for the
        specified wl_surface. This object will deliver feedback about dmabuf
        parameters to use for buffers attached to this surface.

        If the surface is destroyed before the wp_linux_dmabuf_feedback object,
        the feedback object becomes inert.

        Returns:
            zwp_linux_dmabuf_feedback_v1: The created object
        """

        ...

    def on_format(self, format: int) -> None:
        """
        Supported buffer format.

        Override to handle [`wayland.zwp_linux_dmabuf_v1.events.format`][].
        """

        ...

    def on_modifier(self, format: int, modifier_hi: int, modifier_lo: int) -> None:
        """
        Supported buffer format modifier.

        Override to handle [`wayland.zwp_linux_dmabuf_v1.events.modifier`][].
        """

        ...

    class events(WaylandEvent):
        def format(self, format: int) -> None:
            """
            Supported buffer format

            This event advertises one buffer format that the server supports.
            All the supported formats are advertised once when the client
            binds to this interface. A roundtrip after binding guarantees
            that the client has received all supported formats.

            For the definition of the format codes, see the
            zwp_linux_buffer_params_v1::create request.

            Starting version 4, the format event is deprecated and must not be
            sent by compositors. Instead, use get_default_feedback or
            get_surface_feedback.

            Args:
                format: Drm_format code
            """

            ...

        def modifier(self, format: int, modifier_hi: int, modifier_lo: int) -> None:
            """
            Supported buffer format modifier

            This event advertises the formats that the server supports, along with
            the modifiers supported for each format. All the supported modifiers
            for all the supported formats are advertised once when the client
            binds to this interface. A roundtrip after binding guarantees that
            the client has received all supported format-modifier pairs.

            For legacy support, DRM_FORMAT_MOD_INVALID (that is, modifier_hi ==
            0x00ffffff and modifier_lo == 0xffffffff) is allowed in this event.
            It indicates that the server can support the format with an implicit
            modifier. When a plane has DRM_FORMAT_MOD_INVALID as its modifier, it
            is as if no explicit modifier is specified. The effective modifier
            will be derived from the dmabuf.

            A compositor that sends valid modifiers and DRM_FORMAT_MOD_INVALID for
            a given format supports both explicit modifiers and implicit modifiers.

            For the definition of the format and modifier codes, see the
            zwp_linux_buffer_params_v1::create and zwp_linux_buffer_params_v1::add
            requests.

            Starting version 4, the modifier event is deprecated and must not be
            sent by compositors. Instead, use get_default_feedback or
            get_surface_feedback.

            Args:
                format: Drm_format code
                modifier_hi: High 32 bits of layout modifier
                modifier_lo: Low 32 bits of layout modifier
            """

            ...

class zwp_linux_buffer_params_v1:
    """
    Parameters for creating a dmabuf-based `wl_buffer`

    This temporary object is a collection of dmabufs and other
    parameters that together form a single logical buffer. The temporary
    object may eventually create one wl_buffer unless cancelled by
    destroying it before requesting 'create'.

    Single-planar formats only require one dmabuf, however
    multi-planar formats may require more than one dmabuf. For all
    formats, an 'add' request must be called once per plane (even if the
    underlying dmabuf fd is identical).

    You must use consecutive plane indices ('plane_idx' argument for 'add')
    from zero to the number of planes used by the drm_fourcc format code.
    All planes required by the format must be given exactly once, but can
    be given in any order. Each plane index can only be set once; subsequent
    calls with a plane index which has already been set will result in a
    plane_set error being generated.
    """
    object_id = 0
    version = 5

    class error(Enum):
        already_used: int
        """The `dmabuf_batch` object has already been used to create a `wl_buffer`"""

        plane_idx: int
        """Plane index out of bounds"""

        plane_set: int
        """The plane index was already set"""

        incomplete: int
        """Missing or too many planes to create a buffer"""

        invalid_format: int
        """Format not supported"""

        invalid_dimensions: int
        """Invalid width or height"""

        out_of_bounds: int
        """Offset + stride * height goes out of dmabuf bounds"""

        invalid_wl_buffer: int
        """Invalid `wl_buffer` resulted from importing dmabufs via                the `create_immed` request on given `buffer_params`"""



    class flags(IntFlag):
        y_invert: int
        """Contents are y-inverted"""

        interlaced: int
        """Content is interlaced"""

        bottom_first: int
        """Bottom field first"""



    def destroy(self) -> None:
        """
        Delete this object, used or not

        Cleans up the temporary data sent to the server for dmabuf-based
        wl_buffer creation.
        """

        ...

    def add(self, fd: fd, plane_idx: int, offset: int, stride: int, modifier_hi: int, modifier_lo: int) -> None:
        """
        Add a dmabuf to the temporary set

        This request adds one dmabuf to the set in this
        zwp_linux_buffer_params_v1.

        The 64-bit unsigned value combined from modifier_hi and modifier_lo
        is the dmabuf layout modifier. DRM AddFB2 ioctl calls this the
        fb modifier, which is defined in drm_mode.h of Linux UAPI.
        This is an opaque token. Drivers use this token to express tiling,
        compression, etc. driver-specific modifications to the base format
        defined by the DRM fourcc code.

        Starting from version 4, the invalid_format protocol error is sent if
        the format + modifier pair was not advertised as supported.

        Starting from version 5, the invalid_format protocol error is sent if
        all planes don't use the same modifier.

        This request raises the PLANE_IDX error if plane_idx is too large.
        The error PLANE_SET is raised if attempting to set a plane that
        was already set.

        Args:
            fd: Dmabuf fd
            plane_idx: Plane index
            offset: Offset in bytes
            stride: Stride in bytes
            modifier_hi: High 32 bits of layout modifier
            modifier_lo: Low 32 bits of layout modifier
        """

        ...

    def create(self, width: int, height: int, format: int, flags: zwp_linux_buffer_params_v1.flags) -> None:
        """
        Create a `wl_buffer` from the given dmabufs

        This asks for creation of a wl_buffer from the added dmabuf
        buffers. The wl_buffer is not created immediately but returned via
        the 'created' event if the dmabuf sharing succeeds. The sharing
        may fail at runtime for reasons a client cannot predict, in
        which case the 'failed' event is triggered.

        The 'format' argument is a DRM_FORMAT code, as defined by the
        libdrm's drm_fourcc.h. The Linux kernel's DRM sub-system is the
        authoritative source on how the format codes should work.

        The 'flags' is a bitfield of the flags defined in enum "flags".
        'y_invert' means the that the image needs to be y-flipped.

        Flag 'interlaced' means that the frame in the buffer is not
        progressive as usual, but interlaced. An interlaced buffer as
        supported here must always contain both top and bottom fields.
        The top field always begins on the first pixel row. The temporal
        ordering between the two fields is top field first, unless
        'bottom_first' is specified. It is undefined whether 'bottom_first'
        is ignored if 'interlaced' is not set.

        This protocol does not convey any information about field rate,
        duration, or timing, other than the relative ordering between the
        two fields in one buffer. A compositor may have to estimate the
        intended field rate from the incoming buffer rate. It is undefined
        whether the time of receiving wl_surface.commit with a new buffer
        attached, applying the wl_surface state, wl_surface.frame callback
        trigger, presentation, or any other point in the compositor cycle
        is used to measure the frame or field times. There is no support
        for detecting missed or late frames/fields/buffers either, and
        there is no support whatsoever for cooperating with interlaced
        compositor output.

        The composited image quality resulting from the use of interlaced
        buffers is explicitly undefined. A compositor may use elaborate
        hardware features or software to deinterlace and create progressive
        output frames from a sequence of interlaced input buffers, or it
        may produce substandard image quality. However, compositors that
        cannot guarantee reasonable image quality in all cases are recommended
        to just reject all interlaced buffers.

        Any argument errors, including non-positive width or height,
        mismatch between the number of planes and the format, bad
        format, bad offset or stride, may be indicated by fatal protocol
        errors: INCOMPLETE, INVALID_FORMAT, INVALID_DIMENSIONS,
        OUT_OF_BOUNDS.

        Dmabuf import errors in the server that are not obvious client
        bugs are returned via the 'failed' event as non-fatal. This
        allows attempting dmabuf sharing and falling back in the client
        if it fails.

        This request can be sent only once in the object's lifetime, after
        which the only legal request is destroy. This object should be
        destroyed after issuing a 'create' request. Attempting to use this
        object after issuing 'create' raises ALREADY_USED protocol error.

        It is not mandatory to issue 'create'. If a client wants to
        cancel the buffer creation, it can just destroy this object.

        Args:
            width: Base plane width in pixels
            height: Base plane height in pixels
            format: Drm_format code
            flags: See enum flags
        """

        ...

    def create_immed(self, width: int, height: int, format: int, flags: zwp_linux_buffer_params_v1.flags) -> wl_buffer:
        """
        Immediately create a `wl_buffer` from the given                      dmabufs

        This asks for immediate creation of a wl_buffer by importing the
        added dmabufs.

        In case of import success, no event is sent from the server, and the
        wl_buffer is ready to be used by the client.

        Upon import failure, either of the following may happen, as seen fit
        by the implementation:
        - the client is terminated with one of the following fatal protocol
          errors:
          - INCOMPLETE, INVALID_FORMAT, INVALID_DIMENSIONS, OUT_OF_BOUNDS,
            in case of argument errors such as mismatch between the number
            of planes and the format, bad format, non-positive width or
            height, or bad offset or stride.
          - INVALID_WL_BUFFER, in case the cause for failure is unknown or
            platform specific.
        - the server creates an invalid wl_buffer, marks it as failed and
          sends a 'failed' event to the client. The result of using this
          invalid wl_buffer as an argument in any request by the client is
          defined by the compositor implementation.

        This takes the same arguments as a 'create' request, and obeys the
        same restrictions.

        Args:
            width: Base plane width in pixels
            height: Base plane height in pixels
            format: Drm_format code
            flags: See enum flags

        Returns:
            wl_buffer: The created object
        """

        ...

    def on_created(self, buffer: wl_buffer) -> None:
        """
        Buffer creation succeeded.

        Override to handle [`wayland.zwp_linux_buffer_params_v1.events.created`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Buffer creation failed.

        Override to handle [`wayland.zwp_linux_buffer_params_v1.events.failed`][].
        """

        ...

    class events(WaylandEvent):
        def created(self, buffer: wl_buffer) -> None:
            """
            Buffer creation succeeded

            This event indicates that the attempted buffer creation was
            successful. It provides the new wl_buffer referencing the dmabuf(s).

            Upon receiving this event, the client should destroy the
            zwp_linux_buffer_params_v1 object.

            Args:
                buffer: The newly created `wl_buffer`
            """

            ...

        def failed(self) -> None:
            """
            Buffer creation failed

            This event indicates that the attempted buffer creation has
            failed. It usually means that one of the dmabuf constraints
            has not been fulfilled.

            Upon receiving this event, the client should destroy the
            zwp_linux_buffer_params_v1 object.
            """

            ...

class zwp_linux_dmabuf_feedback_v1:
    """
    Dmabuf feedback

    This object advertises dmabuf parameters feedback. This includes the
    preferred devices and the supported formats/modifiers.

    The parameters are sent once when this object is created and whenever they
    change. The done event is always sent once after all parameters have been
    sent. When a single parameter changes, all parameters are re-sent by the
    compositor.

    Compositors can re-send the parameters when the current client buffer
    allocations are sub-optimal. Compositors should not re-send the
    parameters if re-allocating the buffers would not result in a more optimal
    configuration. In particular, compositors should avoid sending the exact
    same parameters multiple times in a row.

    The tranche_target_device and tranche_formats events are grouped by
    tranches of preference. For each tranche, a tranche_target_device, one
    tranche_flags and one or more tranche_formats events are sent, followed
    by a tranche_done event finishing the list. The tranches are sent in
    descending order of preference. All formats and modifiers in the same
    tranche have the same preference.

    To send parameters, the compositor sends one main_device event, tranches
    (each consisting of one tranche_target_device event, one tranche_flags
    event, tranche_formats events and then a tranche_done event), then one
    done event.
    """
    object_id = 0
    version = 5

    class tranche_flags(IntFlag):
        scanout: int
        """Direct scan-out tranche"""



    def destroy(self) -> None:
        """
        Destroy the feedback object

        Using this request a client can tell the server that it is not going to
        use the wp_linux_dmabuf_feedback object anymore.
        """

        ...

    def on_done(self) -> None:
        """
        All feedback has been sent.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.done`][].
        """

        ...

    def on_format_table(self, fd: fd, size: int) -> None:
        """
        Format and modifier table.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.format_table`][].
        """

        ...

    def on_main_device(self, device: list) -> None:
        """
        Preferred main device.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.main_device`][].
        """

        ...

    def on_tranche_done(self) -> None:
        """
        A preference tranche has been sent.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.tranche_done`][].
        """

        ...

    def on_tranche_target_device(self, device: list) -> None:
        """
        Target device.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.tranche_target_device`][].
        """

        ...

    def on_tranche_formats(self, indices: list) -> None:
        """
        Supported buffer format modifier.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.tranche_formats`][].
        """

        ...

    def on_tranche_flags(self, flags: zwp_linux_dmabuf_feedback_v1.tranche_flags) -> None:
        """
        Tranche flags.

        Override to handle [`wayland.zwp_linux_dmabuf_feedback_v1.events.tranche_flags`][].
        """

        ...

    class events(WaylandEvent):
        def done(self) -> None:
            """
            All feedback has been sent

            This event is sent after all parameters of a wp_linux_dmabuf_feedback
            object have been sent.

            This allows changes to the wp_linux_dmabuf_feedback parameters to be
            seen as atomic, even if they happen via multiple events.
            """

            ...

        def format_table(self, fd: fd, size: int) -> None:
            """
            Format and modifier table

            This event provides a file descriptor which can be memory-mapped to
            access the format and modifier table.

            The table contains a tightly packed array of consecutive format +
            modifier pairs. Each pair is 16 bytes wide. It contains a format as a
            32-bit unsigned integer, followed by 4 bytes of unused padding, and a
            modifier as a 64-bit unsigned integer. The native endianness is used.

            The client must map the file descriptor in read-only private mode.

            Compositors are not allowed to mutate the table file contents once this
            event has been sent. Instead, compositors must create a new, separate
            table file and re-send feedback parameters. Compositors are allowed to
            store duplicate format + modifier pairs in the table.

            Args:
                fd: Table file descriptor
                size: Table size, in bytes
            """

            ...

        def main_device(self, device: list) -> None:
            """
            Preferred main device

            This event advertises the main device that the server prefers to use
            when direct scan-out to the target device isn't possible. The
            advertised main device may be different for each
            wp_linux_dmabuf_feedback object, and may change over time.

            There is exactly one main device. The compositor must send at least
            one preference tranche with tranche_target_device equal to main_device.

            Clients need to create buffers that the main device can import and
            read from, otherwise creating the dmabuf wl_buffer will fail (see the
            wp_linux_buffer_params.create and create_immed requests for details).
            The main device will also likely be kept active by the compositor,
            so clients can use it instead of waking up another device for power
            savings.

            In general the device is a DRM node. The DRM node type (primary vs.
            render) is unspecified. Clients must not rely on the compositor sending
            a particular node type. Clients cannot check two devices for equality
            by comparing the dev_t value.

            If explicit modifiers are not supported and the client performs buffer
            allocations on a different device than the main device, then the client
            must force the buffer to have a linear layout.

            Args:
                device: Device `dev_t` value
            """

            ...

        def tranche_done(self) -> None:
            """
            A preference tranche has been sent

            This event splits tranche_target_device and tranche_formats events in
            preference tranches. It is sent after a set of tranche_target_device
            and tranche_formats events; it represents the end of a tranche. The
            next tranche will have a lower preference.
            """

            ...

        def tranche_target_device(self, device: list) -> None:
            """
            Target device

            This event advertises the target device that the server prefers to use
            for a buffer created given this tranche. The advertised target device
            may be different for each preference tranche, and may change over time.

            There is exactly one target device per tranche.

            The target device may be a scan-out device, for example if the
            compositor prefers to directly scan-out a buffer created given this
            tranche. The target device may be a rendering device, for example if
            the compositor prefers to texture from said buffer.

            The client can use this hint to allocate the buffer in a way that makes
            it accessible from the target device, ideally directly. The buffer must
            still be accessible from the main device, either through direct import
            or through a potentially more expensive fallback path. If the buffer
            can't be directly imported from the main device then clients must be
            prepared for the compositor changing the tranche priority or making
            wl_buffer creation fail (see the wp_linux_buffer_params.create and
            create_immed requests for details).

            If the device is a DRM node, the DRM node type (primary vs. render) is
            unspecified. Clients must not rely on the compositor sending a
            particular node type. Clients cannot check two devices for equality by
            comparing the dev_t value.

            This event is tied to a preference tranche, see the tranche_done event.

            Args:
                device: Device `dev_t` value
            """

            ...

        def tranche_formats(self, indices: list) -> None:
            """
            Supported buffer format modifier

            This event advertises the format + modifier combinations that the
            compositor supports.

            It carries an array of indices, each referring to a format + modifier
            pair in the last received format table (see the format_table event).
            Each index is a 16-bit unsigned integer in native endianness.

            For legacy support, DRM_FORMAT_MOD_INVALID is an allowed modifier.
            It indicates that the server can support the format with an implicit
            modifier. When a buffer has DRM_FORMAT_MOD_INVALID as its modifier, it
            is as if no explicit modifier is specified. The effective modifier
            will be derived from the dmabuf.

            A compositor that sends valid modifiers and DRM_FORMAT_MOD_INVALID for
            a given format supports both explicit modifiers and implicit modifiers.

            Compositors must not send duplicate format + modifier pairs within the
            same tranche or across two different tranches with the same target
            device and flags.

            This event is tied to a preference tranche, see the tranche_done event.

            For the definition of the format and modifier codes, see the
            wp_linux_buffer_params.create request.

            Args:
                indices: Array of 16-bit indexes
            """

            ...

        def tranche_flags(self, flags: zwp_linux_dmabuf_feedback_v1.tranche_flags) -> None:
            """
            Tranche flags

            This event sets tranche-specific flags.

            The scanout flag is a hint that direct scan-out may be attempted by the
            compositor on the target device if the client appropriately allocates a
            buffer. How to allocate a buffer that can be scanned out on the target
            device is implementation-defined.

            This event is tied to a preference tranche, see the tranche_done event.

            Args:
                flags: Tranche flags
            """

            ...

class wp_presentation:
    """Timed presentation related `wl_surface` requests"""
    object_id = 0
    version = 2

    class error(Enum):
        """
        Fatal presentation errors

        These fatal protocol errors may be emitted in response to
        illegal presentation requests.
        """

        invalid_timestamp: int
        """Invalid value in `tv_nsec`"""

        invalid_flag: int
        """Invalid flag"""



    def destroy(self) -> None:
        """
        Unbind from the presentation interface

        Informs the server that the client will no longer be using
        this protocol object. Existing objects created by this object
        are not affected.
        """

        ...

    def feedback(self, surface: wl_surface) -> wp_presentation_feedback:
        """
        Request presentation feedback information

        Request presentation feedback for the current content submission
        on the given surface. This creates a new presentation_feedback
        object, which will deliver the feedback information once. If
        multiple presentation_feedback objects are created for the same
        submission, they will all deliver the same information.

        For details on what information is returned, see the
        presentation_feedback interface.

        Args:
            surface: Target surface

        Returns:
            wp_presentation_feedback: The created object
        """

        ...

    def on_clock_id(self, clk_id: int) -> None:
        """
        Clock id for timestamps.

        Override to handle [`wayland.wp_presentation.events.clock_id`][].
        """

        ...

    class events(WaylandEvent):
        def clock_id(self, clk_id: int) -> None:
            """
            Clock id for timestamps

            This event tells the client in which clock domain the
            compositor interprets the timestamps used by the presentation
            extension. This clock is called the presentation clock.

            The compositor sends this event when the client binds to the
            presentation interface. The presentation clock does not change
            during the lifetime of the client connection.

            The clock identifier is platform dependent. On POSIX platforms, the
            identifier value is one of the clockid_t values accepted by
            clock_gettime(). clock_gettime() is defined by POSIX.1-2001.

            Timestamps in this clock domain are expressed as tv_sec_hi,
            tv_sec_lo, tv_nsec triples, each component being an unsigned
            32-bit value. Whole seconds are in tv_sec which is a 64-bit
            value combined from tv_sec_hi and tv_sec_lo, and the
            additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999].

            Note that clock_id applies only to the presentation clock,
            and implies nothing about e.g. the timestamps used in the
            Wayland core protocol input events.

            Compositors should prefer a clock which does not jump and is
            not slewed e.g. by NTP. The absolute value of the clock is
            irrelevant. Precision of one millisecond or better is
            recommended. Clients must be able to query the current clock
            value directly, not by asking the compositor.

            Args:
                clk_id: Platform clock identifier
            """

            ...

class wp_presentation_feedback:
    """
    Presentation time feedback event

    A presentation_feedback object returns an indication that a
    wl_surface content update has become visible to the user.
    One object corresponds to one content update submission
    (wl_surface.commit). There are two possible outcomes: the
    content update is presented to the user, and a presentation
    timestamp delivered; or, the user did not see the content
    update because it was superseded or its surface destroyed,
    and the content update is discarded.

    Once a presentation_feedback object has delivered a 'presented'
    or 'discarded' event it is automatically destroyed.
    """
    object_id = 0
    version = 2

    class kind(IntFlag):
        """
        Bitmask of flags in presented event

        These flags provide information about how the presentation of
        the related content update was done. The intent is to help
        clients assess the reliability of the feedback and the visual
        quality with respect to possible tearing and timings.
        """

        vsync: int
        """
        Presentation was vsync'd
        The presentation was synchronized to the "vertical retrace" by
        the display hardware such that tearing does not happen.
        Relying on software scheduling is not acceptable for this
        flag. If presentation is done by a copy to the active
        frontbuffer, then it must guarantee that tearing cannot
        happen.
        """

        hw_clock: int
        """
        Hardware provided the presentation timestamp
        The display hardware provided measurements that the hardware
        driver converted into a presentation timestamp. Sampling a
        clock in software is not acceptable for this flag.
        """

        hw_completion: int
        """
        Hardware signalled the start of the presentation
        The display hardware signalled that it started using the new
        image content. The opposite of this is e.g. a timer being used
        to guess when the display hardware has switched to the new
        image content.
        """

        zero_copy: int
        """
        Presentation was done zero-copy
        The presentation of this update was done zero-copy. This means
        the buffer from the client was given to display hardware as
        is, without copying it. Compositing with OpenGL counts as
        copying, even if textured directly from the client buffer.
        Possible zero-copy cases include direct scanout of a
        fullscreen surface and a surface on a hardware overlay.
        """




    def on_sync_output(self, output: wl_output) -> None:
        """
        Presentation synchronized to this output.

        Override to handle [`wayland.wp_presentation_feedback.events.sync_output`][].
        """

        ...

    def on_presented(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int, refresh: int, seq_hi: int, seq_lo: int, flags: wp_presentation_feedback.kind) -> None:
        """
        The content update was displayed.

        Override to handle [`wayland.wp_presentation_feedback.events.presented`][].
        """

        ...

    def on_discarded(self) -> None:
        """
        The content update was not displayed.

        Override to handle [`wayland.wp_presentation_feedback.events.discarded`][].
        """

        ...

    class events(WaylandEvent):
        def sync_output(self, output: wl_output) -> None:
            """
            Presentation synchronized to this output

            As presentation can be synchronized to only one output at a
            time, this event tells which output it was. This event is only
            sent prior to the presented event.

            As clients may bind to the same global wl_output multiple
            times, this event is sent for each bound instance that matches
            the synchronized output. If a client has not bound to the
            right wl_output global at all, this event is not sent.

            Args:
                output: Presentation output
            """

            ...

        def presented(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int, refresh: int, seq_hi: int, seq_lo: int, flags: wp_presentation_feedback.kind) -> None:
            """
            The content update was displayed

            The associated content update was displayed to the user at the
            indicated time (tv_sec_hi/lo, tv_nsec). For the interpretation of
            the timestamp, see presentation.clock_id event.

            The timestamp corresponds to the time when the content update
            turned into light the first time on the surface's main output.
            Compositors may approximate this from the framebuffer flip
            completion events from the system, and the latency of the
            physical display path if known.

            This event is preceded by all related sync_output events
            telling which output's refresh cycle the feedback corresponds
            to, i.e. the main output for the surface. Compositors are
            recommended to choose the output containing the largest part
            of the wl_surface, or keeping the output they previously
            chose. Having a stable presentation output association helps
            clients predict future output refreshes (vblank).

            The 'refresh' argument gives the compositor's prediction of how
            many nanoseconds after tv_sec, tv_nsec the very next output
            refresh may occur. This is to further aid clients in
            predicting future refreshes, i.e., estimating the timestamps
            targeting the next few vblanks. If such prediction cannot
            usefully be done, the argument is zero.

            For version 2 and later, if the output does not have a constant
            refresh rate, explicit video mode switches excluded, then the
            refresh argument must be either an appropriate rate picked by the
            compositor (e.g. fastest rate), or 0 if no such rate exists.
            For version 1, if the output does not have a constant refresh rate,
            the refresh argument must be zero.

            The 64-bit value combined from seq_hi and seq_lo is the value
            of the output's vertical retrace counter when the content
            update was first scanned out to the display. This value must
            be compatible with the definition of MSC in
            GLX_OML_sync_control specification. Note, that if the display
            path has a non-zero latency, the time instant specified by
            this counter may differ from the timestamp's.

            If the output does not have a concept of vertical retrace or a
            refresh cycle, or the output device is self-refreshing without
            a way to query the refresh count, then the arguments seq_hi
            and seq_lo must be zero.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the presentation timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the presentation timestamp
                tv_nsec: Nanoseconds part of the presentation timestamp
                refresh: Nanoseconds till next refresh
                seq_hi: High 32 bits of refresh counter
                seq_lo: Low 32 bits of refresh counter
                flags: Combination of 'kind' values
            """

            ...

        def discarded(self) -> None:
            """
            The content update was not displayed

            The content update was never displayed to the user.
            """

            ...

class zwp_tablet_manager_v2:
    """
    Controller object for graphic tablet devices

    An object that provides access to the graphics tablets available on this
    system. All tablets are associated with a seat, to get access to the
    actual tablets, use wp_tablet_manager.get_tablet_seat.
    """
    object_id = 0
    version = 2


    def get_tablet_seat(self, seat: wl_seat) -> zwp_tablet_seat_v2:
        """
        Get the tablet seat

        Get the wp_tablet_seat object for the given seat. This object
        provides access to all graphics tablets in this seat.

        Args:
            seat: The `wl_seat` object to retrieve the tablets for

        Returns:
            zwp_tablet_seat_v2: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Release the memory for the tablet manager object

        Destroy the wp_tablet_manager object. Objects created from this
        object are unaffected and should be destroyed separately.
        """

        ...

class zwp_tablet_seat_v2:
    """
    Controller object for graphic tablet devices of a seat

    An object that provides access to the graphics tablets available on this
    seat. After binding to this interface, the compositor sends a set of
    wp_tablet_seat.tablet_added and wp_tablet_seat.tool_added events.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """
        Release the memory for the tablet seat object

        Destroy the wp_tablet_seat object. Objects created from this
        object are unaffected and should be destroyed separately.
        """

        ...

    def on_tablet_added(self, id: zwp_tablet_v2) -> None:
        """
        New device notification.

        Override to handle [`wayland.zwp_tablet_seat_v2.events.tablet_added`][].
        """

        ...

    def on_tool_added(self, id: zwp_tablet_tool_v2) -> None:
        """
        A new tool has been used with a tablet.

        Override to handle [`wayland.zwp_tablet_seat_v2.events.tool_added`][].
        """

        ...

    def on_pad_added(self, id: zwp_tablet_pad_v2) -> None:
        """
        New pad notification.

        Override to handle [`wayland.zwp_tablet_seat_v2.events.pad_added`][].
        """

        ...

    class events(WaylandEvent):
        def tablet_added(self, id: zwp_tablet_v2) -> None:
            """
            New device notification

            This event is sent whenever a new tablet becomes available on this
            seat. This event only provides the object id of the tablet, any
            static information about the tablet (device name, vid/pid, etc.) is
            sent through the wp_tablet interface.

            Args:
                id: The newly added graphics tablet
            """

            ...

        def tool_added(self, id: zwp_tablet_tool_v2) -> None:
            """
            A new tool has been used with a tablet

            This event is sent whenever a tool that has not previously been used
            with a tablet comes into use. This event only provides the object id
            of the tool; any static information about the tool (capabilities,
            type, etc.) is sent through the wp_tablet_tool interface.

            Args:
                id: The newly added tablet tool
            """

            ...

        def pad_added(self, id: zwp_tablet_pad_v2) -> None:
            """
            New pad notification

            This event is sent whenever a new pad is known to the system. Typically,
            pads are physically attached to tablets and a pad_added event is
            sent immediately after the wp_tablet_seat.tablet_added.
            However, some standalone pad devices logically attach to tablets at
            runtime, and the client must wait for wp_tablet_pad.enter to know
            the tablet a pad is attached to.

            This event only provides the object id of the pad. All further
            features (buttons, strips, rings) are sent through the wp_tablet_pad
            interface.

            Args:
                id: The newly added pad
            """

            ...

class zwp_tablet_tool_v2:
    """
    A physical tablet tool

    An object that represents a physical tool that has been, or is
    currently in use with a tablet in this seat. Each wp_tablet_tool
    object stays valid until the client destroys it; the compositor
    reuses the wp_tablet_tool object to indicate that the object's
    respective physical tool has come into proximity of a tablet again.

    A wp_tablet_tool object's relation to a physical tool depends on the
    tablet's ability to report serial numbers. If the tablet supports
    this capability, then the object represents a specific physical tool
    and can be identified even when used on multiple tablets.

    A tablet tool has a number of static characteristics, e.g. tool type,
    hardware_serial and capabilities. These capabilities are sent in an
    event sequence after the wp_tablet_seat.tool_added event before any
    actual events from this tool. This initial event sequence is
    terminated by a wp_tablet_tool.done event.

    Tablet tool events are grouped by wp_tablet_tool.frame events.
    Any events received before a wp_tablet_tool.frame event should be
    considered part of the same hardware state change.
    """
    object_id = 0
    version = 2

    class type(Enum):
        """
        A physical tool type

        Describes the physical type of a tool. The physical type of a tool
        generally defines its base usage.

        The mouse tool represents a mouse-shaped tool that is not a relative
        device but bound to the tablet's surface, providing absolute
        coordinates.

        The lens tool is a mouse-shaped tool with an attached lens to
        provide precision focus.
        """

        pen: int
        """Pen"""

        eraser: int
        """Eraser"""

        brush: int
        """Brush"""

        pencil: int
        """Pencil"""

        airbrush: int
        """Airbrush"""

        finger: int
        """Finger"""

        mouse: int
        """Mouse"""

        lens: int
        """Lens"""



    class capability(Enum):
        """
        Capability flags for a tool

        Describes extra capabilities on a tablet.

        Any tool must provide x and y values, extra axes are
        device-specific.
        """

        tilt: int
        """Tilt axes"""

        pressure: int
        """Pressure axis"""

        distance: int
        """Distance axis"""

        rotation: int
        """Z-rotation axis"""

        slider: int
        """Slider axis"""

        wheel: int
        """Wheel axis"""



    class button_state(Enum):
        """
        Physical button state

        Describes the physical state of a button that produced the button event.
        """

        released: int
        """Button is not pressed"""

        pressed: int
        """Button is pressed"""



    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""



    def set_cursor(self, serial: int, surface: wl_surface, hotspot_x: int, hotspot_y: int) -> None:
        """
        Set the tablet tool's surface

        Sets the surface of the cursor used for this tool on the given
        tablet. This request only takes effect if the tool is in proximity
        of one of the requesting client's surfaces or the surface parameter
        is the current pointer surface. If there was a previous surface set
        with this request it is replaced. If surface is NULL, the cursor
        image is hidden.

        The parameters hotspot_x and hotspot_y define the position of the
        pointer surface relative to the pointer location. Its top-left corner
        is always at (x, y) - (hotspot_x, hotspot_y), where (x, y) are the
        coordinates of the pointer location, in surface-local coordinates.

        On surface.attach requests to the pointer surface, hotspot_x and
        hotspot_y are decremented by the x and y parameters passed to the
        request. Attach must be confirmed by wl_surface.commit as usual.

        The hotspot can also be updated by passing the currently set pointer
        surface to this request with new values for hotspot_x and hotspot_y.

        The current and pending input regions of the wl_surface are cleared,
        and wl_surface.set_input_region is ignored until the wl_surface is no
        longer used as the cursor. When the use as a cursor ends, the current
        and pending input regions become undefined, and the wl_surface is
        unmapped.

        This request gives the surface the role of a wp_tablet_tool cursor. A
        surface may only ever be used as the cursor surface for one
        wp_tablet_tool. If the surface already has another role or has
        previously been used as cursor surface for a different tool, a
        protocol error is raised.

        Args:
            serial: Serial of the `proximity_in` event
            hotspot_x: Surface-local x coordinate
            hotspot_y: Surface-local y coordinate
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the tool object

        This destroys the client's resource for this tool object.
        """

        ...

    def on_type(self, tool_type: zwp_tablet_tool_v2.type) -> None:
        """
        Tool type.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.type`][].
        """

        ...

    def on_hardware_serial(self, hardware_serial_hi: int, hardware_serial_lo: int) -> None:
        """
        Unique hardware serial number of the tool.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.hardware_serial`][].
        """

        ...

    def on_hardware_id_wacom(self, hardware_id_hi: int, hardware_id_lo: int) -> None:
        """
        Hardware id notification in wacom's format.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.hardware_id_wacom`][].
        """

        ...

    def on_capability(self, capability: zwp_tablet_tool_v2.capability) -> None:
        """
        Tool capability notification.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.capability`][].
        """

        ...

    def on_done(self) -> None:
        """
        Tool description events sequence complete.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.done`][].
        """

        ...

    def on_removed(self) -> None:
        """
        Tool removed.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.removed`][].
        """

        ...

    def on_proximity_in(self, serial: int, tablet: zwp_tablet_v2, surface: wl_surface) -> None:
        """
        Proximity in event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.proximity_in`][].
        """

        ...

    def on_proximity_out(self) -> None:
        """
        Proximity out event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.proximity_out`][].
        """

        ...

    def on_down(self, serial: int) -> None:
        """
        Tablet tool is making contact.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.down`][].
        """

        ...

    def on_up(self) -> None:
        """
        Tablet tool is no longer making contact.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.up`][].
        """

        ...

    def on_motion(self, x: float, y: float) -> None:
        """
        Motion event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.motion`][].
        """

        ...

    def on_pressure(self, pressure: int) -> None:
        """
        Pressure change event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.pressure`][].
        """

        ...

    def on_distance(self, distance: int) -> None:
        """
        Distance change event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.distance`][].
        """

        ...

    def on_tilt(self, tilt_x: float, tilt_y: float) -> None:
        """
        Tilt change event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.tilt`][].
        """

        ...

    def on_rotation(self, degrees: float) -> None:
        """
        Z-rotation change event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.rotation`][].
        """

        ...

    def on_slider(self, position: int) -> None:
        """
        Slider position change event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.slider`][].
        """

        ...

    def on_wheel(self, degrees: float, clicks: int) -> None:
        """
        Wheel delta event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.wheel`][].
        """

        ...

    def on_button(self, serial: int, button: int, state: zwp_tablet_tool_v2.button_state) -> None:
        """
        Button event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.button`][].
        """

        ...

    def on_frame(self, time: int) -> None:
        """
        Frame event.

        Override to handle [`wayland.zwp_tablet_tool_v2.events.frame`][].
        """

        ...

    class events(WaylandEvent):
        def type(self, tool_type: zwp_tablet_tool_v2.type) -> None:
            """
            Tool type

            The tool type is the high-level type of the tool and usually decides
            the interaction expected from this tool.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                tool_type: The physical tool type
            """

            ...

        def hardware_serial(self, hardware_serial_hi: int, hardware_serial_lo: int) -> None:
            """
            Unique hardware serial number of the tool

            If the physical tool can be identified by a unique 64-bit serial
            number, this event notifies the client of this serial number.

            If multiple tablets are available in the same seat and the tool is
            uniquely identifiable by the serial number, that tool may move
            between tablets.

            Otherwise, if the tool has no serial number and this event is
            missing, the tool is tied to the tablet it first comes into
            proximity with. Even if the physical tool is used on multiple
            tablets, separate wp_tablet_tool objects will be created, one per
            tablet.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                hardware_serial_hi: The unique serial number of the tool, most significant bits
                hardware_serial_lo: The unique serial number of the tool, least significant bits
            """

            ...

        def hardware_id_wacom(self, hardware_id_hi: int, hardware_id_lo: int) -> None:
            """
            Hardware id notification in wacom's format

            This event notifies the client of a hardware id available on this tool.

            The hardware id is a device-specific 64-bit id that provides extra
            information about the tool in use, beyond the wl_tool.type
            enumeration. The format of the id is specific to tablets made by
            Wacom Inc. For example, the hardware id of a Wacom Grip
            Pen (a stylus) is 0x802.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                hardware_id_hi: The hardware id, most significant bits
                hardware_id_lo: The hardware id, least significant bits
            """

            ...

        def capability(self, capability: zwp_tablet_tool_v2.capability) -> None:
            """
            Tool capability notification

            This event notifies the client of any capabilities of this tool,
            beyond the main set of x/y axes and tip up/down detection.

            One event is sent for each extra capability available on this tool.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                capability: The capability
            """

            ...

        def done(self) -> None:
            """
            Tool description events sequence complete

            This event signals the end of the initial burst of descriptive
            events. A client may consider the static description of the tool to
            be complete and finalize initialization of the tool.
            """

            ...

        def removed(self) -> None:
            """
            Tool removed

            This event is sent when the tool is removed from the system and will
            send no further events. Should the physical tool come back into
            proximity later, a new wp_tablet_tool object will be created.

            It is compositor-dependent when a tool is removed. A compositor may
            remove a tool on proximity out, tablet removal or any other reason.
            A compositor may also keep a tool alive until shutdown.

            If the tool is currently in proximity, a proximity_out event will be
            sent before the removed event. See wp_tablet_tool.proximity_out for
            the handling of any buttons logically down.

            When this event is received, the client must wp_tablet_tool.destroy
            the object.
            """

            ...

        def proximity_in(self, serial: int, tablet: zwp_tablet_v2, surface: wl_surface) -> None:
            """
            Proximity in event

            Notification that this tool is focused on a certain surface.

            This event can be received when the tool has moved from one surface to
            another, or when the tool has come back into proximity above the
            surface.

            If any button is logically down when the tool comes into proximity,
            the respective button event is sent after the proximity_in event but
            within the same frame as the proximity_in event.

            Args:
                tablet: The tablet the tool is in proximity of
                surface: The current surface the tablet tool is over
            """

            ...

        def proximity_out(self) -> None:
            """
            Proximity out event

            Notification that this tool has either left proximity, or is no
            longer focused on a certain surface.

            When the tablet tool leaves proximity of the tablet, button release
            events are sent for each button that was held down at the time of
            leaving proximity. These events are sent before the proximity_out
            event but within the same wp_tablet.frame.

            If the tool stays within proximity of the tablet, but the focus
            changes from one surface to another, a button release event may not
            be sent until the button is actually released or the tool leaves the
            proximity of the tablet.
            """

            ...

        def down(self, serial: int) -> None:
            """
            Tablet tool is making contact

            Sent whenever the tablet tool comes in contact with the surface of the
            tablet.

            If the tool is already in contact with the tablet when entering the
            input region, the client owning said region will receive a
            wp_tablet.proximity_in event, followed by a wp_tablet.down
            event and a wp_tablet.frame event.

            Note that this event describes logical contact, not physical
            contact. On some devices, a compositor may not consider a tool in
            logical contact until a minimum physical pressure threshold is
            exceeded.
            """

            ...

        def up(self) -> None:
            """
            Tablet tool is no longer making contact

            Sent whenever the tablet tool stops making contact with the surface of
            the tablet, or when the tablet tool moves out of the input region
            and the compositor grab (if any) is dismissed.

            If the tablet tool moves out of the input region while in contact
            with the surface of the tablet and the compositor does not have an
            ongoing grab on the surface, the client owning said region will
            receive a wp_tablet.up event, followed by a wp_tablet.proximity_out
            event and a wp_tablet.frame event. If the compositor has an ongoing
            grab on this device, this event sequence is sent whenever the grab
            is dismissed in the future.

            Note that this event describes logical contact, not physical
            contact. On some devices, a compositor may not consider a tool out
            of logical contact until physical pressure falls below a specific
            threshold.
            """

            ...

        def motion(self, x: float, y: float) -> None:
            """
            Motion event

            Sent whenever a tablet tool moves.

            Args:
                x: Surface-local x coordinate
                y: Surface-local y coordinate
            """

            ...

        def pressure(self, pressure: int) -> None:
            """
            Pressure change event

            Sent whenever the pressure axis on a tool changes. The value of this
            event is normalized to a value between 0 and 65535.

            Note that pressure may be nonzero even when a tool is not in logical
            contact. See the down and up events for more details.

            Args:
                pressure: The current pressure value
            """

            ...

        def distance(self, distance: int) -> None:
            """
            Distance change event

            Sent whenever the distance axis on a tool changes. The value of this
            event is normalized to a value between 0 and 65535.

            Note that distance may be nonzero even when a tool is not in logical
            contact. See the down and up events for more details.

            Args:
                distance: The current distance value
            """

            ...

        def tilt(self, tilt_x: float, tilt_y: float) -> None:
            """
            Tilt change event

            Sent whenever one or both of the tilt axes on a tool change. Each tilt
            value is in degrees, relative to the z-axis of the tablet.
            The angle is positive when the top of a tool tilts along the
            positive x or y axis.

            Args:
                tilt_x: The current value of the x tilt axis
                tilt_y: The current value of the y tilt axis
            """

            ...

        def rotation(self, degrees: float) -> None:
            """
            Z-rotation change event

            Sent whenever the z-rotation axis on the tool changes. The
            rotation value is in degrees clockwise from the tool's
            logical neutral position.

            Args:
                degrees: The current rotation of the z axis
            """

            ...

        def slider(self, position: int) -> None:
            """
            Slider position change event

            Sent whenever the slider position on the tool changes. The
            value is normalized between -65535 and 65535, with 0 as the logical
            neutral position of the slider.

            The slider is available on e.g. the Wacom Airbrush tool.

            Args:
                position: The current position of slider
            """

            ...

        def wheel(self, degrees: float, clicks: int) -> None:
            """
            Wheel delta event

            Sent whenever the wheel on the tool emits an event. This event
            contains two values for the same axis change. The degrees value is
            in the same orientation as the wl_pointer.vertical_scroll axis. The
            clicks value is in discrete logical clicks of the mouse wheel. This
            value may be zero if the movement of the wheel was less
            than one logical click.

            Clients should choose either value and avoid mixing degrees and
            clicks. The compositor may accumulate values smaller than a logical
            click and emulate click events when a certain threshold is met.
            Thus, wl_tablet_tool.wheel events with non-zero clicks values may
            have different degrees values.

            Args:
                degrees: The wheel delta in degrees
                clicks: The wheel delta in discrete clicks
            """

            ...

        def button(self, serial: int, button: int, state: zwp_tablet_tool_v2.button_state) -> None:
            """
            Button event

            Sent whenever a button on the tool is pressed or released.

            If a button is held down when the tool moves in or out of proximity,
            button events are generated by the compositor. See
            wp_tablet_tool.proximity_in and wp_tablet_tool.proximity_out for
            details.

            Args:
                button: The button whose state has changed
                state: Whether the button was pressed or released
            """

            ...

        def frame(self, time: int) -> None:
            """
            Frame event

            Marks the end of a series of axis and/or button updates from the
            tablet. The Wayland protocol requires axis updates to be sent
            sequentially, however all events within a frame should be considered
            one hardware event.

            Args:
                time: The time of the event with millisecond granularity
            """

            ...

class zwp_tablet_v2:
    """
    Graphics tablet device

    The wp_tablet interface represents one graphics tablet device. The
    tablet interface itself does not generate events; all events are
    generated by wp_tablet_tool objects when in proximity above a tablet.

    A tablet has a number of static characteristics, e.g. device name and
    pid/vid. These capabilities are sent in an event sequence after the
    wp_tablet_seat.tablet_added event. This initial event sequence is
    terminated by a wp_tablet.done event.
    """
    object_id = 0
    version = 2

    class bustype(Enum):
        """
        Bus type

        Describes the bus types this tablet is connected to.
        """

        usb: int
        """Usb"""

        bluetooth: int
        """Bluetooth"""

        virtual: int
        """Virtual"""

        serial: int
        """Serial"""

        i2c: int
        """I2c"""



    def destroy(self) -> None:
        """
        Destroy the tablet object

        This destroys the client's resource for this tablet object.
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Tablet device name.

        Override to handle [`wayland.zwp_tablet_v2.events.name`][].
        """

        ...

    def on_id(self, vid: int, pid: int) -> None:
        """
        Tablet device vendor/product id.

        Override to handle [`wayland.zwp_tablet_v2.events.id`][].
        """

        ...

    def on_path(self, path: str) -> None:
        """
        Path to the device.

        Override to handle [`wayland.zwp_tablet_v2.events.path`][].
        """

        ...

    def on_done(self) -> None:
        """
        Tablet description events sequence complete.

        Override to handle [`wayland.zwp_tablet_v2.events.done`][].
        """

        ...

    def on_removed(self) -> None:
        """
        Tablet removed event.

        Override to handle [`wayland.zwp_tablet_v2.events.removed`][].
        """

        ...

    def on_bustype(self, bustype: zwp_tablet_v2.bustype) -> None:
        """
        Tablet device bus type.

        Override to handle [`wayland.zwp_tablet_v2.events.bustype`][].
        """

        ...

    class events(WaylandEvent):
        def name(self, name: str) -> None:
            """
            Tablet device name

            A descriptive name for the tablet device.

            	If the device has no descriptive name, this event is not sent.

            	This event is sent in the initial burst of events before the
                    wp_tablet.done event.

            Args:
                name: The device name
            """

            ...

        def id(self, vid: int, pid: int) -> None:
            """
            Tablet device vendor/product id

            The vendor and product IDs for the tablet device.

            The interpretation of the id depends on the wp_tablet.bustype.
            Prior to version v2 of this protocol, the id was implied to be a USB
            vendor and product ID. If no wp_tablet.bustype is sent, the ID
            is to be interpreted as USB vendor and product ID.

            If the device has no vendor/product ID, this event is not sent.
            This can happen for virtual devices or non-USB devices, for instance.

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                vid: Vendor id
                pid: Product id
            """

            ...

        def path(self, path: str) -> None:
            """
            Path to the device

            A system-specific device path that indicates which device is behind
            this wp_tablet. This information may be used to gather additional
            information about the device, e.g. through libwacom.

            A device may have more than one device path. If so, multiple
            wp_tablet.path events are sent. A device may be emulated and not
            have a device path, and in that case this event will not be sent.

            The format of the path is unspecified, it may be a device node, a
            sysfs path, or some other identifier. It is up to the client to
            identify the string provided.

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                path: Path to local device
            """

            ...

        def done(self) -> None:
            """
            Tablet description events sequence complete

            This event is sent immediately to signal the end of the initial
            burst of descriptive events. A client may consider the static
            description of the tablet to be complete and finalize initialization
            of the tablet.
            """

            ...

        def removed(self) -> None:
            """
            Tablet removed event

            Sent when the tablet has been removed from the system. When a tablet
            is removed, some tools may be removed.

            When this event is received, the client must wp_tablet.destroy
            the object.
            """

            ...

        def bustype(self, bustype: zwp_tablet_v2.bustype) -> None:
            """
            Tablet device bus type

            The bustype argument is one of the BUS_ defines in the Linux kernel's
            linux/input.h

            If the device has no known bustype or the bustype cannot be
            queried, this event is not sent.

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                bustype: Bus type
            """

            ...

class zwp_tablet_pad_ring_v2:
    """
    Pad ring

    A circular interaction area, such as the touch ring on the Wacom Intuos
    Pro series tablets.

    Events on a ring are logically grouped by the wl_tablet_pad_ring.frame
    event.
    """
    object_id = 0
    version = 2

    class source(Enum):
        """
        Ring axis source

        Describes the source types for ring events. This indicates to the
        client how a ring event was physically generated; a client may
        adjust the user interface accordingly. For example, events
        from a "finger" source may trigger kinetic scrolling.
        """

        finger: int
        """Finger"""



    def set_feedback(self, description: str, serial: int) -> None:
        """
        Set compositor feedback

        Request that the compositor use the provided feedback string
        associated with this ring. This request should be issued immediately
        after a wp_tablet_pad_group.mode_switch event from the corresponding
        group is received, or whenever the ring is mapped to a different
        action. See wp_tablet_pad_group.mode_switch for more details.

        Clients are encouraged to provide context-aware descriptions for
        the actions associated with the ring; compositors may use this
        information to offer visual feedback about the button layout
        (eg. on-screen displays).

        The provided string 'description' is a UTF-8 encoded string to be
        associated with this ring, and is considered user-visible; general
        internationalization rules apply.

        The serial argument will be that of the last
        wp_tablet_pad_group.mode_switch event received for the group of this
        ring. Requests providing other serials than the most recent one will be
        ignored.

        Args:
            description: Ring description
            serial: Serial of the mode switch event
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the ring object

        This destroys the client's resource for this ring object.
        """

        ...

    def on_source(self, source: zwp_tablet_pad_ring_v2.source) -> None:
        """
        Ring event source.

        Override to handle [`wayland.zwp_tablet_pad_ring_v2.events.source`][].
        """

        ...

    def on_angle(self, degrees: float) -> None:
        """
        Angle changed.

        Override to handle [`wayland.zwp_tablet_pad_ring_v2.events.angle`][].
        """

        ...

    def on_stop(self) -> None:
        """
        Interaction stopped.

        Override to handle [`wayland.zwp_tablet_pad_ring_v2.events.stop`][].
        """

        ...

    def on_frame(self, time: int) -> None:
        """
        End of a ring event sequence.

        Override to handle [`wayland.zwp_tablet_pad_ring_v2.events.frame`][].
        """

        ...

    class events(WaylandEvent):
        def source(self, source: zwp_tablet_pad_ring_v2.source) -> None:
            """
            Ring event source

            Source information for ring events.

            This event does not occur on its own. It is sent before a
            wp_tablet_pad_ring.frame event and carries the source information
            for all events within that frame.

            The source specifies how this event was generated. If the source is
            wp_tablet_pad_ring.source.finger, a wp_tablet_pad_ring.stop event
            will be sent when the user lifts the finger off the device.

            This event is optional. If the source is unknown for an interaction,
            no event is sent.

            Args:
                source: The event source
            """

            ...

        def angle(self, degrees: float) -> None:
            """
            Angle changed

            Sent whenever the angle on a ring changes.

            The angle is provided in degrees clockwise from the logical
            north of the ring in the pad's current rotation.

            Args:
                degrees: The current angle in degrees
            """

            ...

        def stop(self) -> None:
            """
            Interaction stopped

            Stop notification for ring events.

            For some wp_tablet_pad_ring.source types, a wp_tablet_pad_ring.stop
            event is sent to notify a client that the interaction with the ring
            has terminated. This enables the client to implement kinetic scrolling.
            See the wp_tablet_pad_ring.source documentation for information on
            when this event may be generated.

            Any wp_tablet_pad_ring.angle events with the same source after this
            event should be considered as the start of a new interaction.
            """

            ...

        def frame(self, time: int) -> None:
            """
            End of a ring event sequence

            Indicates the end of a set of ring events that logically belong
            together. A client is expected to accumulate the data in all events
            within the frame before proceeding.

            All wp_tablet_pad_ring events before a wp_tablet_pad_ring.frame event belong
            logically together. For example, on termination of a finger interaction
            on a ring the compositor will send a wp_tablet_pad_ring.source event,
            a wp_tablet_pad_ring.stop event and a wp_tablet_pad_ring.frame event.

            A wp_tablet_pad_ring.frame event is sent for every logical event
            group, even if the group only contains a single wp_tablet_pad_ring
            event. Specifically, a client may get a sequence: angle, frame,
            angle, frame, etc.

            Args:
                time: Timestamp with millisecond granularity
            """

            ...

class zwp_tablet_pad_strip_v2:
    """
    Pad strip

    A linear interaction area, such as the strips found in Wacom Cintiq
    models.

    Events on a strip are logically grouped by the wl_tablet_pad_strip.frame
    event.
    """
    object_id = 0
    version = 2

    class source(Enum):
        """
        Strip axis source

        Describes the source types for strip events. This indicates to the
        client how a strip event was physically generated; a client may
        adjust the user interface accordingly. For example, events
        from a "finger" source may trigger kinetic scrolling.
        """

        finger: int
        """Finger"""



    def set_feedback(self, description: str, serial: int) -> None:
        """
        Set compositor feedback

        Requests the compositor to use the provided feedback string
        associated with this strip. This request should be issued immediately
        after a wp_tablet_pad_group.mode_switch event from the corresponding
        group is received, or whenever the strip is mapped to a different
        action. See wp_tablet_pad_group.mode_switch for more details.

        Clients are encouraged to provide context-aware descriptions for
        the actions associated with the strip, and compositors may use this
        information to offer visual feedback about the button layout
        (eg. on-screen displays).

        The provided string 'description' is a UTF-8 encoded string to be
        associated with this ring, and is considered user-visible; general
        internationalization rules apply.

        The serial argument will be that of the last
        wp_tablet_pad_group.mode_switch event received for the group of this
        strip. Requests providing other serials than the most recent one will be
        ignored.

        Args:
            description: Strip description
            serial: Serial of the mode switch event
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the strip object

        This destroys the client's resource for this strip object.
        """

        ...

    def on_source(self, source: zwp_tablet_pad_strip_v2.source) -> None:
        """
        Strip event source.

        Override to handle [`wayland.zwp_tablet_pad_strip_v2.events.source`][].
        """

        ...

    def on_position(self, position: int) -> None:
        """
        Position changed.

        Override to handle [`wayland.zwp_tablet_pad_strip_v2.events.position`][].
        """

        ...

    def on_stop(self) -> None:
        """
        Interaction stopped.

        Override to handle [`wayland.zwp_tablet_pad_strip_v2.events.stop`][].
        """

        ...

    def on_frame(self, time: int) -> None:
        """
        End of a strip event sequence.

        Override to handle [`wayland.zwp_tablet_pad_strip_v2.events.frame`][].
        """

        ...

    class events(WaylandEvent):
        def source(self, source: zwp_tablet_pad_strip_v2.source) -> None:
            """
            Strip event source

            Source information for strip events.

            This event does not occur on its own. It is sent before a
            wp_tablet_pad_strip.frame event and carries the source information
            for all events within that frame.

            The source specifies how this event was generated. If the source is
            wp_tablet_pad_strip.source.finger, a wp_tablet_pad_strip.stop event
            will be sent when the user lifts their finger off the device.

            This event is optional. If the source is unknown for an interaction,
            no event is sent.

            Args:
                source: The event source
            """

            ...

        def position(self, position: int) -> None:
            """
            Position changed

            Sent whenever the position on a strip changes.

            The position is normalized to a range of [0, 65535], the 0-value
            represents the top-most and/or left-most position of the strip in
            the pad's current rotation.

            Args:
                position: The current position
            """

            ...

        def stop(self) -> None:
            """
            Interaction stopped

            Stop notification for strip events.

            For some wp_tablet_pad_strip.source types, a wp_tablet_pad_strip.stop
            event is sent to notify a client that the interaction with the strip
            has terminated. This enables the client to implement kinetic
            scrolling. See the wp_tablet_pad_strip.source documentation for
            information on when this event may be generated.

            Any wp_tablet_pad_strip.position events with the same source after this
            event should be considered as the start of a new interaction.
            """

            ...

        def frame(self, time: int) -> None:
            """
            End of a strip event sequence

            Indicates the end of a set of events that represent one logical
            hardware strip event. A client is expected to accumulate the data
            in all events within the frame before proceeding.

            All wp_tablet_pad_strip events before a wp_tablet_pad_strip.frame event belong
            logically together. For example, on termination of a finger interaction
            on a strip the compositor will send a wp_tablet_pad_strip.source event,
            a wp_tablet_pad_strip.stop event and a wp_tablet_pad_strip.frame
            event.

            A wp_tablet_pad_strip.frame event is sent for every logical event
            group, even if the group only contains a single wp_tablet_pad_strip
            event. Specifically, a client may get a sequence: position, frame,
            position, frame, etc.

            Args:
                time: Timestamp with millisecond granularity
            """

            ...

class zwp_tablet_pad_group_v2:
    """
    A set of buttons, rings and strips

    A pad group describes a distinct (sub)set of buttons, rings and strips
    present in the tablet. The criteria of this grouping is usually positional,
    eg. if a tablet has buttons on the left and right side, 2 groups will be
    presented. The physical arrangement of groups is undisclosed and may
    change on the fly.

    Pad groups will announce their features during pad initialization. Between
    the corresponding wp_tablet_pad.group event and wp_tablet_pad_group.done, the
    pad group will announce the buttons, rings and strips contained in it,
    plus the number of supported modes.

    Modes are a mechanism to allow multiple groups of actions for every element
    in the pad group. The number of groups and available modes in each is
    persistent across device plugs. The current mode is user-switchable, it
    will be announced through the wp_tablet_pad_group.mode_switch event both
    whenever it is switched, and after wp_tablet_pad.enter.

    The current mode logically applies to all elements in the pad group,
    although it is at clients' discretion whether to actually perform different
    actions, and/or issue the respective .set_feedback requests to notify the
    compositor. See the wp_tablet_pad_group.mode_switch event for more details.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """
        Destroy the pad object

        Destroy the wp_tablet_pad_group object. Objects created from this object
        are unaffected and should be destroyed separately.
        """

        ...

    def on_buttons(self, buttons: list) -> None:
        """
        Buttons announced.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.buttons`][].
        """

        ...

    def on_ring(self, ring: zwp_tablet_pad_ring_v2) -> None:
        """
        Ring announced.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.ring`][].
        """

        ...

    def on_strip(self, strip: zwp_tablet_pad_strip_v2) -> None:
        """
        Strip announced.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.strip`][].
        """

        ...

    def on_modes(self, modes: int) -> None:
        """
        Mode-switch ability announced.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.modes`][].
        """

        ...

    def on_done(self) -> None:
        """
        Tablet group description events sequence complete.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.done`][].
        """

        ...

    def on_mode_switch(self, time: int, serial: int, mode: int) -> None:
        """
        Mode switch event.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.mode_switch`][].
        """

        ...

    def on_dial(self, dial: zwp_tablet_pad_dial_v2) -> None:
        """
        Dial announced.

        Override to handle [`wayland.zwp_tablet_pad_group_v2.events.dial`][].
        """

        ...

    class events(WaylandEvent):
        def buttons(self, buttons: list) -> None:
            """
            Buttons announced

            Sent on wp_tablet_pad_group initialization to announce the available
            buttons in the group. Button indices start at 0, a button may only be
            in one group at a time.

            This event is first sent in the initial burst of events before the
            wp_tablet_pad_group.done event.

            Some buttons are reserved by the compositor. These buttons may not be
            assigned to any wp_tablet_pad_group. Compositors may broadcast this
            event in the case of changes to the mapping of these reserved buttons.
            If the compositor happens to reserve all buttons in a group, this event
            will be sent with an empty array.

            Args:
                buttons: Buttons in this group
            """

            ...

        def ring(self, ring: zwp_tablet_pad_ring_v2) -> None:
            """
            Ring announced

            Sent on wp_tablet_pad_group initialization to announce available rings.
            One event is sent for each ring available on this pad group.

            This event is sent in the initial burst of events before the
            wp_tablet_pad_group.done event.
            """

            ...

        def strip(self, strip: zwp_tablet_pad_strip_v2) -> None:
            """
            Strip announced

            Sent on wp_tablet_pad initialization to announce available strips.
            One event is sent for each strip available on this pad group.

            This event is sent in the initial burst of events before the
            wp_tablet_pad_group.done event.
            """

            ...

        def modes(self, modes: int) -> None:
            """
            Mode-switch ability announced

            Sent on wp_tablet_pad_group initialization to announce that the pad
            group may switch between modes. A client may use a mode to store a
            specific configuration for buttons, rings and strips and use the
            wl_tablet_pad_group.mode_switch event to toggle between these
            configurations. Mode indices start at 0.

            Switching modes is compositor-dependent. See the
            wp_tablet_pad_group.mode_switch event for more details.

            This event is sent in the initial burst of events before the
            wp_tablet_pad_group.done event. This event is only sent when more than
            more than one mode is available.

            Args:
                modes: The number of modes
            """

            ...

        def done(self) -> None:
            """
            Tablet group description events sequence complete

            This event is sent immediately to signal the end of the initial
            burst of descriptive events. A client may consider the static
            description of the tablet to be complete and finalize initialization
            of the tablet group.
            """

            ...

        def mode_switch(self, time: int, serial: int, mode: int) -> None:
            """
            Mode switch event

            Notification that the mode was switched.

            A mode applies to all buttons, rings, strips and dials in a group
            simultaneously, but a client is not required to assign different actions
            for each mode. For example, a client may have mode-specific button
            mappings but map the ring to vertical scrolling in all modes. Mode
            indices start at 0.

            Switching modes is compositor-dependent. The compositor may provide
            visual cues to the user about the mode, e.g. by toggling LEDs on
            the tablet device. Mode-switching may be software-controlled or
            controlled by one or more physical buttons. For example, on a Wacom
            Intuos Pro, the button inside the ring may be assigned to switch
            between modes.

            The compositor will also send this event after wp_tablet_pad.enter on
            each group in order to notify of the current mode. Groups that only
            feature one mode will use mode=0 when emitting this event.

            If a button action in the new mode differs from the action in the
            previous mode, the client should immediately issue a
            wp_tablet_pad.set_feedback request for each changed button.

            If a ring, strip or dial action in the new mode differs from the action
            in the previous mode, the client should immediately issue a
            wp_tablet_ring.set_feedback, wp_tablet_strip.set_feedback or
            wp_tablet_dial.set_feedback request for each changed ring, strip or dial.

            Args:
                time: The time of the event with millisecond granularity
                mode: The new mode of the pad
            """

            ...

        def dial(self, dial: zwp_tablet_pad_dial_v2) -> None:
            """
            Dial announced

            Sent on wp_tablet_pad initialization to announce available dials.
            One event is sent for each dial available on this pad group.

            This event is sent in the initial burst of events before the
            wp_tablet_pad_group.done event.
            """

            ...

class zwp_tablet_pad_v2:
    """
    A set of buttons, rings, strips and dials

    A pad device is a set of buttons, rings, strips and dials
    usually physically present on the tablet device itself. Some
    exceptions exist where the pad device is physically detached, e.g. the
    Wacom ExpressKey Remote.

    Pad devices have no axes that control the cursor and are generally
    auxiliary devices to the tool devices used on the tablet surface.

    A pad device has a number of static characteristics, e.g. the number
    of rings. These capabilities are sent in an event sequence after the
    wp_tablet_seat.pad_added event before any actual events from this pad.
    This initial event sequence is terminated by a wp_tablet_pad.done
    event.

    All pad features (buttons, rings, strips and dials) are logically divided into
    groups and all pads have at least one group. The available groups are
    notified through the wp_tablet_pad.group event; the compositor will
    emit one event per group before emitting wp_tablet_pad.done.

    Groups may have multiple modes. Modes allow clients to map multiple
    actions to a single pad feature. Only one mode can be active per group,
    although different groups may have different active modes.
    """
    object_id = 0
    version = 2

    class button_state(Enum):
        """
        Physical button state

        Describes the physical state of a button that caused the button
        event.
        """

        released: int
        """The button is not pressed"""

        pressed: int
        """The button is pressed"""



    def set_feedback(self, button: int, description: str, serial: int) -> None:
        """
        Set compositor feedback

        Requests the compositor to use the provided feedback string
        associated with this button. This request should be issued immediately
        after a wp_tablet_pad_group.mode_switch event from the corresponding
        group is received, or whenever a button is mapped to a different
        action. See wp_tablet_pad_group.mode_switch for more details.

        Clients are encouraged to provide context-aware descriptions for
        the actions associated with each button, and compositors may use
        this information to offer visual feedback on the button layout
        (e.g. on-screen displays).

        Button indices start at 0. Setting the feedback string on a button
        that is reserved by the compositor (i.e. not belonging to any
        wp_tablet_pad_group) does not generate an error but the compositor
        is free to ignore the request.

        The provided string 'description' is a UTF-8 encoded string to be
        associated with this ring, and is considered user-visible; general
        internationalization rules apply.

        The serial argument will be that of the last
        wp_tablet_pad_group.mode_switch event received for the group of this
        button. Requests providing other serials than the most recent one will
        be ignored.

        Args:
            button: Button index
            description: Button description
            serial: Serial of the mode switch event
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the pad object

        Destroy the wp_tablet_pad object. Objects created from this object
        are unaffected and should be destroyed separately.
        """

        ...

    def on_group(self, pad_group: zwp_tablet_pad_group_v2) -> None:
        """
        Group announced.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.group`][].
        """

        ...

    def on_path(self, path: str) -> None:
        """
        Path to the device.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.path`][].
        """

        ...

    def on_buttons(self, buttons: int) -> None:
        """
        Buttons announced.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.buttons`][].
        """

        ...

    def on_done(self) -> None:
        """
        Pad description event sequence complete.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.done`][].
        """

        ...

    def on_button(self, time: int, button: int, state: zwp_tablet_pad_v2.button_state) -> None:
        """
        Physical button state.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.button`][].
        """

        ...

    def on_enter(self, serial: int, tablet: zwp_tablet_v2, surface: wl_surface) -> None:
        """
        Enter event.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.enter`][].
        """

        ...

    def on_leave(self, serial: int, surface: wl_surface) -> None:
        """
        Leave event.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.leave`][].
        """

        ...

    def on_removed(self) -> None:
        """
        Pad removed event.

        Override to handle [`wayland.zwp_tablet_pad_v2.events.removed`][].
        """

        ...

    class events(WaylandEvent):
        def group(self, pad_group: zwp_tablet_pad_group_v2) -> None:
            """
            Group announced

            Sent on wp_tablet_pad initialization to announce available groups.
            One event is sent for each pad group available.

            This event is sent in the initial burst of events before the
            wp_tablet_pad.done event. At least one group will be announced.
            """

            ...

        def path(self, path: str) -> None:
            """
            Path to the device

            A system-specific device path that indicates which device is behind
            this wp_tablet_pad. This information may be used to gather additional
            information about the device, e.g. through libwacom.

            The format of the path is unspecified, it may be a device node, a
            sysfs path, or some other identifier. It is up to the client to
            identify the string provided.

            This event is sent in the initial burst of events before the
            wp_tablet_pad.done event.

            Args:
                path: Path to local device
            """

            ...

        def buttons(self, buttons: int) -> None:
            """
            Buttons announced

            Sent on wp_tablet_pad initialization to announce the available
            buttons.

            This event is sent in the initial burst of events before the
            wp_tablet_pad.done event. This event is only sent when at least one
            button is available.

            Args:
                buttons: The number of buttons
            """

            ...

        def done(self) -> None:
            """
            Pad description event sequence complete

            This event signals the end of the initial burst of descriptive
            events. A client may consider the static description of the pad to
            be complete and finalize initialization of the pad.
            """

            ...

        def button(self, time: int, button: int, state: zwp_tablet_pad_v2.button_state) -> None:
            """
            Physical button state

            Sent whenever the physical state of a button changes.

            Args:
                time: The time of the event with millisecond granularity
                button: The index of the button that changed state
            """

            ...

        def enter(self, serial: int, tablet: zwp_tablet_v2, surface: wl_surface) -> None:
            """
            Enter event

            Notification that this pad is focused on the specified surface.

            Args:
                serial: Serial number of the enter event
                tablet: The tablet the pad is attached to
                surface: Surface the pad is focused on
            """

            ...

        def leave(self, serial: int, surface: wl_surface) -> None:
            """
            Leave event

            Notification that this pad is no longer focused on the specified
            surface.

            Args:
                serial: Serial number of the leave event
                surface: Surface the pad is no longer focused on
            """

            ...

        def removed(self) -> None:
            """
            Pad removed event

            Sent when the pad has been removed from the system. When a tablet
            is removed its pad(s) will be removed too.

            When this event is received, the client must destroy all rings, strips
            and groups that were offered by this pad, and issue wp_tablet_pad.destroy
            the pad itself.
            """

            ...

class zwp_tablet_pad_dial_v2:
    """
    Pad dial

    A rotary control, e.g. a dial or a wheel.

    Events on a dial are logically grouped by the wl_tablet_pad_dial.frame
    event.
    """
    object_id = 0
    version = 2


    def set_feedback(self, description: str, serial: int) -> None:
        """
        Set compositor feedback

        Requests the compositor to use the provided feedback string
        associated with this dial. This request should be issued immediately
        after a wp_tablet_pad_group.mode_switch event from the corresponding
        group is received, or whenever the dial is mapped to a different
        action. See wp_tablet_pad_group.mode_switch for more details.

        Clients are encouraged to provide context-aware descriptions for
        the actions associated with the dial, and compositors may use this
        information to offer visual feedback about the button layout
        (eg. on-screen displays).

        The provided string 'description' is a UTF-8 encoded string to be
        associated with this ring, and is considered user-visible; general
        internationalization rules apply.

        The serial argument will be that of the last
        wp_tablet_pad_group.mode_switch event received for the group of this
        dial. Requests providing other serials than the most recent one will be
        ignored.

        Args:
            description: Dial description
            serial: Serial of the mode switch event
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the dial object

        This destroys the client's resource for this dial object.
        """

        ...

    def on_delta(self, value120: int) -> None:
        """
        Delta movement.

        Override to handle [`wayland.zwp_tablet_pad_dial_v2.events.delta`][].
        """

        ...

    def on_frame(self, time: int) -> None:
        """
        End of a dial event sequence.

        Override to handle [`wayland.zwp_tablet_pad_dial_v2.events.frame`][].
        """

        ...

    class events(WaylandEvent):
        def delta(self, value120: int) -> None:
            """
            Delta movement

            Sent whenever the position on a dial changes.

            This event carries the wheel delta as multiples or fractions
            of 120 with each multiple of 120 representing one logical wheel detent.
            For example, an axis_value120 of 30 is one quarter of
            a logical wheel step in the positive direction, a value120 of
            -240 are two logical wheel steps in the negative direction within the
            same hardware event. See the wl_pointer.axis_value120 for more details.

            The value120 must not be zero.

            Args:
                value120: Rotation distance as fraction of 120
            """

            ...

        def frame(self, time: int) -> None:
            """
            End of a dial event sequence

            Indicates the end of a set of events that represent one logical
            hardware dial event. A client is expected to accumulate the data
            in all events within the frame before proceeding.

            All wp_tablet_pad_dial events before a wp_tablet_pad_dial.frame event belong
            logically together.

            A wp_tablet_pad_dial.frame event is sent for every logical event
            group, even if the group only contains a single wp_tablet_pad_dial
            event. Specifically, a client may get a sequence: delta, frame,
            delta, frame, etc.

            Args:
                time: Timestamp with millisecond granularity
            """

            ...

class wp_viewporter:
    """
    Surface cropping and scaling

    The global interface exposing surface cropping and scaling
    capabilities is used to instantiate an interface extension for a
    wl_surface object. This extended interface will then allow
    cropping and scaling the surface contents, effectively
    disconnecting the direct relationship between the buffer and the
    surface size.
    """
    object_id = 0
    version = 1

    class error(Enum):
        viewport_exists: int
        """The surface already has a viewport object associated"""



    def destroy(self) -> None:
        """
        Unbind from the cropping and scaling interface

        Informs the server that the client will not be using this
        protocol object anymore. This does not affect any other objects,
        wp_viewport objects included.
        """

        ...

    def get_viewport(self, surface: wl_surface) -> wp_viewport:
        """
        Extend surface interface for crop and scale

        Instantiate an interface extension for the given wl_surface to
        crop and scale its content. If the given wl_surface already has
        a wp_viewport object associated, the viewport_exists
        protocol error is raised.

        Args:
            surface: The surface

        Returns:
            wp_viewport: The created object
        """

        ...

class wp_viewport:
    """
    Crop and scale interface to a `wl_surface`

    An additional interface to a wl_surface object, which allows the
    client to specify the cropping and scaling of the surface
    contents.

    This interface works with two concepts: the source rectangle (src_x,
    src_y, src_width, src_height), and the destination size (dst_width,
    dst_height). The contents of the source rectangle are scaled to the
    destination size, and content outside the source rectangle is ignored.
    This state is double-buffered, see wl_surface.commit.

    The two parts of crop and scale state are independent: the source
    rectangle, and the destination size. Initially both are unset, that
    is, no scaling is applied. The whole of the current wl_buffer is
    used as the source, and the surface size is as defined in
    wl_surface.attach.

    If the destination size is set, it causes the surface size to become
    dst_width, dst_height. The source (rectangle) is scaled to exactly
    this size. This overrides whatever the attached wl_buffer size is,
    unless the wl_buffer is NULL. If the wl_buffer is NULL, the surface
    has no content and therefore no size. Otherwise, the size is always
    at least 1x1 in surface local coordinates.

    If the source rectangle is set, it defines what area of the wl_buffer is
    taken as the source. If the source rectangle is set and the destination
    size is not set, then src_width and src_height must be integers, and the
    surface size becomes the source rectangle size. This results in cropping
    without scaling. If src_width or src_height are not integers and
    destination size is not set, the bad_size protocol error is raised when
    the surface state is applied.

    The coordinate transformations from buffer pixel coordinates up to
    the surface-local coordinates happen in the following order:
      1. buffer_transform (wl_surface.set_buffer_transform)
      2. buffer_scale (wl_surface.set_buffer_scale)
      3. crop and scale (wp_viewport.set*)
    This means, that the source rectangle coordinates of crop and scale
    are given in the coordinates after the buffer transform and scale,
    i.e. in the coordinates that would be the surface-local coordinates
    if the crop and scale was not applied.

    If src_x or src_y are negative, the bad_value protocol error is raised.
    Otherwise, if the source rectangle is partially or completely outside of
    the non-NULL wl_buffer, then the out_of_buffer protocol error is raised
    when the surface state is applied. A NULL wl_buffer does not raise the
    out_of_buffer error.

    If the wl_surface associated with the wp_viewport is destroyed,
    all wp_viewport requests except 'destroy' raise the protocol error
    no_surface.

    If the wp_viewport object is destroyed, the crop and scale
    state is removed from the wl_surface. The change will be applied
    on the next wl_surface.commit.
    """
    object_id = 0
    version = 1

    class error(Enum):
        bad_value: int
        """Negative or zero values in width or height"""

        bad_size: int
        """Destination size is not integer"""

        out_of_buffer: int
        """Source rectangle extends outside of the content area"""

        no_surface: int
        """The `wl_surface` was destroyed"""



    def destroy(self) -> None:
        """
        Remove scaling and cropping from the surface

        The associated wl_surface's crop and scale state is removed.
        The change is applied on the next wl_surface.commit.
        """

        ...

    def set_source(self, x: float, y: float, width: float, height: float) -> None:
        """
        Set the source rectangle for cropping

        Set the source rectangle of the associated wl_surface. See
        wp_viewport for the description, and relation to the wl_buffer
        size.

        If all of x, y, width and height are -1.0, the source rectangle is
        unset instead. Any other set of values where width or height are zero
        or negative, or x or y are negative, raise the bad_value protocol
        error.

        The crop and scale state is double-buffered, see wl_surface.commit.

        Args:
            x: Source rectangle x
            y: Source rectangle y
            width: Source rectangle width
            height: Source rectangle height
        """

        ...

    def set_destination(self, width: int, height: int) -> None:
        """
        Set the surface size for scaling

        Set the destination size of the associated wl_surface. See
        wp_viewport for the description, and relation to the wl_buffer
        size.

        If width is -1 and height is -1, the destination size is unset
        instead. Any other pair of values for width and height that
        contains zero or negative values raises the bad_value protocol
        error.

        The crop and scale state is double-buffered, see wl_surface.commit.

        Args:
            width: Surface width
            height: Surface height
        """

        ...

class xdg_wm_base:
    """
    Create desktop-style surfaces

    The xdg_wm_base interface is exposed as a global object enabling clients
    to turn their wl_surfaces into windows in a desktop environment. It
    defines the basic functionality needed for clients and the compositor to
    create windows that can be dragged, resized, maximized, etc, as well as
    creating transient windows such as popup menus.
    """
    object_id = 0
    version = 7

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""

        defunct_surfaces: int
        """`xdg_wm_base` was destroyed before children"""

        not_the_topmost_popup: int
        """The client tried to map or destroy a non-topmost popup"""

        invalid_popup_parent: int
        """The client specified an invalid popup parent surface"""

        invalid_surface_state: int
        """The client provided an invalid surface state"""

        invalid_positioner: int
        """The client provided an invalid positioner"""

        unresponsive: int
        """The client didn’t respond to a ping event in time"""



    def destroy(self) -> None:
        """
        Destroy `xdg_wm_base`

        Destroy this xdg_wm_base object.

        Destroying a bound xdg_wm_base object while there are surfaces
        still alive created by this xdg_wm_base object instance is illegal
        and will result in a defunct_surfaces error.
        """

        ...

    def create_positioner(self) -> xdg_positioner:
        """
        Create a positioner object

        Create a positioner object. A positioner object is used to position
        surfaces relative to some parent surface. See the interface description
        and xdg_surface.get_popup for details.

        Returns:
            xdg_positioner: The created object
        """

        ...

    def get_xdg_surface(self, surface: wl_surface) -> xdg_surface:
        """
        Create a shell surface from a surface

        This creates an xdg_surface for the given surface. While xdg_surface
        itself is not a role, the corresponding surface may only be assigned
        a role extending xdg_surface, such as xdg_toplevel or xdg_popup. It is
        illegal to create an xdg_surface for a wl_surface which already has an
        assigned role and this will result in a role error.

        This creates an xdg_surface for the given surface. An xdg_surface is
        used as basis to define a role to a given surface, such as xdg_toplevel
        or xdg_popup. It also manages functionality shared between xdg_surface
        based surface roles.

        See the documentation of xdg_surface for more details about what an
        xdg_surface is and how it is used.

        Returns:
            xdg_surface: The created object
        """

        ...

    def pong(self, serial: int) -> None:
        """
        Respond to a ping event

        A client must respond to a ping event with a pong request or
        the client may be deemed unresponsive. See xdg_wm_base.ping
        and xdg_wm_base.error.unresponsive.

        Args:
            serial: Serial of the ping event
        """

        ...

    def on_ping(self, serial: int) -> None:
        """
        Check if the client is alive.

        Override to handle [`wayland.xdg_wm_base.events.ping`][].
        """

        ...

    class events(WaylandEvent):
        def ping(self, serial: int) -> None:
            """
            Check if the client is alive

            The ping event asks the client if it's still alive. Pass the
            serial specified in the event back to the compositor by sending
            a "pong" request back with the specified serial. See xdg_wm_base.pong.

            Compositors can use this to determine if the client is still
            alive. It's unspecified what will happen if the client doesn't
            respond to the ping request, or in what timeframe. Clients should
            try to respond in a reasonable amount of time. The “unresponsive”
            error is provided for compositors that wish to disconnect unresponsive
            clients.

            A compositor is free to ping in any way it wants, but a client must
            always respond to any xdg_wm_base object it created.

            Args:
                serial: Pass this to the pong request
            """

            ...

class xdg_positioner:
    """
    Child surface positioner

    The xdg_positioner provides a collection of rules for the placement of a
    child surface relative to a parent surface. Rules can be defined to ensure
    the child surface remains within the visible area's borders, and to
    specify how the child surface changes its position, such as sliding along
    an axis, or flipping around a rectangle. These positioner-created rules are
    constrained by the requirement that a child surface must intersect with or
    be at least partially adjacent to its parent surface.

    See the various requests for details about possible rules.

    At the time of the request, the compositor makes a copy of the rules
    specified by the xdg_positioner. Thus, after the request is complete the
    xdg_positioner object can be destroyed or reused; further changes to the
    object will have no effect on previous usages.

    For an xdg_positioner object to be considered complete, it must have a
    non-zero size set by set_size, and a non-zero anchor rectangle set by
    set_anchor_rect. Passing an incomplete xdg_positioner object when
    positioning a surface raises an invalid_positioner error.
    """
    object_id = 0
    version = 7

    class error(Enum):
        invalid_input: int
        """Invalid input provided"""



    class anchor(Enum):
        none: int
        top: int
        bottom: int
        left: int
        right: int
        top_left: int
        bottom_left: int
        top_right: int
        bottom_right: int


    class gravity(Enum):
        none: int
        top: int
        bottom: int
        left: int
        right: int
        top_left: int
        bottom_left: int
        top_right: int
        bottom_right: int


    class constraint_adjustment(IntFlag):
        """
        Constraint adjustments

        The constraint adjustment value define ways the compositor will adjust
        the position of the surface, if the unadjusted position would result
        in the surface being partly constrained.

        Whether a surface is considered 'constrained' is left to the compositor
        to determine. For example, the surface may be partly outside the
        compositor's defined 'work area', thus necessitating the child surface's
        position be adjusted until it is entirely inside the work area.

        The adjustments can be combined, according to a defined precedence: 1)
        Flip, 2) Slide, 3) Resize.
        """

        none: int
        """
        Don't move the child surface when constrained
        Don't alter the surface position even if it is constrained on some
        axis, for example partially outside the edge of an output.
        """

        slide_x: int
        """
        Move along the x axis until unconstrained
        Slide the surface along the x axis until it is no longer constrained.
        First try to slide towards the direction of the gravity on the x axis
        until either the edge in the opposite direction of the gravity is
        unconstrained or the edge in the direction of the gravity is
        constrained.
        Then try to slide towards the opposite direction of the gravity on the
        x axis until either the edge in the direction of the gravity is
        unconstrained or the edge in the opposite direction of the gravity is
        constrained.
        """

        slide_y: int
        """
        Move along the y axis until unconstrained
        Slide the surface along the y axis until it is no longer constrained.
        First try to slide towards the direction of the gravity on the y axis
        until either the edge in the opposite direction of the gravity is
        unconstrained or the edge in the direction of the gravity is
        constrained.
        Then try to slide towards the opposite direction of the gravity on the
        y axis until either the edge in the direction of the gravity is
        unconstrained or the edge in the opposite direction of the gravity is
        constrained.
        """

        flip_x: int
        """
        Invert the anchor and gravity on the x axis
        Invert the anchor and gravity on the x axis if the surface is
        constrained on the x axis. For example, if the left edge of the
        surface is constrained, the gravity is 'left' and the anchor is
        'left', change the gravity to 'right' and the anchor to 'right'.
        If the adjusted position also ends up being constrained, the resulting
        position of the flip_x adjustment will be the one before the
        adjustment.
        """

        flip_y: int
        """
        Invert the anchor and gravity on the y axis
        Invert the anchor and gravity on the y axis if the surface is
        constrained on the y axis. For example, if the bottom edge of the
        surface is constrained, the gravity is 'bottom' and the anchor is
        'bottom', change the gravity to 'top' and the anchor to 'top'.
        The adjusted position is calculated given the original anchor
        rectangle and offset, but with the new flipped anchor and gravity
        values.
        If the adjusted position also ends up being constrained, the resulting
        position of the flip_y adjustment will be the one before the
        adjustment.
        """

        resize_x: int
        """
        Horizontally resize the surface
        Resize the surface horizontally so that it is completely
        unconstrained.
        """

        resize_y: int
        """
        Vertically resize the surface
        Resize the surface vertically so that it is completely unconstrained.
        """



    def destroy(self) -> None:
        """
        Destroy the `xdg_positioner` object

        Notify the compositor that the xdg_positioner will no longer be used.
        """

        ...

    def set_size(self, width: int, height: int) -> None:
        """
        Set the size of the to-be positioned rectangle

        Set the size of the surface that is to be positioned with the positioner
        object. The size is in surface-local coordinates and corresponds to the
        window geometry. See xdg_surface.set_window_geometry.

        If a zero or negative size is set the invalid_input error is raised.

        Args:
            width: Width of positioned rectangle
            height: Height of positioned rectangle
        """

        ...

    def set_anchor_rect(self, x: int, y: int, width: int, height: int) -> None:
        """
        Set the anchor rectangle within the parent surface

        Specify the anchor rectangle within the parent surface that the child
        surface will be placed relative to. The rectangle is relative to the
        window geometry as defined by xdg_surface.set_window_geometry of the
        parent surface.

        When the xdg_positioner object is used to position a child surface, the
        anchor rectangle may not extend outside the window geometry of the
        positioned child's parent surface.

        If a negative size is set the invalid_input error is raised.

        Args:
            x: X position of anchor rectangle
            y: Y position of anchor rectangle
            width: Width of anchor rectangle
            height: Height of anchor rectangle
        """

        ...

    def set_anchor(self, anchor: xdg_positioner.anchor) -> None:
        """
        Set anchor rectangle anchor

        Defines the anchor point for the anchor rectangle. The specified anchor
        is used derive an anchor point that the child surface will be
        positioned relative to. If a corner anchor is set (e.g. 'top_left' or
        'bottom_right'), the anchor point will be at the specified corner;
        otherwise, the derived anchor point will be centered on the specified
        edge, or in the center of the anchor rectangle if no edge is specified.

        Args:
            anchor: Anchor
        """

        ...

    def set_gravity(self, gravity: xdg_positioner.gravity) -> None:
        """
        Set child surface gravity

        Defines in what direction a surface should be positioned, relative to
        the anchor point of the parent surface. If a corner gravity is
        specified (e.g. 'bottom_right' or 'top_left'), then the child surface
        will be placed towards the specified gravity; otherwise, the child
        surface will be centered over the anchor point on any axis that had no
        gravity specified. If the gravity is not in the ‘gravity’ enum, an
        invalid_input error is raised.

        Args:
            gravity: Gravity direction
        """

        ...

    def set_constraint_adjustment(self, constraint_adjustment: xdg_positioner.constraint_adjustment) -> None:
        """
        Set the adjustment to be done when constrained

        Specify how the window should be positioned if the originally intended
        position caused the surface to be constrained, meaning at least
        partially outside positioning boundaries set by the compositor. The
        adjustment is set by constructing a bitmask describing the adjustment to
        be made when the surface is constrained on that axis.

        If no bit for one axis is set, the compositor will assume that the child
        surface should not change its position on that axis when constrained.

        If more than one bit for one axis is set, the order of how adjustments
        are applied is specified in the corresponding adjustment descriptions.

        The default adjustment is none.

        Args:
            constraint_adjustment: Bit mask of constraint adjustments
        """

        ...

    def set_offset(self, x: int, y: int) -> None:
        """
        Set surface position offset

        Specify the surface position offset relative to the position of the
        anchor on the anchor rectangle and the anchor on the surface. For
        example if the anchor of the anchor rectangle is at (x, y), the surface
        has the gravity bottom|right, and the offset is (ox, oy), the calculated
        surface position will be (x + ox, y + oy). The offset position of the
        surface is the one used for constraint testing. See
        set_constraint_adjustment.

        An example use case is placing a popup menu on top of a user interface
        element, while aligning the user interface element of the parent surface
        with some user interface element placed somewhere in the popup surface.

        Args:
            x: Surface position x offset
            y: Surface position y offset
        """

        ...

    def set_reactive(self) -> None:
        """
        Continuously reconstrain the surface

        When set reactive, the surface is reconstrained if the conditions used
        for constraining changed, e.g. the parent window moved.

        If the conditions changed and the popup was reconstrained, an
        xdg_popup.configure event is sent with updated geometry, followed by an
        xdg_surface.configure event.
        """

        ...

    def set_parent_size(self, parent_width: int, parent_height: int) -> None:
        """
        Set the parent window geometry the compositor should use when
        positioning the popup. The compositor may use this information to
        determine the future state the popup should be constrained using. If
        this doesn't match the dimension of the parent the popup is eventually
        positioned against, the behavior is undefined.

        The arguments are given in the surface-local coordinate space.

        Args:
            parent_width: Future window geometry width of parent
            parent_height: Future window geometry height of parent
        """

        ...

    def set_parent_configure(self, serial: int) -> None:
        """
        Set parent configure this is a response to

        Set the serial of an xdg_surface.configure event this positioner will be
        used in response to. The compositor may use this information together
        with set_parent_size to determine what future state the popup should be
        constrained using.

        Args:
            serial: Serial of parent configure event
        """

        ...

class xdg_surface:
    """
    Desktop user interface surface base interface

    An interface that may be implemented by a wl_surface, for
    implementations that provide a desktop-style user interface.

    It provides a base set of functionality required to construct user
    interface elements requiring management by the compositor, such as
    toplevel windows, menus, etc. The types of functionality are split into
    xdg_surface roles.

    Creating an xdg_surface does not set the role for a wl_surface. In order
    to map an xdg_surface, the client must create a role-specific object
    using, e.g., get_toplevel, get_popup. The wl_surface for any given
    xdg_surface can have at most one role, and may not be assigned any role
    not based on xdg_surface.

    A role must be assigned before any other requests are made to the
    xdg_surface object.

    The client must call wl_surface.commit on the corresponding wl_surface
    for the xdg_surface state to take effect.

    Creating an xdg_surface from a wl_surface which has a buffer attached or
    committed is a client error, and any attempts by a client to attach or
    manipulate a buffer prior to the first xdg_surface.configure call must
    also be treated as errors.

    After creating a role-specific object and setting it up (e.g. by sending
    the title, app ID, size constraints, parent, etc), the client must
    perform an initial commit without any buffer attached. The compositor
    will reply with initial wl_surface state such as
    wl_surface.preferred_buffer_scale followed by an xdg_surface.configure
    event. The client must acknowledge it and is then allowed to attach a
    buffer to map the surface.

    Mapping an xdg_surface-based role surface is defined as making it
    possible for the surface to be shown by the compositor. Note that
    a mapped surface is not guaranteed to be visible once it is mapped.

    For an xdg_surface to be mapped by the compositor, the following
    conditions must be met:
    (1) the client has assigned an xdg_surface-based role to the surface
    (2) the client has set and committed the xdg_surface state and the
    role-dependent state to the surface
    (3) the client has committed a buffer to the surface

    A newly-unmapped surface is considered to have met condition (1) out
    of the 3 required conditions for mapping a surface if its role surface
    has not been destroyed, i.e. the client must perform the initial commit
    again before attaching a buffer.
    """
    object_id = 0
    version = 7

    class error(Enum):
        not_constructed: int
        """Surface was not fully constructed"""

        already_constructed: int
        """Surface was already constructed"""

        unconfigured_buffer: int
        """Attaching a buffer to an unconfigured surface"""

        invalid_serial: int
        """Invalid serial number when acking a configure event"""

        invalid_size: int
        """Width or height was zero or negative"""

        defunct_role_object: int
        """Surface was destroyed before its role object"""



    def destroy(self) -> None:
        """
        Destroy the `xdg_surface`

        Destroy the xdg_surface object. An xdg_surface must only be destroyed
        after its role object has been destroyed, otherwise
        a defunct_role_object error is raised.
        """

        ...

    def get_toplevel(self) -> xdg_toplevel:
        """
        Assign the `xdg_toplevel` surface role

        This creates an xdg_toplevel object for the given xdg_surface and gives
        the associated wl_surface the xdg_toplevel role.

        See the documentation of xdg_toplevel for more details about what an
        xdg_toplevel is and how it is used.

        Returns:
            xdg_toplevel: The created object
        """

        ...

    def get_popup(self, parent: xdg_surface, positioner: xdg_positioner) -> xdg_popup:
        """
        Assign the `xdg_popup` surface role

        This creates an xdg_popup object for the given xdg_surface and gives
        the associated wl_surface the xdg_popup role.

        If null is passed as a parent, a parent surface must be specified using
        some other protocol, before committing the initial state.

        See the documentation of xdg_popup for more details about what an
        xdg_popup is and how it is used.

        Returns:
            xdg_popup: The created object
        """

        ...

    def set_window_geometry(self, x: int, y: int, width: int, height: int) -> None:
        """
        Set the new window geometry

        The window geometry of a surface is its "visible bounds" from the
        user's perspective. Client-side decorations often have invisible
        portions like drop-shadows which should be ignored for the
        purposes of aligning, placing and constraining windows.

        The window geometry is double-buffered state, see wl_surface.commit.

        When maintaining a position, the compositor should treat the (x, y)
        coordinate of the window geometry as the top left corner of the window.
        A client changing the (x, y) window geometry coordinate should in
        general not alter the position of the window.

        Once the window geometry of the surface is set, it is not possible to
        unset it, and it will remain the same until set_window_geometry is
        called again, even if a new subsurface or buffer is attached.

        If never set, the value is the full bounds of the surface,
        including any subsurfaces. This updates dynamically on every
        commit. This unset is meant for extremely simple clients.

        The arguments are given in the surface-local coordinate space of
        the wl_surface associated with this xdg_surface, and may extend outside
        of the wl_surface itself to mark parts of the subsurface tree as part of
        the window geometry.

        When applied, the effective window geometry will be the set window
        geometry clamped to the bounding rectangle of the combined
        geometry of the surface of the xdg_surface and the associated
        subsurfaces.

        The effective geometry will not be recalculated unless a new call to
        set_window_geometry is done and the new pending surface state is
        subsequently applied.

        The width and height of the effective window geometry must be
        greater than zero. Setting an invalid size will raise an
        invalid_size error.
        """

        ...

    def ack_configure(self, serial: int) -> None:
        """
        Ack a configure event

        When a configure event is received, if a client commits the
        surface in response to the configure event, then the client
        must make an ack_configure request sometime before the commit
        request, passing along the serial of the configure event.

        For instance, for toplevel surfaces the compositor might use this
        information to move a surface to the top left only when the client has
        drawn itself for the maximized or fullscreen state.

        If the client receives multiple configure events before it
        can respond to one, it only has to ack the last configure event.
        Acking a configure event that was never sent raises an invalid_serial
        error.

        A client is not required to commit immediately after sending
        an ack_configure request - it may even ack_configure several times
        before its next surface commit.

        A client may send multiple ack_configure requests before committing, but
        only the last request sent before a commit indicates which configure
        event the client really is responding to.

        Sending an ack_configure request consumes the serial number sent with
        the request, as well as serial numbers sent by all configure events
        sent on this xdg_surface prior to the configure event referenced by
        the committed serial.

        It is an error to issue multiple ack_configure requests referencing a
        serial from the same configure event, or to issue an ack_configure
        request referencing a serial from a configure event issued before the
        event identified by the last ack_configure request for the same
        xdg_surface. Doing so will raise an invalid_serial error.

        Args:
            serial: The serial from the configure event
        """

        ...

    def on_configure(self, serial: int) -> None:
        """
        Suggest a surface change.

        Override to handle [`wayland.xdg_surface.events.configure`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, serial: int) -> None:
            """
            Suggest a surface change

            The configure event marks the end of a configure sequence. A configure
            sequence is a set of one or more events configuring the state of the
            xdg_surface, including the final xdg_surface.configure event.

            Where applicable, xdg_surface surface roles will during a configure
            sequence extend this event as a latched state sent as events before the
            xdg_surface.configure event. Such events should be considered to make up
            a set of atomically applied configuration states, where the
            xdg_surface.configure commits the accumulated state.

            Clients should arrange their surface for the new states, and then send
            an ack_configure request with the serial sent in this configure event at
            some point before committing the new surface.

            If the client receives multiple configure events before it can respond
            to one, it is free to discard all but the last event it received.

            Args:
                serial: Serial of the configure event
            """

            ...

class xdg_toplevel:
    """
    Toplevel surface

    This interface defines an xdg_surface role which allows a surface to,
    among other things, set window-like properties such as maximize,
    fullscreen, and minimize, set application-specific metadata like title and
    id, and well as trigger user interactive operations such as interactive
    resize and move.

    A xdg_toplevel by default is responsible for providing the full intended
    visual representation of the toplevel, which depending on the window
    state, may mean things like a title bar, window controls and drop shadow.

    Unmapping an xdg_toplevel means that the surface cannot be shown
    by the compositor until it is explicitly mapped again.
    All active operations (e.g., move, resize) are canceled and all
    attributes (e.g. title, state, stacking, ...) are discarded for
    an xdg_toplevel surface when it is unmapped. The xdg_toplevel returns to
    the state it had right after xdg_surface.get_toplevel. The client
    can re-map the toplevel by performing a commit without any buffer
    attached, waiting for a configure event and handling it as usual (see
    xdg_surface description).

    Attaching a null buffer to a toplevel unmaps the surface.
    """
    object_id = 0
    version = 7

    class error(Enum):
        invalid_resize_edge: int
        """Provided value is         not a valid variant of the `resize_edge` enum"""

        invalid_parent: int
        """Invalid parent toplevel"""

        invalid_size: int
        """Client provided an invalid min or max size"""



    class resize_edge(Enum):
        """
        Edge values for resizing

        These values are used to indicate which edge of a surface
        is being dragged in a resize operation.
        """

        none: int
        top: int
        bottom: int
        left: int
        top_left: int
        bottom_left: int
        right: int
        top_right: int
        bottom_right: int


    class state(Enum):
        """
        Types of state on the surface

        The different state values used on the surface. This is designed for
        state values like maximized, fullscreen. It is paired with the
        configure event to ensure that both the client and the compositor
        setting the state can be synchronized.

        States set in this way are double-buffered, see wl_surface.commit.
        """

        maximized: int
        """
        The surface is maximized
        The surface is maximized. The window geometry specified in the configure
        event must be obeyed by the client, or the xdg_wm_base.invalid_surface_state
        error is raised.
        The client should draw without shadow or other
        decoration outside of the window geometry.
        """

        fullscreen: int
        """
        The surface is fullscreen
        The surface is fullscreen. The window geometry specified in the
        configure event is a maximum; the client cannot resize beyond it. For
        a surface to cover the whole fullscreened area, the geometry
        dimensions must be obeyed by the client. For more details, see
        xdg_toplevel.set_fullscreen.
        """

        resizing: int
        """
        The surface is being resized
        The surface is being resized. The window geometry specified in the
        configure event is a maximum; the client cannot resize beyond it.
        Clients that have aspect ratio or cell sizing configuration can use
        a smaller size, however.
        """

        activated: int
        """
        The surface is now activated
        Client window decorations should be painted as if the window is
        active. Do not assume this means that the window actually has
        keyboard or pointer focus.
        """

        tiled_left: int
        """
        The surface’s left edge is tiled
        The window is currently in a tiled layout and the left edge is
        considered to be adjacent to another part of the tiling grid.
        The client should draw without shadow or other decoration outside of
        the window geometry on the left edge.
        """

        tiled_right: int
        """
        The surface’s right edge is tiled
        The window is currently in a tiled layout and the right edge is
        considered to be adjacent to another part of the tiling grid.
        The client should draw without shadow or other decoration outside of
        the window geometry on the right edge.
        """

        tiled_top: int
        """
        The surface’s top edge is tiled
        The window is currently in a tiled layout and the top edge is
        considered to be adjacent to another part of the tiling grid.
        The client should draw without shadow or other decoration outside of
        the window geometry on the top edge.
        """

        tiled_bottom: int
        """
        The surface’s bottom edge is tiled
        The window is currently in a tiled layout and the bottom edge is
        considered to be adjacent to another part of the tiling grid.
        The client should draw without shadow or other decoration outside of
        the window geometry on the bottom edge.
        """

        suspended: int
        """
        Surface repaint is suspended
        The surface is currently not ordinarily being repainted; for
        example because its content is occluded by another window, or its
        outputs are switched off due to screen locking.
        """

        constrained_left: int
        """
        The surface’s left edge is constrained
        The left edge of the window is currently constrained, meaning it
        shouldn't attempt to resize from that edge. It can for example mean
        it's tiled next to a monitor edge on the constrained side of the
        window.
        """

        constrained_right: int
        """
        The surface’s right edge is constrained
        The right edge of the window is currently constrained, meaning it
        shouldn't attempt to resize from that edge. It can for example mean
        it's tiled next to a monitor edge on the constrained side of the
        window.
        """

        constrained_top: int
        """
        The surface’s top edge is constrained
        The top edge of the window is currently constrained, meaning it
        shouldn't attempt to resize from that edge. It can for example mean
        it's tiled next to a monitor edge on the constrained side of the
        window.
        """

        constrained_bottom: int
        """
        The surface’s bottom edge is constrained
        The bottom edge of the window is currently constrained, meaning it
        shouldn't attempt to resize from that edge. It can for example mean
        it's tiled next to a monitor edge on the constrained side of the
        window.
        """



    class wm_capabilities(Enum):
        window_menu: int
        """`show_window_menu` is available"""

        maximize: int
        """`set_maximized` and `unset_maximized` are available"""

        fullscreen: int
        """`set_fullscreen` and `unset_fullscreen` are available"""

        minimize: int
        """`set_minimized` is available"""



    def destroy(self) -> None:
        """
        Destroy the `xdg_toplevel`

        This request destroys the role surface and unmaps the surface;
        see "Unmapping" behavior in interface section for details.
        """

        ...

    def set_parent(self, parent: xdg_toplevel) -> None:
        """
        Set the parent of this surface

        Set the "parent" of this surface. This surface should be stacked
        above the parent surface and all other ancestor surfaces.

        Parent surfaces should be set on dialogs, toolboxes, or other
        "auxiliary" surfaces, so that the parent is raised when the dialog
        is raised.

        Setting a null parent for a child surface unsets its parent. Setting
        a null parent for a surface which currently has no parent is a no-op.

        Only mapped surfaces can have child surfaces. Setting a parent which
        is not mapped is equivalent to setting a null parent. If a surface
        becomes unmapped, its children's parent is set to the parent of
        the now-unmapped surface. If the now-unmapped surface has no parent,
        its children's parent is unset. If the now-unmapped surface becomes
        mapped again, its parent-child relationship is not restored.

        The parent toplevel must not be one of the child toplevel's
        descendants, and the parent must be different from the child toplevel,
        otherwise the invalid_parent protocol error is raised.
        """

        ...

    def set_title(self, title: str) -> None:
        """
        Set surface title

        Set a short title for the surface.

        This string may be used to identify the surface in a task bar,
        window list, or other user interface elements provided by the
        compositor.

        The string must be encoded in UTF-8.
        """

        ...

    def set_app_id(self, app_id: str) -> None:
        """
        Set application id

        Set an application identifier for the surface.

        The app ID identifies the general class of applications to which
        the surface belongs. The compositor can use this to group multiple
        surfaces together, or to determine how to launch a new application.

        For D-Bus activatable applications, the app ID is used as the D-Bus
        service name.

        The compositor shell will try to group application surfaces together
        by their app ID. As a best practice, it is suggested to select app
        ID's that match the basename of the application's .desktop file.
        For example, "org.freedesktop.FooViewer" where the .desktop file is
        "org.freedesktop.FooViewer.desktop".

        Like other properties, a set_app_id request can be sent after the
        xdg_toplevel has been mapped to update the property.

        See the desktop-entry specification [0] for more details on
        application identifiers and how they relate to well-known D-Bus
        names and .desktop files.

        [0] https://standards.freedesktop.org/desktop-entry-spec/
        """

        ...

    def show_window_menu(self, seat: wl_seat, serial: int, x: int, y: int) -> None:
        """
        Show the window menu

        Clients implementing client-side decorations might want to show
        a context menu when right-clicking on the decorations, giving the
        user a menu that they can use to maximize or minimize the window.

        This request asks the compositor to pop up such a window menu at
        the given position, relative to the local surface coordinates of
        the parent surface. There are no guarantees as to what menu items
        the window menu contains, or even if a window menu will be drawn
        at all.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
            x: The x position to pop up the window menu at
            y: The y position to pop up the window menu at
        """

        ...

    def move(self, seat: wl_seat, serial: int) -> None:
        """
        Start an interactive move

        Start an interactive, user-driven move of the surface.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event. The passed
        serial is used to determine the type of interactive move (touch,
        pointer, etc).

        The server may ignore move requests depending on the state of
        the surface (e.g. fullscreen or maximized), or if the passed serial
        is no longer valid.

        If triggered, the surface will lose the focus of the device
        (wl_pointer, wl_touch, etc) used for the move. It is up to the
        compositor to visually indicate that the move is taking place, such as
        updating a pointer cursor, during the move. There is no guarantee
        that the device focus will return when the move is completed.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
        """

        ...

    def resize(self, seat: wl_seat, serial: int, edges: xdg_toplevel.resize_edge) -> None:
        """
        Start an interactive resize

        Start a user-driven, interactive resize of the surface.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event. The passed
        serial is used to determine the type of interactive resize (touch,
        pointer, etc).

        The server may ignore resize requests depending on the state of
        the surface (e.g. fullscreen or maximized).

        If triggered, the client will receive configure events with the
        "resize" state enum value and the expected sizes. See the "resize"
        enum value for more details about what is required. The client
        must also acknowledge configure events using "ack_configure". After
        the resize is completed, the client will receive another "configure"
        event without the resize state.

        If triggered, the surface also will lose the focus of the device
        (wl_pointer, wl_touch, etc) used for the resize. It is up to the
        compositor to visually indicate that the resize is taking place,
        such as updating a pointer cursor, during the resize. There is no
        guarantee that the device focus will return when the resize is
        completed.

        The edges parameter specifies how the surface should be resized, and
        is one of the values of the resize_edge enum. Values not matching
        a variant of the enum will cause the invalid_resize_edge protocol error.
        The compositor may use this information to update the surface position
        for example when dragging the top left corner. The compositor may also
        use this information to adapt its behavior, e.g. choose an appropriate
        cursor image.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
            edges: Which edge or corner is being dragged
        """

        ...

    def set_max_size(self, width: int, height: int) -> None:
        """
        Set the maximum size

        Set a maximum size for the window.

        The client can specify a maximum size so that the compositor does
        not try to configure the window beyond this size.

        The width and height arguments are in window geometry coordinates.
        See xdg_surface.set_window_geometry.

        Values set in this way are double-buffered, see wl_surface.commit.

        The compositor can use this information to allow or disallow
        different states like maximize or fullscreen and draw accurate
        animations.

        Similarly, a tiling window manager may use this information to
        place and resize client windows in a more effective way.

        The client should not rely on the compositor to obey the maximum
        size. The compositor may decide to ignore the values set by the
        client and request a larger size.

        If never set, or a value of zero in the request, means that the
        client has no expected maximum size in the given dimension.
        As a result, a client wishing to reset the maximum size
        to an unspecified state can use zero for width and height in the
        request.

        Requesting a maximum size to be smaller than the minimum size of
        a surface is illegal and will result in an invalid_size error.

        The width and height must be greater than or equal to zero. Using
        strictly negative values for width or height will result in a
        invalid_size error.
        """

        ...

    def set_min_size(self, width: int, height: int) -> None:
        """
        Set the minimum size

        Set a minimum size for the window.

        The client can specify a minimum size so that the compositor does
        not try to configure the window below this size.

        The width and height arguments are in window geometry coordinates.
        See xdg_surface.set_window_geometry.

        Values set in this way are double-buffered, see wl_surface.commit.

        The compositor can use this information to allow or disallow
        different states like maximize or fullscreen and draw accurate
        animations.

        Similarly, a tiling window manager may use this information to
        place and resize client windows in a more effective way.

        The client should not rely on the compositor to obey the minimum
        size. The compositor may decide to ignore the values set by the
        client and request a smaller size.

        If never set, or a value of zero in the request, means that the
        client has no expected minimum size in the given dimension.
        As a result, a client wishing to reset the minimum size
        to an unspecified state can use zero for width and height in the
        request.

        Requesting a minimum size to be larger than the maximum size of
        a surface is illegal and will result in an invalid_size error.

        The width and height must be greater than or equal to zero. Using
        strictly negative values for width and height will result in a
        invalid_size error.
        """

        ...

    def set_maximized(self) -> None:
        """
        Maximize the window

        Maximize the surface.

        After requesting that the surface should be maximized, the compositor
        will respond by emitting a configure event. Whether this configure
        actually sets the window maximized is subject to compositor policies.
        The client must then update its content, drawing in the configured
        state. The client must also acknowledge the configure when committing
        the new content (see ack_configure).

        It is up to the compositor to decide how and where to maximize the
        surface, for example which output and what region of the screen should
        be used.

        If the surface was already maximized, the compositor will still emit
        a configure event with the "maximized" state.

        If the surface is in a fullscreen state, this request has no direct
        effect. It may alter the state the surface is returned to when
        unmaximized unless overridden by the compositor.
        """

        ...

    def unset_maximized(self) -> None:
        """
        Unmaximize the window

        Unmaximize the surface.

        After requesting that the surface should be unmaximized, the compositor
        will respond by emitting a configure event. Whether this actually
        un-maximizes the window is subject to compositor policies.
        If available and applicable, the compositor will include the window
        geometry dimensions the window had prior to being maximized in the
        configure event. The client must then update its content, drawing it in
        the configured state. The client must also acknowledge the configure
        when committing the new content (see ack_configure).

        It is up to the compositor to position the surface after it was
        unmaximized; usually the position the surface had before maximizing, if
        applicable.

        If the surface was already not maximized, the compositor will still
        emit a configure event without the "maximized" state.

        If the surface is in a fullscreen state, this request has no direct
        effect. It may alter the state the surface is returned to when
        unmaximized unless overridden by the compositor.
        """

        ...

    def set_fullscreen(self, output: wl_output) -> None:
        """
        Set the window as fullscreen on an output

        Make the surface fullscreen.

        After requesting that the surface should be fullscreened, the
        compositor will respond by emitting a configure event. Whether the
        client is actually put into a fullscreen state is subject to compositor
        policies. The client must also acknowledge the configure when
        committing the new content (see ack_configure).

        The output passed by the request indicates the client's preference as
        to which display it should be set fullscreen on. If this value is NULL,
        it's up to the compositor to choose which display will be used to map
        this surface.

        If the surface doesn't cover the whole output, the compositor will
        position the surface in the center of the output and compensate with
        with border fill covering the rest of the output. The content of the
        border fill is undefined, but should be assumed to be in some way that
        attempts to blend into the surrounding area (e.g. solid black).

        If the fullscreened surface is not opaque, the compositor must make
        sure that other screen content not part of the same surface tree (made
        up of subsurfaces, popups or similarly coupled surfaces) are not
        visible below the fullscreened surface.
        """

        ...

    def unset_fullscreen(self) -> None:
        """
        Unset the window as fullscreen

        Make the surface no longer fullscreen.

        After requesting that the surface should be unfullscreened, the
        compositor will respond by emitting a configure event.
        Whether this actually removes the fullscreen state of the client is
        subject to compositor policies.

        Making a surface unfullscreen sets states for the surface based on the following:
        * the state(s) it may have had before becoming fullscreen
        * any state(s) decided by the compositor
        * any state(s) requested by the client while the surface was fullscreen

        The compositor may include the previous window geometry dimensions in
        the configure event, if applicable.

        The client must also acknowledge the configure when committing the new
        content (see ack_configure).
        """

        ...

    def set_minimized(self) -> None:
        """
        Set the window as minimized

        Request that the compositor minimize your surface. There is no
        way to know if the surface is currently minimized, nor is there
        any way to unset minimization on this surface.

        If you are looking to throttle redrawing when minimized, please
        instead use the wl_surface.frame event for this, as this will
        also work with live previews on windows in Alt-Tab, Expose or
        similar compositor features.
        """

        ...

    def on_configure(self, width: int, height: int, states: list) -> None:
        """
        Suggest a surface change.

        Override to handle [`wayland.xdg_toplevel.events.configure`][].
        """

        ...

    def on_close(self) -> None:
        """
        Surface wants to be closed.

        Override to handle [`wayland.xdg_toplevel.events.close`][].
        """

        ...

    def on_configure_bounds(self, width: int, height: int) -> None:
        """
        Recommended window geometry bounds.

        Override to handle [`wayland.xdg_toplevel.events.configure_bounds`][].
        """

        ...

    def on_wm_capabilities(self, capabilities: list) -> None:
        """
        Compositor capabilities.

        Override to handle [`wayland.xdg_toplevel.events.wm_capabilities`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, width: int, height: int, states: list) -> None:
            """
            Suggest a surface change

            This configure event asks the client to resize its toplevel surface or
            to change its state. The configured state should not be applied
            immediately. See xdg_surface.configure for details.

            The width and height arguments specify a hint to the window
            about how its surface should be resized in window geometry
            coordinates. See set_window_geometry.

            If the width or height arguments are zero, it means the client
            should decide its own window dimension. This may happen when the
            compositor needs to configure the state of the surface but doesn't
            have any information about any previous or expected dimension.

            The states listed in the event specify how the width/height
            arguments should be interpreted, and possibly how it should be
            drawn.

            Clients must send an ack_configure in response to this event. See
            xdg_surface.configure and xdg_surface.ack_configure for details.
            """

            ...

        def close(self) -> None:
            """
            Surface wants to be closed

            The close event is sent by the compositor when the user
            wants the surface to be closed. This should be equivalent to
            the user clicking the close button in client-side decorations,
            if your application has any.

            This is only a request that the user intends to close the
            window. The client may choose to ignore this request, or show
            a dialog to ask the user to save their data, etc.
            """

            ...

        def configure_bounds(self, width: int, height: int) -> None:
            """
            Recommended window geometry bounds

            The configure_bounds event may be sent prior to a xdg_toplevel.configure
            event to communicate the bounds a window geometry size is recommended
            to constrain to.

            The passed width and height are in surface coordinate space. If width
            and height are 0, it means bounds is unknown and equivalent to as if no
            configure_bounds event was ever sent for this surface.

            The bounds can for example correspond to the size of a monitor excluding
            any panels or other shell components, so that a surface isn't created in
            a way that it cannot fit.

            The bounds may change at any point, and in such a case, a new
            xdg_toplevel.configure_bounds will be sent, followed by
            xdg_toplevel.configure and xdg_surface.configure.
            """

            ...

        def wm_capabilities(self, capabilities: list) -> None:
            """
            Compositor capabilities

            This event advertises the capabilities supported by the compositor. If
            a capability isn't supported, clients should hide or disable the UI
            elements that expose this functionality. For instance, if the
            compositor doesn't advertise support for minimized toplevels, a button
            triggering the set_minimized request should not be displayed.

            The compositor will ignore requests it doesn't support. For instance,
            a compositor which doesn't advertise support for minimized will ignore
            set_minimized requests.

            Compositors must send this event once before the first
            xdg_surface.configure event. When the capabilities change, compositors
            must send this event again and then send an xdg_surface.configure
            event.

            The configured state should not be applied immediately. See
            xdg_surface.configure for details.

            The capabilities are sent as an array of 32-bit unsigned integers in
            native endianness.

            Args:
                capabilities: Array of 32-bit capabilities
            """

            ...

class xdg_popup:
    """
    Short-lived, popup surfaces for menus

    A popup surface is a short-lived, temporary surface. It can be used to
    implement for example menus, popovers, tooltips and other similar user
    interface concepts.

    A popup can be made to take an explicit grab. See xdg_popup.grab for
    details.

    When the popup is dismissed, a popup_done event will be sent out, and at
    the same time the surface will be unmapped. See the xdg_popup.popup_done
    event for details.

    Explicitly destroying the xdg_popup object will also dismiss the popup and
    unmap the surface. Clients that want to dismiss the popup when another
    surface of their own is clicked should dismiss the popup using the destroy
    request.

    A newly created xdg_popup will be stacked on top of all previously created
    xdg_popup surfaces associated with the same xdg_toplevel.

    The parent of an xdg_popup must be mapped (see the xdg_surface
    description) before the xdg_popup itself.

    The client must call wl_surface.commit on the corresponding wl_surface
    for the xdg_popup state to take effect.
    """
    object_id = 0
    version = 7

    class error(Enum):
        invalid_grab: int
        """Tried to grab after being mapped"""



    def destroy(self) -> None:
        """
        Remove `xdg_popup` interface

        This destroys the popup. Explicitly destroying the xdg_popup
        object will also dismiss the popup, and unmap the surface.

        If this xdg_popup is not the "topmost" popup, the
        xdg_wm_base.not_the_topmost_popup protocol error will be sent.
        """

        ...

    def grab(self, seat: wl_seat, serial: int) -> None:
        """
        Make the popup take an explicit grab

        This request makes the created popup take an explicit grab. An explicit
        grab will be dismissed when the user dismisses the popup, or when the
        client destroys the xdg_popup. This can be done by the user clicking
        outside the surface, using the keyboard, or even locking the screen
        through closing the lid or a timeout.

        If the compositor denies the grab, the popup will be immediately
        dismissed.

        This request must be used in response to some sort of user action like a
        button press, key press, or touch down event. The serial number of the
        event should be passed as 'serial'.

        The parent of a grabbing popup must either be an xdg_toplevel surface or
        another xdg_popup with an explicit grab. If the parent is another
        xdg_popup it means that the popups are nested, with this popup now being
        the topmost popup.

        Nested popups must be destroyed in the reverse order they were created
        in, e.g. the only popup you are allowed to destroy at all times is the
        topmost one.

        When compositors choose to dismiss a popup, they may dismiss every
        nested grabbing popup as well. When a compositor dismisses popups, it
        will follow the same dismissing order as required from the client.

        If the topmost grabbing popup is destroyed, the grab will be returned to
        the parent of the popup, if that parent previously had an explicit grab.

        If the parent is a grabbing popup which has already been dismissed, this
        popup will be immediately dismissed. If the parent is a popup that did
        not take an explicit grab, an error will be raised.

        During a popup grab, the client owning the grab will receive pointer
        and touch events for all their surfaces as normal (similar to an
        "owner-events" grab in X11 parlance), while the top most grabbing popup
        will always have keyboard focus.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
        """

        ...

    def reposition(self, positioner: xdg_positioner, token: int) -> None:
        """
        Recalculate the popup's location

        Reposition an already-mapped popup. The popup will be placed given the
        details in the passed xdg_positioner object, and a
        xdg_popup.repositioned followed by xdg_popup.configure and
        xdg_surface.configure will be emitted in response. Any parameters set
        by the previous positioner will be discarded.

        The passed token will be sent in the corresponding
        xdg_popup.repositioned event. The new popup position will not take
        effect until the corresponding configure event is acknowledged by the
        client. See xdg_popup.repositioned for details. The token itself is
        opaque, and has no other special meaning.

        If multiple reposition requests are sent, the compositor may skip all
        but the last one.

        If the popup is repositioned in response to a configure event for its
        parent, the client should send an xdg_positioner.set_parent_configure
        and possibly an xdg_positioner.set_parent_size request to allow the
        compositor to properly constrain the popup.

        If the popup is repositioned together with a parent that is being
        resized, but not in response to a configure event, the client should
        send an xdg_positioner.set_parent_size request.

        Args:
            token: Reposition request token
        """

        ...

    def on_configure(self, x: int, y: int, width: int, height: int) -> None:
        """
        Configure the popup surface.

        Override to handle [`wayland.xdg_popup.events.configure`][].
        """

        ...

    def on_popup_done(self) -> None:
        """
        Popup interaction is done.

        Override to handle [`wayland.xdg_popup.events.popup_done`][].
        """

        ...

    def on_repositioned(self, token: int) -> None:
        """
        Signal the completion of a repositioned request.

        Override to handle [`wayland.xdg_popup.events.repositioned`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, x: int, y: int, width: int, height: int) -> None:
            """
            Configure the popup surface

            This event asks the popup surface to configure itself given the
            configuration. The configured state should not be applied immediately.
            See xdg_surface.configure for details.

            The x and y arguments represent the position the popup was placed at
            given the xdg_positioner rule, relative to the upper left corner of the
            window geometry of the parent surface.

            For version 2 or older, the configure event for an xdg_popup is only
            ever sent once for the initial configuration. Starting with version 3,
            it may be sent again if the popup is setup with an xdg_positioner with
            set_reactive requested, or in response to xdg_popup.reposition requests.

            Args:
                x: X position relative to parent surface window geometry
                y: Y position relative to parent surface window geometry
                width: Window geometry width
                height: Window geometry height
            """

            ...

        def popup_done(self) -> None:
            """
            Popup interaction is done

            The popup_done event is sent out when a popup is dismissed by the
            compositor. The client should destroy the xdg_popup object at this
            point.
            """

            ...

        def repositioned(self, token: int) -> None:
            """
            Signal the completion of a repositioned request

            The repositioned event is sent as part of a popup configuration
            sequence, together with xdg_popup.configure and lastly
            xdg_surface.configure to notify the completion of a reposition request.

            The repositioned event is to notify about the completion of a
            xdg_popup.reposition request. The token argument is the token passed
            in the xdg_popup.reposition request.

            Immediately after this event is emitted, xdg_popup.configure and
            xdg_surface.configure will be sent with the updated size and position,
            as well as a new configure serial.

            The client should optionally update the content of the popup, but must
            acknowledge the new popup configuration for the new position to take
            effect. See xdg_surface.ack_configure for details.

            Args:
                token: Reposition request token
            """

            ...

class wp_alpha_modifier_v1:
    """
    Surface alpha modifier manager

    This interface allows a client to set a factor for the alpha values on a
    surface, which can be used to offload such operations to the compositor,
    which can in turn for example offload them to KMS.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_constructed: int
        """`wl_surface` already has a alpha modifier object"""



    def destroy(self) -> None:
        """
        Destroy the alpha modifier manager object

        Destroy the alpha modifier manager. This doesn't destroy objects
        created with the manager.
        """

        ...

    def get_surface(self, surface: wl_surface) -> wp_alpha_modifier_surface_v1:
        """
        Create a new alpha modifier surface object

        Create a new alpha modifier surface object associated with the
        given wl_surface. If there is already such an object associated with
        the wl_surface, the already_constructed error will be raised.

        Returns:
            wp_alpha_modifier_surface_v1: The created object
        """

        ...

class wp_alpha_modifier_surface_v1:
    """
    Alpha modifier object for a surface

    This interface allows the client to set a factor for the alpha values on
    a surface, which can be used to offload such operations to the compositor.
    The default factor is UINT32_MAX.

    This object has to be destroyed before the associated wl_surface. Once the
    wl_surface is destroyed, all request on this object will raise the
    no_surface error.
    """
    object_id = 0
    version = 1

    class error(Enum):
        no_surface: int
        """`wl_surface` was destroyed"""



    def destroy(self) -> None:
        """
        Destroy the alpha modifier object

        This destroys the object, and is equivalent to set_multiplier with
        a value of UINT32_MAX, with the same double-buffered semantics as
        set_multiplier.
        """

        ...

    def set_multiplier(self, factor: int) -> None:
        """
        Specify the alpha multiplier

        Sets the alpha multiplier for the surface. The alpha multiplier is
        double-buffered state, see wl_surface.commit for details.

        This factor is applied in the compositor's blending space, as an
        additional step after the processing of per-pixel alpha values for the
        wl_surface. The exact meaning of the factor is thus undefined, unless
        the blending space is specified in a different extension.

        This multiplier is applied even if the buffer attached to the
        wl_surface doesn't have an alpha channel; in that case an alpha value
        of one is used instead.

        Zero means completely transparent, UINT32_MAX means completely opaque.
        """

        ...

class wp_color_manager_v1:
    """
    Color manager singleton

    A singleton global interface used for getting color management extensions
    for wl_surface and wl_output objects, and for creating client defined
    image description objects. The extension interfaces allow
    getting the image description of outputs and setting the image
    description of surfaces.

    Compositors should never remove this global.
    """
    object_id = 0
    version = 1

    class error(Enum):
        unsupported_feature: int
        """Request not supported"""

        surface_exists: int
        """Color management surface exists already"""



    class render_intent(Enum):
        """
        Rendering intents

        See the ICC.1:2022 specification from the International Color Consortium
        for more details about rendering intents.

        The principles of ICC defined rendering intents apply with all types of
        image descriptions, not only those with ICC file profiles.

        Compositors must support the perceptual rendering intent. Other
        rendering intents are optional.
        """

        perceptual: int
        """Perceptual"""

        relative: int
        """Media-relative colorimetric"""

        saturation: int
        """Saturation"""

        absolute: int
        """Icc-absolute colorimetric"""

        relative_bpc: int
        """Media-relative colorimetric + black point compensation"""



    class feature(Enum):
        """Compositor supported features"""

        icc_v2_v4: int
        """`create_icc_creator` request"""

        parametric: int
        """`create_parametric_creator` request"""

        set_primaries: int
        """Parametric `set_primaries` request"""

        set_tf_power: int
        """Parametric `set_tf_power` request"""

        set_luminances: int
        """Parametric `set_luminances` request"""

        set_mastering_display_primaries: int
        """
        Parametric `set_mastering_display_primaries` request
        The compositor supports set_mastering_display_primaries request with a
        target color volume fully contained inside the primary color volume.
        """

        extended_target_volume: int
        """
        Parametric target exceeds primary color volume
        The compositor additionally supports target color volumes that
        extend outside of the primary color volume.
        This can only be advertised if feature set_mastering_display_primaries
        is supported as well.
        """

        windows_scrgb: int
        """`create_windows_scrgb` request"""



    class primaries(Enum):
        """
        Named color primaries

        Named color primaries used to encode well-known sets of primaries. H.273
        is the authority, when it comes to the exact values of primaries and
        authoritative specifications, where an equivalent code point exists.

        A value of 0 is invalid and will never be present in the list of enums.

        Descriptions do list the specifications for convenience.
        """

        srgb: int
        """
        Color primaries for the srgb color space as defined by the bt.709 standard
        Color primaries as defined by
        - Rec. ITU-R BT.709-6
        - Rec. ITU-R BT.1361-0 conventional colour gamut system and extended
        colour gamut system (historical)
        - IEC 61966-2-1 sRGB or sYCC
        - IEC 61966-2-4
        - Society of Motion Picture and Television Engineers (SMPTE) RP 177
        (1993) Annex B
        Equivalent to H.273 ColourPrimaries code point 1.
        """

        pal_m: int
        """
        Color primaries for pal-m as defined by the bt.470 standard
        Color primaries as defined by
        - Rec. ITU-R BT.470-6 System M (historical)
        - United States National Television System Committee 1953
        Recommendation for transmission standards for color television
        - United States Federal Communications Commission (2003) Title 47 Code
        of Federal Regulations 73.682 (a)(20)
        Equivalent to H.273 ColourPrimaries code point 4.
        """

        pal: int
        """
        Color primaries for pal as defined by the bt.601 standard
        Color primaries as defined by
        - Rec. ITU-R BT.470-6 System B, G (historical)
        - Rec. ITU-R BT.601-7 625
        - Rec. ITU-R BT.1358-0 625 (historical)
        - Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
        Equivalent to H.273 ColourPrimaries code point 5.
        """

        ntsc: int
        """
        Color primaries for ntsc as defined by the bt.601 standard
        Color primaries as defined by
        - Rec. ITU-R BT.601-7 525
        - Rec. ITU-R BT.1358-1 525 or 625 (historical)
        - Rec. ITU-R BT.1700-0 NTSC
        - SMPTE 170M (2004)
        - SMPTE 240M (1999) (historical)
        Equivalent to H.273 ColourPrimaries code point 6 and 7.
        """

        generic_film: int
        """
        Generic film with colour filters using illuminant c
        Color primaries as defined by H.273 for generic film.
        Equivalent to H.273 ColourPrimaries code point 8.
        """

        bt2020: int
        """
        Color primaries as defined by the bt.2020 and bt.2100 standard
        Color primaries as defined by
        - Rec. ITU-R BT.2020-2
        - Rec. ITU-R BT.2100-0
        Equivalent to H.273 ColourPrimaries code point 9.
        """

        cie1931_xyz: int
        """
        Color primaries of the full cie 1931 xyz color space
        Color primaries as defined as the maximum of the CIE 1931 XYZ color
        space by
        - SMPTE ST 428-1
        - (CIE 1931 XYZ as in ISO 11664-1)
        Equivalent to H.273 ColourPrimaries code point 10.
        """

        dci_p3: int
        """
        Color primaries of the dci p3 color space as defined by the smpte rp 431 standard
        Color primaries as defined by Digital Cinema System and published in
        SMPTE RP 431-2 (2011). Equivalent to H.273 ColourPrimaries code point
        11.
        """

        display_p3: int
        """
        Color primaries of display p3 variant of the dci-p3 color space as defined by the smpte eg 432 standard
        Color primaries as defined by Digital Cinema System and published in
        SMPTE EG 432-1 (2010).
        Equivalent to H.273 ColourPrimaries code point 12.
        """

        adobe_rgb: int
        """
        Color primaries of the adobe rgb color space as defined by the iso 12640 standard
        Color primaries as defined by Adobe as "Adobe RGB" and later published
        by ISO 12640-4 (2011).
        """



    class transfer_function(Enum):
        """
        Named transfer functions

        Named transfer functions used to represent well-known transfer
        characteristics. H.273 is the authority, when it comes to the exact
        formulas and authoritative specifications, where an equivalent code
        point exists.

        A value of 0 is invalid and will never be present in the list of enums.

        Descriptions do list the specifications for convenience.
        """

        bt1886: int
        """
        Bt.1886 display transfer characteristic
        Rec. ITU-R BT.1886 is the display transfer characteristic assumed by
        - Rec. ITU-R BT.601-7 525 and 625
        - Rec. ITU-R BT.709-6
        - Rec. ITU-R BT.2020-2
        These recommendations are referred to by H.273 TransferCharacteristics
        code points 1, 6, 14, and 15, which are all equivalent.
        This TF implies these default luminances from Rec. ITU-R BT.2035:
        - primary color volume minimum: 0.01 cd/m²
        - primary color volume maximum: 100 cd/m²
        - reference white: 100 cd/m²
        """

        gamma22: int
        """
        Assumed display gamma 2.2 transfer function
        Transfer characteristics as defined by
        - Rec. ITU-R BT.470-6 System M (historical)
        - United States National Television System Committee 1953
        Recommendation for transmission standards for color television
        - United States Federal Communications Commission (2003) Title 47 Code
        of Federal Regulations 73.682 (a) (20)
        - Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
        Equivalent to H.273 TransferCharacteristics code point 4.
        Note: an sRGB display (IEC 61966-2-1) uses this transfer function.
        """

        gamma28: int
        """
        Assumed display gamma 2.8 transfer function
        Transfer characteristics as defined by
        - Rec. ITU-R BT.470-6 System B, G (historical)
        Equivalent to H.273 TransferCharacteristics code point 5.
        """

        st240: int
        """
        Smpte st 240 transfer function
        Transfer characteristics as defined by
        - SMPTE ST 240 (1999)
        Equivalent to H.273 TransferCharacteristics code point 7.
        """

        ext_linear: int
        """
        Extended linear transfer function
        Linear transfer function defined over all real numbers.
        Normalised electrical values are equal the normalised optical values.
        The differences to H.273 TransferCharacteristics code point 8 are
        the definition over all real numbers.
        """

        log_100: int
        """
        Logarithmic 100:1 transfer function
        Logarithmic transfer characteristic (100:1 range).
        Equivalent to H.273 TransferCharacteristics code point 9.
        """

        log_316: int
        """
        Logarithmic (100*sqrt(10) : 1) transfer function
        Logarithmic transfer characteristic (100 * Sqrt(10) : 1 range).
        Equivalent to H.273 TransferCharacteristics code point 10.
        """

        xvycc: int
        """
        Iec 61966-2-4 transfer function
        Transfer characteristics as defined by
        - IEC 61966-2-4
        Equivalent to H.273 TransferCharacteristics code point 11.
        """

        srgb: int
        """
        Srgb piece-wise transfer function
        Transfer characteristics as defined by
        - IEC 61966-2-1 sRGB
        Equivalent to H.273 TransferCharacteristics code point 13 with
        MatrixCoefficients set to 0.
        Note: This is not appropriate for describing sRGB material.
        sRGB material is intended to be viewed on an sRGB display, and
        that is described by gamma22.
        """

        ext_srgb: int
        """
        Extended srgb piece-wise transfer function
        Transfer characteristics as defined by
        - IEC 61966-2-1 sYCC
        Equivalent to H.273 TransferCharacteristics code point 13 with
        MatrixCoefficients set to anything but 0.
        """

        st2084_pq: int
        """
        Perceptual quantizer transfer function
        Transfer characteristics as defined by
        - SMPTE ST 2084 (2014) for 10-, 12-, 14- and 16-bit systems
        - Rec. ITU-R BT.2100-2 perceptual quantization (PQ) system
        Equivalent to H.273 TransferCharacteristics code point 16.
        This TF implies these default luminances
        - primary color volume minimum: 0.005 cd/m²
        - primary color volume maximum: 10000 cd/m²
        - reference white: 203 cd/m²
        The difference between the primary color volume minimum and maximum
        must be approximately 10000 cd/m² as that is the swing of the EOTF
        defined by ST 2084 and BT.2100. The default value for the
        reference white is a protocol addition: it is suggested by
        Report ITU-R BT.2408-7 and is not part of ST 2084 or BT.2100.
        """

        st428: int
        """
        Smpte st 428 transfer function
        Transfer characteristics as defined by
        - SMPTE ST 428-1 (2019)
        Equivalent to H.273 TransferCharacteristics code point 17.
        """

        hlg: int
        """
        Hybrid log-gamma transfer function
        Transfer characteristics as defined by
        - ARIB STD-B67 (2015)
        - Rec. ITU-R BT.2100-2 hybrid log-gamma (HLG) system
        Equivalent to H.273 TransferCharacteristics code point 18.
        This TF implies these default luminances
        - primary color volume minimum: 0.005 cd/m²
        - primary color volume maximum: 1000 cd/m²
        - reference white: 203 cd/m²
        HLG is a relative display-referred signal with a specified
        non-linear mapping to the display peak luminance (the HLG OOTF).
        All absolute luminance values used here for HLG assume a 1000 cd/m²
        peak display.
        The default value for the reference white is a protocol addition:
        it is suggested by Report ITU-R BT.2408-7 and is not part of
        ARIB STD-B67 or BT.2100.
        """



    def destroy(self) -> None:
        """
        Destroy the color manager

        Destroy the wp_color_manager_v1 object. This does not affect any other
        objects in any way.
        """

        ...

    def get_output(self, output: wl_output) -> wp_color_management_output_v1:
        """
        Create a color management interface for a `wl_output`

        This creates a new wp_color_management_output_v1 object for the
        given wl_output.

        See the wp_color_management_output_v1 interface for more details.

        Returns:
            wp_color_management_output_v1: The created object
        """

        ...

    def get_surface(self, surface: wl_surface) -> wp_color_management_surface_v1:
        """
        Create a color management interface for a `wl_surface`

        If a wp_color_management_surface_v1 object already exists for the given
        wl_surface, the protocol error surface_exists is raised.

        This creates a new color wp_color_management_surface_v1 object for the
        given wl_surface.

        See the wp_color_management_surface_v1 interface for more details.

        Returns:
            wp_color_management_surface_v1: The created object
        """

        ...

    def get_surface_feedback(self, surface: wl_surface) -> wp_color_management_surface_feedback_v1:
        """
        Create a color management feedback interface

        This creates a new color wp_color_management_surface_feedback_v1 object
        for the given wl_surface.

        See the wp_color_management_surface_feedback_v1 interface for more
        details.

        Returns:
            wp_color_management_surface_feedback_v1: The created object
        """

        ...

    def create_icc_creator(self) -> wp_image_description_creator_icc_v1:
        """
        Make a new icc-based image description creator object

        Makes a new ICC-based image description creator object with all
        properties initially unset. The client can then use the object's
        interface to define all the required properties for an image description
        and finally create a wp_image_description_v1 object.

        This request can be used when the compositor advertises
        wp_color_manager_v1.feature.icc_v2_v4.
        Otherwise this request raises the protocol error unsupported_feature.

        Returns:
            wp_image_description_creator_icc_v1: The created object
        """

        ...

    def create_parametric_creator(self) -> wp_image_description_creator_params_v1:
        """
        Make a new parametric image description creator object

        Makes a new parametric image description creator object with all
        properties initially unset. The client can then use the object's
        interface to define all the required properties for an image description
        and finally create a wp_image_description_v1 object.

        This request can be used when the compositor advertises
        wp_color_manager_v1.feature.parametric.
        Otherwise this request raises the protocol error unsupported_feature.

        Returns:
            wp_image_description_creator_params_v1: The created object
        """

        ...

    def create_windows_scrgb(self) -> wp_image_description_v1:
        """
        Create windows-scrgb image description object

        This creates a pre-defined image description for the so-called
        Windows-scRGB stimulus encoding. This comes from the Windows 10 handling
        of its own definition of an scRGB color space for an HDR screen
        driven in BT.2100/PQ signalling mode.

        Windows-scRGB uses sRGB (BT.709) color primaries and white point.
        The transfer characteristic is extended linear.

        The nominal color channel value range is extended, meaning it includes
        negative and greater than 1.0 values. Negative values are used to
        escape the sRGB color gamut boundaries. To make use of the extended
        range, the client needs to use a pixel format that can represent those
        values, e.g. floating-point 16 bits per channel.

        Nominal color value R=G=B=0.0 corresponds to BT.2100/PQ system
        0 cd/m², and R=G=B=1.0 corresponds to BT.2100/PQ system 80 cd/m².
        The maximum is R=G=B=125.0 corresponding to 10k cd/m².

        Windows-scRGB is displayed by Windows 10 by converting it to
        BT.2100/PQ, maintaining the CIE 1931 chromaticity and mapping the
        luminance as above. No adjustment is made to the signal to account
        for the viewing conditions.

        The reference white level of Windows-scRGB is unknown. If a
        reference white level must be assumed for compositor processing, it
        should be R=G=B=2.5375 corresponding to 203 cd/m² of Report ITU-R
        BT.2408-7.

        The target color volume of Windows-scRGB is unknown. The color gamut
        may be anything between sRGB and BT.2100.

        Note: EGL_EXT_gl_colorspace_scrgb_linear definition differs from
        Windows-scRGB by using R=G=B=1.0 as the reference white level, while
        Windows-scRGB reference white level is unknown or varies. However,
        it seems probable that Windows implements both
        EGL_EXT_gl_colorspace_scrgb_linear and Vulkan
        VK_COLOR_SPACE_EXTENDED_SRGB_LINEAR_EXT as Windows-scRGB.

        This request can be used when the compositor advertises
        wp_color_manager_v1.feature.windows_scrgb.
        Otherwise this request raises the protocol error unsupported_feature.

        The resulting image description object does not allow get_information
        request. The wp_image_description_v1.ready event shall be sent.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def on_supported_intent(self, render_intent: wp_color_manager_v1.render_intent) -> None:
        """
        Supported rendering intent.

        Override to handle [`wayland.wp_color_manager_v1.events.supported_intent`][].
        """

        ...

    def on_supported_feature(self, feature: wp_color_manager_v1.feature) -> None:
        """
        Supported features.

        Override to handle [`wayland.wp_color_manager_v1.events.supported_feature`][].
        """

        ...

    def on_supported_tf_named(self, tf: wp_color_manager_v1.transfer_function) -> None:
        """
        Supported named transfer characteristic.

        Override to handle [`wayland.wp_color_manager_v1.events.supported_tf_named`][].
        """

        ...

    def on_supported_primaries_named(self, primaries: wp_color_manager_v1.primaries) -> None:
        """
        Supported named primaries.

        Override to handle [`wayland.wp_color_manager_v1.events.supported_primaries_named`][].
        """

        ...

    def on_done(self) -> None:
        """
        All features have been sent.

        Override to handle [`wayland.wp_color_manager_v1.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def supported_intent(self, render_intent: wp_color_manager_v1.render_intent) -> None:
            """
            Supported rendering intent

            When this object is created, it shall immediately send this event once
            for each rendering intent the compositor supports.

            Args:
                render_intent: Rendering intent
            """

            ...

        def supported_feature(self, feature: wp_color_manager_v1.feature) -> None:
            """
            Supported features

            When this object is created, it shall immediately send this event once
            for each compositor supported feature listed in the enumeration.

            Args:
                feature: Supported feature
            """

            ...

        def supported_tf_named(self, tf: wp_color_manager_v1.transfer_function) -> None:
            """
            Supported named transfer characteristic

            When this object is created, it shall immediately send this event once
            for each named transfer function the compositor supports with the
            parametric image description creator.

            Args:
                tf: Named transfer function
            """

            ...

        def supported_primaries_named(self, primaries: wp_color_manager_v1.primaries) -> None:
            """
            Supported named primaries

            When this object is created, it shall immediately send this event once
            for each named set of primaries the compositor supports with the
            parametric image description creator.

            Args:
                primaries: Named color primaries
            """

            ...

        def done(self) -> None:
            """
            All features have been sent

            This event is sent when all supported rendering intents, features,
            transfer functions and named primaries have been sent.
            """

            ...

class wp_color_management_output_v1:
    """
    Output color properties

    A wp_color_management_output_v1 describes the color properties of an
    output.

    The wp_color_management_output_v1 is associated with the wl_output global
    underlying the wl_output object. Therefore the client destroying the
    wl_output object has no impact, but the compositor removing the output
    global makes the wp_color_management_output_v1 object inert.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the color management output

        Destroy the color wp_color_management_output_v1 object. This does not
        affect any remaining protocol objects.
        """

        ...

    def get_image_description(self) -> wp_image_description_v1:
        """
        Get the image description of the output

        This creates a new wp_image_description_v1 object for the current image
        description of the output. There always is exactly one image description
        active for an output so the client should destroy the image description
        created by earlier invocations of this request. This request is usually
        sent as a reaction to the image_description_changed event or when
        creating a wp_color_management_output_v1 object.

        The image description of an output represents the color encoding the
        output expects. There might be performance and power advantages, as well
        as improved color reproduction, if a content update matches the image
        description of the output it is being shown on. If a content update is
        shown on any other output than the one it matches the image description
        of, then the color reproduction on those outputs might be considerably
        worse.

        The created wp_image_description_v1 object preserves the image
        description of the output from the time the object was created.

        The resulting image description object allows get_information request.

        If this protocol object is inert, the resulting image description object
        shall immediately deliver the wp_image_description_v1.failed event with
        the no_output cause.

        If the interface version is inadequate for the output's image
        description, meaning that the client does not support all the events
        needed to deliver the crucial information, the resulting image
        description object shall immediately deliver the
        wp_image_description_v1.failed event with the low_version cause.

        Otherwise the object shall immediately deliver the ready event.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def on_image_description_changed(self) -> None:
        """
        Image description changed.

        Override to handle [`wayland.wp_color_management_output_v1.events.image_description_changed`][].
        """

        ...

    class events(WaylandEvent):
        def image_description_changed(self) -> None:
            """
            Image description changed

            This event is sent whenever the image description of the output changed,
            followed by one wl_output.done event common to output events across all
            extensions.

            If the client wants to use the updated image description, it needs to do
            get_image_description again, because image description objects are
            immutable.
            """

            ...

class wp_color_management_surface_v1:
    """
    Color management extension to a surface

    A wp_color_management_surface_v1 allows the client to set the color
    space and HDR properties of a surface.

    If the wl_surface associated with the wp_color_management_surface_v1 is
    destroyed, the wp_color_management_surface_v1 object becomes inert.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        render_intent: int
        """Unsupported rendering intent"""

        image_description: int
        """Invalid image description"""

        inert: int
        """Forbidden request on inert object"""



    def destroy(self) -> None:
        """
        Destroy the color management interface for a surface

        Destroy the wp_color_management_surface_v1 object and do the same as
        unset_image_description.
        """

        ...

    def set_image_description(self, image_description: wp_image_description_v1, render_intent: wp_color_manager_v1.render_intent) -> None:
        """
        Set the surface image description

        If this protocol object is inert, the protocol error inert is raised.

        Set the image description of the underlying surface. The image
        description and rendering intent are double-buffered state, see
        wl_surface.commit.

        It is the client's responsibility to understand the image description
        it sets on a surface, and to provide content that matches that image
        description. Compositors might convert images to match their own or any
        other image descriptions.

        Image descriptions which are not ready (see wp_image_description_v1)
        are forbidden in this request, and in such case the protocol error
        image_description is raised.

        All image descriptions which are ready (see wp_image_description_v1)
        are allowed and must always be accepted by the compositor.

        A rendering intent provides the client's preference on how content
        colors should be mapped to each output. The render_intent value must
        be one advertised by the compositor with
        wp_color_manager_v1.render_intent event, otherwise the protocol error
        render_intent is raised.

        When an image description is set on a surface, the Transfer
        Characteristics of the image description defines the valid range of
        the nominal (real-valued) color channel values. The processing of
        out-of-range color channel values is undefined, but compositors are
        recommended to clamp the values to the valid range when possible.

        By default, a surface does not have an associated image description
        nor a rendering intent. The handling of color on such surfaces is
        compositor implementation defined. Compositors should handle such
        surfaces as sRGB, but may handle them differently if they have specific
        requirements.

        Setting the image description has copy semantics; after this request,
        the image description can be immediately destroyed without affecting
        the pending state of the surface.

        Args:
            render_intent: Rendering intent
        """

        ...

    def unset_image_description(self) -> None:
        """
        Remove the surface image description

        If this protocol object is inert, the protocol error inert is raised.

        This request removes any image description from the surface. See
        set_image_description for how a compositor handles a surface without
        an image description. This is double-buffered state, see
        wl_surface.commit.
        """

        ...

class wp_color_management_surface_feedback_v1:
    """
    Color management extension to a surface

    A wp_color_management_surface_feedback_v1 allows the client to get the
    preferred image description of a surface.

    If the wl_surface associated with this object is destroyed, the
    wp_color_management_surface_feedback_v1 object becomes inert.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        inert: int
        """Forbidden request on inert object"""

        unsupported_feature: int
        """Attempted to use an unsupported feature"""



    def destroy(self) -> None:
        """
        Destroy the color management interface for a surface

        Destroy the wp_color_management_surface_feedback_v1 object.
        """

        ...

    def get_preferred(self) -> wp_image_description_v1:
        """
        Get the preferred image description

        If this protocol object is inert, the protocol error inert is raised.

        The preferred image description represents the compositor's preferred
        color encoding for this wl_surface at the current time. There might be
        performance and power advantages, as well as improved color
        reproduction, if the image description of a content update matches the
        preferred image description.

        This creates a new wp_image_description_v1 object for the currently
        preferred image description for the wl_surface. The client should
        stop using and destroy the image descriptions created by earlier
        invocations of this request for the associated wl_surface.
        This request is usually sent as a reaction to the preferred_changed
        event or when creating a wp_color_management_surface_feedback_v1 object
        if the client is capable of adapting to image descriptions.

        The created wp_image_description_v1 object preserves the preferred image
        description of the wl_surface from the time the object was created.

        The resulting image description object allows get_information request.

        If the image description is parametric, the client should set it on its
        wl_surface only if the image description is an exact match with the
        client content. Particularly if everything else matches, but the target
        color volume is greater than what the client needs, the client should
        create its own parameric image description with its exact parameters.

        If the interface version is inadequate for the preferred image
        description, meaning that the client does not support all the
        events needed to deliver the crucial information, the resulting image
        description object shall immediately deliver the
        wp_image_description_v1.failed event with the low_version cause,
        otherwise the object shall immediately deliver the ready event.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def get_preferred_parametric(self) -> wp_image_description_v1:
        """
        Get the preferred image description

        The same description as for get_preferred applies, except the returned
        image description is guaranteed to be parametric. This is meant for
        clients that can only deal with parametric image descriptions.

        If the compositor doesn't support parametric image descriptions, the
        unsupported_feature error is emitted.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def on_preferred_changed(self, identity: int) -> None:
        """
        The preferred image description changed.

        Override to handle [`wayland.wp_color_management_surface_feedback_v1.events.preferred_changed`][].
        """

        ...

    class events(WaylandEvent):
        def preferred_changed(self, identity: int) -> None:
            """
            The preferred image description changed

            The preferred image description is the one which likely has the most
            performance and/or quality benefits for the compositor if used by the
            client for its wl_surface contents. This event is sent whenever the
            compositor changes the wl_surface's preferred image description.

            This event sends the identity of the new preferred state as the argument,
            so clients who are aware of the image description already can reuse it.
            Otherwise, if the client client wants to know what the preferred image
            description is, it shall use the get_preferred request.

            The preferred image description is not automatically used for anything.
            It is only a hint, and clients may set any valid image description with
            set_image_description, but there might be performance and color accuracy
            improvements by providing the wl_surface contents in the preferred
            image description. Therefore clients that can, should render according
            to the preferred image description

            Args:
                identity: Image description id number
            """

            ...

class wp_image_description_creator_icc_v1:
    """
    Holder of image description icc information

    This type of object is used for collecting all the information required
    to create a wp_image_description_v1 object from an ICC file. A complete
    set of required parameters consists of these properties:
    - ICC file

    Each required property must be set exactly once if the client is to create
    an image description. The set requests verify that a property was not
    already set. The create request verifies that all required properties are
    set. There may be several alternative requests for setting each property,
    and in that case the client must choose one of them.

    Once all properties have been set, the create request must be used to
    create the image description object, destroying the creator in the
    process.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        incomplete_set: int
        """Incomplete parameter set"""

        already_set: int
        """Property already set"""

        bad_fd: int
        """Fd not seekable and readable"""

        bad_size: int
        """No or too much data"""

        out_of_file: int
        """Offset + length exceeds file size"""



    def create(self) -> wp_image_description_v1:
        """
        Create the image description object from icc data

        Create an image description object based on the ICC information
        previously set on this object. A compositor must parse the ICC data in
        some undefined but finite amount of time.

        The completeness of the parameter set is verified. If the set is not
        complete, the protocol error incomplete_set is raised. For the
        definition of a complete set, see the description of this interface.

        If the particular combination of the information is not supported
        by the compositor, the resulting image description object shall
        immediately deliver the wp_image_description_v1.failed event with the
        'unsupported' cause. If a valid image description was created from the
        information, the wp_image_description_v1.ready event will eventually
        be sent instead.

        This request destroys the wp_image_description_creator_icc_v1 object.

        The resulting image description object does not allow get_information
        request.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def set_icc_file(self, icc_profile: fd, offset: int, length: int) -> None:
        """
        Set the icc profile file

        Sets the ICC profile file to be used as the basis of the image
        description.

        The data shall be found through the given fd at the given offset, having
        the given length. The fd must be seekable and readable. Violating these
        requirements raises the bad_fd protocol error.

        If reading the data fails due to an error independent of the client, the
        compositor shall send the wp_image_description_v1.failed event on the
        created wp_image_description_v1 with the 'operating_system' cause.

        The maximum size of the ICC profile is 32 MB. If length is greater than
        that or zero, the protocol error bad_size is raised. If offset + length
        exceeds the file size, the protocol error out_of_file is raised.

        A compositor may read the file at any time starting from this request
        and only until whichever happens first:
        - If create request was issued, the wp_image_description_v1 object
          delivers either failed or ready event; or
        - if create request was not issued, this
          wp_image_description_creator_icc_v1 object is destroyed.

        A compositor shall not modify the contents of the file, and the fd may
        be sealed for writes and size changes. The client must ensure to its
        best ability that the data does not change while the compositor is
        reading it.

        The data must represent a valid ICC profile. The ICC profile version
        must be 2 or 4, it must be a 3 channel profile and the class must be
        Display or ColorSpace. Violating these requirements will not result in a
        protocol error, but will eventually send the
        wp_image_description_v1.failed event on the created
        wp_image_description_v1 with the 'unsupported' cause.

        See the International Color Consortium specification ICC.1:2022 for more
        details about ICC profiles.

        If ICC file has already been set on this object, the protocol error
        already_set is raised.

        Args:
            icc_profile: Icc profile
            offset: Byte offset in fd to start of icc data
            length: Length of icc data in bytes
        """

        ...

class wp_image_description_creator_params_v1:
    """
    Holder of image description parameters

    This type of object is used for collecting all the parameters required
    to create a wp_image_description_v1 object. A complete set of required
    parameters consists of these properties:
    - transfer characteristic function (tf)
    - chromaticities of primaries and white point (primary color volume)

    The following properties are optional and have a well-defined default
    if not explicitly set:
    - primary color volume luminance range
    - reference white luminance level
    - mastering display primaries and white point (target color volume)
    - mastering luminance range

    The following properties are optional and will be ignored
    if not explicitly set:
    - maximum content light level
    - maximum frame-average light level

    Each required property must be set exactly once if the client is to create
    an image description. The set requests verify that a property was not
    already set. The create request verifies that all required properties are
    set. There may be several alternative requests for setting each property,
    and in that case the client must choose one of them.

    Once all properties have been set, the create request must be used to
    create the image description object, destroying the creator in the
    process.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        incomplete_set: int
        """Incomplete parameter set"""

        already_set: int
        """Property already set"""

        unsupported_feature: int
        """Request not supported"""

        invalid_tf: int
        """Invalid transfer characteristic"""

        invalid_primaries_named: int
        """Invalid primaries named"""

        invalid_luminance: int
        """Invalid luminance value or range"""



    def create(self) -> wp_image_description_v1:
        """
        Create the image description object using params

        Create an image description object based on the parameters previously
        set on this object.

        The completeness of the parameter set is verified. If the set is not
        complete, the protocol error incomplete_set is raised. For the
        definition of a complete set, see the description of this interface.

        The protocol error invalid_luminance is raised if any of the following
        requirements is not met:
        - When max_cll is set, it must be greater than min L and less or equal
          to max L of the mastering luminance range.
        - When max_fall is set, it must be greater than min L and less or equal
          to max L of the mastering luminance range.
        - When both max_cll and max_fall are set, max_fall must be less or equal
          to max_cll.

        If the particular combination of the parameter set is not supported
        by the compositor, the resulting image description object shall
        immediately deliver the wp_image_description_v1.failed event with the
        'unsupported' cause. If a valid image description was created from the
        parameter set, the wp_image_description_v1.ready event will eventually
        be sent instead.

        This request destroys the wp_image_description_creator_params_v1
        object.

        The resulting image description object does not allow get_information
        request.

        Returns:
            wp_image_description_v1: The created object
        """

        ...

    def set_tf_named(self, tf: wp_color_manager_v1.transfer_function) -> None:
        """
        Named transfer characteristic

        Sets the transfer characteristic using explicitly enumerated named
        functions.

        When the resulting image description is attached to an image, the
        content should be encoded and decoded according to the industry standard
        practices for the transfer characteristic.

        Only names advertised with wp_color_manager_v1 event supported_tf_named
        are allowed. Other values shall raise the protocol error invalid_tf.

        If transfer characteristic has already been set on this object, the
        protocol error already_set is raised.

        Args:
            tf: Named transfer function
        """

        ...

    def set_tf_power(self, eexp: int) -> None:
        """
        Transfer characteristic as a power curve

        Sets the color component transfer characteristic to a power curve with
        the given exponent. Negative values are handled by mirroring the
        positive half of the curve through the origin. The valid domain and
        range of the curve are all finite real numbers. This curve represents
        the conversion from electrical to optical color channel values.

        When the resulting image description is attached to an image, the
        content should be encoded with the inverse of the power curve.

        The curve exponent shall be multiplied by 10000 to get the argument eexp
        value to carry the precision of 4 decimals.

        The curve exponent must be at least 1.0 and at most 10.0. Otherwise the
        protocol error invalid_tf is raised.

        If transfer characteristic has already been set on this object, the
        protocol error already_set is raised.

        This request can be used when the compositor advertises
        wp_color_manager_v1.feature.set_tf_power. Otherwise this request raises
        the protocol error unsupported_feature.

        Args:
            eexp: The exponent * 10000
        """

        ...

    def set_primaries_named(self, primaries: wp_color_manager_v1.primaries) -> None:
        """
        Named primaries

        Sets the color primaries and white point using explicitly named sets.
        This describes the primary color volume which is the basis for color
        value encoding.

        Only names advertised with wp_color_manager_v1 event
        supported_primaries_named are allowed. Other values shall raise the
        protocol error invalid_primaries_named.

        If primaries have already been set on this object, the protocol error
        already_set is raised.

        Args:
            primaries: Named primaries
        """

        ...

    def set_primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
        """
        Primaries as chromaticity coordinates

        Sets the color primaries and white point using CIE 1931 xy chromaticity
        coordinates. This describes the primary color volume which is the basis
        for color value encoding.

        Each coordinate value is multiplied by 1 million to get the argument
        value to carry precision of 6 decimals.

        If primaries have already been set on this object, the protocol error
        already_set is raised.

        This request can be used if the compositor advertises
        wp_color_manager_v1.feature.set_primaries. Otherwise this request raises
        the protocol error unsupported_feature.

        Args:
            r_x: Red x * 1m
            r_y: Red y * 1m
            g_x: Green x * 1m
            g_y: Green y * 1m
            b_x: Blue x * 1m
            b_y: Blue y * 1m
            w_x: White x * 1m
            w_y: White y * 1m
        """

        ...

    def set_luminances(self, min_lum: int, max_lum: int, reference_lum: int) -> None:
        """
        Primary color volume luminance range and reference white

        Sets the primary color volume luminance range and the reference white
        luminance level. These values include the minimum display emission
        and ambient flare luminances, assumed to be optically additive and have
        the chromaticity of the primary color volume white point.

        The default luminances from
        https://www.color.org/chardata/rgb/srgb.xalter are
        - primary color volume minimum: 0.2 cd/m²
        - primary color volume maximum: 80 cd/m²
        - reference white: 80 cd/m²

        Setting a named transfer characteristic can imply other default
        luminances.

        The default luminances get overwritten when this request is used.
        With transfer_function.st2084_pq the given 'max_lum' value is ignored,
        and 'max_lum' is taken as 'min_lum' + 10000 cd/m².

        'min_lum' and 'max_lum' specify the minimum and maximum luminances of
        the primary color volume as reproduced by the targeted display.

        'reference_lum' specifies the luminance of the reference white as
        reproduced by the targeted display, and reflects the targeted viewing
        environment.

        Compositors should make sure that all content is anchored, meaning that
        an input signal level of 'reference_lum' on one image description and
        another input signal level of 'reference_lum' on another image
        description should produce the same output level, even though the
        'reference_lum' on both image representations can be different.

        'reference_lum' may be higher than 'max_lum'. In that case reaching
        the reference white output level in image content requires the
        'extended_target_volume' feature support.

        If 'max_lum' or 'reference_lum' are less than or equal to 'min_lum',
        the protocol error invalid_luminance is raised.

        The minimum luminance is multiplied by 10000 to get the argument
        'min_lum' value and carries precision of 4 decimals. The maximum
        luminance and reference white luminance values are unscaled.

        If the primary color volume luminance range and the reference white
        luminance level have already been set on this object, the protocol error
        already_set is raised.

        This request can be used if the compositor advertises
        wp_color_manager_v1.feature.set_luminances. Otherwise this request
        raises the protocol error unsupported_feature.

        Args:
            min_lum: Minimum luminance (cd/m²) * 10000
            max_lum: Maximum luminance (cd/m²)
            reference_lum: Reference white luminance (cd/m²)
        """

        ...

    def set_mastering_display_primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
        """
        Mastering display primaries as chromaticity coordinates

        Provides the color primaries and white point of the mastering display
        using CIE 1931 xy chromaticity coordinates. This is compatible with the
        SMPTE ST 2086 definition of HDR static metadata.

        The mastering display primaries and mastering display luminances define
        the target color volume.

        If mastering display primaries are not explicitly set, the target color
        volume is assumed to have the same primaries as the primary color volume.

        The target color volume is defined by all tristimulus values between 0.0
        and 1.0 (inclusive) of the color space defined by the given mastering
        display primaries and white point. The colorimetry is identical between
        the container color space and the mastering display color space,
        including that no chromatic adaptation is applied even if the white
        points differ.

        The target color volume can exceed the primary color volume to allow for
        a greater color volume with an existing color space definition (for
        example scRGB). It can be smaller than the primary color volume to
        minimize gamut and tone mapping distances for big color spaces (HDR
        metadata).

        To make use of the entire target color volume a suitable pixel format
        has to be chosen (e.g. floating point to exceed the primary color
        volume, or abusing limited quantization range as with xvYCC).

        Each coordinate value is multiplied by 1 million to get the argument
        value to carry precision of 6 decimals.

        If mastering display primaries have already been set on this object, the
        protocol error already_set is raised.

        This request can be used if the compositor advertises
        wp_color_manager_v1.feature.set_mastering_display_primaries. Otherwise
        this request raises the protocol error unsupported_feature. The
        advertisement implies support only for target color volumes fully
        contained within the primary color volume.

        If a compositor additionally supports target color volume exceeding the
        primary color volume, it must advertise
        wp_color_manager_v1.feature.extended_target_volume. If a client uses
        target color volume exceeding the primary color volume and the
        compositor does not support it, the result is implementation defined.
        Compositors are recommended to detect this case and fail the image
        description gracefully, but it may as well result in color artifacts.

        Args:
            r_x: Red x * 1m
            r_y: Red y * 1m
            g_x: Green x * 1m
            g_y: Green y * 1m
            b_x: Blue x * 1m
            b_y: Blue y * 1m
            w_x: White x * 1m
            w_y: White y * 1m
        """

        ...

    def set_mastering_luminance(self, min_lum: int, max_lum: int) -> None:
        """
        Display mastering luminance range

        Sets the luminance range that was used during the content mastering
        process as the minimum and maximum absolute luminance L. These values
        include the minimum display emission and ambient flare luminances,
        assumed to be optically additive and have the chromaticity of the
        primary color volume white point. This should be
        compatible with the SMPTE ST 2086 definition of HDR static metadata.

        The mastering display primaries and mastering display luminances define
        the target color volume.

        If mastering luminances are not explicitly set, the target color volume
        is assumed to have the same min and max luminances as the primary color
        volume.

        If max L is less than or equal to min L, the protocol error
        invalid_luminance is raised.

        Min L value is multiplied by 10000 to get the argument min_lum value
        and carry precision of 4 decimals. Max L value is unscaled for max_lum.

        This request can be used if the compositor advertises
        wp_color_manager_v1.feature.set_mastering_display_primaries. Otherwise
        this request raises the protocol error unsupported_feature. The
        advertisement implies support only for target color volumes fully
        contained within the primary color volume.

        If a compositor additionally supports target color volume exceeding the
        primary color volume, it must advertise
        wp_color_manager_v1.feature.extended_target_volume. If a client uses
        target color volume exceeding the primary color volume and the
        compositor does not support it, the result is implementation defined.
        Compositors are recommended to detect this case and fail the image
        description gracefully, but it may as well result in color artifacts.

        Args:
            min_lum: Min l (cd/m²) * 10000
            max_lum: Max l (cd/m²)
        """

        ...

    def set_max_cll(self, max_cll: int) -> None:
        """
        Maximum content light level

        Sets the maximum content light level (max_cll) as defined by CTA-861-H.

        max_cll is undefined by default.

        Args:
            max_cll: Maximum content light level (cd/m²)
        """

        ...

    def set_max_fall(self, max_fall: int) -> None:
        """
        Maximum frame-average light level

        Sets the maximum frame-average light level (max_fall) as defined by
        CTA-861-H.

        max_fall is undefined by default.

        Args:
            max_fall: Maximum frame-average light level (cd/m²)
        """

        ...

class wp_image_description_v1:
    """
    Colorimetric image description

    An image description carries information about the color encoding used on
    a surface when attached to a wl_surface via
    wp_color_management_surface_v1.set_image_description. A compositor can use
    this information to decode pixel values into colorimetrically meaningful
    quantities.

    Note, that the wp_image_description_v1 object is not ready to be used
    immediately after creation. The object eventually delivers either the
    'ready' or the 'failed' event, specified in all requests creating it. The
    object is deemed "ready" after receiving the 'ready' event.

    An object which is not ready is illegal to use, it can only be destroyed.
    Any other request in this interface shall result in the 'not_ready'
    protocol error. Attempts to use an object which is not ready through other
    interfaces shall raise protocol errors defined there.

    Once created and regardless of how it was created, a
    wp_image_description_v1 object always refers to one fixed image
    description. It cannot change after creation.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        not_ready: int
        """Attempted to use an object which is not ready"""

        no_information: int
        """`get_information` not allowed"""



    class cause(Enum):
        """Generic reason for failure"""

        low_version: int
        """Interface version too low"""

        unsupported: int
        """Unsupported image description data"""

        operating_system: int
        """Error independent of the client"""

        no_output: int
        """The relevant output no longer exists"""



    def destroy(self) -> None:
        """
        Destroy the image description

        Destroy this object. It is safe to destroy an object which is not ready.

        Destroying a wp_image_description_v1 object has no side-effects, not
        even if a wp_color_management_surface_v1.set_image_description has not
        yet been followed by a wl_surface.commit.
        """

        ...

    def get_information(self) -> wp_image_description_info_v1:
        """
        Get information about the image description

        Creates a wp_image_description_info_v1 object which delivers the
        information that makes up the image description.

        Not all image description protocol objects allow get_information
        request. Whether it is allowed or not is defined by the request that
        created the object. If get_information is not allowed, the protocol
        error no_information is raised.

        Returns:
            wp_image_description_info_v1: The created object
        """

        ...

    def on_failed(self, cause: wp_image_description_v1.cause, msg: str) -> None:
        """
        Graceful error on creating the image description.

        Override to handle [`wayland.wp_image_description_v1.events.failed`][].
        """

        ...

    def on_ready(self, identity: int) -> None:
        """
        Indication that the object is ready to be used.

        Override to handle [`wayland.wp_image_description_v1.events.ready`][].
        """

        ...

    class events(WaylandEvent):
        def failed(self, cause: wp_image_description_v1.cause, msg: str) -> None:
            """
            Graceful error on creating the image description

            If creating a wp_image_description_v1 object fails for a reason that is
            not defined as a protocol error, this event is sent.

            The requests that create image description objects define whether and
            when this can occur. Only such creation requests can trigger this event.
            This event cannot be triggered after the image description was
            successfully formed.

            Once this event has been sent, the wp_image_description_v1 object will
            never become ready and it can only be destroyed.

            Args:
                cause: Generic reason
                msg: Ad hoc human-readable explanation
            """

            ...

        def ready(self, identity: int) -> None:
            """
            Indication that the object is ready to be used

            Once this event has been sent, the wp_image_description_v1 object is
            deemed "ready". Ready objects can be used to send requests and can be
            used through other interfaces.

            Every ready wp_image_description_v1 protocol object refers to an
            underlying image description record in the compositor. Multiple protocol
            objects may end up referring to the same record. Clients may identify
            these "copies" by comparing their id numbers: if the numbers from two
            protocol objects are identical, the protocol objects refer to the same
            image description record. Two different image description records
            cannot have the same id number simultaneously. The id number does not
            change during the lifetime of the image description record.

            The id number is valid only as long as the protocol object is alive. If
            all protocol objects referring to the same image description record are
            destroyed, the id number may be recycled for a different image
            description record.

            Image description id number is not a protocol object id. Zero is
            reserved as an invalid id number. It shall not be possible for a client
            to refer to an image description by its id number in protocol. The id
            numbers might not be portable between Wayland connections. A compositor
            shall not send an invalid id number.

            This identity allows clients to de-duplicate image description records
            and avoid get_information request if they already have the image
            description information.

            Args:
                identity: Image description id number
            """

            ...

class wp_image_description_info_v1:
    """
    Colorimetric image description information

    Sends all matching events describing an image description object exactly
    once and finally sends the 'done' event.

    This means
    - if the image description is parametric, it must send
      - primaries
      - named_primaries, if applicable
      - at least one of tf_power and tf_named, as applicable
      - luminances
      - target_primaries
      - target_luminance
    - if the image description is parametric, it may send, if applicable,
      - target_max_cll
      - target_max_fall
    - if the image description contains an ICC profile, it must send the
      icc_file event

    Once a wp_image_description_info_v1 object has delivered a 'done' event it
    is automatically destroyed.

    Every wp_image_description_info_v1 created from the same
    wp_image_description_v1 shall always return the exact same data.
    """
    object_id = 0
    version = 1



    def on_done(self) -> None:
        """
        End of information.

        Override to handle [`wayland.wp_image_description_info_v1.events.done`][].
        """

        ...

    def on_icc_file(self, icc: fd, icc_size: int) -> None:
        """
        Icc profile matching the image description.

        Override to handle [`wayland.wp_image_description_info_v1.events.icc_file`][].
        """

        ...

    def on_primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
        """
        Primaries as chromaticity coordinates.

        Override to handle [`wayland.wp_image_description_info_v1.events.primaries`][].
        """

        ...

    def on_primaries_named(self, primaries: wp_color_manager_v1.primaries) -> None:
        """
        Named primaries.

        Override to handle [`wayland.wp_image_description_info_v1.events.primaries_named`][].
        """

        ...

    def on_tf_power(self, eexp: int) -> None:
        """
        Transfer characteristic as a power curve.

        Override to handle [`wayland.wp_image_description_info_v1.events.tf_power`][].
        """

        ...

    def on_tf_named(self, tf: wp_color_manager_v1.transfer_function) -> None:
        """
        Named transfer characteristic.

        Override to handle [`wayland.wp_image_description_info_v1.events.tf_named`][].
        """

        ...

    def on_luminances(self, min_lum: int, max_lum: int, reference_lum: int) -> None:
        """
        Primary color volume luminance range and reference white.

        Override to handle [`wayland.wp_image_description_info_v1.events.luminances`][].
        """

        ...

    def on_target_primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
        """
        Target primaries as chromaticity coordinates.

        Override to handle [`wayland.wp_image_description_info_v1.events.target_primaries`][].
        """

        ...

    def on_target_luminance(self, min_lum: int, max_lum: int) -> None:
        """
        Target luminance range.

        Override to handle [`wayland.wp_image_description_info_v1.events.target_luminance`][].
        """

        ...

    def on_target_max_cll(self, max_cll: int) -> None:
        """
        Target maximum content light level.

        Override to handle [`wayland.wp_image_description_info_v1.events.target_max_cll`][].
        """

        ...

    def on_target_max_fall(self, max_fall: int) -> None:
        """
        Target maximum frame-average light level.

        Override to handle [`wayland.wp_image_description_info_v1.events.target_max_fall`][].
        """

        ...

    class events(WaylandEvent):
        def done(self) -> None:
            """
            End of information

            Signals the end of information events and destroys the object.
            """

            ...

        def icc_file(self, icc: fd, icc_size: int) -> None:
            """
            Icc profile matching the image description

            The icc argument provides a file descriptor to the client which may be
            memory-mapped to provide the ICC profile matching the image description.
            The fd is read-only, and if mapped then it must be mapped with
            MAP_PRIVATE by the client.

            The ICC profile version and other details are determined by the
            compositor. There is no provision for a client to ask for a specific
            kind of a profile.

            Args:
                icc: Icc profile file descriptor
                icc_size: Icc profile size, in bytes
            """

            ...

        def primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
            """
            Primaries as chromaticity coordinates

            Delivers the primary color volume primaries and white point using CIE
            1931 xy chromaticity coordinates.

            Each coordinate value is multiplied by 1 million to get the argument
            value to carry precision of 6 decimals.

            Args:
                r_x: Red x * 1m
                r_y: Red y * 1m
                g_x: Green x * 1m
                g_y: Green y * 1m
                b_x: Blue x * 1m
                b_y: Blue y * 1m
                w_x: White x * 1m
                w_y: White y * 1m
            """

            ...

        def primaries_named(self, primaries: wp_color_manager_v1.primaries) -> None:
            """
            Named primaries

            Delivers the primary color volume primaries and white point using an
            explicitly enumerated named set.

            Args:
                primaries: Named primaries
            """

            ...

        def tf_power(self, eexp: int) -> None:
            """
            Transfer characteristic as a power curve

            The color component transfer characteristic of this image description is
            a pure power curve. This event provides the exponent of the power
            function. This curve represents the conversion from electrical to
            optical pixel or color values.

            The curve exponent has been multiplied by 10000 to get the argument eexp
            value to carry the precision of 4 decimals.

            Args:
                eexp: The exponent * 10000
            """

            ...

        def tf_named(self, tf: wp_color_manager_v1.transfer_function) -> None:
            """
            Named transfer characteristic

            Delivers the transfer characteristic using an explicitly enumerated
            named function.

            Args:
                tf: Named transfer function
            """

            ...

        def luminances(self, min_lum: int, max_lum: int, reference_lum: int) -> None:
            """
            Primary color volume luminance range and reference white

            Delivers the primary color volume luminance range and the reference
            white luminance level. These values include the minimum display emission
            and ambient flare luminances, assumed to be optically additive and have
            the chromaticity of the primary color volume white point.

            The minimum luminance is multiplied by 10000 to get the argument
            'min_lum' value and carries precision of 4 decimals. The maximum
            luminance and reference white luminance values are unscaled.

            Args:
                min_lum: Minimum luminance (cd/m²) * 10000
                max_lum: Maximum luminance (cd/m²)
                reference_lum: Reference white luminance (cd/m²)
            """

            ...

        def target_primaries(self, r_x: int, r_y: int, g_x: int, g_y: int, b_x: int, b_y: int, w_x: int, w_y: int) -> None:
            """
            Target primaries as chromaticity coordinates

            Provides the color primaries and white point of the target color volume
            using CIE 1931 xy chromaticity coordinates. This is compatible with the
            SMPTE ST 2086 definition of HDR static metadata for mastering displays.

            While primary color volume is about how color is encoded, the target
            color volume is the actually displayable color volume. If target color
            volume is equal to the primary color volume, then this event is not
            sent.

            Each coordinate value is multiplied by 1 million to get the argument
            value to carry precision of 6 decimals.

            Args:
                r_x: Red x * 1m
                r_y: Red y * 1m
                g_x: Green x * 1m
                g_y: Green y * 1m
                b_x: Blue x * 1m
                b_y: Blue y * 1m
                w_x: White x * 1m
                w_y: White y * 1m
            """

            ...

        def target_luminance(self, min_lum: int, max_lum: int) -> None:
            """
            Target luminance range

            Provides the luminance range that the image description is targeting as
            the minimum and maximum absolute luminance L. These values include the
            minimum display emission and ambient flare luminances, assumed to be
            optically additive and have the chromaticity of the primary color
            volume white point. This should be compatible with the SMPTE ST 2086
            definition of HDR static metadata.

            This luminance range is only theoretical and may not correspond to the
            luminance of light emitted on an actual display.

            Min L value is multiplied by 10000 to get the argument min_lum value and
            carry precision of 4 decimals. Max L value is unscaled for max_lum.

            Args:
                min_lum: Min l (cd/m²) * 10000
                max_lum: Max l (cd/m²)
            """

            ...

        def target_max_cll(self, max_cll: int) -> None:
            """
            Target maximum content light level

            Provides the targeted max_cll of the image description. max_cll is
            defined by CTA-861-H.

            This luminance is only theoretical and may not correspond to the
            luminance of light emitted on an actual display.

            Args:
                max_cll: Maximum content light-level (cd/m²)
            """

            ...

        def target_max_fall(self, max_fall: int) -> None:
            """
            Target maximum frame-average light level

            Provides the targeted max_fall of the image description. max_fall is
            defined by CTA-861-H.

            This luminance is only theoretical and may not correspond to the
            luminance of light emitted on an actual display.

            Args:
                max_fall: Maximum frame-average light level (cd/m²)
            """

            ...

class wp_color_representation_manager_v1:
    """
    Color representation manager singleton

    A singleton global interface used for getting color representation
    extensions for wl_surface. The extension interfaces allow setting the
    color representation of surfaces.

    Compositors should never remove this global.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        surface_exists: int
        """Color representation surface exists already"""



    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the wp_color_representation_manager_v1 object. This does not
        affect any other objects in any way.
        """

        ...

    def get_surface(self, surface: wl_surface) -> wp_color_representation_surface_v1:
        """
        Create a color representation interface for a `wl_surface`

        If a wp_color_representation_surface_v1 object already exists for the
        given wl_surface, the protocol error surface_exists is raised.

        This creates a new color wp_color_representation_surface_v1 object for
        the given wl_surface.

        See the wp_color_representation_surface_v1 interface for more details.

        Returns:
            wp_color_representation_surface_v1: The created object
        """

        ...

    def on_supported_alpha_mode(self, alpha_mode: wp_color_representation_surface_v1.alpha_mode) -> None:
        """
        Supported alpha modes.

        Override to handle [`wayland.wp_color_representation_manager_v1.events.supported_alpha_mode`][].
        """

        ...

    def on_supported_coefficients_and_ranges(self, coefficients: wp_color_representation_surface_v1.coefficients, range: wp_color_representation_surface_v1.range) -> None:
        """
        Supported matrix coefficients and ranges.

        Override to handle [`wayland.wp_color_representation_manager_v1.events.supported_coefficients_and_ranges`][].
        """

        ...

    def on_done(self) -> None:
        """
        All features have been sent.

        Override to handle [`wayland.wp_color_representation_manager_v1.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def supported_alpha_mode(self, alpha_mode: wp_color_representation_surface_v1.alpha_mode) -> None:
            """
            Supported alpha modes

            When this object is created, it shall immediately send this event once
            for each alpha mode the compositor supports.

            For the definition of the supported values, see the
            wp_color_representation_surface_v1::alpha_mode enum.

            Args:
                alpha_mode: Supported alpha mode
            """

            ...

        def supported_coefficients_and_ranges(self, coefficients: wp_color_representation_surface_v1.coefficients, range: wp_color_representation_surface_v1.range) -> None:
            """
            Supported matrix coefficients and ranges

            When this object is created, it shall immediately send this event once
            for each matrix coefficient and color range combination the compositor
            supports.

            For the definition of the supported values, see the
            wp_color_representation_surface_v1::coefficients and
            wp_color_representation_surface_v1::range enums.

            Args:
                coefficients: Supported matrix coefficients
                range: Full range flag
            """

            ...

        def done(self) -> None:
            """
            All features have been sent

            This event is sent when all supported features have been sent.
            """

            ...

class wp_color_representation_surface_v1:
    """
    Color representation extension to a surface

    A wp_color_representation_surface_v1 allows the client to set the color
    representation metadata of a surface.

    By default, a surface does not have any color representation metadata set.
    The reconstruction of R, G, B signals on such surfaces is compositor
    implementation defined. The alpha mode is assumed to be
    premultiplied_electrical when the alpha mode is unset.

    If the wl_surface associated with the wp_color_representation_surface_v1
    is destroyed, the wp_color_representation_surface_v1 object becomes inert.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """Protocol errors"""

        alpha_mode: int
        """Unsupported alpha mode"""

        coefficients: int
        """Unsupported coefficients"""

        pixel_format: int
        """The pixel format and a set value are incompatible"""

        inert: int
        """Forbidden request on inert object"""



    class alpha_mode(Enum):
        """
        Alpha mode

        Specifies how the alpha channel affects the color channels.
        """

        premultiplied_electrical: int
        """
        Premultiplied alpha in electrical values
        Electrical color channel values (after transfer function encoding)
        are already multiplied with the alpha channel value.
        """

        premultiplied_optical: int
        """
        Premultiplied alpha in optical values
        Optical color channel values (before transfer function encoding)
        are already multiplied with the alpha channel value.
        """

        straight: int
        """
        Straight alpha
        Alpha channel has not been pre-multiplied into color channels.
        """



    class coefficients(Enum):
        """
        Named coefficients

        Named matrix coefficients used to encode well-known sets of
        coefficients. H.273 is the authority, when it comes to the exact values
        of coefficients and authoritative specifications, where an equivalent
        code point exists.

        A value of 0 is invalid and will never be present in the list of enums.

        Descriptions do list the specifications for convenience.
        """

        identity: int
        """
        The identity matrix
        Coefficients as defined by
        - IEC 61966-2-1 sRGB
        - SMPTE ST 428-1 (2019)
        Equivalent to H.273 MatrixCoefficients code point 0.
        Compatible with pixel formats of the RGB family.
        """

        bt709: int
        """
        Bt.709 matrix coefficients
        Coefficients as defined by
        - Rec. ITU-R BT.709-6
        - Rec. ITU-R BT.1361-0 conventional colour gamut system (historical)
        - Rec. ITU-R BT.1361-0 conventional colour gamut system and extended
        colour gamut system (historical)
        - IEC 61966-2-4 xvYCC709
        - SMPTE RP 177 (1993) Annex B
        Equivalent to H.273 MatrixCoefficients code point 1.
        Compatible with pixel formats of the YCbCr family.
        """

        fcc: int
        """
        Fcc matrix coefficients
        Coefficients as defined by
        - United States Federal Communications Commission (2003) Title 47
        Code of Federal Regulations 73.682 (a) (20)
        Equivalent to H.273 MatrixCoefficients code point 4.
        Compatible with pixel formats of the YCbCr family.
        """

        bt601: int
        """
        Bt.601-7 matrix coefficients
        Coefficients as defined by
        - Rec. ITU-R BT.470-6 System B, G (historical)
        - Rec. ITU-R BT.601-7 625
        - Rec. ITU-R BT.601-7 525
        - Rec. ITU-R BT.1358-0 625 (historical)
        - Rec. ITU-R BT.1358-1 525 or 625 (historical)
        - Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
        - Rec. ITU-R BT.1700-0 NTSC
        - IEC 61966-2-1 sYCC
        - IEC 61966-2-4 xvYCC601
        - SMPTE ST 170 (2004)
        Equivalent to H.273 MatrixCoefficients code point 5, 6.
        Compatible with pixel formats of the YCbCr family.
        """

        smpte240: int
        """
        Smpte st 240 matrix coefficients
        Coefficients as defined by
        - SMPTE ST 240 (1999)
        Equivalent to H.273 MatrixCoefficients code point 7.
        Compatible with pixel formats of the YCbCr family.
        """

        bt2020: int
        """
        Bt.2020 and bt.2100 ycbcr matrix coefficients
        Coefficients as defined by
        - Rec. ITU-R BT.2020-2 (non-constant luminance)
        - Rec. ITU-R BT.2100-2 Y′CbCr
        Equivalent to H.273 MatrixCoefficients code point 9.
        Compatible with pixel formats of the YCbCr family.
        """

        bt2020_cl: int
        """
        Bt.2020 matrix coefficients for constant luminance
        Coefficients as defined by
        - Rec. ITU-R BT.2020-2 (constant luminance)
        Equivalent to H.273 MatrixCoefficients code point 10.
        Compatible with pixel formats of the YCbCr family.
        """

        ictcp: int
        """
        Bt.2100 ictcp matrix coefficients
        Coefficients as defined by
        - Rec. ITU-R BT.2100-2 ICTCP
        Equivalent to H.273 MatrixCoefficients code point 14.
        Compatible with pixel formats of the YCbCr family.
        """



    class range(Enum):
        """
        Color range values

        Possible color range values.

        A value of 0 is invalid and will never be present in the list of enums.
        """

        full: int
        """Full color range"""

        limited: int
        """Limited color range"""



    class chroma_location(Enum):
        """
        Chroma sample location for 4:2:0 ycbcr

        Chroma sample location as defined by H.273 Chroma420SampleLocType.

        A value of 0 is invalid and will never be present in the list of enums.

        The descriptions list the matching Vulkan VkChromaLocation combinations
        for convenience.
        """

        type_0: int
        """
        Horizontal offset of 0, vertical offset of 0.5
        Corresponding to VkChromaLocations:
        - xChromaOffset: VK_CHROMA_LOCATION_COSITED_EVEN
        - yChromaOffset: VK_CHROMA_LOCATION_MIDPOINT
        Equivalent to H.273 Chroma420SampleLocType 0.
        """

        type_1: int
        """
        Horizontal offset of 0.5, vertical offset of 0.5
        Corresponding to VkChromaLocations:
        - xChromaOffset: VK_CHROMA_LOCATION_MIDPOINT
        - yChromaOffset: VK_CHROMA_LOCATION_MIDPOINT
        Equivalent to H.273 Chroma420SampleLocType 1.
        """

        type_2: int
        """
        Horizontal offset of 0, vertical offset of 0
        Corresponding to VkChromaLocations:
        - xChromaOffset: VK_CHROMA_LOCATION_COSITED_EVEN
        - yChromaOffset: VK_CHROMA_LOCATION_COSITED_EVEN
        Equivalent to H.273 Chroma420SampleLocType 2.
        """

        type_3: int
        """
        Horizontal offset of 0.5, vertical offset of 0
        Corresponding to VkChromaLocations:
        - xChromaOffset: VK_CHROMA_LOCATION_MIDPOINT
        - yChromaOffset: VK_CHROMA_LOCATION_COSITED_EVEN
        Equivalent to H.273 Chroma420SampleLocType 3.
        """

        type_4: int
        """
        Horizontal offset of 0, vertical offset of 1
        Equivalent to H.273 Chroma420SampleLocType 4.
        """

        type_5: int
        """
        Horizontal offset of 0.5, vertical offset of 1
        Equivalent to H.273 Chroma420SampleLocType 5.
        """



    def destroy(self) -> None:
        """
        Destroy the color representation

        Destroy the wp_color_representation_surface_v1 object.

        Destroying this object unsets all the color representation metadata from
        the surface. See the wp_color_representation_surface_v1 interface
        description for how a compositor handles a surface without color
        representation metadata. Unsetting is double-buffered state, see
        wl_surface.commit.
        """

        ...

    def set_alpha_mode(self, alpha_mode: wp_color_representation_surface_v1.alpha_mode) -> None:
        """
        Set the surface alpha mode

        If this protocol object is inert, the protocol error inert is raised.

        Assuming an alpha channel exists, it is always linear. The alpha mode
        determines whether and how the color channels include pre-multiplied
        alpha. Using straight alpha might have performance benefits.

        Only alpha modes advertised by the compositor are allowed to be used as
        argument for this request. The "alpha_mode" protocol error is raised
        otherwise.

        Alpha mode is double buffered, see wl_surface.commit.

        Args:
            alpha_mode: Alpha mode
        """

        ...

    def set_coefficients_and_range(self, coefficients: wp_color_representation_surface_v1.coefficients, range: wp_color_representation_surface_v1.range) -> None:
        """
        Set the matrix coefficients and range

        If this protocol object is inert, the protocol error inert is raised.

        Set the matrix coefficients and video range which defines the formula
        and the related constants used to derive red, green and blue signals.
        Usually coefficients correspond to MatrixCoefficients code points in
        H.273.

        Only combinations advertised by the compositor are allowed to be used as
        argument for this request. The "coefficients" protocol error is raised
        otherwise.

        A call to wl_surface.commit verifies that the pixel format and the
        coefficients-range combination in the committed surface contents are
        compatible, if contents exist. The "pixel_format" protocol error is
        raised otherwise.

        A pixel format is compatible with the coefficients-range combination if
        the related equations and conventions as defined in H.273 can produce
        the color channels (RGB or YCbCr) of the pixel format.

        For the definition of the supported combination, see the
        wp_color_representation_surface_v1::coefficients and
        wp_color_representation_surface_v1::range enums.

        The coefficients-range combination is double-buffered, see
        wl_surface.commit.

        Args:
            coefficients: Matrix coefficients
            range: Range
        """

        ...

    def set_chroma_location(self, chroma_location: wp_color_representation_surface_v1.chroma_location) -> None:
        """
        Set the chroma location

        If this protocol object is inert, the protocol error inert is raised.

        Set the chroma location type which defines the position of downsampled
        chroma samples, corresponding to Chroma420SampleLocType code points in
        H.273.

        A call to wl_surface.commit verifies that the pixel format and chroma
        location type in the committed surface contents are compatible, if
        contents exist. The "pixel_format" protocol error is raised otherwise.

        For the definition of the supported chroma location types, see the
        wp_color_representation_surface_v1::chroma_location enum.

        The chroma location type is double-buffered, see wl_surface.commit.

        Args:
            chroma_location: Chroma sample location
        """

        ...

class wp_commit_timing_manager_v1:
    """
    Commit timing

    When a compositor latches on to new content updates it will check for
    any number of requirements of the available content updates (such as
    fences of all buffers being signalled) to consider the update ready.

    This protocol provides a method for adding a time constraint to surface
    content. This constraint indicates to the compositor that a content
    update should be presented as closely as possible to, but not before,
    a specified time.

    This protocol does not change the Wayland property that content
    updates are applied in the order they are received, even when some
    content updates contain timestamps and others do not.

    To provide timestamps, this global factory interface must be used to
    acquire a wp_commit_timing_v1 object for a surface, which may then be
    used to provide timestamp information for commits.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        commit_timer_exists: int
        """Commit timer already exists for surface"""



    def destroy(self) -> None:
        """
        Unbind from the commit timing interface

        Informs the server that the client will no longer be using
        this protocol object. Existing objects created by this object
        are not affected.
        """

        ...

    def get_timer(self, surface: wl_surface) -> wp_commit_timer_v1:
        """
        Request commit timer interface for surface

        Establish a timing controller for a surface.

        Only one commit timer can be created for a surface, or a
        commit_timer_exists protocol error will be generated.

        Returns:
            wp_commit_timer_v1: The created object
        """

        ...

class wp_commit_timer_v1:
    """
    Surface commit timer

    An object to set a time constraint for a content update on a surface.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_timestamp: int
        """Timestamp contains an invalid value"""

        timestamp_exists: int
        """Timestamp exists"""

        surface_destroyed: int
        """The associated surface no longer exists"""



    def set_timestamp(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Specify time the following commit takes effect

        Provide a timing constraint for a surface content update.

        A set_timestamp request may be made before a wl_surface.commit to
        tell the compositor that the content is intended to be presented
        as closely as possible to, but not before, the specified time.
        The time is in the domain of the compositor's presentation clock.

        An invalid_timestamp error will be generated for invalid tv_nsec.

        If a timestamp already exists on the surface, a timestamp_exists
        error is generated.

        Requesting set_timestamp after the commit_timer object's surface is
        destroyed will generate a "surface_destroyed" error.

        Args:
            tv_sec_hi: High 32 bits of the seconds part of target time
            tv_sec_lo: Low 32 bits of the seconds part of target time
            tv_nsec: Nanoseconds part of target time
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the timer

        Informs the server that the client will no longer be using
        this protocol object.

        Existing timing constraints are not affected by the destruction.
        """

        ...

class wp_content_type_manager_v1:
    """
    Surface content type manager

    This interface allows a client to describe the kind of content a surface
    will display, to allow the compositor to optimize its behavior for it.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_constructed: int
        """`wl_surface` already has a content type object"""



    def destroy(self) -> None:
        """
        Destroy the content type manager object

        Destroy the content type manager. This doesn't destroy objects created
        with the manager.
        """

        ...

    def get_surface_content_type(self, surface: wl_surface) -> wp_content_type_v1:
        """
        Create a new content type object

        Create a new content type object associated with the given surface.

        Creating a wp_content_type_v1 from a wl_surface which already has one
        attached is a client error: already_constructed.

        Returns:
            wp_content_type_v1: The created object
        """

        ...

class wp_content_type_v1:
    """
    Content type object for a surface

    The content type object allows the compositor to optimize for the kind
    of content shown on the surface. A compositor may for example use it to
    set relevant drm properties like "content type".

    The client may request to switch to another content type at any time.
    When the associated surface gets destroyed, this object becomes inert and
    the client should destroy it.
    """
    object_id = 0
    version = 1

    class type(Enum):
        """
        Possible content types

        These values describe the available content types for a surface.
        """

        none: int
        """
        No content type applies
        The content type none means that either the application has no data
        about the content type, or that the content doesn't fit into one of
        the other categories.
        """

        photo: int
        """
        Photo content type
        The content type photo describes content derived from digital still
        pictures and may be presented with minimal processing.
        """

        video: int
        """
        Video content type
        The content type video describes a video or animation and may be
        presented with more accurate timing to avoid stutter. Where scaling
        is needed, scaling methods more appropriate for video may be used.
        """

        game: int
        """
        Game content type
        The content type game describes a running game. Its content may be
        presented with reduced latency.
        """



    def destroy(self) -> None:
        """
        Destroy the content type object

        Switch back to not specifying the content type of this surface. This is
        equivalent to setting the content type to none, including double
        buffering semantics. See set_content_type for details.
        """

        ...

    def set_content_type(self, content_type: wp_content_type_v1.type) -> None:
        """
        Specify the content type

        Set the surface content type. This informs the compositor that the
        client believes it is displaying buffers matching this content type.

        This is purely a hint for the compositor, which can be used to adjust
        its behavior or hardware settings to fit the presented content best.

        The content type is double-buffered state, see wl_surface.commit for
        details.

        Args:
            content_type: The content type
        """

        ...

class wp_cursor_shape_manager_v1:
    """
    Cursor shape manager

    This global offers an alternative, optional way to set cursor images. This
    new way uses enumerated cursors instead of a wl_surface like
    wl_pointer.set_cursor does.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the cursor shape manager.
        """

        ...

    def get_pointer(self, pointer: wl_pointer) -> wp_cursor_shape_device_v1:
        """
        Manage the cursor shape of a pointer device

        Obtain a wp_cursor_shape_device_v1 for a wl_pointer object.

        When the pointer capability is removed from the wl_seat, the
        wp_cursor_shape_device_v1 object becomes inert.

        Returns:
            wp_cursor_shape_device_v1: The created object
        """

        ...

    def get_tablet_tool_v2(self, tablet_tool: zwp_tablet_tool_v2) -> wp_cursor_shape_device_v1:
        """
        Manage the cursor shape of a tablet tool device

        Obtain a wp_cursor_shape_device_v1 for a zwp_tablet_tool_v2 object.

        When the zwp_tablet_tool_v2 is removed, the wp_cursor_shape_device_v1
        object becomes inert.

        Returns:
            wp_cursor_shape_device_v1: The created object
        """

        ...

class wp_cursor_shape_device_v1:
    """
    Cursor shape for a device

    This interface allows clients to set the cursor shape.
    """
    object_id = 0
    version = 2

    class shape(Enum):
        """
        Cursor shapes

        This enum describes cursor shapes.

        The names are taken from the CSS W3C specification:
        https://w3c.github.io/csswg-drafts/css-ui/#cursor
        with a few additions.

        Note that there are some groups of cursor shapes that are related:
        The first group is drag-and-drop cursors which are used to indicate
        the selected action during dnd operations. The second group is resize
        cursors which are used to indicate resizing and moving possibilities
        on window borders. It is recommended that the shapes in these groups
        should use visually compatible images and metaphors.
        """

        default: int
        """Default cursor"""

        context_menu: int
        """A context menu is available for the object under the cursor"""

        help: int
        """Help is available for the object under the cursor"""

        pointer: int
        """Pointer that indicates a link or another interactive element"""

        progress: int
        """Progress indicator"""

        wait: int
        """Program is busy, user should wait"""

        cell: int
        """A cell or set of cells may be selected"""

        crosshair: int
        """Simple crosshair"""

        text: int
        """Text may be selected"""

        vertical_text: int
        """Vertical text may be selected"""

        alias: int
        """Drag-and-drop: alias of/shortcut to something is to be created"""

        copy: int
        """Drag-and-drop: something is to be copied"""

        move: int
        """Drag-and-drop: something is to be moved"""

        no_drop: int
        """Drag-and-drop: the dragged item cannot be dropped at the current cursor location"""

        not_allowed: int
        """Drag-and-drop: the requested action will not be carried out"""

        grab: int
        """Drag-and-drop: something can be grabbed"""

        grabbing: int
        """Drag-and-drop: something is being grabbed"""

        e_resize: int
        """Resizing: the east border is to be moved"""

        n_resize: int
        """Resizing: the north border is to be moved"""

        ne_resize: int
        """Resizing: the north-east corner is to be moved"""

        nw_resize: int
        """Resizing: the north-west corner is to be moved"""

        s_resize: int
        """Resizing: the south border is to be moved"""

        se_resize: int
        """Resizing: the south-east corner is to be moved"""

        sw_resize: int
        """Resizing: the south-west corner is to be moved"""

        w_resize: int
        """Resizing: the west border is to be moved"""

        ew_resize: int
        """Resizing: the east and west borders are to be moved"""

        ns_resize: int
        """Resizing: the north and south borders are to be moved"""

        nesw_resize: int
        """Resizing: the north-east and south-west corners are to be moved"""

        nwse_resize: int
        """Resizing: the north-west and south-east corners are to be moved"""

        col_resize: int
        """Resizing: that the item/column can be resized horizontally"""

        row_resize: int
        """Resizing: that the item/row can be resized vertically"""

        all_scroll: int
        """Something can be scrolled in any direction"""

        zoom_in: int
        """Something can be zoomed in"""

        zoom_out: int
        """Something can be zoomed out"""

        dnd_ask: int
        """Drag-and-drop: the user will select which action will be carried out (non-css value)"""

        all_resize: int
        """Resizing: something can be moved or resized in any direction (non-css value)"""



    class error(Enum):
        invalid_shape: int
        """The specified shape value is invalid"""



    def destroy(self) -> None:
        """
        Destroy the cursor shape device

        Destroy the cursor shape device.

        The device cursor shape remains unchanged.
        """

        ...

    def set_shape(self, serial: int, shape: wp_cursor_shape_device_v1.shape) -> None:
        """
        Set device cursor to the shape

        Sets the device cursor to the specified shape. The compositor will
        change the cursor image based on the specified shape.

        The cursor actually changes only if the input device focus is one of
        the requesting client's surfaces. If any, the previous cursor image
        (surface or shape) is replaced.

        The "shape" argument must be a valid enum entry, otherwise the
        invalid_shape protocol error is raised.

        This is similar to the wl_pointer.set_cursor and
        zwp_tablet_tool_v2.set_cursor requests, but this request accepts a
        shape instead of contents in the form of a surface. Clients can mix
        set_cursor and set_shape requests.

        The serial parameter must match the latest wl_pointer.enter or
        zwp_tablet_tool_v2.proximity_in serial number sent to the client.
        Otherwise the request will be ignored.

        Args:
            serial: Serial number of the enter event
        """

        ...

class wp_drm_lease_device_v1:
    """
    Lease device

    This protocol is used by Wayland compositors which act as Direct
    Rendering Manager (DRM) masters to lease DRM resources to Wayland
    clients.

    The compositor will advertise one wp_drm_lease_device_v1 global for each
    DRM node. Some time after a client binds to the wp_drm_lease_device_v1
    global, the compositor will send a drm_fd event followed by zero, one or
    more connector events. After all currently available connectors have been
    sent, the compositor will send a wp_drm_lease_device_v1.done event.

    When the list of connectors available for lease changes the compositor
    will send wp_drm_lease_device_v1.connector events for added connectors and
    wp_drm_lease_connector_v1.withdrawn events for removed connectors,
    followed by a wp_drm_lease_device_v1.done event.

    The compositor will indicate when a device is gone by removing the global
    via a wl_registry.global_remove event. Upon receiving this event, the
    client should destroy any matching wp_drm_lease_device_v1 object.

    To destroy a wp_drm_lease_device_v1 object, the client must first issue
    a release request. Upon receiving this request, the compositor will
    immediately send a released event and destroy the object. The client must
    continue to process and discard drm_fd and connector events until it
    receives the released event. Upon receiving the released event, the
    client can safely cleanup any client-side resources.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1


    def create_lease_request(self) -> wp_drm_lease_request_v1:
        """
        Create a lease request object

        Creates a lease request object.

        See the documentation for wp_drm_lease_request_v1 for details.

        Returns:
            wp_drm_lease_request_v1: The created object
        """

        ...

    def release(self) -> None:
        """
        Release this object

        Indicates the client no longer wishes to use this object. In response
        the compositor will immediately send the released event and destroy
        this object. It can however not guarantee that the client won't receive
        connector events before the released event. The client must not send any
        requests after this one, doing so will raise a wl_display error.
        Existing connectors, lease request and leases will not be affected.
        """

        ...

    def on_drm_fd(self, fd: fd) -> None:
        """
        Open a non-master fd for this drm node.

        Override to handle [`wayland.wp_drm_lease_device_v1.events.drm_fd`][].
        """

        ...

    def on_connector(self, id: wp_drm_lease_connector_v1) -> None:
        """
        Advertise connectors available for leases.

        Override to handle [`wayland.wp_drm_lease_device_v1.events.connector`][].
        """

        ...

    def on_done(self) -> None:
        """
        Signals grouping of connectors.

        Override to handle [`wayland.wp_drm_lease_device_v1.events.done`][].
        """

        ...

    def on_released(self) -> None:
        """
        The compositor has finished using the device.

        Override to handle [`wayland.wp_drm_lease_device_v1.events.released`][].
        """

        ...

    class events(WaylandEvent):
        def drm_fd(self, fd: fd) -> None:
            """
            Open a non-master fd for this drm node

            The compositor will send this event when the wp_drm_lease_device_v1
            global is bound, although there are no guarantees as to how long this
            takes - the compositor might need to wait until regaining DRM master.
            The included fd is a non-master DRM file descriptor opened for this
            device and the compositor must not authenticate it.
            The purpose of this event is to give the client the ability to
            query DRM and discover information which may help them pick the
            appropriate DRM device or select the appropriate connectors therein.

            Args:
                fd: Drm file descriptor
            """

            ...

        def connector(self, id: wp_drm_lease_connector_v1) -> None:
            """
            Advertise connectors available for leases

            The compositor will use this event to advertise connectors available for
            lease by clients. This object may be passed into a lease request to
            indicate the client would like to lease that connector, see
            wp_drm_lease_request_v1.request_connector for details. While the
            compositor will make a best effort to not send disconnected connectors,
            no guarantees can be made.

            The compositor must send the drm_fd event before sending connectors.
            After the drm_fd event it will send all available connectors but may
            send additional connectors at any time.
            """

            ...

        def done(self) -> None:
            """
            Signals grouping of connectors

            The compositor will send this event to indicate that it has sent all
            currently available connectors after the client binds to the global or
            when it updates the connector list, for example on hotplug, drm master
            change or when a leased connector becomes available again. It will
            similarly send this event to group wp_drm_lease_connector_v1.withdrawn
            events of connectors of this device.
            """

            ...

        def released(self) -> None:
            """
            The compositor has finished using the device

            This event is sent in response to the release request and indicates
            that the compositor is done sending connector events.
            The compositor will destroy this object immediately after sending the
            event and it will become invalid. The client should release any
            resources associated with this device after receiving this event.
            """

            ...

class wp_drm_lease_connector_v1:
    """
    A leasable drm connector

    Represents a DRM connector which is available for lease. These objects are
    created via wp_drm_lease_device_v1.connector events, and should be passed
    to lease requests via wp_drm_lease_request_v1.request_connector.
    Immediately after the wp_drm_lease_connector_v1 object is created the
    compositor will send a name, a description, a connector_id and a done
    event. When the description is updated the compositor will send a
    description event followed by a done event.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy connector

        The client may send this request to indicate that it will not use this
        connector. Clients are encouraged to send this after receiving the
        "withdrawn" event so that the server can release the resources
        associated with this connector offer. Neither existing lease requests
        nor leases will be affected.
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Name.

        Override to handle [`wayland.wp_drm_lease_connector_v1.events.name`][].
        """

        ...

    def on_description(self, description: str) -> None:
        """
        Description.

        Override to handle [`wayland.wp_drm_lease_connector_v1.events.description`][].
        """

        ...

    def on_connector_id(self, connector_id: int) -> None:
        """
        `connector_id`.

        Override to handle [`wayland.wp_drm_lease_connector_v1.events.connector_id`][].
        """

        ...

    def on_done(self) -> None:
        """
        All properties have been sent.

        Override to handle [`wayland.wp_drm_lease_connector_v1.events.done`][].
        """

        ...

    def on_withdrawn(self) -> None:
        """
        Lease offer withdrawn.

        Override to handle [`wayland.wp_drm_lease_connector_v1.events.withdrawn`][].
        """

        ...

    class events(WaylandEvent):
        def name(self, name: str) -> None:
            """
            Name

            The compositor sends this event once the connector is created to
            indicate the name of this connector. This will not change for the
            duration of the Wayland session, but is not guaranteed to be consistent
            between sessions.

            If the compositor supports wl_output version 4 and this connector
            corresponds to a wl_output, the compositor should use the same name as
            for the wl_output.

            Args:
                name: Connector name
            """

            ...

        def description(self, description: str) -> None:
            """
            Description

            The compositor sends this event once the connector is created to provide
            a human-readable description for this connector, which may be presented
            to the user. The compositor may send this event multiple times over the
            lifetime of this object to reflect changes in the description.

            Args:
                description: Connector description
            """

            ...

        def connector_id(self, connector_id: int) -> None:
            """
            `connector_id`

            The compositor sends this event once the connector is created to
            indicate the DRM object ID which represents the underlying connector
            that is being offered. Note that the final lease may include additional
            object IDs, such as CRTCs and planes.

            Args:
                connector_id: Drm connector id
            """

            ...

        def done(self) -> None:
            """
            All properties have been sent

            This event is sent after all properties of a connector have been sent.
            This allows changes to the properties to be seen as atomic even if they
            happen via multiple events.
            """

            ...

        def withdrawn(self) -> None:
            """
            Lease offer withdrawn

            Sent to indicate that the compositor will no longer honor requests for
            DRM leases which include this connector. The client may still issue a
            lease request including this connector, but the compositor will send
            wp_drm_lease_v1.finished without issuing a lease fd. Compositors are
            encouraged to send this event when they lose access to connector, for
            example when the connector is hot-unplugged, when the connector gets
            leased to a client or when the compositor loses DRM master.

            If a client holds a lease for the connector, the status of the lease
            remains the same. The client should destroy the object after receiving
            this event.
            """

            ...

class wp_drm_lease_request_v1:
    """
    Drm lease request

    A client that wishes to lease DRM resources will attach the list of
    connectors advertised with wp_drm_lease_device_v1.connector that they
    wish to lease, then use wp_drm_lease_request_v1.submit to submit the
    request.
    """
    object_id = 0
    version = 1

    class error(Enum):
        wrong_device: int
        """Requested a connector from a different lease device"""

        duplicate_connector: int
        """Requested a connector twice"""

        empty_lease: int
        """Requested a lease without requesting a connector"""



    def request_connector(self, connector: wp_drm_lease_connector_v1) -> None:
        """
        Request a connector for this lease

        Indicates that the client would like to lease the given connector.
        This is only used as a suggestion, the compositor may choose to
        include any resources in the lease it issues, or change the set of
        leased resources at any time. Compositors are however encouraged to
        include the requested connector and other resources necessary
        to drive the connected output in the lease.

        Requesting a connector that was created from a different lease device
        than this lease request raises the wrong_device error. Requesting a
        connector twice will raise the duplicate_connector error.
        """

        ...

    def submit(self) -> wp_drm_lease_v1:
        """
        Submit the lease request

        Submits the lease request and creates a new wp_drm_lease_v1 object.
        After calling submit the compositor will immediately destroy this
        object, issuing any more requests will cause a wl_display error.
        The compositor doesn't make any guarantees about the events of the
        lease object, clients cannot expect an immediate response.
        Not requesting any connectors before submitting the lease request
        will raise the empty_lease error.

        Returns:
            wp_drm_lease_v1: The created object
        """

        ...

class wp_drm_lease_v1:
    """
    A drm lease

    A DRM lease object is used to transfer the DRM file descriptor to the
    client and manage the lifetime of the lease.

    Some time after the wp_drm_lease_v1 object is created, the compositor
    will reply with the lease request's result. If the lease request is
    granted, the compositor will send a lease_fd event. If the lease request
    is denied, the compositor will send a finished event without a lease_fd
    event.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroys the lease object

        The client should send this to indicate that it no longer wishes to use
        this lease. The compositor should use drmModeRevokeLease on the
        appropriate file descriptor, if necessary.

        Upon destruction, the compositor should advertise the connector for
        leasing again by sending the connector event through the
        wp_drm_lease_device_v1 interface.
        """

        ...

    def on_lease_fd(self, leased_fd: fd) -> None:
        """
        Shares the drm file descriptor.

        Override to handle [`wayland.wp_drm_lease_v1.events.lease_fd`][].
        """

        ...

    def on_finished(self) -> None:
        """
        Sent when the lease has been revoked.

        Override to handle [`wayland.wp_drm_lease_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def lease_fd(self, leased_fd: fd) -> None:
            """
            Shares the drm file descriptor

            This event returns a file descriptor suitable for use with DRM-related
            ioctls. The client should use drmModeGetLease to enumerate the DRM
            objects which have been leased to them. The compositor guarantees it
            will not use the leased DRM objects itself until it sends the finished
            event. If the compositor cannot or will not grant a lease for the
            requested connectors, it will not send this event, instead sending the
            finished event.

            The compositor will send this event at most once during this objects
            lifetime.

            Args:
                leased_fd: Leased drm file descriptor
            """

            ...

        def finished(self) -> None:
            """
            Sent when the lease has been revoked

            The compositor uses this event to either reject a lease request, or if
            it previously sent a lease_fd, to notify the client that the lease has
            been revoked. If the client requires a new lease, they should destroy
            this object and submit a new lease request. The compositor will send
            no further events for this object after sending the finish event.
            Compositors should revoke the lease when any of the leased resources
            become unavailable, namely when a hot-unplug occurs or when the
            compositor loses DRM master. Compositors may advertise the connector
            for leasing again, if the resource is available, by sending the
            connector event through the wp_drm_lease_device_v1 interface.
            """

            ...

class ext_background_effect_manager_v1:
    """
    Background effect factory

    This protocol provides a way to improve visuals of translucent surfaces
    by applying effects like blur to the background behind them.

    The capabilities are send when the global is bound, and every time they
    change. Note that when the capability goes away, the corresponding effect
    is no longer applied by the compositor, even if it was set before.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        background_effect_exists: int
        """The surface already has a background effect object"""



    class capability(IntFlag):
        blur: int
        """The compositor supports applying blur"""



    def destroy(self) -> None:
        """
        Destroy the background effect manager

        Informs the server that the client will no longer be using this
        protocol object. Existing objects created by this object are not
        affected.
        """

        ...

    def get_background_effect(self, surface: wl_surface) -> ext_background_effect_surface_v1:
        """
        Get a background effects object

        Instantiate an interface extension for the given wl_surface to add
        effects like blur for the background behind it.

        If the given wl_surface already has a ext_background_effect_surface_v1
        object associated, the background_effect_exists protocol error will be
        raised.

        Args:
            surface: The surface

        Returns:
            ext_background_effect_surface_v1: The created object
        """

        ...

    def on_capabilities(self, flags: ext_background_effect_manager_v1.capability) -> None:
        """
        Capabilities of the compositor.

        Override to handle [`wayland.ext_background_effect_manager_v1.events.capabilities`][].
        """

        ...

    class events(WaylandEvent):
        def capabilities(self, flags: ext_background_effect_manager_v1.capability) -> None:
            """Capabilities of the compositor"""

            ...

class ext_background_effect_surface_v1:
    """
    Background effects for a surface

    The background effect object provides a way to specify a region behind
    a surface that should have background effects like blur applied.

    If the wl_surface associated with the ext_background_effect_surface_v1
    object has been destroyed, this object becomes inert.
    """
    object_id = 0
    version = 1

    class error(Enum):
        surface_destroyed: int
        """The associated surface has been destroyed"""



    def destroy(self) -> None:
        """
        Release the blur object

        Informs the server that the client will no longer be using this protocol
        object. The effect regions will be removed on the next commit.
        """

        ...

    def set_blur_region(self, region: wl_region) -> None:
        """
        Set blur region

        This request sets the region of the surface that will have its
        background blurred.

        The blur region is specified in the surface-local coordinates, and
        clipped by the compositor to the surface size.

        The initial value for the blur region is empty. Setting the pending
        blur region has copy semantics, and the wl_region object can be
        destroyed immediately. A NULL wl_region removes the effect.

        The blur region is double-buffered state, and will be applied on
        the next wl_surface.commit.

        The blur algorithm is subject to compositor policies.

        If the associated surface has been destroyed, the surface_destroyed
        error will be raised.

        Args:
            region: Blur region of the surface
        """

        ...

class ext_data_control_manager_v1:
    """
    Manager to control data devices

    This interface is a manager that allows creating per-seat data device
    controls.
    """
    object_id = 0
    version = 1


    def create_data_source(self) -> ext_data_control_source_v1:
        """
        Create a new data source

        Create a new data source.

        Returns:
            ext_data_control_source_v1: The created object
        """

        ...

    def get_data_device(self, seat: wl_seat) -> ext_data_control_device_v1:
        """
        Get a data device for a seat

        Create a data device that can be used to manage a seat's selection.

        Returns:
            ext_data_control_device_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class ext_data_control_device_v1:
    """
    Manage a data device for a seat

    This interface allows a client to manage a seat's selection.

    When the seat is destroyed, this object becomes inert.
    """
    object_id = 0
    version = 1

    class error(Enum):
        used_source: int
        """Source given to `set_selection` or `set_primary_selection` was already used before"""



    def set_selection(self, source: ext_data_control_source_v1) -> None:
        """
        Copy data to the selection

        This request asks the compositor to set the selection to the data from
        the source on behalf of the client.

        The given source may not be used in any further set_selection or
        set_primary_selection requests. Attempting to use a previously used
        source triggers the used_source protocol error.

        To unset the selection, set the source to NULL.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this data device

        Destroys the data device object.
        """

        ...

    def set_primary_selection(self, source: ext_data_control_source_v1) -> None:
        """
        Copy data to the primary selection

        This request asks the compositor to set the primary selection to the
        data from the source on behalf of the client.

        The given source may not be used in any further set_selection or
        set_primary_selection requests. Attempting to use a previously used
        source triggers the used_source protocol error.

        To unset the primary selection, set the source to NULL.

        The compositor will ignore this request if it does not support primary
        selection.
        """

        ...

    def on_data_offer(self, id: ext_data_control_offer_v1) -> None:
        """
        Introduce a new `ext_data_control_offer`.

        Override to handle [`wayland.ext_data_control_device_v1.events.data_offer`][].
        """

        ...

    def on_selection(self, id: ext_data_control_offer_v1) -> None:
        """
        Advertise new selection.

        Override to handle [`wayland.ext_data_control_device_v1.events.selection`][].
        """

        ...

    def on_finished(self) -> None:
        """
        This data control is no longer valid.

        Override to handle [`wayland.ext_data_control_device_v1.events.finished`][].
        """

        ...

    def on_primary_selection(self, id: ext_data_control_offer_v1) -> None:
        """
        Advertise new primary selection.

        Override to handle [`wayland.ext_data_control_device_v1.events.primary_selection`][].
        """

        ...

    class events(WaylandEvent):
        def data_offer(self, id: ext_data_control_offer_v1) -> None:
            """
            Introduce a new `ext_data_control_offer`

            The data_offer event introduces a new ext_data_control_offer object,
            which will subsequently be used in either the
            ext_data_control_device.selection event (for the regular clipboard
            selections) or the ext_data_control_device.primary_selection event (for
            the primary clipboard selections). Immediately following the
            ext_data_control_device.data_offer event, the new data_offer object
            will send out ext_data_control_offer.offer events to describe the MIME
            types it offers.
            """

            ...

        def selection(self, id: ext_data_control_offer_v1) -> None:
            """
            Advertise new selection

            The selection event is sent out to notify the client of a new
            ext_data_control_offer for the selection for this device. The
            ext_data_control_device.data_offer and the ext_data_control_offer.offer
            events are sent out immediately before this event to introduce the data
            offer object. The selection event is sent to a client when a new
            selection is set. The ext_data_control_offer is valid until a new
            ext_data_control_offer or NULL is received. The client must destroy the
            previous selection ext_data_control_offer, if any, upon receiving this
            event. Regardless, the previous selection will be ignored once a new
            selection ext_data_control_offer is received.

            The first selection event is sent upon binding the
            ext_data_control_device object.
            """

            ...

        def finished(self) -> None:
            """
            This data control is no longer valid

            This data control object is no longer valid and should be destroyed by
            the client.
            """

            ...

        def primary_selection(self, id: ext_data_control_offer_v1) -> None:
            """
            Advertise new primary selection

            The primary_selection event is sent out to notify the client of a new
            ext_data_control_offer for the primary selection for this device. The
            ext_data_control_device.data_offer and the ext_data_control_offer.offer
            events are sent out immediately before this event to introduce the data
            offer object. The primary_selection event is sent to a client when a
            new primary selection is set. The ext_data_control_offer is valid until
            a new ext_data_control_offer or NULL is received. The client must
            destroy the previous primary selection ext_data_control_offer, if any,
            upon receiving this event. Regardless, the previous primary selection
            will be ignored once a new primary selection ext_data_control_offer is
            received.

            If the compositor supports primary selection, the first
            primary_selection event is sent upon binding the
            ext_data_control_device object.
            """

            ...

class ext_data_control_source_v1:
    """
    Offer to transfer data

    The ext_data_control_source object is the source side of a
    ext_data_control_offer. It is created by the source client in a data
    transfer and provides a way to describe the offered data and a way to
    respond to requests to transfer the data.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_offer: int
        """Offer sent after `ext_data_control_device`.`set_selection`"""



    def offer(self, mime_type: str) -> None:
        """
        Add an offered mime type

        This request adds a MIME type to the set of MIME types advertised to
        targets. Can be called several times to offer multiple types.

        Calling this after ext_data_control_device.set_selection is a protocol
        error.

        Args:
            mime_type: Mime type offered by the data source
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this source

        Destroys the data source object.
        """

        ...

    def on_send(self, mime_type: str, fd: fd) -> None:
        """
        Send the data.

        Override to handle [`wayland.ext_data_control_source_v1.events.send`][].
        """

        ...

    def on_cancelled(self) -> None:
        """
        Selection was cancelled.

        Override to handle [`wayland.ext_data_control_source_v1.events.cancelled`][].
        """

        ...

    class events(WaylandEvent):
        def send(self, mime_type: str, fd: fd) -> None:
            """
            Send the data

            Request for data from the client. Send the data as the specified MIME
            type over the passed file descriptor, then close it.

            Args:
                mime_type: Mime type for the data
                fd: File descriptor for the data
            """

            ...

        def cancelled(self) -> None:
            """
            Selection was cancelled

            This data source is no longer valid. The data source has been replaced
            by another data source.

            The client should clean up and destroy this data source.
            """

            ...

class ext_data_control_offer_v1:
    """
    Offer to transfer data

    A ext_data_control_offer represents a piece of data offered for transfer
    by another client (the source client). The offer describes the different
    MIME types that the data can be converted to and provides the mechanism
    for transferring the data directly from the source client.
    """
    object_id = 0
    version = 1


    def receive(self, mime_type: str, fd: fd) -> None:
        """
        Request that the data is transferred

        To transfer the offered data, the client issues this request and
        indicates the MIME type it wants to receive. The transfer happens
        through the passed file descriptor (typically created with the pipe
        system call). The source client writes the data in the MIME type
        representation requested and then closes the file descriptor.

        The receiving client reads from the read end of the pipe until EOF and
        then closes its end, at which point the transfer is complete.

        This request may happen multiple times for different MIME types.

        Args:
            mime_type: Mime type desired by receiver
            fd: File descriptor for data transfer
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this offer

        Destroys the data offer object.
        """

        ...

    def on_offer(self, mime_type: str) -> None:
        """
        Advertise offered mime type.

        Override to handle [`wayland.ext_data_control_offer_v1.events.offer`][].
        """

        ...

    class events(WaylandEvent):
        def offer(self, mime_type: str) -> None:
            """
            Advertise offered mime type

            Sent immediately after creating the ext_data_control_offer object.
            One event per offered MIME type.

            Args:
                mime_type: Offered mime type
            """

            ...

class ext_foreign_toplevel_list_v1:
    """
    List toplevels

    A toplevel is defined as a surface with a role similar to xdg_toplevel.
    XWayland surfaces may be treated like toplevels in this protocol.

    After a client binds the ext_foreign_toplevel_list_v1, each mapped
    toplevel window will be sent using the ext_foreign_toplevel_list_v1.toplevel
    event.

    Clients which only care about the current state can perform a roundtrip after
    binding this global.

    For each instance of ext_foreign_toplevel_list_v1, the compositor must
    create a new ext_foreign_toplevel_handle_v1 object for each mapped toplevel.

    If a compositor implementation sends the ext_foreign_toplevel_list_v1.finished
    event after the global is bound, the compositor must not send any
    ext_foreign_toplevel_list_v1.toplevel events.
    """
    object_id = 0
    version = 1


    def stop(self) -> None:
        """
        Stop sending events

        This request indicates that the client no longer wishes to receive
        events for new toplevels.

        The Wayland protocol is asynchronous, meaning the compositor may send
        further toplevel events until the stop request is processed.
        The client should wait for a ext_foreign_toplevel_list_v1.finished
        event before destroying this object.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the ext_foreign_toplevel_list_v1 object

        This request should be called either when the client will no longer
        use the ext_foreign_toplevel_list_v1 or after the finished event
        has been received to allow destruction of the object.

        If a client wishes to destroy this object it should send a
        ext_foreign_toplevel_list_v1.stop request and wait for a ext_foreign_toplevel_list_v1.finished
        event, then destroy the handles and then this object.
        """

        ...

    def on_toplevel(self, toplevel: ext_foreign_toplevel_handle_v1) -> None:
        """
        A toplevel has been created.

        Override to handle [`wayland.ext_foreign_toplevel_list_v1.events.toplevel`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The compositor has finished with the toplevel manager.

        Override to handle [`wayland.ext_foreign_toplevel_list_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def toplevel(self, toplevel: ext_foreign_toplevel_handle_v1) -> None:
            """
            A toplevel has been created

            This event is emitted whenever a new toplevel window is created. It is
            emitted for all toplevels, regardless of the app that has created them.

            All initial properties of the toplevel (identifier, title, app_id) will be sent
            immediately after this event using the corresponding events for
            ext_foreign_toplevel_handle_v1. The compositor will use the
            ext_foreign_toplevel_handle_v1.done event to indicate when all data has
            been sent.
            """

            ...

        def finished(self) -> None:
            """
            The compositor has finished with the toplevel manager

            This event indicates that the compositor is done sending events
            to this object. The client should destroy the object.
            See ext_foreign_toplevel_list_v1.destroy for more information.

            The compositor must not send any more toplevel events after this event.
            """

            ...

class ext_foreign_toplevel_handle_v1:
    """
    A mapped toplevel

    A ext_foreign_toplevel_handle_v1 object represents a mapped toplevel
    window. A single app may have multiple mapped toplevels.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the ext_foreign_toplevel_handle_v1 object

        This request should be used when the client will no longer use the handle
        or after the closed event has been received to allow destruction of the
        object.

        When a handle is destroyed, a new handle may not be created by the server
        until the toplevel is unmapped and then remapped. Destroying a toplevel handle
        is not recommended unless the client is cleaning up child objects
        before destroying the ext_foreign_toplevel_list_v1 object, the toplevel
        was closed or the toplevel handle will not be used in the future.

        Other protocols which extend the ext_foreign_toplevel_handle_v1
        interface should require destructors for extension interfaces be
        called before allowing the toplevel handle to be destroyed.
        """

        ...

    def on_closed(self) -> None:
        """
        The toplevel has been closed.

        Override to handle [`wayland.ext_foreign_toplevel_handle_v1.events.closed`][].
        """

        ...

    def on_done(self) -> None:
        """
        All information about the toplevel has been sent.

        Override to handle [`wayland.ext_foreign_toplevel_handle_v1.events.done`][].
        """

        ...

    def on_title(self, title: str) -> None:
        """
        Title change.

        Override to handle [`wayland.ext_foreign_toplevel_handle_v1.events.title`][].
        """

        ...

    def on_app_id(self, app_id: str) -> None:
        """
        `app_id` change.

        Override to handle [`wayland.ext_foreign_toplevel_handle_v1.events.app_id`][].
        """

        ...

    def on_identifier(self, identifier: str) -> None:
        """
        A stable identifier for a toplevel.

        Override to handle [`wayland.ext_foreign_toplevel_handle_v1.events.identifier`][].
        """

        ...

    class events(WaylandEvent):
        def closed(self) -> None:
            """
            The toplevel has been closed

            The server will emit no further events on the ext_foreign_toplevel_handle_v1
            after this event. Any requests received aside from the destroy request must
            be ignored. Upon receiving this event, the client should destroy the handle.

            Other protocols which extend the ext_foreign_toplevel_handle_v1
            interface must also ignore requests other than destructors.
            """

            ...

        def done(self) -> None:
            """
            All information about the toplevel has been sent

            This event is sent after all changes in the toplevel state have
            been sent.

            This allows changes to the ext_foreign_toplevel_handle_v1 properties
            to be atomically applied. Other protocols which extend the
            ext_foreign_toplevel_handle_v1 interface may use this event to also
            atomically apply any pending state.

            This event must not be sent after the ext_foreign_toplevel_handle_v1.closed
            event.
            """

            ...

        def title(self, title: str) -> None:
            """
            Title change

            The title of the toplevel has changed.

            The configured state must not be applied immediately. See
            ext_foreign_toplevel_handle_v1.done for details.
            """

            ...

        def app_id(self, app_id: str) -> None:
            """
            `app_id` change

            The app id of the toplevel has changed.

            The configured state must not be applied immediately. See
            ext_foreign_toplevel_handle_v1.done for details.
            """

            ...

        def identifier(self, identifier: str) -> None:
            """
            A stable identifier for a toplevel

            This identifier is used to check if two or more toplevel handles belong
            to the same toplevel.

            The identifier is useful for command line tools or privileged clients
            which may need to reference an exact toplevel across processes or
            instances of the ext_foreign_toplevel_list_v1 global.

            The compositor must only send this event when the handle is created.

            The identifier must be unique per toplevel and it's handles. Two different
            toplevels must not have the same identifier. The identifier is only valid
            as long as the toplevel is mapped. If the toplevel is unmapped the identifier
            must not be reused. An identifier must not be reused by the compositor to
            ensure there are no races when sharing identifiers between processes.

            An identifier is a string that contains up to 32 printable ASCII bytes.
            An identifier must not be an empty string. It is recommended that a
            compositor includes an opaque generation value in identifiers. How the
            generation value is used when generating the identifier is implementation
            dependent.
            """

            ...

class ext_idle_notifier_v1:
    """
    Idle notification manager

    This interface allows clients to monitor user idle status.

    After binding to this global, clients can create ext_idle_notification_v1
    objects to get notified when the user is idle for a given amount of time.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the manager object. All objects created via this interface
        remain valid.
        """

        ...

    def get_idle_notification(self, timeout: int, seat: wl_seat) -> ext_idle_notification_v1:
        """
        Create a notification object

        Create a new idle notification object.

        The notification object has a minimum timeout duration and is tied to a
        seat. The client will be notified if the seat is inactive for at least
        the provided timeout. See ext_idle_notification_v1 for more details.

        A zero timeout is valid and means the client wants to be notified as
        soon as possible when the seat is inactive.

        Args:
            timeout: Minimum idle timeout in msec

        Returns:
            ext_idle_notification_v1: The created object
        """

        ...

    def get_input_idle_notification(self, timeout: int, seat: wl_seat) -> ext_idle_notification_v1:
        """
        Create a notification object

        Create a new idle notification object to track input from the
        user, such as keyboard and mouse movement. Because this object is
        meant to track user input alone, it ignores idle inhibitors.

        The notification object has a minimum timeout duration and is tied to a
        seat. The client will be notified if the seat is inactive for at least
        the provided timeout. See ext_idle_notification_v1 for more details.

        A zero timeout is valid and means the client wants to be notified as
        soon as possible when the seat is inactive.

        Args:
            timeout: Minimum idle timeout in msec

        Returns:
            ext_idle_notification_v1: The created object
        """

        ...

class ext_idle_notification_v1:
    """
    Idle notification

    This interface is used by the compositor to send idle notification events
    to clients.

    Initially the notification object is not idle. The notification object
    becomes idle when no user activity has happened for at least the timeout
    duration, starting from the creation of the notification object. User
    activity may include input events or a presence sensor, but is
    compositor-specific.

    How this notification responds to idle inhibitors depends on how
    it was constructed. If constructed from the
    get_idle_notification request, then if an idle inhibitor is
    active (e.g. another client has created a zwp_idle_inhibitor_v1
    on a visible surface), the compositor must not make the
    notification object idle. However, if constructed from the
    get_input_idle_notification request, then idle inhibitors are
    ignored, and only input from the user, e.g. from a keyboard or
    mouse, counts as activity.

    When the notification object becomes idle, an idled event is sent. When
    user activity starts again, the notification object stops being idle,
    a resumed event is sent and the timeout is restarted.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """
        Destroy the notification object

        Destroy the notification object.
        """

        ...

    def on_idled(self) -> None:
        """
        Notification object is idle.

        Override to handle [`wayland.ext_idle_notification_v1.events.idled`][].
        """

        ...

    def on_resumed(self) -> None:
        """
        Notification object is no longer idle.

        Override to handle [`wayland.ext_idle_notification_v1.events.resumed`][].
        """

        ...

    class events(WaylandEvent):
        def idled(self) -> None:
            """
            Notification object is idle

            This event is sent when the notification object becomes idle.

            It's a compositor protocol error to send this event twice without a
            resumed event in-between.
            """

            ...

        def resumed(self) -> None:
            """
            Notification object is no longer idle

            This event is sent when the notification object stops being idle.

            It's a compositor protocol error to send this event twice without an
            idled event in-between. It's a compositor protocol error to send this
            event prior to any idled event.
            """

            ...

class ext_image_capture_source_v1:
    """
    Opaque image capture source object

    The image capture source object is an opaque descriptor for a capturable
    resource.  This resource may be any sort of entity from which an image
    may be derived.

    Note, because ext_image_capture_source_v1 objects are created from multiple
    independent factory interfaces, the ext_image_capture_source_v1 interface is
    frozen at version 1.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Delete this object

        Destroys the image capture source. This request may be sent at any time
        by the client.
        """

        ...

class ext_output_image_capture_source_manager_v1:
    """
    Image capture source manager for outputs

    A manager for creating image capture source objects for wl_output objects.
    """
    object_id = 0
    version = 1


    def create_source(self, output: wl_output) -> ext_image_capture_source_v1:
        """
        Create source object for output

        Creates a source object for an output. Images captured from this source
        will show the same content as the output. Some elements may be omitted,
        such as cursors and overlays that have been marked as transparent to
        capturing.

        Returns:
            ext_image_capture_source_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Delete this object

        Destroys the manager. This request may be sent at any time by the client
        and objects created by the manager will remain valid after its
        destruction.
        """

        ...

class ext_foreign_toplevel_image_capture_source_manager_v1:
    """
    Image capture source manager for foreign toplevels

    A manager for creating image capture source objects for
    ext_foreign_toplevel_handle_v1 objects.
    """
    object_id = 0
    version = 1


    def create_source(self, toplevel_handle: ext_foreign_toplevel_handle_v1) -> ext_image_capture_source_v1:
        """
        Create source object for foreign toplevel

        Creates a source object for a foreign toplevel handle. Images captured
        from this source will show the same content as the toplevel.

        Returns:
            ext_image_capture_source_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Delete this object

        Destroys the manager. This request may be sent at any time by the client
        and objects created by the manager will remain valid after its
        destruction.
        """

        ...

class ext_image_copy_capture_manager_v1:
    """
    Manager to inform clients and begin capturing

    This object is a manager which offers requests to start capturing from a
    source.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_option: int
        """Invalid option flag"""



    class options(IntFlag):
        paint_cursors: int
        """Paint cursors onto captured frames"""



    def create_session(self, source: ext_image_capture_source_v1, options: ext_image_copy_capture_manager_v1.options) -> ext_image_copy_capture_session_v1:
        """
        Capture an image capture source

        Create a capturing session for an image capture source.

        If the paint_cursors option is set, cursors shall be composited onto
        the captured frame. The cursor must not be composited onto the frame
        if this flag is not set.

        If the options bitfield is invalid, the invalid_option protocol error
        is sent.

        Returns:
            ext_image_copy_capture_session_v1: The created object
        """

        ...

    def create_pointer_cursor_session(self, source: ext_image_capture_source_v1, pointer: wl_pointer) -> ext_image_copy_capture_cursor_session_v1:
        """
        Capture the pointer cursor of an image capture source

        Create a cursor capturing session for the pointer of an image capture
        source.

        Returns:
            ext_image_copy_capture_cursor_session_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the manager object.

        Other objects created via this interface are unaffected.
        """

        ...

class ext_image_copy_capture_session_v1:
    """
    Image copy capture session

    This object represents an active image copy capture session.

    After a capture session is created, buffer constraint events will be
    emitted from the compositor to tell the client which buffer types and
    formats are supported for reading from the session. The compositor may
    re-send buffer constraint events whenever they change.

    To advertise buffer constraints, the compositor must send in no
    particular order: zero or more shm_format and dmabuf_format events, zero
    or one dmabuf_device event, and exactly one buffer_size event. Then the
    compositor must send a done event.

    When the client has received all the buffer constraints, it can create a
    buffer accordingly, attach it to the capture session using the
    attach_buffer request, set the buffer damage using the damage_buffer
    request and then send the capture request.
    """
    object_id = 0
    version = 1

    class error(Enum):
        duplicate_frame: int
        """`create_frame` sent before destroying previous frame"""



    def create_frame(self) -> ext_image_copy_capture_frame_v1:
        """
        Create a frame

        Create a capture frame for this session.

        At most one frame object can exist for a given session at any time. If
        a client sends a create_frame request before a previous frame object
        has been destroyed, the duplicate_frame protocol error is raised.

        Returns:
            ext_image_copy_capture_frame_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Delete this object

        Destroys the session. This request can be sent at any time by the
        client.

        This request doesn't affect ext_image_copy_capture_frame_v1 objects created by
        this object.
        """

        ...

    def on_buffer_size(self, width: int, height: int) -> None:
        """
        Image capture source dimensions.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.buffer_size`][].
        """

        ...

    def on_shm_format(self, format: wl_shm.format) -> None:
        """
        Shm buffer format.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.shm_format`][].
        """

        ...

    def on_dmabuf_device(self, device: list) -> None:
        """
        Dma-buf device.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.dmabuf_device`][].
        """

        ...

    def on_dmabuf_format(self, format: int, modifiers: list) -> None:
        """
        Dma-buf format.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.dmabuf_format`][].
        """

        ...

    def on_done(self) -> None:
        """
        All constraints have been sent.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.done`][].
        """

        ...

    def on_stopped(self) -> None:
        """
        Session is no longer available.

        Override to handle [`wayland.ext_image_copy_capture_session_v1.events.stopped`][].
        """

        ...

    class events(WaylandEvent):
        def buffer_size(self, width: int, height: int) -> None:
            """
            Image capture source dimensions

            Provides the dimensions of the source image in buffer pixel coordinates.

            The client must attach buffers that match this size.

            Args:
                width: Buffer width
                height: Buffer height
            """

            ...

        def shm_format(self, format: wl_shm.format) -> None:
            """
            Shm buffer format

            Provides the format that must be used for shared-memory buffers.

            This event may be emitted multiple times, in which case the client may
            choose any given format.

            Args:
                format: Shm format
            """

            ...

        def dmabuf_device(self, device: list) -> None:
            """
            Dma-buf device

            This event advertises the device buffers must be allocated on for
            dma-buf buffers.

            In general the device is a DRM node. The DRM node type (primary vs.
            render) is unspecified. Clients must not rely on the compositor sending
            a particular node type. Clients cannot check two devices for equality
            by comparing the dev_t value.

            Args:
                device: Device `dev_t` value
            """

            ...

        def dmabuf_format(self, format: int, modifiers: list) -> None:
            """
            Dma-buf format

            Provides the format that must be used for dma-buf buffers.

            The client may choose any of the modifiers advertised in the array of
            64-bit unsigned integers.

            This event may be emitted multiple times, in which case the client may
            choose any given format.

            Args:
                format: Drm format code
                modifiers: Drm format modifiers
            """

            ...

        def done(self) -> None:
            """
            All constraints have been sent

            This event is sent once when all buffer constraint events have been
            sent.

            The compositor must always end a batch of buffer constraint events with
            this event, regardless of whether it sends the initial constraints or
            an update.
            """

            ...

        def stopped(self) -> None:
            """
            Session is no longer available

            This event indicates that the capture session has stopped and is no
            longer available. This can happen in a number of cases, e.g. when the
            underlying source is destroyed, if the user decides to end the image
            capture, or if an unrecoverable runtime error has occurred.

            The client should destroy the session after receiving this event.
            """

            ...

class ext_image_copy_capture_frame_v1:
    """
    Image capture frame

    This object represents an image capture frame.

    The client should attach a buffer, damage the buffer, and then send a
    capture request.

    If the capture is successful, the compositor must send the frame metadata
    (transform, damage, presentation_time in any order) followed by the ready
    event.

    If the capture fails, the compositor must send the failed event.
    """
    object_id = 0
    version = 1

    class error(Enum):
        no_buffer: int
        """Capture sent without `attach_buffer`"""

        invalid_buffer_damage: int
        """Invalid buffer damage"""

        already_captured: int
        """Capture request has been sent"""



    class failure_reason(Enum):
        unknown: int
        """
        Unknown runtime error
        An unspecified runtime error has occurred. The client may retry.
        """

        buffer_constraints: int
        """
        Buffer constraints mismatch
        The buffer submitted by the client doesn't match the latest session
        constraints. The client should re-allocate its buffers and retry.
        """

        stopped: int
        """
        Session is no longer available
        The session has stopped. See ext_image_copy_capture_session_v1.stopped.
        """



    def destroy(self) -> None:
        """
        Destroy this object

        Destroys the frame. This request can be sent at any time by the
        client.
        """

        ...

    def attach_buffer(self, buffer: wl_buffer) -> None:
        """
        Attach buffer to session

        Attach a buffer to the session.

        The wl_buffer.release request is unused.

        The new buffer replaces any previously attached buffer.

        This request must not be sent after capture, or else the
        already_captured protocol error is raised.
        """

        ...

    def damage_buffer(self, x: int, y: int, width: int, height: int) -> None:
        """
        Damage buffer

        Apply damage to the buffer which is to be captured next. This request
        may be sent multiple times to describe a region.

        The client indicates the accumulated damage since this wl_buffer was
        last captured. During capture, the compositor will update the buffer
        with at least the union of the region passed by the client and the
        region advertised by ext_image_copy_capture_frame_v1.damage.

        When a wl_buffer is captured for the first time, or when the client
        doesn't track damage, the client must damage the whole buffer.

        This is for optimisation purposes. The compositor may use this
        information to reduce copying.

        These coordinates originate from the upper left corner of the buffer.

        If x or y are strictly negative, or if width or height are negative or
        zero, the invalid_buffer_damage protocol error is raised.

        This request must not be sent after capture, or else the
        already_captured protocol error is raised.

        Args:
            x: Region x coordinate
            y: Region y coordinate
            width: Region width
            height: Region height
        """

        ...

    def capture(self) -> None:
        """
        Capture a frame

        Capture a frame.

        Unless this is the first successful captured frame performed in this
        session, the compositor may wait an indefinite amount of time for the
        source content to change before performing the copy.

        This request may only be sent once, or else the already_captured
        protocol error is raised. A buffer must be attached before this request
        is sent, or else the no_buffer protocol error is raised.
        """

        ...

    def on_transform(self, transform: wl_output.transform) -> None:
        """
        Buffer transform.

        Override to handle [`wayland.ext_image_copy_capture_frame_v1.events.transform`][].
        """

        ...

    def on_damage(self, x: int, y: int, width: int, height: int) -> None:
        """
        Buffer damaged region.

        Override to handle [`wayland.ext_image_copy_capture_frame_v1.events.damage`][].
        """

        ...

    def on_presentation_time(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Presentation time of the frame.

        Override to handle [`wayland.ext_image_copy_capture_frame_v1.events.presentation_time`][].
        """

        ...

    def on_ready(self) -> None:
        """
        Frame is available for reading.

        Override to handle [`wayland.ext_image_copy_capture_frame_v1.events.ready`][].
        """

        ...

    def on_failed(self, reason: ext_image_copy_capture_frame_v1.failure_reason) -> None:
        """
        Capture failed.

        Override to handle [`wayland.ext_image_copy_capture_frame_v1.events.failed`][].
        """

        ...

    class events(WaylandEvent):
        def transform(self, transform: wl_output.transform) -> None:
            """
            Buffer transform

            This event is sent before the ready event and holds the transform that
            the compositor has applied to the buffer contents.
            """

            ...

        def damage(self, x: int, y: int, width: int, height: int) -> None:
            """
            Buffer damaged region

            This event is sent before the ready event. It may be generated multiple
            times to describe a region.

            The first captured frame in a session will always carry full damage.
            Subsequent frames' damaged regions describe which parts of the buffer
            have changed since the last ready event.

            These coordinates originate in the upper left corner of the buffer.

            Args:
                x: Damage x coordinate
                y: Damage y coordinate
                width: Damage width
                height: Damage height
            """

            ...

        def presentation_time(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Presentation time of the frame

            This event indicates the time at which the frame is presented to the
            output in system monotonic time. This event is sent before the ready
            event.

            The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples,
            each component being an unsigned 32-bit value. Whole seconds are in
            tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo,
            and the additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999].

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

        def ready(self) -> None:
            """
            Frame is available for reading

            Called as soon as the frame is copied, indicating it is available
            for reading.

            The buffer may be re-used by the client after this event.

            After receiving this event, the client must destroy the object.
            """

            ...

        def failed(self, reason: ext_image_copy_capture_frame_v1.failure_reason) -> None:
            """
            Capture failed

            This event indicates that the attempted frame copy has failed.

            After receiving this event, the client must destroy the object.
            """

            ...

class ext_image_copy_capture_cursor_session_v1:
    """
    Cursor capture session

    This object represents a cursor capture session. It extends the base
    capture session with cursor-specific metadata.
    """
    object_id = 0
    version = 1

    class error(Enum):
        duplicate_session: int
        """`get_capture_session` sent twice"""



    def destroy(self) -> None:
        """
        Delete this object

        Destroys the session. This request can be sent at any time by the
        client.

        This request doesn't affect ext_image_copy_capture_frame_v1 objects created by
        this object.
        """

        ...

    def get_capture_session(self) -> ext_image_copy_capture_session_v1:
        """
        Get image copy capturer session

        Gets the image copy capture session for this cursor session.

        The session will produce frames of the cursor image. The compositor may
        pause the session when the cursor leaves the captured area.

        This request must not be sent more than once, or else the
        duplicate_session protocol error is raised.

        Returns:
            ext_image_copy_capture_session_v1: The created object
        """

        ...

    def on_enter(self) -> None:
        """
        Cursor entered captured area.

        Override to handle [`wayland.ext_image_copy_capture_cursor_session_v1.events.enter`][].
        """

        ...

    def on_leave(self) -> None:
        """
        Cursor left captured area.

        Override to handle [`wayland.ext_image_copy_capture_cursor_session_v1.events.leave`][].
        """

        ...

    def on_position(self, x: int, y: int) -> None:
        """
        Position changed.

        Override to handle [`wayland.ext_image_copy_capture_cursor_session_v1.events.position`][].
        """

        ...

    def on_hotspot(self, x: int, y: int) -> None:
        """
        Hotspot changed.

        Override to handle [`wayland.ext_image_copy_capture_cursor_session_v1.events.hotspot`][].
        """

        ...

    class events(WaylandEvent):
        def enter(self) -> None:
            """
            Cursor entered captured area

            Sent when a cursor enters the captured area. It shall be generated
            before the "position" and "hotspot" events when and only when a cursor
            enters the area.

            The cursor enters the captured area when the cursor image intersects
            with the captured area. Note, this is different from e.g.
            wl_pointer.enter.
            """

            ...

        def leave(self) -> None:
            """
            Cursor left captured area

            Sent when a cursor leaves the captured area. No "position" or "hotspot"
            event is generated for the cursor until the cursor enters the captured
            area again.
            """

            ...

        def position(self, x: int, y: int) -> None:
            """
            Position changed

            Cursors outside the image capture source do not get captured and no
            event will be generated for them.

            The given position is the position of the cursor's hotspot and it is
            relative to the main buffer's top left corner in transformed buffer
            pixel coordinates. The coordinates may be negative or greater than the
            main buffer size.

            Args:
                x: Position x coordinates
                y: Position y coordinates
            """

            ...

        def hotspot(self, x: int, y: int) -> None:
            """
            Hotspot changed

            The hotspot describes the offset between the cursor image and the
            position of the input device.

            The given coordinates are the hotspot's offset from the origin in
            buffer coordinates.

            Clients should not apply the hotspot immediately: the hotspot becomes
            effective when the next ext_image_copy_capture_frame_v1.ready event is received.

            Compositors may delay this event until the client captures a new frame.

            Args:
                x: Hotspot x coordinates
                y: Hotspot y coordinates
            """

            ...

class ext_session_lock_manager_v1:
    """
    Used to lock the session

    This interface is used to request that the session be locked.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the session lock manager object

        This informs the compositor that the session lock manager object will
        no longer be used. Existing objects created through this interface
        remain valid.
        """

        ...

    def lock(self) -> ext_session_lock_v1:
        """
        Attempt to lock the session

        This request creates a session lock and asks the compositor to lock the
        session. The compositor will send either the ext_session_lock_v1.locked
        or ext_session_lock_v1.finished event on the created object in
        response to this request.

        Returns:
            ext_session_lock_v1: The created object
        """

        ...

class ext_session_lock_v1:
    """
    Manage lock state and create lock surfaces

    In response to the creation of this object the compositor must send
    either the locked or finished event.

    The locked event indicates that the session is locked. This means
    that the compositor must stop rendering and providing input to normal
    clients. Instead the compositor must blank all outputs with an opaque
    color such that their normal content is fully hidden.

    The only surfaces that should be rendered while the session is locked
    are the lock surfaces created through this interface and optionally,
    at the compositor's discretion, special privileged surfaces such as
    input methods or portions of desktop shell UIs.

    The locked event must not be sent until a new "locked" frame (either
    from a session lock surface or the compositor blanking the output) has
    been presented on all outputs and no security sensitive normal/unlocked
    content is possibly visible.

    The finished event should be sent immediately on creation of this
    object if the compositor decides that the locked event will not be sent.

    The compositor may wait for the client to create and render session lock
    surfaces before sending the locked event to avoid displaying intermediate
    blank frames. However, it must impose a reasonable time limit if
    waiting and send the locked event as soon as the hard requirements
    described above can be met if the time limit expires. Clients should
    immediately create lock surfaces for all outputs on creation of this
    object to make this possible.

    This behavior of the locked event is required in order to prevent
    possible race conditions with clients that wish to suspend the system
    or similar after locking the session. Without these semantics, clients
    triggering a suspend after receiving the locked event would race with
    the first "locked" frame being presented and normal/unlocked frames
    might be briefly visible as the system is resumed if the suspend
    operation wins the race.

    If the client dies while the session is locked, the compositor must not
    unlock the session in response. It is acceptable for the session to be
    permanently locked if this happens. The compositor may choose to continue
    to display the lock surfaces the client had mapped before it died or
    alternatively fall back to a solid color, this is compositor policy.

    Compositors may also allow a secure way to recover the session, the
    details of this are compositor policy. Compositors may allow a new
    client to create a ext_session_lock_v1 object and take responsibility
    for unlocking the session, they may even start a new lock client
    instance automatically.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_destroy: int
        """Attempted to destroy session lock while locked"""

        invalid_unlock: int
        """Unlock requested but locked event was never sent"""

        role: int
        """Given `wl_surface` already has a role"""

        duplicate_output: int
        """Given output already has a lock surface"""

        already_constructed: int
        """Given `wl_surface` has a buffer attached or committed"""



    def destroy(self) -> None:
        """
        Destroy the session lock

        This informs the compositor that the lock object will no longer be
        used. Existing objects created through this interface remain valid.

        After this request is made, lock surfaces created through this object
        should be destroyed by the client as they will no longer be used by
        the compositor.

        It is a protocol error to make this request if the locked event was
        sent, the unlock_and_destroy request must be used instead.
        """

        ...

    def get_lock_surface(self, surface: wl_surface, output: wl_output) -> ext_session_lock_surface_v1:
        """
        Create a lock surface for a given output

        The client is expected to create lock surfaces for all outputs
        currently present and any new outputs as they are advertised. These
        won't be displayed by the compositor unless the lock is successful
        and the locked event is sent.

        Providing a wl_surface which already has a role or already has a buffer
        attached or committed is a protocol error, as is attaching/committing
        a buffer before the first ext_session_lock_surface_v1.configure event.

        Attempting to create more than one lock surface for a given output
        is a duplicate_output protocol error.

        Returns:
            ext_session_lock_surface_v1: The created object
        """

        ...

    def unlock_and_destroy(self) -> None:
        """
        Unlock the session, destroying the object

        This request indicates that the session should be unlocked, for
        example because the user has entered their password and it has been
        verified by the client.

        This request also informs the compositor that the lock object will
        no longer be used and should be destroyed. Existing objects created
        through this interface remain valid.

        After this request is made, lock surfaces created through this object
        should be destroyed by the client as they will no longer be used by
        the compositor.

        It is a protocol error to make this request if the locked event has
        not been sent. In that case, the lock object must be destroyed using
        the destroy request.

        Note that a correct client that wishes to exit directly after unlocking
        the session must use the wl_display.sync request to ensure the server
        receives and processes the unlock_and_destroy request. Otherwise
        there is no guarantee that the server has unlocked the session due
        to the asynchronous nature of the Wayland protocol. For example,
        the server might terminate the client with a protocol error before
        it processes the unlock_and_destroy request.
        """

        ...

    def on_locked(self) -> None:
        """
        Session successfully locked.

        Override to handle [`wayland.ext_session_lock_v1.events.locked`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The session lock object should be destroyed.

        Override to handle [`wayland.ext_session_lock_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def locked(self) -> None:
            """
            Session successfully locked

            This client is now responsible for displaying graphics while the
            session is locked and deciding when to unlock the session.

            The locked event must not be sent until a new "locked" frame has been
            presented on all outputs and no security sensitive normal/unlocked
            content is possibly visible.

            If this event is sent, making the destroy request is a protocol error,
            the lock object must be destroyed using the unlock_and_destroy request.
            """

            ...

        def finished(self) -> None:
            """
            The session lock object should be destroyed

            The compositor has decided that the session lock should be destroyed
            as it will no longer be used by the compositor. Exactly when this
            event is sent is compositor policy, but it must never be sent more
            than once for a given session lock object.

            This might be sent because there is already another ext_session_lock_v1
            object held by a client, or the compositor has decided to deny the
            request to lock the session for some other reason. This might also
            be sent because the compositor implements some alternative, secure
            way to authenticate and unlock the session.

            The finished event should be sent immediately on creation of this
            object if the compositor decides that the locked event will not
            be sent.

            If the locked event is sent on creation of this object the finished
            event may still be sent at some later time in this object's
            lifetime. This is compositor policy.

            Upon receiving this event, the client should make either the destroy
            request or the unlock_and_destroy request, depending on whether or
            not the locked event was received on this object.
            """

            ...

class ext_session_lock_surface_v1:
    """
    A surface displayed while the session is locked

    The client may use lock surfaces to display a screensaver, render a
    dialog to enter a password and unlock the session, or however else it
    sees fit.

    On binding this interface the compositor will immediately send the
    first configure event. After making the ack_configure request in
    response to this event the client should attach and commit the first
    buffer. Committing the surface before acking the first configure is a
    protocol error. Committing the surface with a null buffer at any time
    is a protocol error.

    The compositor is free to handle keyboard/pointer focus for lock
    surfaces however it chooses. A reasonable way to do this would be to
    give the first lock surface created keyboard focus and change keyboard
    focus if the user clicks on other surfaces.
    """
    object_id = 0
    version = 1

    class error(Enum):
        commit_before_first_ack: int
        """Surface committed before first `ack_configure` request"""

        null_buffer: int
        """Surface committed with a null buffer"""

        dimensions_mismatch: int
        """Failed to match ack'd width/height"""

        invalid_serial: int
        """Serial provided in `ack_configure` is invalid"""



    def destroy(self) -> None:
        """
        Destroy the lock surface object

        This informs the compositor that the lock surface object will no
        longer be used.

        It is recommended for a lock client to destroy lock surfaces if
        their corresponding wl_output global is removed.

        If a lock surface on an active output is destroyed before the
        ext_session_lock_v1.unlock_and_destroy event is sent, the compositor
        must fall back to rendering a solid color.
        """

        ...

    def ack_configure(self, serial: int) -> None:
        """
        Ack a configure event

        When a configure event is received, if a client commits the surface
        in response to the configure event, then the client must make an
        ack_configure request sometime before the commit request, passing
        along the serial of the configure event.

        If the client receives multiple configure events before it can
        respond to one, it only has to ack the last configure event.

        A client is not required to commit immediately after sending an
        ack_configure request - it may even ack_configure several times
        before its next surface commit.

        A client may send multiple ack_configure requests before committing,
        but only the last request sent before a commit indicates which
        configure event the client really is responding to.

        Sending an ack_configure request consumes the configure event
        referenced by the given serial, as well as all older configure events
        sent on this object.

        It is a protocol error to issue multiple ack_configure requests
        referencing the same configure event or to issue an ack_configure
        request referencing a configure event older than the last configure
        event acked for a given lock surface.

        Args:
            serial: Serial from the configure event
        """

        ...

    def on_configure(self, serial: int, width: int, height: int) -> None:
        """
        The client should resize its surface.

        Override to handle [`wayland.ext_session_lock_surface_v1.events.configure`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, serial: int, width: int, height: int) -> None:
            """
            The client should resize its surface

            This event is sent once on binding the interface and may be sent again
            at the compositor's discretion, for example if output geometry changes.

            The width and height are in surface-local coordinates and are exact
            requirements. Failing to match these surface dimensions in the next
            commit after acking a configure is a protocol error.

            Args:
                serial: Serial for use in `ack_configure`
            """

            ...

class ext_transient_seat_manager_v1:
    """
    Transient seat manager

    The transient seat manager creates short-lived seats.
    """
    object_id = 0
    version = 1


    def create(self) -> ext_transient_seat_v1:
        """
        Create a transient seat

        Create a new seat that is removed when the client side transient seat
        object is destroyed.

        The actual seat may be removed sooner, in which case the transient seat
        object shall become inert.

        Returns:
            ext_transient_seat_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the manager.

        All objects created by the manager will remain valid until they are
        destroyed themselves.
        """

        ...

class ext_transient_seat_v1:
    """
    Transient seat handle

    When the transient seat handle is destroyed, the seat itself will also be
    destroyed.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy transient seat

        When the transient seat object is destroyed by the client, the
        associated seat created by the compositor is also destroyed.
        """

        ...

    def on_ready(self, global_name: int) -> None:
        """
        Transient seat is ready.

        Override to handle [`wayland.ext_transient_seat_v1.events.ready`][].
        """

        ...

    def on_denied(self) -> None:
        """
        Transient seat creation denied.

        Override to handle [`wayland.ext_transient_seat_v1.events.denied`][].
        """

        ...

    class events(WaylandEvent):
        def ready(self, global_name: int) -> None:
            """
            Transient seat is ready

            This event advertises the global name for the wl_seat to be used with
            wl_registry_bind.

            It is sent exactly once, immediately after the transient seat is created
            and the new "wl_seat" global is advertised, if and only if the creation
            of the transient seat was allowed.
            """

            ...

        def denied(self) -> None:
            """
            Transient seat creation denied

            The event informs the client that the compositor denied its request to
            create a transient seat.

            It is sent exactly once, immediately after the transient seat object is
            created, if and only if the creation of the transient seat was denied.

            After receiving this event, the client should destroy the object.
            """

            ...

class ext_workspace_manager_v1:
    """
    List and control workspaces

    Workspaces, also called virtual desktops, are groups of surfaces. A
    compositor with a concept of workspaces may only show some such groups of
    surfaces (those of 'active' workspaces) at a time. 'Activating' a
    workspace is a request for the compositor to display that workspace's
    surfaces as normal, whereas the compositor may hide or otherwise
    de-emphasise surfaces that are associated only with 'inactive' workspaces.
    Workspaces are grouped by which sets of outputs they correspond to, and
    may contain surfaces only from those outputs. In this way, it is possible
    for each output to have its own set of workspaces, or for all outputs (or
    any other arbitrary grouping) to share workspaces. Compositors may
    optionally conceptually arrange each group of workspaces in an
    N-dimensional grid.

    The purpose of this protocol is to enable the creation of taskbars and
    docks by providing them with a list of workspaces and their properties,
    and allowing them to activate and deactivate workspaces.

    After a client binds the ext_workspace_manager_v1, each workspace will be
    sent via the workspace event.
    """
    object_id = 0
    version = 1


    def commit(self) -> None:
        """
        All requests about the workspaces have been sent

        The client must send this request after it has finished sending other
        requests. The compositor must process a series of requests preceding a
        commit request atomically.

        This allows changes to the workspace properties to be seen as atomic,
        even if they happen via multiple events, and even if they involve
        multiple ext_workspace_handle_v1 objects, for example, deactivating one
        workspace and activating another.
        """

        ...

    def stop(self) -> None:
        """
        Stop sending events

        Indicates the client no longer wishes to receive events for new
        workspace groups. However the compositor may emit further workspace
        events, until the finished event is emitted. The compositor is expected
        to send the finished event eventually once the stop request has been processed.

        The client must not send any requests after this one, doing so will raise a wl_display
        invalid_object error.
        """

        ...

    def on_workspace_group(self, workspace_group: ext_workspace_group_handle_v1) -> None:
        """
        A workspace group has been created.

        Override to handle [`wayland.ext_workspace_manager_v1.events.workspace_group`][].
        """

        ...

    def on_workspace(self, workspace: ext_workspace_handle_v1) -> None:
        """
        Workspace has been created.

        Override to handle [`wayland.ext_workspace_manager_v1.events.workspace`][].
        """

        ...

    def on_done(self) -> None:
        """
        All information about the workspaces and workspace groups has been sent.

        Override to handle [`wayland.ext_workspace_manager_v1.events.done`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The compositor has finished with the `workspace_manager`.

        Override to handle [`wayland.ext_workspace_manager_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def workspace_group(self, workspace_group: ext_workspace_group_handle_v1) -> None:
            """
            A workspace group has been created

            This event is emitted whenever a new workspace group has been created.

            All initial details of the workspace group (outputs) will be
            sent immediately after this event via the corresponding events in
            ext_workspace_group_handle_v1 and ext_workspace_handle_v1.
            """

            ...

        def workspace(self, workspace: ext_workspace_handle_v1) -> None:
            """
            Workspace has been created

            This event is emitted whenever a new workspace has been created.

            All initial details of the workspace (name, coordinates, state) will
            be sent immediately after this event via the corresponding events in
            ext_workspace_handle_v1.

            Workspaces start off unassigned to any workspace group.
            """

            ...

        def done(self) -> None:
            """
            All information about the workspaces and workspace groups has been sent

            This event is sent after all changes in all workspaces and workspace groups have been
            sent.

            This allows changes to one or more ext_workspace_group_handle_v1
            properties and ext_workspace_handle_v1 properties
            to be seen as atomic, even if they happen via multiple events.
            In particular, an output moving from one workspace group to
            another sends an output_enter event and an output_leave event to the two
            ext_workspace_group_handle_v1 objects in question. The compositor sends
            the done event only after updating the output information in both
            workspace groups.
            """

            ...

        def finished(self) -> None:
            """
            The compositor has finished with the `workspace_manager`

            This event indicates that the compositor is done sending events to the
            ext_workspace_manager_v1. The server will destroy the object
            immediately after sending this request.
            """

            ...

class ext_workspace_group_handle_v1:
    """
    A workspace group assigned to a set of outputs

    A ext_workspace_group_handle_v1 object represents a workspace group
    that is assigned a set of outputs and contains a number of workspaces.

    The set of outputs assigned to the workspace group is conveyed to the client via
    output_enter and output_leave events, and its workspaces are conveyed with
    workspace events.

    For example, a compositor which has a set of workspaces for each output may
    advertise a workspace group (and its workspaces) per output, whereas a compositor
    where a workspace spans all outputs may advertise a single workspace group for all
    outputs.
    """
    object_id = 0
    version = 1

    class group_capabilities(IntFlag):
        create_workspace: int
        """`create_workspace` request is available"""



    def create_workspace(self, workspace: str) -> None:
        """
        Create a new workspace

        Request that the compositor create a new workspace with the given name
        and assign it to this group.

        There is no guarantee that the compositor will create a new workspace,
        or that the created workspace will have the provided name.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the ext_workspace_group_handle_v1 object

        Destroys the ext_workspace_group_handle_v1 object.

        This request should be send either when the client does not want to
        use the workspace group object any more or after the removed event to finalize
        the destruction of the object.
        """

        ...

    def on_capabilities(self, capabilities: ext_workspace_group_handle_v1.group_capabilities) -> None:
        """
        Compositor capabilities.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.capabilities`][].
        """

        ...

    def on_output_enter(self, output: wl_output) -> None:
        """
        Output assigned to workspace group.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.output_enter`][].
        """

        ...

    def on_output_leave(self, output: wl_output) -> None:
        """
        Output removed from workspace group.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.output_leave`][].
        """

        ...

    def on_workspace_enter(self, workspace: ext_workspace_handle_v1) -> None:
        """
        Workspace added to workspace group.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.workspace_enter`][].
        """

        ...

    def on_workspace_leave(self, workspace: ext_workspace_handle_v1) -> None:
        """
        Workspace removed from workspace group.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.workspace_leave`][].
        """

        ...

    def on_removed(self) -> None:
        """
        This workspace group has been removed.

        Override to handle [`wayland.ext_workspace_group_handle_v1.events.removed`][].
        """

        ...

    class events(WaylandEvent):
        def capabilities(self, capabilities: ext_workspace_group_handle_v1.group_capabilities) -> None:
            """
            Compositor capabilities

            This event advertises the capabilities supported by the compositor. If
            a capability isn't supported, clients should hide or disable the UI
            elements that expose this functionality. For instance, if the
            compositor doesn't advertise support for creating workspaces, a button
            triggering the create_workspace request should not be displayed.

            The compositor will ignore requests it doesn't support. For instance,
            a compositor which doesn't advertise support for creating workspaces will ignore
            create_workspace requests.

            Compositors must send this event once after creation of an
            ext_workspace_group_handle_v1. When the capabilities change, compositors
            must send this event again.

            Args:
                capabilities: Capabilities
            """

            ...

        def output_enter(self, output: wl_output) -> None:
            """
            Output assigned to workspace group

            This event is emitted whenever an output is assigned to the workspace
            group or a new `wl_output` object is bound by the client, which was already
            assigned to this workspace_group.
            """

            ...

        def output_leave(self, output: wl_output) -> None:
            """
            Output removed from workspace group

            This event is emitted whenever an output is removed from the workspace
            group.
            """

            ...

        def workspace_enter(self, workspace: ext_workspace_handle_v1) -> None:
            """
            Workspace added to workspace group

            This event is emitted whenever a workspace is assigned to this group.
            A workspace may only ever be assigned to a single group at a single point
            in time, but can be re-assigned during it's lifetime.
            """

            ...

        def workspace_leave(self, workspace: ext_workspace_handle_v1) -> None:
            """
            Workspace removed from workspace group

            This event is emitted whenever a workspace is removed from this group.
            """

            ...

        def removed(self) -> None:
            """
            This workspace group has been removed

            This event is send when the group associated with the ext_workspace_group_handle_v1
            has been removed. After sending this request the compositor will immediately consider
            the object inert. Any requests will be ignored except the destroy request.
            It is guaranteed there won't be any more events referencing this
            ext_workspace_group_handle_v1.

            The compositor must remove all workspaces belonging to a workspace group
            via a workspace_leave event before removing the workspace group.
            """

            ...

class ext_workspace_handle_v1:
    """
    A workspace handing a group of surfaces

    A ext_workspace_handle_v1 object represents a workspace that handles a
    group of surfaces.

    Each workspace has:
    - a name, conveyed to the client with the name event
    - potentially an id conveyed with the id event
    - a list of states, conveyed to the client with the state event
    - and optionally a set of coordinates, conveyed to the client with the
    coordinates event

    The client may request that the compositor activate or deactivate the workspace.

    Each workspace can belong to only a single workspace group.
    Depending on the compositor policy, there might be workspaces with
    the same name in different workspace groups, but these workspaces are still
    separate (e.g. one of them might be active while the other is not).
    """
    object_id = 0
    version = 1

    class state(IntFlag):
        """
        Types of states on the workspace

        The different states that a workspace can have.
        """

        active: int
        """The workspace is active"""

        urgent: int
        """The workspace requests attention"""

        hidden: int
        """
        The workspace is not visible
        The workspace is not visible in its workspace group, and clients
        attempting to visualize the compositor workspace state should not
        display such workspaces.
        """



    class workspace_capabilities(IntFlag):
        activate: int
        """Activate request is available"""

        deactivate: int
        """Deactivate request is available"""

        remove: int
        """Remove request is available"""

        assign: int
        """Assign request is available"""



    def destroy(self) -> None:
        """
        Destroy the ext_workspace_handle_v1 object

        Destroys the ext_workspace_handle_v1 object.

        This request should be made either when the client does not want to
        use the workspace object any more or after the remove event to finalize
        the destruction of the object.
        """

        ...

    def activate(self) -> None:
        """
        Activate the workspace

        Request that this workspace be activated.

        There is no guarantee the workspace will be actually activated, and
        behaviour may be compositor-dependent. For example, activating a
        workspace may or may not deactivate all other workspaces in the same
        group.
        """

        ...

    def deactivate(self) -> None:
        """
        Deactivate the workspace

        Request that this workspace be deactivated.

        There is no guarantee the workspace will be actually deactivated.
        """

        ...

    def assign(self, workspace_group: ext_workspace_group_handle_v1) -> None:
        """
        Assign workspace to group

        Requests that this workspace is assigned to the given workspace group.

        There is no guarantee the workspace will be assigned.
        """

        ...

    def remove(self) -> None:
        """
        Remove the workspace

        Request that this workspace be removed.

        There is no guarantee the workspace will be actually removed.
        """

        ...

    def on_id(self, id: str) -> None:
        """
        Workspace id.

        Override to handle [`wayland.ext_workspace_handle_v1.events.id`][].
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Workspace name changed.

        Override to handle [`wayland.ext_workspace_handle_v1.events.name`][].
        """

        ...

    def on_coordinates(self, coordinates: list) -> None:
        """
        Workspace coordinates changed.

        Override to handle [`wayland.ext_workspace_handle_v1.events.coordinates`][].
        """

        ...

    def on_state(self, state: ext_workspace_handle_v1.state) -> None:
        """
        The state of the workspace changed.

        Override to handle [`wayland.ext_workspace_handle_v1.events.state`][].
        """

        ...

    def on_capabilities(self, capabilities: ext_workspace_handle_v1.workspace_capabilities) -> None:
        """
        Compositor capabilities.

        Override to handle [`wayland.ext_workspace_handle_v1.events.capabilities`][].
        """

        ...

    def on_removed(self) -> None:
        """
        This workspace has been removed.

        Override to handle [`wayland.ext_workspace_handle_v1.events.removed`][].
        """

        ...

    class events(WaylandEvent):
        def id(self, id: str) -> None:
            """
            Workspace id

            If this event is emitted, it will be send immediately after the
            ext_workspace_handle_v1 is created or when an id is assigned to
            a workspace (at most once during it's lifetime).

            An id will never change during the lifetime of the `ext_workspace_handle_v1`
            and is guaranteed to be unique during it's lifetime.

            Ids are not human-readable and shouldn't be displayed, use `name` for that purpose.

            Compositors are expected to only send ids for workspaces likely stable across multiple
            sessions and can be used by clients to store preferences for workspaces. Workspaces without
            ids should be considered temporary and any data associated with them should be deleted once
            the respective object is lost.
            """

            ...

        def name(self, name: str) -> None:
            """
            Workspace name changed

            This event is emitted immediately after the ext_workspace_handle_v1 is
            created and whenever the name of the workspace changes.

            A name is meant to be human-readable and can be displayed to a user.
            Unlike the id it is neither stable nor unique.
            """

            ...

        def coordinates(self, coordinates: list) -> None:
            """
            Workspace coordinates changed

            This event is used to organize workspaces into an N-dimensional grid
            within a workspace group, and if supported, is emitted immediately after
            the ext_workspace_handle_v1 is created and whenever the coordinates of
            the workspace change. Compositors may not send this event if they do not
            conceptually arrange workspaces in this way. If compositors simply
            number workspaces, without any geometric interpretation, they may send
            1D coordinates, which clients should not interpret as implying any
            geometry. Sending an empty array means that the compositor no longer
            orders the workspace geometrically.

            Coordinates have an arbitrary number of dimensions N with an uint32
            position along each dimension. By convention if N > 1, the first
            dimension is X, the second Y, the third Z, and so on. The compositor may
            chose to utilize these events for a more novel workspace layout
            convention, however. No guarantee is made about the grid being filled or
            bounded; there may be a workspace at coordinate 1 and another at
            coordinate 1000 and none in between. Within a workspace group, however,
            workspaces must have unique coordinates of equal dimensionality.
            """

            ...

        def state(self, state: ext_workspace_handle_v1.state) -> None:
            """
            The state of the workspace changed

            This event is emitted immediately after the ext_workspace_handle_v1 is
            created and each time the workspace state changes, either because of a
            compositor action or because of a request in this protocol.

            Missing states convey the opposite meaning, e.g. an unset active bit
            means the workspace is currently inactive.
            """

            ...

        def capabilities(self, capabilities: ext_workspace_handle_v1.workspace_capabilities) -> None:
            """
            Compositor capabilities

            This event advertises the capabilities supported by the compositor. If
            a capability isn't supported, clients should hide or disable the UI
            elements that expose this functionality. For instance, if the
            compositor doesn't advertise support for removing workspaces, a button
            triggering the remove request should not be displayed.

            The compositor will ignore requests it doesn't support. For instance,
            a compositor which doesn't advertise support for remove will ignore
            remove requests.

            Compositors must send this event once after creation of an
            ext_workspace_handle_v1 . When the capabilities change, compositors
            must send this event again.

            Args:
                capabilities: Capabilities
            """

            ...

        def removed(self) -> None:
            """
            This workspace has been removed

            This event is send when the workspace associated with the ext_workspace_handle_v1
            has been removed. After sending this request, the compositor will immediately consider
            the object inert. Any requests will be ignored except the destroy request.

            It is guaranteed there won't be any more events referencing this
            ext_workspace_handle_v1.

            The compositor must only remove a workspaces not currently belonging to any
            workspace_group.
            """

            ...

class wp_fifo_manager_v1:
    """
    Protocol for fifo constraints

    When a Wayland compositor considers applying a content update,
    it must ensure all the update's readiness constraints (fences, etc)
    are met.

    This protocol provides a way to use the completion of a display refresh
    cycle as an additional readiness constraint.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        Fatal presentation error

        These fatal protocol errors may be emitted in response to
        illegal requests.
        """

        already_exists: int
        """Fifo manager already exists for surface"""



    def destroy(self) -> None:
        """
        Unbind from the manager interface

        Informs the server that the client will no longer be using
        this protocol object. Existing objects created by this object
        are not affected.
        """

        ...

    def get_fifo(self, surface: wl_surface) -> wp_fifo_v1:
        """
        Request fifo interface for surface

        Establish a fifo object for a surface that may be used to add
        display refresh constraints to content updates.

        Only one such object may exist for a surface and attempting
        to create more than one will result in an already_exists
        protocol error. If a surface is acted on by multiple software
        components, general best practice is that only the component
        performing wl_surface.attach operations should use this protocol.

        Returns:
            wp_fifo_v1: The created object
        """

        ...

class wp_fifo_v1:
    """
    Fifo interface

    A fifo object for a surface that may be used to add
    display refresh constraints to content updates.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        Fatal error

        These fatal protocol errors may be emitted in response to
        illegal requests.
        """

        surface_destroyed: int
        """The associated surface no longer exists"""



    def set_barrier(self) -> None:
        """
        Sets the start point for a fifo constraint

        When the content update containing the "set_barrier" is applied,
        it sets a "fifo_barrier" condition on the surface associated with
        the fifo object. The condition is cleared immediately after the
        following latching deadline for non-tearing presentation.

        The compositor may clear the condition early if it must do so to
        ensure client forward progress assumptions.

        To wait for this condition to clear, use the "wait_barrier" request.

        "set_barrier" is double-buffered state, see wl_surface.commit.

        Requesting set_barrier after the fifo object's surface is
        destroyed will generate a "surface_destroyed" error.
        """

        ...

    def wait_barrier(self) -> None:
        """
        Adds a fifo constraint to a content update

        Indicate that this content update is not ready while a
        "fifo_barrier" condition is present on the surface.

        This means that when the content update containing "set_barrier"
        was made active at a latching deadline, it will be active for
        at least one refresh cycle. A content update which is allowed to
        tear might become active after a latching deadline if no content
        update became active at the deadline.

        The constraint must be ignored if the surface is a subsurface in
        synchronized mode. If the surface is not being updated by the
        compositor (off-screen, occluded) the compositor may ignore the
        constraint. Clients must use an additional mechanism such as
        frame callbacks or timestamps to ensure throttling occurs under
        all conditions.

        "wait_barrier" is double-buffered state, see wl_surface.commit.

        Requesting "wait_barrier" after the fifo object's surface is
        destroyed will generate a "surface_destroyed" error.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the fifo interface

        Informs the server that the client will no longer be using
        this protocol object.

        Surface state changes previously made by this protocol are
        unaffected by this object's destruction.
        """

        ...

class wp_fractional_scale_manager_v1:
    """
    Fractional surface scale information

    A global interface for requesting surfaces to use fractional scales.
    """
    object_id = 0
    version = 1

    class error(Enum):
        fractional_scale_exists: int
        """The surface already has a `fractional_scale` object associated"""



    def destroy(self) -> None:
        """
        Unbind the fractional surface scale interface

        Informs the server that the client will not be using this protocol
        object anymore. This does not affect any other objects,
        wp_fractional_scale_v1 objects included.
        """

        ...

    def get_fractional_scale(self, surface: wl_surface) -> wp_fractional_scale_v1:
        """
        Extend surface interface for scale information

        Create an add-on object for the the wl_surface to let the compositor
        request fractional scales. If the given wl_surface already has a
        wp_fractional_scale_v1 object associated, the fractional_scale_exists
        protocol error is raised.

        Args:
            surface: The surface

        Returns:
            wp_fractional_scale_v1: The created object
        """

        ...

class wp_fractional_scale_v1:
    """
    Fractional scale interface to a `wl_surface`

    An additional interface to a wl_surface object which allows the compositor
    to inform the client of the preferred scale.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Remove surface scale information for surface

        Destroy the fractional scale object. When this object is destroyed,
        preferred_scale events will no longer be sent.
        """

        ...

    def on_preferred_scale(self, scale: int) -> None:
        """
        Notify of new preferred scale.

        Override to handle [`wayland.wp_fractional_scale_v1.events.preferred_scale`][].
        """

        ...

    class events(WaylandEvent):
        def preferred_scale(self, scale: int) -> None:
            """
            Notify of new preferred scale

            Notification of a new preferred scale for this surface that the
            compositor suggests that the client should use.

            The sent scale is the numerator of a fraction with a denominator of 120.

            Args:
                scale: The new preferred scale
            """

            ...

class wp_linux_drm_syncobj_manager_v1:
    """
    Global for providing explicit synchronization

    This global is a factory interface, allowing clients to request
    explicit synchronization for buffers on a per-surface basis.

    See wp_linux_drm_syncobj_surface_v1 for more information.
    """
    object_id = 0
    version = 1

    class error(Enum):
        surface_exists: int
        """The surface already has a synchronization object associated"""

        invalid_timeline: int
        """The timeline object could not be imported"""



    def destroy(self) -> None:
        """
        Destroy explicit synchronization factory object

        Destroy this explicit synchronization factory object. Other objects
        shall not be affected by this request.
        """

        ...

    def get_surface(self, surface: wl_surface) -> wp_linux_drm_syncobj_surface_v1:
        """
        Extend surface interface for explicit synchronization

        Instantiate an interface extension for the given wl_surface to provide
        explicit synchronization.

        If the given wl_surface already has an explicit synchronization object
        associated, the surface_exists protocol error is raised.

        Graphics APIs, like EGL or Vulkan, that manage the buffer queue and
        commits of a wl_surface themselves, are likely to be using this
        extension internally. If a client is using such an API for a
        wl_surface, it should not directly use this extension on that surface,
        to avoid raising a surface_exists protocol error.

        Args:
            surface: The surface

        Returns:
            wp_linux_drm_syncobj_surface_v1: The created object
        """

        ...

    def import_timeline(self, fd: fd) -> wp_linux_drm_syncobj_timeline_v1:
        """
        Import a drm syncobj timeline

        Import a DRM synchronization object timeline.

        If the FD cannot be imported, the invalid_timeline error is raised.

        Args:
            fd: `drm_syncobj` file descriptor

        Returns:
            wp_linux_drm_syncobj_timeline_v1: The created object
        """

        ...

class wp_linux_drm_syncobj_timeline_v1:
    """
    Synchronization object timeline

    This object represents an explicit synchronization object timeline
    imported by the client to the compositor.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the timeline

        Destroy the synchronization object timeline. Other objects are not
        affected by this request, in particular timeline points set by
        set_acquire_point and set_release_point are not unset.
        """

        ...

class wp_linux_drm_syncobj_surface_v1:
    """
    Per-surface explicit synchronization

    This object is an add-on interface for wl_surface to enable explicit
    synchronization.

    Each surface can be associated with only one object of this interface at
    any time.

    Explicit synchronization is guaranteed to be supported for buffers
    created with any version of the linux-dmabuf protocol. Compositors are
    free to support explicit synchronization for additional buffer types.
    If at surface commit time the attached buffer does not support explicit
    synchronization, an unsupported_buffer error is raised.

    As long as the wp_linux_drm_syncobj_surface_v1 object is alive, the
    compositor may ignore implicit synchronization for buffers attached and
    committed to the wl_surface. The delivery of wl_buffer.release events
    for buffers attached to the surface becomes undefined.

    Clients must set both acquire and release points if and only if a
    non-null buffer is attached in the same surface commit. See the
    no_buffer, no_acquire_point and no_release_point protocol errors.

    If at surface commit time the acquire and release DRM syncobj timelines
    are identical, the acquire point value must be strictly less than the
    release point value, or else the conflicting_points protocol error is
    raised.
    """
    object_id = 0
    version = 1

    class error(Enum):
        no_surface: int
        """The associated `wl_surface` was destroyed"""

        unsupported_buffer: int
        """The buffer does not support explicit synchronization"""

        no_buffer: int
        """No buffer was attached"""

        no_acquire_point: int
        """No acquire timeline point was set"""

        no_release_point: int
        """No release timeline point was set"""

        conflicting_points: int
        """Acquire and release timeline points are in conflict"""



    def destroy(self) -> None:
        """
        Destroy the surface synchronization object

        Destroy this surface synchronization object.

        Any timeline point set by this object with set_acquire_point or
        set_release_point since the last commit may be discarded by the
        compositor. Any timeline point set by this object before the last
        commit will not be affected.
        """

        ...

    def set_acquire_point(self, timeline: wp_linux_drm_syncobj_timeline_v1, point_hi: int, point_lo: int) -> None:
        """
        Set the acquire timeline point

        Set the timeline point that must be signalled before the compositor may
        sample from the buffer attached with wl_surface.attach.

        The 64-bit unsigned value combined from point_hi and point_lo is the
        point value.

        The acquire point is double-buffered state, and will be applied on the
        next wl_surface.commit request for the associated surface. Thus, it
        applies only to the buffer that is attached to the surface at commit
        time.

        If an acquire point has already been attached during the same commit
        cycle, the new point replaces the old one.

        If the associated wl_surface was destroyed, a no_surface error is
        raised.

        If at surface commit time there is a pending acquire timeline point set
        but no pending buffer attached, a no_buffer error is raised. If at
        surface commit time there is a pending buffer attached but no pending
        acquire timeline point set, the no_acquire_point protocol error is
        raised.

        Args:
            point_hi: High 32 bits of the point value
            point_lo: Low 32 bits of the point value
        """

        ...

    def set_release_point(self, timeline: wp_linux_drm_syncobj_timeline_v1, point_hi: int, point_lo: int) -> None:
        """
        Set the release timeline point

        Set the timeline point that must be signalled by the compositor when it
        has finished its usage of the buffer attached with wl_surface.attach
        for the relevant commit.

        Once the timeline point is signaled, and assuming the associated buffer
        is not pending release from other wl_surface.commit requests, no
        additional explicit or implicit synchronization with the compositor is
        required to safely re-use the buffer.

        Note that clients cannot rely on the release point being always
        signaled after the acquire point: compositors may release buffers
        without ever reading from them. In addition, the compositor may use
        different presentation paths for different commits, which may have
        different release behavior. As a result, the compositor may signal the
        release points in a different order than the client committed them.

        Because signaling a timeline point also signals every previous point,
        it is generally not safe to use the same timeline object for the
        release points of multiple buffers. The out-of-order signaling
        described above may lead to a release point being signaled before the
        compositor has finished reading. To avoid this, it is strongly
        recommended that each buffer should use a separate timeline for its
        release points.

        The 64-bit unsigned value combined from point_hi and point_lo is the
        point value.

        The release point is double-buffered state, and will be applied on the
        next wl_surface.commit request for the associated surface. Thus, it
        applies only to the buffer that is attached to the surface at commit
        time.

        If a release point has already been attached during the same commit
        cycle, the new point replaces the old one.

        If the associated wl_surface was destroyed, a no_surface error is
        raised.

        If at surface commit time there is a pending release timeline point set
        but no pending buffer attached, a no_buffer error is raised. If at
        surface commit time there is a pending buffer attached but no pending
        release timeline point set, the no_release_point protocol error is
        raised.

        Args:
            point_hi: High 32 bits of the point value
            point_lo: Low 32 bits of the point value
        """

        ...

class wp_pointer_warp_v1:
    """
    Reposition the pointer to a location on a surface

    This global interface allows applications to request the pointer to be
    moved to a position relative to a wl_surface.

    Note that if the desired behavior is to constrain the pointer to an area
    or lock it to a position, this protocol does not provide a reliable way
    to do that. The pointer constraint and pointer lock protocols should be
    used for those use cases instead.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the warp manager

        Destroy the pointer warp manager.
        """

        ...

    def warp_pointer(self, surface: wl_surface, pointer: wl_pointer, x: float, y: float, serial: int) -> None:
        """
        Reposition the pointer

        Request the compositor to move the pointer to a surface-local position.
        Whether or not the compositor honors the request is implementation defined,
        but it should
        - honor it if the surface has pointer focus, including
          when it has an implicit pointer grab
        - reject it if the enter serial is incorrect
        - reject it if the requested position is outside of the surface

        Note that the enter serial is valid for any surface of the client,
        and does not have to be from the surface the pointer is warped to.

        Args:
            surface: Surface to position the pointer on
            pointer: The pointer that should be repositioned
            serial: Serial number of the enter event
        """

        ...

class wp_security_context_manager_v1:
    """
    Client security context manager

    This interface allows a client to register a new Wayland connection to
    the compositor and attach a security context to it.

    This is intended to be used by sandboxes. Sandbox engines attach a
    security context to all connections coming from inside the sandbox. The
    compositor can then restrict the features that the sandboxed connections
    can use.

    Compositors should forbid nesting multiple security contexts by not
    exposing wp_security_context_manager_v1 global to clients with a security
    context attached, or by sending the nested protocol error. Nested
    security contexts are dangerous because they can potentially allow
    privilege escalation of a sandboxed client.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_listen_fd: int
        """Listening socket fd is invalid"""

        nested: int
        """Nested security contexts are forbidden"""



    def destroy(self) -> None:
        """
        Destroy the manager object

        Destroy the manager. This doesn't destroy objects created with the
        manager.
        """

        ...

    def create_listener(self, listen_fd: fd, close_fd: fd) -> wp_security_context_v1:
        """
        Create a new security context

        Creates a new security context with a socket listening FD.

        The compositor will accept new client connections on listen_fd.
        listen_fd must be ready to accept new connections when this request is
        sent by the client. In other words, the client must call bind(2) and
        listen(2) before sending the FD.

        close_fd is a FD that will signal hangup when the compositor should stop
        accepting new connections on listen_fd.

        The compositor must continue to accept connections on listen_fd when
        the Wayland client which created the security context disconnects.

        After sending this request, closing listen_fd and close_fd remains the
        only valid operation on them.

        Args:
            listen_fd: Listening socket fd
            close_fd: Fd signaling when done

        Returns:
            wp_security_context_v1: The created object
        """

        ...

class wp_security_context_v1:
    """
    Client security context

    The security context allows a client to register a new client and attach
    security context metadata to the connections.

    When both are set, the combination of the application ID and the sandbox
    engine must uniquely identify an application. The same application ID
    will be used across instances (e.g. if the application is restarted, or
    if the application is started multiple times).

    When both are set, the combination of the instance ID and the sandbox
    engine must uniquely identify a running instance of an application.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_used: int
        """Security context has already been committed"""

        already_set: int
        """Metadata has already been set"""

        invalid_metadata: int
        """Metadata is invalid"""



    def destroy(self) -> None:
        """
        Destroy the security context object

        Destroy the security context object.
        """

        ...

    def set_sandbox_engine(self, name: str) -> None:
        """
        Set the sandbox engine

        Attach a unique sandbox engine name to the security context. The name
        should follow the reverse-DNS style (e.g. "org.flatpak").

        A list of well-known engines is maintained at:
        https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

        It is a protocol error to call this request twice. The already_set
        error is sent in this case.

        Args:
            name: The sandbox engine name
        """

        ...

    def set_app_id(self, app_id: str) -> None:
        """
        Set the application id

        Attach an application ID to the security context.

        The application ID is an opaque, sandbox-specific identifier for an
        application. See the well-known engines document for more details:
        https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

        The compositor may use the application ID to group clients belonging to
        the same security context application.

        Whether this request is optional or not depends on the sandbox engine used.

        It is a protocol error to call this request twice. The already_set
        error is sent in this case.

        Args:
            app_id: The application id
        """

        ...

    def set_instance_id(self, instance_id: str) -> None:
        """
        Set the instance id

        Attach an instance ID to the security context.

        The instance ID is an opaque, sandbox-specific identifier for a running
        instance of an application. See the well-known engines document for
        more details:
        https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

        Whether this request is optional or not depends on the sandbox engine used.

        It is a protocol error to call this request twice. The already_set
        error is sent in this case.

        Args:
            instance_id: The instance id
        """

        ...

    def commit(self) -> None:
        """
        Register the security context

        Atomically register the new client and attach the security context
        metadata.

        If the provided metadata is inconsistent or does not match with out of
        band metadata (see
        https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md),
        the invalid_metadata error may be sent eventually.

        It's a protocol error to send any request other than "destroy" after
        this request. In this case, the already_used error is sent.
        """

        ...

class wp_single_pixel_buffer_manager_v1:
    """
    Global factory for single-pixel buffers

    The wp_single_pixel_buffer_manager_v1 interface is a factory for
    single-pixel buffers.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the wp_single_pixel_buffer_manager_v1 object.

        The child objects created via this interface are unaffected.
        """

        ...

    def create_u32_rgba_buffer(self, r: int, g: int, b: int, a: int) -> wl_buffer:
        """
        Create a 1×1 buffer from 32-bit rgba values

        Create a single-pixel buffer from four 32-bit RGBA values.

        Unless specified in another protocol extension, the RGBA values use
        pre-multiplied alpha.

        The width and height of the buffer are 1.

        The r, g, b and a arguments valid range is from UINT32_MIN (0)
        to UINT32_MAX (0xffffffff).

        These arguments should be interpreted as a percentage, i.e.
        - UINT32_MIN = 0% of the given color component
        - UINT32_MAX = 100% of the given color component

        Args:
            r: Value of the buffer's red channel
            g: Value of the buffer's green channel
            b: Value of the buffer's blue channel
            a: Value of the buffer's alpha channel

        Returns:
            wl_buffer: The created object
        """

        ...

class wp_tearing_control_manager_v1:
    """
    Protocol for tearing control

    For some use cases like games or drawing tablets it can make sense to
    reduce latency by accepting tearing with the use of asynchronous page
    flips. This global is a factory interface, allowing clients to inform
    which type of presentation the content of their surfaces is suitable for.

    Graphics APIs like EGL or Vulkan, that manage the buffer queue and commits
    of a wl_surface themselves, are likely to be using this extension
    internally. If a client is using such an API for a wl_surface, it should
    not directly use this extension on that surface, to avoid raising a
    tearing_control_exists protocol error.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        tearing_control_exists: int
        """The surface already has a tearing object associated"""



    def destroy(self) -> None:
        """
        Destroy tearing control factory object

        Destroy this tearing control factory object. Other objects, including
        wp_tearing_control_v1 objects created by this factory, are not affected
        by this request.
        """

        ...

    def get_tearing_control(self, surface: wl_surface) -> wp_tearing_control_v1:
        """
        Extend surface interface for tearing control

        Instantiate an interface extension for the given wl_surface to request
        asynchronous page flips for presentation.

        If the given wl_surface already has a wp_tearing_control_v1 object
        associated, the tearing_control_exists protocol error is raised.

        Returns:
            wp_tearing_control_v1: The created object
        """

        ...

class wp_tearing_control_v1:
    """
    Per-surface tearing control interface

    An additional interface to a wl_surface object, which allows the client
    to hint to the compositor if the content on the surface is suitable for
    presentation with tearing.
    The default presentation hint is vsync. See presentation_hint for more
    details.

    If the associated wl_surface is destroyed, this object becomes inert and
    should be destroyed.
    """
    object_id = 0
    version = 1

    class presentation_hint(Enum):
        """
        Presentation hint values

        This enum provides information for if submitted frames from the client
        may be presented with tearing.
        """

        vsync: int
        """
        Tearing-free presentation
        The content of this surface is meant to be synchronized to the
        vertical blanking period. This should not result in visible tearing
        and may result in a delay before a surface commit is presented.
        """

        async_: int
        """
        Asynchronous presentation
        The content of this surface is meant to be presented with minimal
        latency and tearing is acceptable.
        """



    def set_presentation_hint(self, hint: wp_tearing_control_v1.presentation_hint) -> None:
        """
        Set presentation hint

        Set the presentation hint for the associated wl_surface. This state is
        double-buffered, see wl_surface.commit.

        The compositor is free to dynamically respect or ignore this hint based
        on various conditions like hardware capabilities, surface state and
        user preferences.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy tearing control object

        Destroy this surface tearing object and revert the presentation hint to
        vsync. The change will be applied on the next wl_surface.commit.
        """

        ...

class xdg_activation_v1:
    """
    Interface for activating surfaces

    A global interface used for informing the compositor about applications
    being activated or started, or for applications to request to be
    activated.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `xdg_activation` object

        Notify the compositor that the xdg_activation object will no longer be
        used.

        The child objects created via this interface are unaffected and should
        be destroyed separately.
        """

        ...

    def get_activation_token(self) -> xdg_activation_token_v1:
        """
        Requests a token

        Creates an xdg_activation_token_v1 object that will provide
        the initiating client with a unique token for this activation. This
        token should be offered to the clients to be activated.

        Returns:
            xdg_activation_token_v1: The created object
        """

        ...

    def activate(self, token: str, surface: wl_surface) -> None:
        """
        Notify new interaction being available

        Requests surface activation. It's up to the compositor to display
        this information as desired, for example by placing the surface above
        the rest.

        The compositor may know who requested this by checking the activation
        token and might decide not to follow through with the activation if it's
        considered unwanted.

        Compositors can ignore unknown activation tokens when an invalid
        token is passed.

        Args:
            token: The activation token of the initiating client
            surface: The `wl_surface` to activate
        """

        ...

class xdg_activation_token_v1:
    """
    An exported activation handle

    An object for setting up a token and receiving a token handle that can
    be passed as an activation token to another client.

    The object is created using the xdg_activation_v1.get_activation_token
    request. This object should then be populated with the app_id, surface
    and serial information and committed. The compositor shall then issue a
    done event with the token. In case the request's parameters are invalid,
    the compositor will provide an invalid token.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_used: int
        """The token has already been used previously"""



    def set_serial(self, serial: int, seat: wl_seat) -> None:
        """
        Specifies the seat and serial of the activating event

        Provides information about the seat and serial event that requested the
        token.

        The serial can come from an input or focus event. For instance, if a
        click triggers the launch of a third-party client, the launcher client
        should send a set_serial request with the serial and seat from the
        wl_pointer.button event.

        Some compositors might refuse to activate toplevels when the token
        doesn't have a valid and recent enough event serial.

        Must be sent before commit. This information is optional.

        Args:
            serial: The serial of the event that triggered the activation
            seat: The `wl_seat` of the event
        """

        ...

    def set_app_id(self, app_id: str) -> None:
        """
        Specifies the application being activated

        The requesting client can specify an app_id to associate the token
        being created with it.

        Must be sent before commit. This information is optional.

        Args:
            app_id: The application id of the client being activated.
        """

        ...

    def set_surface(self, surface: wl_surface) -> None:
        """
        Specifies the surface requesting activation

        This request sets the surface requesting the activation. Note, this is
        different from the surface that will be activated.

        Some compositors might refuse to activate toplevels when the token
        doesn't have a requesting surface.

        Must be sent before commit. This information is optional.

        Args:
            surface: The requesting surface
        """

        ...

    def commit(self) -> None:
        """
        Issues the token request

        Requests an activation token based on the different parameters that
        have been offered through set_serial, set_surface and set_app_id.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the xdg_activation_token_v1 object

        Notify the compositor that the xdg_activation_token_v1 object will no
        longer be used. The received token stays valid.
        """

        ...

    def on_done(self, token: str) -> None:
        """
        The exported activation token.

        Override to handle [`wayland.xdg_activation_token_v1.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def done(self, token: str) -> None:
            """
            The exported activation token

            The 'done' event contains the unique token of this activation request
            and notifies that the provider is done.

            Args:
                token: The exported activation token
            """

            ...

class xdg_wm_dialog_v1:
    """
    Create dialogs related to other toplevels

    The xdg_wm_dialog_v1 interface is exposed as a global object allowing
    to register surfaces with a xdg_toplevel role as "dialogs" relative to
    another toplevel.

    The compositor may let this relation influence how the surface is
    placed, displayed or interacted with.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_used: int
        """The `xdg_toplevel` object has already been used to create a xdg_dialog_v1"""



    def destroy(self) -> None:
        """
        Destroy the dialog manager object

        Destroys the xdg_wm_dialog_v1 object. This does not affect
        the xdg_dialog_v1 objects generated through it.
        """

        ...

    def get_xdg_dialog(self, toplevel: xdg_toplevel) -> xdg_dialog_v1:
        """
        Create a dialog object

        Creates a xdg_dialog_v1 object for the given toplevel. See the interface
                description for more details.

        	Compositors must raise an already_used error if clients attempt to
        	create multiple xdg_dialog_v1 objects for the same xdg_toplevel.

        Returns:
            xdg_dialog_v1: The created object
        """

        ...

class xdg_dialog_v1:
    """
    Dialog object

    A xdg_dialog_v1 object is an ancillary object tied to a xdg_toplevel. Its
    purpose is hinting the compositor that the toplevel is a "dialog" (e.g. a
    temporary window) relative to another toplevel (see
    xdg_toplevel.set_parent). If the xdg_toplevel is destroyed, the xdg_dialog_v1
    becomes inert.

    Through this object, the client may provide additional hints about
    the purpose of the secondary toplevel. This interface has no effect
    on toplevels that are not attached to a parent toplevel.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the dialog object

        Destroys the xdg_dialog_v1 object. If this object is destroyed
        before the related xdg_toplevel, the compositor should unapply its
        effects.
        """

        ...

    def set_modal(self) -> None:
        """
        Mark dialog as modal

        Hints that the dialog has "modal" behavior. Modal dialogs typically
        require to be fully addressed by the user (i.e. closed) before resuming
        interaction with the parent toplevel, and may require a distinct
        presentation.

        Clients must implement the logic to filter events in the parent
        toplevel on their own.

        Compositors may choose any policy in event delivery to the parent
        toplevel, from delivering all events unfiltered to using them for
        internal consumption.
        """

        ...

    def unset_modal(self) -> None:
        """
        Mark dialog as not modal

        Drops the hint that this dialog has "modal" behavior. See
        xdg_dialog_v1.set_modal for more details.
        """

        ...

class xdg_system_bell_v1:
    """
    System bell

    This global interface enables clients to ring the system bell.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the system bell object

        Notify that the object will no longer be used.
        """

        ...

    def ring(self, surface: wl_surface) -> None:
        """
        Ring the system bell

        This requests rings the system bell on behalf of a client. How ringing
        	the bell is implemented is up to the compositor. It may be an audible
        	sound, a visual feedback of some kind, or any other thing including
        	nothing.

                The passed surface should correspond to a toplevel like surface role,
                or be null, meaning the client doesn't have a particular toplevel it
                wants to associate the bell ringing with. See the xdg-shell protocol
                extension for a toplevel like surface role.

        Args:
            surface: Associated surface
        """

        ...

class xdg_toplevel_drag_manager_v1:
    """
    Move a window during a drag

    This protocol enhances normal drag and drop with the ability to move a
    window at the same time. This allows having detachable parts of a window
    that when dragged out of it become a new window and can be dragged over
    an existing window to be reattached.

    A typical workflow would be when the user starts dragging on top of a
    detachable part of a window, the client would create a wl_data_source and
    a xdg_toplevel_drag_v1 object and start the drag as normal via
    wl_data_device.start_drag. Once the client determines that the detachable
    window contents should be detached from the originating window, it creates
    a new xdg_toplevel with these contents and issues a
    xdg_toplevel_drag_v1.attach request before mapping it. From now on the new
    window is moved by the compositor during the drag as if the client called
    xdg_toplevel.move.

    Dragging an existing window is similar. The client creates a
    xdg_toplevel_drag_v1 object and attaches the existing toplevel before
    starting the drag.

    Clients use the existing drag and drop mechanism to detect when a window
    can be docked or undocked. If the client wants to snap a window into a
    parent window it should delete or unmap the dragged top-level. If the
    contents should be detached again it attaches a new toplevel as described
    above. If a drag operation is cancelled without being dropped, clients
    should revert to the previous state, deleting any newly created windows
    as appropriate. When a drag operation ends as indicated by
    wl_data_source.dnd_drop_performed the dragged toplevel window's final
    position is determined as if a xdg_toplevel_move operation ended.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_source: int
        """`data_source` already used for toplevel drag"""



    def destroy(self) -> None:
        """
        Destroy the xdg_toplevel_drag_manager_v1 object

        Destroy this xdg_toplevel_drag_manager_v1 object. Other objects,
        including xdg_toplevel_drag_v1 objects created by this factory, are not
        affected by this request.
        """

        ...

    def get_xdg_toplevel_drag(self, data_source: wl_data_source) -> xdg_toplevel_drag_v1:
        """
        Get an `xdg_toplevel_drag` for a `wl_data_source`

        Create an xdg_toplevel_drag for a drag and drop operation that is going
        to be started with data_source.

        This request can only be made on sources used in drag-and-drop, so it
        must be performed before wl_data_device.start_drag. Attempting to use
        the source other than for drag-and-drop such as in
        wl_data_device.set_selection will raise an invalid_source error.

        Destroying data_source while a toplevel is attached to the
        xdg_toplevel_drag is undefined.

        Returns:
            xdg_toplevel_drag_v1: The created object
        """

        ...

class xdg_toplevel_drag_v1:
    """Object representing a toplevel move during a drag"""
    object_id = 0
    version = 1

    class error(Enum):
        toplevel_attached: int
        """Valid toplevel already attached"""

        ongoing_drag: int
        """Drag has not ended"""



    def destroy(self) -> None:
        """
        Destroy an xdg_toplevel_drag_v1 object

        Destroy this xdg_toplevel_drag_v1 object. This request must only be
        called after the underlying wl_data_source drag has ended, as indicated
        by the dnd_drop_performed or cancelled events. In any other case an
        ongoing_drag error is raised.
        """

        ...

    def attach(self, toplevel: xdg_toplevel, x_offset: int, y_offset: int) -> None:
        """
        Move a toplevel with the drag operation

        Request that the window will be moved with the cursor during the drag
        operation. The offset is a hint to the compositor how the toplevel
        should be positioned relative to the cursor hotspot in surface local
        coordinates and relative to the geometry of the toplevel being attached.
        See xdg_surface.set_window_geometry. For example it might only
        be used when an unmapped window is attached. The attached window
        does not participate in the selection of the drag target.

        If the toplevel is unmapped while it is attached, it is automatically
        detached from the drag. In this case this request has to be called again
        if the window should be attached after it is remapped.

        This request can be called multiple times but issuing it while a
        toplevel with an active role is attached raises a toplevel_attached
        error.

        Args:
            x_offset: Dragged surface x offset
            y_offset: Dragged surface y offset
        """

        ...

class xdg_toplevel_icon_manager_v1:
    """
    Interface to manage toplevel icons

    This interface allows clients to create toplevel window icons and set
    them on toplevel windows to be displayed to the user.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the toplevel icon manager

        Destroy the toplevel icon manager.
        This does not destroy objects created with the manager.
        """

        ...

    def create_icon(self) -> xdg_toplevel_icon_v1:
        """
        Create a new icon instance

        Creates a new icon object. This icon can then be attached to a
        xdg_toplevel via the 'set_icon' request.

        Returns:
            xdg_toplevel_icon_v1: The created object
        """

        ...

    def set_icon(self, toplevel: xdg_toplevel, icon: xdg_toplevel_icon_v1) -> None:
        """
        Set an icon on a toplevel window

        This request assigns the icon 'icon' to 'toplevel', or clears the
        toplevel icon if 'icon' was null.
        This state is double-buffered and is applied on the next
        wl_surface.commit of the toplevel.

        After making this call, the xdg_toplevel_icon_v1 provided as 'icon'
        can be destroyed by the client without 'toplevel' losing its icon.
        The xdg_toplevel_icon_v1 is immutable from this point, and any
        future attempts to change it must raise the
        'xdg_toplevel_icon_v1.immutable' protocol error.

        The compositor must set the toplevel icon from either the pixel data
        the icon provides, or by loading a stock icon using the icon name.
        See the description of 'xdg_toplevel_icon_v1' for details.

        If 'icon' is set to null, the icon of the respective toplevel is reset
        to its default icon (usually the icon of the application, derived from
        its desktop-entry file, or a placeholder icon).
        If this request is passed an icon with no pixel buffers or icon name
        assigned, the icon must be reset just like if 'icon' was null.

        Args:
            toplevel: The toplevel to act on
        """

        ...

    def on_icon_size(self, size: int) -> None:
        """
        Describes a supported & preferred icon size.

        Override to handle [`wayland.xdg_toplevel_icon_manager_v1.events.icon_size`][].
        """

        ...

    def on_done(self) -> None:
        """
        All information has been sent.

        Override to handle [`wayland.xdg_toplevel_icon_manager_v1.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def icon_size(self, size: int) -> None:
            """
            Describes a supported & preferred icon size

            This event indicates an icon size the compositor prefers to be
            available if the client has scalable icons and can render to any size.

            When the 'xdg_toplevel_icon_manager_v1' object is created, the
            compositor may send one or more 'icon_size' events to describe the list
            of preferred icon sizes. If the compositor has no size preference, it
            may not send any 'icon_size' event, and it is up to the client to
            decide a suitable icon size.

            A sequence of 'icon_size' events must be finished with a 'done' event.
            If the compositor has no size preferences, it must still send the
            'done' event, without any preceding 'icon_size' events.

            Args:
                size: The edge size of the square icon in surface-local coordinates, e.g. 64
            """

            ...

        def done(self) -> None:
            """
            All information has been sent

            This event is sent after all 'icon_size' events have been sent.
            """

            ...

class xdg_toplevel_icon_v1:
    """
    A toplevel window icon

    This interface defines a toplevel icon.
    An icon can have a name, and multiple buffers.
    In order to be applied, the icon must have either a name, or at least
    one buffer assigned. Applying an empty icon (with no buffer or name) to
    a toplevel should reset its icon to the default icon.

    It is up to compositor policy whether to prefer using a buffer or loading
    an icon via its name. See 'set_name' and 'add_buffer' for details.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_buffer: int
        """The provided buffer does not satisfy requirements"""

        immutable: int
        """The icon has already been assigned to a toplevel and must not be changed"""

        no_buffer: int
        """The provided buffer has been destroyed before the toplevel icon"""



    def destroy(self) -> None:
        """
        Destroy the icon object

        Destroys the 'xdg_toplevel_icon_v1' object.
        The icon must still remain set on every toplevel it was assigned to,
        until the toplevel icon is reset explicitly.
        """

        ...

    def set_name(self, icon_name: str) -> None:
        """
        Set an icon name

        This request assigns an icon name to this icon.
        Any previously set name is overridden.

        The compositor must resolve 'icon_name' according to the lookup rules
        described in the XDG icon theme specification[1] using the
        environment's current icon theme.

        If the compositor does not support icon names or cannot resolve
        'icon_name' according to the XDG icon theme specification it must
        fall back to using pixel buffer data instead.

        If this request is made after the icon has been assigned to a toplevel
        via 'set_icon', a 'immutable' error must be raised.

        [1]: https://specifications.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
        """

        ...

    def add_buffer(self, buffer: wl_buffer, scale: int) -> None:
        """
        Add icon data from a pixel buffer

        This request adds pixel data supplied as wl_buffer to the icon.

        The client should add pixel data for all icon sizes and scales that
        it can provide, or which are explicitly requested by the compositor
        via 'icon_size' events on xdg_toplevel_icon_manager_v1.

        The wl_buffer supplying pixel data as 'buffer' must be backed by wl_shm
        and must be a square (width and height being equal).
        If any of these buffer requirements are not fulfilled, a 'invalid_buffer'
        error must be raised.

        If this icon instance already has a buffer of the same size and scale
        from a previous 'add_buffer' request, data from the last request
        overrides the preexisting pixel data.

        The wl_buffer must be kept alive for as long as the xdg_toplevel_icon
        it is associated with is not destroyed, otherwise a 'no_buffer' error
        is raised. The buffer contents must not be modified after it was
        assigned to the icon. As a result, the region of the wl_shm_pool's
        backing storage used for the wl_buffer must not be modified after this
        request is sent. The wl_buffer.release event is unused.

        If this request is made after the icon has been assigned to a toplevel
        via 'set_icon', a 'immutable' error must be raised.

        Args:
            scale: The scaling factor of the icon, e.g. 1
        """

        ...

class xdg_toplevel_tag_manager_v1:
    """
    Protocol for setting toplevel tags

    In order to make some window properties like position, size,
    "always on top" or user defined rules for window behavior persistent, the
    compositor needs some way to identify windows even after the application
    has been restarted.
    This protocol allows clients to make this possible by setting a tag for
    toplevels.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy toplevel tag object

        Destroy this toplevel tag manager object. This request has no other
        effects.
        """

        ...

    def set_toplevel_tag(self, toplevel: xdg_toplevel, tag: str) -> None:
        """
        Set tag

        Set a tag for a toplevel. The tag may be shown to the user in UI, so
        it's preferable for it to be human readable, but it must be suitable
        for configuration files and should not be translated.
        Suitable tags would for example be "main window", "settings",
        "e-mail composer" or similar.

        The tag does not need to be unique across applications, and the client
        may set the same tag for multiple windows, for example if the user has
        opened the same UI twice. How the potentially resulting conflicts are
        handled is compositor policy.

        The client should set the tag as part of the initial commit on the
        associated toplevel, but it may set it at any time afterwards as well,
        for example if the purpose of the toplevel changes.

        Args:
            tag: Untranslated tag
        """

        ...

    def set_toplevel_description(self, toplevel: xdg_toplevel, description: str) -> None:
        """
        Set description

        Set a description for a toplevel. This description may be shown to the
        user in UI or read by a screen reader for accessibility purposes, and
        should be translated.
        It is recommended to make the description the translation of the tag.

        The client should set the description as part of the initial commit on
        the associated toplevel, but it may set it at any time afterwards as
        well, for example if the purpose of the toplevel changes.

        Args:
            description: Translated description
        """

        ...

class xwayland_shell_v1:
    """
    Context object for xwayland shell

    xwayland_shell_v1 is a singleton global object that
    provides the ability to create a xwayland_surface_v1 object
    for a given wl_surface.

    This interface is intended to be bound by the Xwayland server.

    A compositor must not allow clients other than Xwayland to
    bind to this interface. A compositor should hide this global
    from other clients' wl_registry.
    A client the compositor does not consider to be an Xwayland
    server attempting to bind this interface will result in
    an implementation-defined error.

    An Xwayland server that has bound this interface must not
    set the `WL_SURFACE_ID` atom on a window.
    """
    object_id = 0
    version = 1

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""



    def destroy(self) -> None:
        """
        Destroy the xwayland shell object

        Destroy the xwayland_shell_v1 object.

        The child objects created via this interface are unaffected.
        """

        ...

    def get_xwayland_surface(self, surface: wl_surface) -> xwayland_surface_v1:
        """
        Assign the `xwayland_surface` surface role

        Create an xwayland_surface_v1 interface for a given wl_surface
        object and gives it the xwayland_surface role.

        It is illegal to create an xwayland_surface_v1 for a wl_surface
        which already has an assigned role and this will result in the
        `role` protocol error.

        See the documentation of xwayland_surface_v1 for more details
        about what an xwayland_surface_v1 is and how it is used.

        Returns:
            xwayland_surface_v1: The created object
        """

        ...

class xwayland_surface_v1:
    """
    Interface for associating xwayland windows to `wl_surfaces`

    An Xwayland surface is a surface managed by an Xwayland server.
    It is used for associating surfaces to Xwayland windows.

    The Xwayland server associated with actions in this interface is
    determined by the Wayland client making the request.

    The client must call wl_surface.commit on the corresponding wl_surface
    for the xwayland_surface_v1 state to take effect.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_associated: int
        """Given `wl_surface` is already associated with an x11 window"""

        invalid_serial: int
        """Serial was not valid"""



    def set_serial(self, serial_lo: int, serial_hi: int) -> None:
        """
        Associates a xwayland window to a `wl_surface`

        Associates an Xwayland window to a wl_surface.
        The association state is double-buffered, see wl_surface.commit.

        The `serial_lo` and `serial_hi` parameters specify a non-zero
        monotonic serial number which is entirely unique and provided by the
        Xwayland server equal to the serial value provided by a client message
        with a message type of the `WL_SURFACE_SERIAL` atom on the X11 window
        for this surface to be associated to.

        The serial value in the `WL_SURFACE_SERIAL` client message is specified
        as having the lo-bits specified in `l[0]` and the hi-bits specified
        in `l[1]`.

        If the serial value provided by `serial_lo` and `serial_hi` is not
        valid, the `invalid_serial` protocol error will be raised.

        An X11 window may be associated with multiple surfaces throughout its
        lifespan. (eg. unmapping and remapping a window).

        For each wl_surface, this state must not be committed more than once,
        otherwise the `already_associated` protocol error will be raised.

        Args:
            serial_lo: The lower 32-bits of the serial number associated with the x11 window
            serial_hi: The upper 32-bits of the serial number associated with the x11 window
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the xwayland surface object

        Destroy the xwayland_surface_v1 object.

        Any already existing associations are unaffected by this action.
        """

        ...

class zwp_fullscreen_shell_v1:
    """
    Displays a single surface per output

    Displays a single surface per output.

    This interface provides a mechanism for a single client to display
    simple full-screen surfaces.  While there technically may be multiple
    clients bound to this interface, only one of those clients should be
    shown at a time.

    To present a surface, the client uses either the present_surface or
    present_surface_for_mode requests.  Presenting a surface takes effect
    on the next wl_surface.commit.  See the individual requests for
    details about scaling and mode switches.

    The client can have at most one surface per output at any time.
    Requesting a surface to be presented on an output that already has a
    surface replaces the previously presented surface.  Presenting a null
    surface removes its content and effectively disables the output.
    Exactly what happens when an output is "disabled" is
    compositor-specific.  The same surface may be presented on multiple
    outputs simultaneously.

    Once a surface is presented on an output, it stays on that output
    until either the client removes it or the compositor destroys the
    output.  This way, the client can update the output's contents by
    simply attaching a new buffer.

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 1

    class capability(Enum):
        """
        Capabilities advertised by the compositor

        Various capabilities that can be advertised by the compositor.  They
        are advertised one-at-a-time when the wl_fullscreen_shell interface is
        bound.  See the wl_fullscreen_shell.capability event for more details.

        ARBITRARY_MODES:
        This is a hint to the client that indicates that the compositor is
        capable of setting practically any mode on its outputs.  If this
        capability is provided, wl_fullscreen_shell.present_surface_for_mode
        will almost never fail and clients should feel free to set whatever
        mode they like.  If the compositor does not advertise this, it may
        still support some modes that are not advertised through wl_global.mode
        but it is less likely.

        CURSOR_PLANE:
        This is a hint to the client that indicates that the compositor can
        handle a cursor surface from the client without actually compositing.
        This may be because of a hardware cursor plane or some other mechanism.
        If the compositor does not advertise this capability then setting
        wl_pointer.cursor may degrade performance or be ignored entirely.  If
        CURSOR_PLANE is not advertised, it is recommended that the client draw
        its own cursor and set wl_pointer.cursor(NULL).
        """

        arbitrary_modes: int
        """Compositor is capable of almost any output mode"""

        cursor_plane: int
        """Compositor has a separate cursor plane"""



    class present_method(Enum):
        """
        Different method to set the surface fullscreen

        Hints to indicate to the compositor how to deal with a conflict
        between the dimensions of the surface and the dimensions of the
        output. The compositor is free to ignore this parameter.
        """

        default: int
        """No preference, apply default policy"""

        center: int
        """Center the surface on the output"""

        zoom: int
        """Scale the surface, preserving aspect ratio, to the largest size that will fit on the output"""

        zoom_crop: int
        """Scale the surface, preserving aspect ratio, to fully fill the output cropping if needed"""

        stretch: int
        """Scale the surface to the size of the output ignoring aspect ratio"""



    class error(Enum):
        """
        `wl_fullscreen_shell` error values

        These errors can be emitted in response to wl_fullscreen_shell requests.
        """

        invalid_method: int
        """`present_method` is not known"""

        role: int
        """Given `wl_surface` has another role"""



    def release(self) -> None:
        """
        Release the `wl_fullscreen_shell` interface

        Release the binding from the wl_fullscreen_shell interface.

        This destroys the server-side object and frees this binding.  If
        the client binds to wl_fullscreen_shell multiple times, it may wish
        to free some of those bindings.
        """

        ...

    def present_surface(self, surface: wl_surface, method: zwp_fullscreen_shell_v1.present_method, output: wl_output) -> None:
        """
        Present surface for display

        Present a surface on the given output.

        If the output is null, the compositor will present the surface on
        whatever display (or displays) it thinks best.  In particular, this
        may replace any or all surfaces currently presented so it should
        not be used in combination with placing surfaces on specific
        outputs.

        The method parameter is a hint to the compositor for how the surface
        is to be presented.  In particular, it tells the compositor how to
        handle a size mismatch between the presented surface and the
        output.  The compositor is free to ignore this parameter.

        The "zoom", "zoom_crop", and "stretch" methods imply a scaling
        operation on the surface.  This will override any kind of output
        scaling, so the buffer_scale property of the surface is effectively
        ignored.

        This request gives the surface the role of a fullscreen shell surface.
        If the surface already has another role, it raises a role protocol
        error.
        """

        ...

    def present_surface_for_mode(self, surface: wl_surface, output: wl_output, framerate: int) -> zwp_fullscreen_shell_mode_feedback_v1:
        """
        Present surface for display at a particular mode

        Presents a surface on the given output for a particular mode.

        If the current size of the output differs from that of the surface,
        the compositor will attempt to change the size of the output to
        match the surface.  The result of the mode-switch operation will be
        returned via the provided wl_fullscreen_shell_mode_feedback object.

        If the current output mode matches the one requested or if the
        compositor successfully switches the mode to match the surface,
        then the mode_successful event will be sent and the output will
        contain the contents of the given surface.  If the compositor
        cannot match the output size to the surface size, the mode_failed
        will be sent and the output will contain the contents of the
        previously presented surface (if any).  If another surface is
        presented on the given output before either of these has a chance
        to happen, the present_cancelled event will be sent.

        Due to race conditions and other issues unknown to the client, no
        mode-switch operation is guaranteed to succeed.  However, if the
        mode is one advertised by wl_output.mode or if the compositor
        advertises the ARBITRARY_MODES capability, then the client should
        expect that the mode-switch operation will usually succeed.

        If the size of the presented surface changes, the resulting output
        is undefined.  The compositor may attempt to change the output mode
        to compensate.  However, there is no guarantee that a suitable mode
        will be found and the client has no way to be notified of success
        or failure.

        The framerate parameter specifies the desired framerate for the
        output in mHz.  The compositor is free to ignore this parameter.  A
        value of 0 indicates that the client has no preference.

        If the value of wl_output.scale differs from wl_surface.buffer_scale,
        then the compositor may choose a mode that matches either the buffer
        size or the surface size.  In either case, the surface will fill the
        output.

        This request gives the surface the role of a fullscreen shell surface.
        If the surface already has another role, it raises a role protocol
        error.

        Returns:
            zwp_fullscreen_shell_mode_feedback_v1: The created object
        """

        ...

    def on_capability(self, capability: zwp_fullscreen_shell_v1.capability) -> None:
        """
        Advertises a capability of the compositor.

        Override to handle [`wayland.zwp_fullscreen_shell_v1.events.capability`][].
        """

        ...

    class events(WaylandEvent):
        def capability(self, capability: zwp_fullscreen_shell_v1.capability) -> None:
            """
            Advertises a capability of the compositor

            Advertises a single capability of the compositor.

            When the wl_fullscreen_shell interface is bound, this event is emitted
            once for each capability advertised.  Valid capabilities are given by
            the wl_fullscreen_shell.capability enum.  If clients want to take
            advantage of any of these capabilities, they should use a
            wl_display.sync request immediately after binding to ensure that they
            receive all the capability events.
            """

            ...

class zwp_fullscreen_shell_mode_feedback_v1:
    """"""
    object_id = 0
    version = 1



    def on_mode_successful(self) -> None:
        """
        Mode switch succeeded.

        Override to handle [`wayland.zwp_fullscreen_shell_mode_feedback_v1.events.mode_successful`][].
        """

        ...

    def on_mode_failed(self) -> None:
        """
        Mode switch failed.

        Override to handle [`wayland.zwp_fullscreen_shell_mode_feedback_v1.events.mode_failed`][].
        """

        ...

    def on_present_cancelled(self) -> None:
        """
        Mode switch cancelled.

        Override to handle [`wayland.zwp_fullscreen_shell_mode_feedback_v1.events.present_cancelled`][].
        """

        ...

    class events(WaylandEvent):
        def mode_successful(self) -> None:
            """
            Mode switch succeeded

            This event indicates that the attempted mode switch operation was
            successful.  A surface of the size requested in the mode switch
            will fill the output without scaling.

            Upon receiving this event, the client should destroy the
            wl_fullscreen_shell_mode_feedback object.
            """

            ...

        def mode_failed(self) -> None:
            """
            Mode switch failed

            This event indicates that the attempted mode switch operation
            failed.  This may be because the requested output mode is not
            possible or it may mean that the compositor does not want to allow it.

            Upon receiving this event, the client should destroy the
            wl_fullscreen_shell_mode_feedback object.
            """

            ...

        def present_cancelled(self) -> None:
            """
            Mode switch cancelled

            This event indicates that the attempted mode switch operation was
            cancelled.  Most likely this is because the client requested a
            second mode switch before the first one completed.

            Upon receiving this event, the client should destroy the
            wl_fullscreen_shell_mode_feedback object.
            """

            ...

class zwp_idle_inhibit_manager_v1:
    """
    Control behavior when display idles

    This interface permits inhibiting the idle behavior such as screen
    blanking, locking, and screensaving.  The client binds the idle manager
    globally, then creates idle-inhibitor objects for each surface.

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the idle inhibitor object

        Destroy the inhibit manager.
        """

        ...

    def create_inhibitor(self, surface: wl_surface) -> zwp_idle_inhibitor_v1:
        """
        Create a new inhibitor object

        Create a new inhibitor object associated with the given surface.

        Args:
            surface: The surface that inhibits the idle behavior

        Returns:
            zwp_idle_inhibitor_v1: The created object
        """

        ...

class zwp_idle_inhibitor_v1:
    """
    Context object for inhibiting idle behavior

    An idle inhibitor prevents the output that the associated surface is
    visible on from being set to a state where it is not visually usable due
    to lack of user interaction (e.g. blanked, dimmed, locked, set to power
    save, etc.)  Any screensaver processes are also blocked from displaying.

    If the surface is destroyed, unmapped, becomes occluded, loses
    visibility, or otherwise becomes not visually relevant for the user, the
    idle inhibitor will not be honored by the compositor; if the surface
    subsequently regains visibility the inhibitor takes effect once again.
    Likewise, the inhibitor isn't honored if the system was already idled at
    the time the inhibitor was established, although if the system later
    de-idles and re-idles the inhibitor will take effect.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the idle inhibitor object

        Remove the inhibitor effect from the associated wl_surface.
        """

        ...

class zwp_input_method_context_v1:
    """
    Input method context

    Corresponds to a text input on the input method side. An input method context
    is created on text input activation on the input method side. It allows
    receiving information about the text input from the application via events.
    Input method contexts do not keep state after deactivation and should be
    destroyed after deactivation is handled.

    Text is generally UTF-8 encoded, indices and lengths are in bytes.

    Serials are used to synchronize the state between the text input and
    an input method. New serials are sent by the text input in the
    commit_state request and are used by the input method to indicate
    the known text input state in events like preedit_string, commit_string,
    and keysym. The text input can then ignore events from the input method
    which are based on an outdated state (for example after a reset).

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """"""

        ...

    def commit_string(self, serial: int, text: str) -> None:
        """
        Commit string

        Send the commit string text for insertion to the application.

        The text to commit could be either just a single character after a key
        press or the result of some composing (pre-edit). It could be also an
        empty text when some text should be removed (see
        delete_surrounding_text) or when the input cursor should be moved (see
        cursor_position).

        Any previously set composing text will be removed.

        Args:
            serial: Serial of the latest known text input state
        """

        ...

    def preedit_string(self, serial: int, text: str, commit: str) -> None:
        """
        Pre-edit string

        Send the pre-edit string text to the application text input.

        The commit text can be used to replace the pre-edit text on reset (for
        example on unfocus).

        Previously sent preedit_style and preedit_cursor requests are also
        processed by the text_input.

        Args:
            serial: Serial of the latest known text input state
        """

        ...

    def preedit_styling(self, index: int, length: int, style: int) -> None:
        """
        Pre-edit styling

        Set the styling information on composing text. The style is applied for
        length in bytes from index relative to the beginning of
        the composing text (as byte offset). Multiple styles can
        be applied to a composing text.

        This request should be sent before sending a preedit_string request.
        """

        ...

    def preedit_cursor(self, index: int) -> None:
        """
        Pre-edit cursor

        Set the cursor position inside the composing text (as byte offset)
        relative to the start of the composing text.

        When index is negative no cursor should be displayed.

        This request should be sent before sending a preedit_string request.
        """

        ...

    def delete_surrounding_text(self, index: int, length: int) -> None:
        """
        Delete text

        Remove the surrounding text.

        This request will be handled on the text_input side directly following
        a commit_string request.
        """

        ...

    def cursor_position(self, index: int, anchor: int) -> None:
        """
        Set cursor to a new position

        Set the cursor and anchor to a new position. Index is the new cursor
        position in bytes (when >= 0 this is relative to the end of the inserted text,
        otherwise it is relative to the beginning of the inserted text). Anchor is
        the new anchor position in bytes (when >= 0 this is relative to the end of the
        inserted text, otherwise it is relative to the beginning of the inserted
        text). When there should be no selected text, anchor should be the same
        as index.

        This request will be handled on the text_input side directly following
        a commit_string request.
        """

        ...

    def modifiers_map(self, map: list) -> None:
        """"""

        ...

    def keysym(self, serial: int, time: int, sym: int, state: int, modifiers: int) -> None:
        """
        Keysym

        Notify when a key event was sent. Key events should not be used for
        normal text input operations, which should be done with commit_string,
        delete_surrounding_text, etc. The key event follows the wl_keyboard key
        event convention. Sym is an XKB keysym, state is a wl_keyboard key_state.

        Args:
            serial: Serial of the latest known text input state
        """

        ...

    def grab_keyboard(self) -> wl_keyboard:
        """
        Grab hardware keyboard

        Allow an input method to receive hardware keyboard input and process
        key events to generate text events (with pre-edit) over the wire. This
        allows input methods which compose multiple key events for inputting
        text like it is done for CJK languages.

        Returns:
            wl_keyboard: The created object
        """

        ...

    def key(self, serial: int, time: int, key: int, state: int) -> None:
        """
        Forward key event

        Forward a wl_keyboard::key event to the client that was not processed
        by the input method itself. Should be used when filtering key events
        with grab_keyboard.  The arguments should be the ones from the
        wl_keyboard::key event.

        For generating custom key events use the keysym request instead.

        Args:
            serial: Serial from `wl_keyboard`::key
            time: Time from `wl_keyboard`::key
            key: Key from `wl_keyboard`::key
            state: State from `wl_keyboard`::key
        """

        ...

    def modifiers(self, serial: int, mods_depressed: int, mods_latched: int, mods_locked: int, group: int) -> None:
        """
        Forward modifiers event

        Forward a wl_keyboard::modifiers event to the client that was not
        processed by the input method itself.  Should be used when filtering
        key events with grab_keyboard. The arguments should be the ones
        from the wl_keyboard::modifiers event.

        Args:
            serial: Serial from `wl_keyboard`::modifiers
            mods_depressed: `mods_depressed` from `wl_keyboard`::modifiers
            mods_latched: `mods_latched` from `wl_keyboard`::modifiers
            mods_locked: `mods_locked` from `wl_keyboard`::modifiers
            group: Group from `wl_keyboard`::modifiers
        """

        ...

    def language(self, serial: int, language: str) -> None:
        """

        Args:
            serial: Serial of the latest known text input state
        """

        ...

    def text_direction(self, serial: int, direction: int) -> None:
        """

        Args:
            serial: Serial of the latest known text input state
        """

        ...

    def on_surrounding_text(self, text: str, cursor: int, anchor: int) -> None:
        """
        Surrounding text event.

        Override to handle [`wayland.zwp_input_method_context_v1.events.surrounding_text`][].
        """

        ...

    def on_reset(self) -> None:
        """Override to handle [`wayland.zwp_input_method_context_v1.events.reset`][]"""

        ...

    def on_content_type(self, hint: int, purpose: int) -> None:
        """Override to handle [`wayland.zwp_input_method_context_v1.events.content_type`][]"""

        ...

    def on_invoke_action(self, button: int, index: int) -> None:
        """Override to handle [`wayland.zwp_input_method_context_v1.events.invoke_action`][]"""

        ...

    def on_commit_state(self, serial: int) -> None:
        """Override to handle [`wayland.zwp_input_method_context_v1.events.commit_state`][]"""

        ...

    def on_preferred_language(self, language: str) -> None:
        """Override to handle [`wayland.zwp_input_method_context_v1.events.preferred_language`][]"""

        ...

    class events(WaylandEvent):
        def surrounding_text(self, text: str, cursor: int, anchor: int) -> None:
            """
            Surrounding text event

            The plain surrounding text around the input position. Cursor is the
            position in bytes within the surrounding text relative to the beginning
            of the text. Anchor is the position in bytes of the selection anchor
            within the surrounding text relative to the beginning of the text. If
            there is no selected text then anchor is the same as cursor.
            """

            ...

        def reset(self) -> None:
            """"""

            ...

        def content_type(self, hint: int, purpose: int) -> None:
            """"""

            ...

        def invoke_action(self, button: int, index: int) -> None:
            """"""

            ...

        def commit_state(self, serial: int) -> None:
            """

            Args:
                serial: Serial of text input state
            """

            ...

        def preferred_language(self, language: str) -> None:
            """"""

            ...

class zwp_input_method_v1:
    """
    Input method

    An input method object is responsible for composing text in response to
    input from hardware or virtual keyboards. There is one input method
    object per seat. On activate there is a new input method context object
    created which allows the input method to communicate with the text input.
    """
    object_id = 0
    version = 1



    def on_activate(self, id: zwp_input_method_context_v1) -> None:
        """
        Activate event.

        Override to handle [`wayland.zwp_input_method_v1.events.activate`][].
        """

        ...

    def on_deactivate(self, context: zwp_input_method_context_v1) -> None:
        """
        Deactivate event.

        Override to handle [`wayland.zwp_input_method_v1.events.deactivate`][].
        """

        ...

    class events(WaylandEvent):
        def activate(self, id: zwp_input_method_context_v1) -> None:
            """
            Activate event

            A text input was activated. Creates an input method context object
            which allows communication with the text input.
            """

            ...

        def deactivate(self, context: zwp_input_method_context_v1) -> None:
            """
            Deactivate event

            The text input corresponding to the context argument was deactivated.
            The input method context should be destroyed after deactivation is
            handled.
            """

            ...

class zwp_input_panel_v1:
    """
    Interface for implementing keyboards

    Only one client can bind this interface at a time.
    """
    object_id = 0
    version = 1


    def get_input_panel_surface(self, surface: wl_surface) -> zwp_input_panel_surface_v1:
        """

        Returns:
            zwp_input_panel_surface_v1: The created object
        """

        ...

class zwp_input_panel_surface_v1:
    """"""
    object_id = 0
    version = 1

    class position(Enum):
        center_bottom: int


    def set_toplevel(self, output: wl_output, position: int) -> None:
        """
        Set the surface type as a keyboard

        Set the input_panel_surface type to keyboard.

        A keyboard surface is only shown when a text input is active.
        """

        ...

    def set_overlay_panel(self) -> None:
        """
        Set the surface type as an overlay panel

        Set the input_panel_surface to be an overlay panel.

        This is shown near the input cursor above the application window when
        a text input is active.
        """

        ...

class zwp_input_timestamps_manager_v1:
    """
    Context object for high-resolution input timestamps

    A global interface used for requesting high-resolution timestamps
    for input events.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the input timestamps manager object

        Informs the server that the client will no longer be using this
        protocol object. Existing objects created by this object are not
        affected.
        """

        ...

    def get_keyboard_timestamps(self, keyboard: wl_keyboard) -> zwp_input_timestamps_v1:
        """
        Subscribe to high-resolution keyboard timestamp events

        Creates a new input timestamps object that represents a subscription
        to high-resolution timestamp events for all wl_keyboard events that
        carry a timestamp.

        If the associated wl_keyboard object is invalidated, either through
        client action (e.g. release) or server-side changes, the input
        timestamps object becomes inert and the client should destroy it
        by calling zwp_input_timestamps_v1.destroy.

        Args:
            keyboard: The `wl_keyboard` object for which to get timestamp events

        Returns:
            zwp_input_timestamps_v1: The created object
        """

        ...

    def get_pointer_timestamps(self, pointer: wl_pointer) -> zwp_input_timestamps_v1:
        """
        Subscribe to high-resolution pointer timestamp events

        Creates a new input timestamps object that represents a subscription
        to high-resolution timestamp events for all wl_pointer events that
        carry a timestamp.

        If the associated wl_pointer object is invalidated, either through
        client action (e.g. release) or server-side changes, the input
        timestamps object becomes inert and the client should destroy it
        by calling zwp_input_timestamps_v1.destroy.

        Args:
            pointer: The `wl_pointer` object for which to get timestamp events

        Returns:
            zwp_input_timestamps_v1: The created object
        """

        ...

    def get_touch_timestamps(self, touch: wl_touch) -> zwp_input_timestamps_v1:
        """
        Subscribe to high-resolution touch timestamp events

        Creates a new input timestamps object that represents a subscription
        to high-resolution timestamp events for all wl_touch events that
        carry a timestamp.

        If the associated wl_touch object becomes invalid, either through
        client action (e.g. release) or server-side changes, the input
        timestamps object becomes inert and the client should destroy it
        by calling zwp_input_timestamps_v1.destroy.

        Args:
            touch: The `wl_touch` object for which to get timestamp events

        Returns:
            zwp_input_timestamps_v1: The created object
        """

        ...

class zwp_input_timestamps_v1:
    """
    Context object for input timestamps

    Provides high-resolution timestamp events for a set of subscribed input
    events. The set of subscribed input events is determined by the
    zwp_input_timestamps_manager_v1 request used to create this object.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the input timestamps object

        Informs the server that the client will no longer be using this
        protocol object. After the server processes the request, no more
        timestamp events will be emitted.
        """

        ...

    def on_timestamp(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        High-resolution timestamp event.

        Override to handle [`wayland.zwp_input_timestamps_v1.events.timestamp`][].
        """

        ...

    class events(WaylandEvent):
        def timestamp(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            High-resolution timestamp event

            The timestamp event is associated with the first subsequent input event
            carrying a timestamp which belongs to the set of input events this
            object is subscribed to.

            The timestamp provided by this event is a high-resolution version of
            the timestamp argument of the associated input event. The provided
            timestamp is in the same clock domain and is at least as accurate as
            the associated input event timestamp.

            The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples,
            each component being an unsigned 32-bit value. Whole seconds are in
            tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo,
            and the additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999].

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

class zwp_keyboard_shortcuts_inhibit_manager_v1:
    """
    Context object for keyboard `grab_manager`

    A global interface used for inhibiting the compositor keyboard shortcuts.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_inhibited: int
        """The shortcuts are already inhibited for this surface"""



    def destroy(self) -> None:
        """
        Destroy the keyboard shortcuts inhibitor object

        Destroy the keyboard shortcuts inhibitor manager.
        """

        ...

    def inhibit_shortcuts(self, surface: wl_surface, seat: wl_seat) -> zwp_keyboard_shortcuts_inhibitor_v1:
        """
        Create a new keyboard shortcuts inhibitor object

        Create a new keyboard shortcuts inhibitor object associated with
        the given surface for the given seat.

        If shortcuts are already inhibited for the specified seat and surface,
        a protocol error "already_inhibited" is raised by the compositor.

        Args:
            surface: The surface that inhibits the keyboard shortcuts behavior
            seat: The `wl_seat` for which keyboard shortcuts should be disabled

        Returns:
            zwp_keyboard_shortcuts_inhibitor_v1: The created object
        """

        ...

class zwp_keyboard_shortcuts_inhibitor_v1:
    """
    Context object for keyboard shortcuts inhibitor

    A keyboard shortcuts inhibitor instructs the compositor to ignore
    its own keyboard shortcuts when the associated surface has keyboard
    focus. As a result, when the surface has keyboard focus on the given
    seat, it will receive all key events originating from the specified
    seat, even those which would normally be caught by the compositor for
    its own shortcuts.

    The Wayland compositor is however under no obligation to disable
    all of its shortcuts, and may keep some special key combo for its own
    use, including but not limited to one allowing the user to forcibly
    restore normal keyboard events routing in the case of an unwilling
    client. The compositor may also use the same key combo to reactivate
    an existing shortcut inhibitor that was previously deactivated on
    user request.

    When the compositor restores its own keyboard shortcuts, an
    "inactive" event is emitted to notify the client that the keyboard
    shortcuts inhibitor is not effectively active for the surface and
    seat any more, and the client should not expect to receive all
    keyboard events.

    When the keyboard shortcuts inhibitor is inactive, the client has
    no way to forcibly reactivate the keyboard shortcuts inhibitor.

    The user can chose to re-enable a previously deactivated keyboard
    shortcuts inhibitor using any mechanism the compositor may offer,
    in which case the compositor will send an "active" event to notify
    the client.

    If the surface is destroyed, unmapped, or loses the seat's keyboard
    focus, the keyboard shortcuts inhibitor becomes irrelevant and the
    compositor will restore its own keyboard shortcuts but no "inactive"
    event is emitted in this case.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the keyboard shortcuts inhibitor object

        Remove the keyboard shortcuts inhibitor from the associated wl_surface.
        """

        ...

    def on_active(self) -> None:
        """
        Shortcuts are inhibited.

        Override to handle [`wayland.zwp_keyboard_shortcuts_inhibitor_v1.events.active`][].
        """

        ...

    def on_inactive(self) -> None:
        """
        Shortcuts are restored.

        Override to handle [`wayland.zwp_keyboard_shortcuts_inhibitor_v1.events.inactive`][].
        """

        ...

    class events(WaylandEvent):
        def active(self) -> None:
            """
            Shortcuts are inhibited

            This event indicates that the shortcut inhibitor is active.

            The compositor sends this event every time compositor shortcuts
            are inhibited on behalf of the surface. When active, the client
            may receive input events normally reserved by the compositor
            (see zwp_keyboard_shortcuts_inhibitor_v1).

            This occurs typically when the initial request "inhibit_shortcuts"
            first becomes active or when the user instructs the compositor to
            re-enable and existing shortcuts inhibitor using any mechanism
            offered by the compositor.
            """

            ...

        def inactive(self) -> None:
            """
            Shortcuts are restored

            This event indicates that the shortcuts inhibitor is inactive,
            normal shortcuts processing is restored by the compositor.
            """

            ...

class zwp_linux_explicit_synchronization_v1:
    """
    Protocol for providing explicit synchronization

    This global is a factory interface, allowing clients to request
    explicit synchronization for buffers on a per-surface basis.

    See zwp_linux_surface_synchronization_v1 for more information.

    This interface is derived from Chromium's
    zcr_linux_explicit_synchronization_v1.

    Note: this protocol is superseded by linux-drm-syncobj.

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 2

    class error(Enum):
        synchronization_exists: int
        """The surface already has a synchronization object associated"""



    def destroy(self) -> None:
        """
        Destroy explicit synchronization factory object

        Destroy this explicit synchronization factory object. Other objects,
        including zwp_linux_surface_synchronization_v1 objects created by this
        factory, shall not be affected by this request.
        """

        ...

    def get_synchronization(self, surface: wl_surface) -> zwp_linux_surface_synchronization_v1:
        """
        Extend surface interface for explicit synchronization

        Instantiate an interface extension for the given wl_surface to provide
        explicit synchronization.

        If the given wl_surface already has an explicit synchronization object
        associated, the synchronization_exists protocol error is raised.

        Graphics APIs, like EGL or Vulkan, that manage the buffer queue and
        commits of a wl_surface themselves, are likely to be using this
        extension internally. If a client is using such an API for a
        wl_surface, it should not directly use this extension on that surface,
        to avoid raising a synchronization_exists protocol error.

        Args:
            surface: The surface

        Returns:
            zwp_linux_surface_synchronization_v1: The created object
        """

        ...

class zwp_linux_surface_synchronization_v1:
    """
    Per-surface explicit synchronization support

    This object implements per-surface explicit synchronization.

    Synchronization refers to co-ordination of pipelined operations performed
    on buffers. Most GPU clients will schedule an asynchronous operation to
    render to the buffer, then immediately send the buffer to the compositor
    to be attached to a surface.

    In implicit synchronization, ensuring that the rendering operation is
    complete before the compositor displays the buffer is an implementation
    detail handled by either the kernel or userspace graphics driver.

    By contrast, in explicit synchronization, dma_fence objects mark when the
    asynchronous operations are complete. When submitting a buffer, the
    client provides an acquire fence which will be waited on before the
    compositor accesses the buffer. The Wayland server, through a
    zwp_linux_buffer_release_v1 object, will inform the client with an event
    which may be accompanied by a release fence, when the compositor will no
    longer access the buffer contents due to the specific commit that
    requested the release event.

    Each surface can be associated with only one object of this interface at
    any time.

    In version 1 of this interface, explicit synchronization is only
    guaranteed to be supported for buffers created with any version of the
    wp_linux_dmabuf buffer factory. Version 2 additionally guarantees
    explicit synchronization support for opaque EGL buffers, which is a type
    of platform specific buffers described in the EGL_WL_bind_wayland_display
    extension. Compositors are free to support explicit synchronization for
    additional buffer types.
    """
    object_id = 0
    version = 2

    class error(Enum):
        invalid_fence: int
        """The fence specified by the client could not be imported"""

        duplicate_fence: int
        """Multiple fences added for a single surface commit"""

        duplicate_release: int
        """Multiple releases added for a single surface commit"""

        no_surface: int
        """The associated `wl_surface` was destroyed"""

        unsupported_buffer: int
        """The buffer does not support explicit synchronization"""

        no_buffer: int
        """No buffer was attached"""



    def destroy(self) -> None:
        """
        Destroy synchronization object

        Destroy this explicit synchronization object.

        Any fence set by this object with set_acquire_fence since the last
        commit will be discarded by the server. Any fences set by this object
        before the last commit are not affected.

        zwp_linux_buffer_release_v1 objects created by this object are not
        affected by this request.
        """

        ...

    def set_acquire_fence(self, fd: fd) -> None:
        """
        Set the acquire fence

        Set the acquire fence that must be signaled before the compositor
        may sample from the buffer attached with wl_surface.attach. The fence
        is a dma_fence kernel object.

        The acquire fence is double-buffered state, and will be applied on the
        next wl_surface.commit request for the associated surface. Thus, it
        applies only to the buffer that is attached to the surface at commit
        time.

        If the provided fd is not a valid dma_fence fd, then an INVALID_FENCE
        error is raised.

        If a fence has already been attached during the same commit cycle, a
        DUPLICATE_FENCE error is raised.

        If the associated wl_surface was destroyed, a NO_SURFACE error is
        raised.

        If at surface commit time the attached buffer does not support explicit
        synchronization, an UNSUPPORTED_BUFFER error is raised.

        If at surface commit time there is no buffer attached, a NO_BUFFER
        error is raised.

        Args:
            fd: Acquire fence fd
        """

        ...

    def get_release(self) -> zwp_linux_buffer_release_v1:
        """
        Release fence for last-attached buffer

        Create a listener for the release of the buffer attached by the
        client with wl_surface.attach. See zwp_linux_buffer_release_v1
        documentation for more information.

        The release object is double-buffered state, and will be associated
        with the buffer that is attached to the surface at wl_surface.commit
        time.

        If a zwp_linux_buffer_release_v1 object has already been requested for
        the surface in the same commit cycle, a DUPLICATE_RELEASE error is
        raised.

        If the associated wl_surface was destroyed, a NO_SURFACE error
        is raised.

        If at surface commit time there is no buffer attached, a NO_BUFFER
        error is raised.

        Returns:
            zwp_linux_buffer_release_v1: The created object
        """

        ...

class zwp_linux_buffer_release_v1:
    """
    Buffer release explicit synchronization

    This object is instantiated in response to a
    zwp_linux_surface_synchronization_v1.get_release request.

    It provides an alternative to wl_buffer.release events, providing a
    unique release from a single wl_surface.commit request. The release event
    also supports explicit synchronization, providing a fence FD for the
    client to synchronize against.

    Exactly one event, either a fenced_release or an immediate_release, will
    be emitted for the wl_surface.commit request. The compositor can choose
    release by release which event it uses.

    This event does not replace wl_buffer.release events; servers are still
    required to send those events.

    Once a buffer release object has delivered a 'fenced_release' or an
    'immediate_release' event it is automatically destroyed.
    """
    object_id = 0
    version = 1



    def on_fenced_release(self, fence: fd) -> None:
        """
        Release buffer with fence.

        Override to handle [`wayland.zwp_linux_buffer_release_v1.events.fenced_release`][].
        """

        ...

    def on_immediate_release(self) -> None:
        """
        Release buffer immediately.

        Override to handle [`wayland.zwp_linux_buffer_release_v1.events.immediate_release`][].
        """

        ...

    class events(WaylandEvent):
        def fenced_release(self, fence: fd) -> None:
            """
            Release buffer with fence

            Sent when the compositor has finalised its usage of the associated
            buffer for the relevant commit, providing a dma_fence which will be
            signaled when all operations by the compositor on that buffer for that
            commit have finished.

            Once the fence has signaled, and assuming the associated buffer is not
            pending release from other wl_surface.commit requests, no additional
            explicit or implicit synchronization is required to safely reuse or
            destroy the buffer.

            This event destroys the zwp_linux_buffer_release_v1 object.

            Args:
                fence: Fence for last operation on buffer
            """

            ...

        def immediate_release(self) -> None:
            """
            Release buffer immediately

            Sent when the compositor has finalised its usage of the associated
            buffer for the relevant commit, and either performed no operations
            using it, or has a guarantee that all its operations on that buffer for
            that commit have finished.

            Once this event is received, and assuming the associated buffer is not
            pending release from other wl_surface.commit requests, no additional
            explicit or implicit synchronization is required to safely reuse or
            destroy the buffer.

            This event destroys the zwp_linux_buffer_release_v1 object.
            """

            ...

class zwp_pointer_constraints_v1:
    """
    Constrain the movement of a pointer

    The global interface exposing pointer constraining functionality. It
    exposes two requests: lock_pointer for locking the pointer to its
    position, and confine_pointer for locking the pointer to a region.

    The lock_pointer and confine_pointer requests create the objects
    wp_locked_pointer and wp_confined_pointer respectively, and the client can
    use these objects to interact with the lock.

    For any surface, only one lock or confinement may be active across all
    wl_pointer objects of the same seat. If a lock or confinement is requested
    when another lock or confinement is active or requested on the same surface
    and with any of the wl_pointer objects of the same seat, an
    'already_constrained' error will be raised.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        `wp_pointer_constraints` error values

        These errors can be emitted in response to wp_pointer_constraints
        requests.
        """

        already_constrained: int
        """Pointer constraint already requested on that surface"""



    class lifetime(Enum):
        """
        Constraint lifetime

        These values represent different lifetime semantics. They are passed
        as arguments to the factory requests to specify how the constraint
        lifetimes should be managed.
        """

        oneshot: int
        """
        The pointer constraint is defunct once deactivated
        A oneshot pointer constraint will never reactivate once it has been
        deactivated. See the corresponding deactivation event
        (wp_locked_pointer.unlocked and wp_confined_pointer.unconfined) for
        details.
        """

        persistent: int
        """
        The pointer constraint may reactivate
        A persistent pointer constraint may again reactivate once it has
        been deactivated. See the corresponding deactivation event
        (wp_locked_pointer.unlocked and wp_confined_pointer.unconfined) for
        details.
        """



    def destroy(self) -> None:
        """
        Destroy the pointer constraints manager object

        Used by the client to notify the server that it will no longer use this
        pointer constraints object.
        """

        ...

    def lock_pointer(self, surface: wl_surface, pointer: wl_pointer, region: wl_region, lifetime: zwp_pointer_constraints_v1.lifetime) -> zwp_locked_pointer_v1:
        """
        Lock pointer to a position

        The lock_pointer request lets the client request to disable movements of
        the virtual pointer (i.e. the cursor), effectively locking the pointer
        to a position. This request may not take effect immediately; in the
        future, when the compositor deems implementation-specific constraints
        are satisfied, the pointer lock will be activated and the compositor
        sends a locked event.

        The protocol provides no guarantee that the constraints are ever
        satisfied, and does not require the compositor to send an error if the
        constraints cannot ever be satisfied. It is thus possible to request a
        lock that will never activate.

        There may not be another pointer constraint of any kind requested or
        active on the surface for any of the wl_pointer objects of the seat of
        the passed pointer when requesting a lock. If there is, an error will be
        raised. See general pointer lock documentation for more details.

        The intersection of the region passed with this request and the input
        region of the surface is used to determine where the pointer must be
        in order for the lock to activate. It is up to the compositor whether to
        warp the pointer or require some kind of user interaction for the lock
        to activate. If the region is null the surface input region is used.

        A surface may receive pointer focus without the lock being activated.

        The request creates a new object wp_locked_pointer which is used to
        interact with the lock as well as receive updates about its state. See
        the the description of wp_locked_pointer for further information.

        Note that while a pointer is locked, the wl_pointer objects of the
        corresponding seat will not emit any wl_pointer.motion events, but
        relative motion events will still be emitted via wp_relative_pointer
        objects of the same seat. wl_pointer.axis and wl_pointer.button events
        are unaffected.

        Args:
            surface: Surface to lock pointer to
            pointer: The pointer that should be locked
            region: Region of surface
            lifetime: Lock lifetime

        Returns:
            zwp_locked_pointer_v1: The created object
        """

        ...

    def confine_pointer(self, surface: wl_surface, pointer: wl_pointer, region: wl_region, lifetime: zwp_pointer_constraints_v1.lifetime) -> zwp_confined_pointer_v1:
        """
        Confine pointer to a region

        The confine_pointer request lets the client request to confine the
        pointer cursor to a given region. This request may not take effect
        immediately; in the future, when the compositor deems implementation-
        specific constraints are satisfied, the pointer confinement will be
        activated and the compositor sends a confined event.

        The intersection of the region passed with this request and the input
        region of the surface is used to determine where the pointer must be
        in order for the confinement to activate. It is up to the compositor
        whether to warp the pointer or require some kind of user interaction for
        the confinement to activate. If the region is null the surface input
        region is used.

        The request will create a new object wp_confined_pointer which is used
        to interact with the confinement as well as receive updates about its
        state. See the the description of wp_confined_pointer for further
        information.

        Args:
            surface: Surface to lock pointer to
            pointer: The pointer that should be confined
            region: Region of surface
            lifetime: Confinement lifetime

        Returns:
            zwp_confined_pointer_v1: The created object
        """

        ...

class zwp_locked_pointer_v1:
    """
    Receive relative pointer motion events

    The wp_locked_pointer interface represents a locked pointer state.

    While the lock of this object is active, the wl_pointer objects of the
    associated seat will not emit any wl_pointer.motion events.

    This object will send the event 'locked' when the lock is activated.
    Whenever the lock is activated, it is guaranteed that the locked surface
    will already have received pointer focus and that the pointer will be
    within the region passed to the request creating this object.

    To unlock the pointer, send the destroy request. This will also destroy
    the wp_locked_pointer object.

    If the compositor decides to unlock the pointer the unlocked event is
    sent. See wp_locked_pointer.unlock for details.

    When unlocking, the compositor may warp the cursor position to the set
    cursor position hint. If it does, it will not result in any relative
    motion events emitted via wp_relative_pointer.

    If the surface the lock was requested on is destroyed and the lock is not
    yet activated, the wp_locked_pointer object is now defunct and must be
    destroyed.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the locked pointer object

        Destroy the locked pointer object. If applicable, the compositor will
        unlock the pointer.
        """

        ...

    def set_cursor_position_hint(self, surface_x: float, surface_y: float) -> None:
        """
        Set the pointer cursor position hint

        Set the cursor position hint relative to the top left corner of the
        surface.

        If the client is drawing its own cursor, it should update the position
        hint to the position of its own cursor. A compositor may use this
        information to warp the pointer upon unlock in order to avoid pointer
        jumps.

        The cursor position hint is double-buffered state, see
        wl_surface.commit.

        Args:
            surface_x: Surface-local x coordinate
            surface_y: Surface-local y coordinate
        """

        ...

    def set_region(self, region: wl_region) -> None:
        """
        Set a new lock region

        Set a new region used to lock the pointer.

        The new lock region is double-buffered, see wl_surface.commit.

        For details about the lock region, see wp_locked_pointer.

        Args:
            region: Region of surface
        """

        ...

    def on_locked(self) -> None:
        """
        Lock activation event.

        Override to handle [`wayland.zwp_locked_pointer_v1.events.locked`][].
        """

        ...

    def on_unlocked(self) -> None:
        """
        Lock deactivation event.

        Override to handle [`wayland.zwp_locked_pointer_v1.events.unlocked`][].
        """

        ...

    class events(WaylandEvent):
        def locked(self) -> None:
            """
            Lock activation event

            Notification that the pointer lock of the seat's pointer is activated.
            """

            ...

        def unlocked(self) -> None:
            """
            Lock deactivation event

            Notification that the pointer lock of the seat's pointer is no longer
            active. If this is a oneshot pointer lock (see
            wp_pointer_constraints.lifetime) this object is now defunct and should
            be destroyed. If this is a persistent pointer lock (see
            wp_pointer_constraints.lifetime) this pointer lock may again
            reactivate in the future.
            """

            ...

class zwp_confined_pointer_v1:
    """
    Confined pointer object

    The wp_confined_pointer interface represents a confined pointer state.

    This object will send the event 'confined' when the confinement is
    activated. Whenever the confinement is activated, it is guaranteed that
    the surface the pointer is confined to will already have received pointer
    focus and that the pointer will be within the region passed to the request
    creating this object. It is up to the compositor to decide whether this
    requires some user interaction and if the pointer will warp to within the
    passed region if outside.

    To unconfine the pointer, send the destroy request. This will also destroy
    the wp_confined_pointer object.

    If the compositor decides to unconfine the pointer the unconfined event is
    sent. The wp_confined_pointer object is at this point defunct and should
    be destroyed.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the confined pointer object

        Destroy the confined pointer object. If applicable, the compositor will
        unconfine the pointer.
        """

        ...

    def set_region(self, region: wl_region) -> None:
        """
        Set a new confine region

        Set a new region used to confine the pointer.

        The new confine region is double-buffered, see wl_surface.commit.

        If the confinement is active when the new confinement region is applied
        and the pointer ends up outside of newly applied region, the pointer may
        warped to a position within the new confinement region. If warped, a
        wl_pointer.motion event will be emitted, but no
        wp_relative_pointer.relative_motion event.

        The compositor may also, instead of using the new region, unconfine the
        pointer.

        For details about the confine region, see wp_confined_pointer.

        Args:
            region: Region of surface
        """

        ...

    def on_confined(self) -> None:
        """
        Pointer confined.

        Override to handle [`wayland.zwp_confined_pointer_v1.events.confined`][].
        """

        ...

    def on_unconfined(self) -> None:
        """
        Pointer unconfined.

        Override to handle [`wayland.zwp_confined_pointer_v1.events.unconfined`][].
        """

        ...

    class events(WaylandEvent):
        def confined(self) -> None:
            """
            Pointer confined

            Notification that the pointer confinement of the seat's pointer is
            activated.
            """

            ...

        def unconfined(self) -> None:
            """
            Pointer unconfined

            Notification that the pointer confinement of the seat's pointer is no
            longer active. If this is a oneshot pointer confinement (see
            wp_pointer_constraints.lifetime) this object is now defunct and should
            be destroyed. If this is a persistent pointer confinement (see
            wp_pointer_constraints.lifetime) this pointer confinement may again
            reactivate in the future.
            """

            ...

class zwp_pointer_gestures_v1:
    """
    Touchpad gestures

    A global interface to provide semantic touchpad gestures for a given
    pointer.

    Three gestures are currently supported: swipe, pinch, and hold.
    Pinch and swipe gestures follow a three-stage cycle: begin, update,
    end. Hold gestures follow a two-stage cycle: begin and end. All
    gestures are identified by a unique id.

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 3


    def get_swipe_gesture(self, pointer: wl_pointer) -> zwp_pointer_gesture_swipe_v1:
        """
        Get swipe gesture

        Create a swipe gesture object. See the
        wl_pointer_gesture_swipe interface for details.

        Returns:
            zwp_pointer_gesture_swipe_v1: The created object
        """

        ...

    def get_pinch_gesture(self, pointer: wl_pointer) -> zwp_pointer_gesture_pinch_v1:
        """
        Get pinch gesture

        Create a pinch gesture object. See the
        wl_pointer_gesture_pinch interface for details.

        Returns:
            zwp_pointer_gesture_pinch_v1: The created object
        """

        ...

    def release(self) -> None:
        """
        Destroy the pointer gesture object

        Destroy the pointer gesture object. Swipe, pinch and hold objects
        created via this gesture object remain valid.
        """

        ...

    def get_hold_gesture(self, pointer: wl_pointer) -> zwp_pointer_gesture_hold_v1:
        """
        Get hold gesture

        Create a hold gesture object. See the
        wl_pointer_gesture_hold interface for details.

        Returns:
            zwp_pointer_gesture_hold_v1: The created object
        """

        ...

class zwp_pointer_gesture_swipe_v1:
    """
    A swipe gesture object

    A swipe gesture object notifies a client about a multi-finger swipe
    gesture detected on an indirect input device such as a touchpad.
    The gesture is usually initiated by multiple fingers moving in the
    same direction but once initiated the direction may change.
    The precise conditions of when such a gesture is detected are
    implementation-dependent.

    A gesture consists of three stages: begin, update (optional) and end.
    There cannot be multiple simultaneous hold, pinch or swipe gestures on a
    same pointer/seat, how compositors prevent these situations is
    implementation-dependent.

    A gesture may be cancelled by the compositor or the hardware.
    Clients should not consider performing permanent or irreversible
    actions until the end of a gesture has been received.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """Destroy the pointer swipe gesture object"""

        ...

    def on_begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
        """
        Multi-finger swipe begin.

        Override to handle [`wayland.zwp_pointer_gesture_swipe_v1.events.begin`][].
        """

        ...

    def on_update(self, time: int, dx: float, dy: float) -> None:
        """
        Multi-finger swipe motion.

        Override to handle [`wayland.zwp_pointer_gesture_swipe_v1.events.update`][].
        """

        ...

    def on_end(self, serial: int, time: int, cancelled: int) -> None:
        """
        Multi-finger swipe end.

        Override to handle [`wayland.zwp_pointer_gesture_swipe_v1.events.end`][].
        """

        ...

    class events(WaylandEvent):
        def begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
            """
            Multi-finger swipe begin

            This event is sent when a multi-finger swipe gesture is detected
            on the device.

            Args:
                time: Timestamp with millisecond granularity
                fingers: Number of fingers
            """

            ...

        def update(self, time: int, dx: float, dy: float) -> None:
            """
            Multi-finger swipe motion

            This event is sent when a multi-finger swipe gesture changes the
            position of the logical center.

            The dx and dy coordinates are relative coordinates of the logical
            center of the gesture compared to the previous event.

            Args:
                time: Timestamp with millisecond granularity
                dx: Delta x coordinate in surface coordinate space
                dy: Delta y coordinate in surface coordinate space
            """

            ...

        def end(self, serial: int, time: int, cancelled: int) -> None:
            """
            Multi-finger swipe end

            This event is sent when a multi-finger swipe gesture ceases to
            be valid. This may happen when one or more fingers are lifted or
            the gesture is cancelled.

            When a gesture is cancelled, the client should undo state changes
            caused by this gesture. What causes a gesture to be cancelled is
            implementation-dependent.

            Args:
                time: Timestamp with millisecond granularity
                cancelled: 1 if the gesture was cancelled, 0 otherwise
            """

            ...

class zwp_pointer_gesture_pinch_v1:
    """
    A pinch gesture object

    A pinch gesture object notifies a client about a multi-finger pinch
    gesture detected on an indirect input device such as a touchpad.
    The gesture is usually initiated by multiple fingers moving towards
    each other or away from each other, or by two or more fingers rotating
    around a logical center of gravity. The precise conditions of when
    such a gesture is detected are implementation-dependent.

    A gesture consists of three stages: begin, update (optional) and end.
    There cannot be multiple simultaneous hold, pinch or swipe gestures on a
    same pointer/seat, how compositors prevent these situations is
    implementation-dependent.

    A gesture may be cancelled by the compositor or the hardware.
    Clients should not consider performing permanent or irreversible
    actions until the end of a gesture has been received.
    """
    object_id = 0
    version = 2


    def destroy(self) -> None:
        """Destroy the pinch gesture object"""

        ...

    def on_begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
        """
        Multi-finger pinch begin.

        Override to handle [`wayland.zwp_pointer_gesture_pinch_v1.events.begin`][].
        """

        ...

    def on_update(self, time: int, dx: float, dy: float, scale: float, rotation: float) -> None:
        """
        Multi-finger pinch motion.

        Override to handle [`wayland.zwp_pointer_gesture_pinch_v1.events.update`][].
        """

        ...

    def on_end(self, serial: int, time: int, cancelled: int) -> None:
        """
        Multi-finger pinch end.

        Override to handle [`wayland.zwp_pointer_gesture_pinch_v1.events.end`][].
        """

        ...

    class events(WaylandEvent):
        def begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
            """
            Multi-finger pinch begin

            This event is sent when a multi-finger pinch gesture is detected
            on the device.

            Args:
                time: Timestamp with millisecond granularity
                fingers: Number of fingers
            """

            ...

        def update(self, time: int, dx: float, dy: float, scale: float, rotation: float) -> None:
            """
            Multi-finger pinch motion

            This event is sent when a multi-finger pinch gesture changes the
            position of the logical center, the rotation or the relative scale.

            The dx and dy coordinates are relative coordinates in the
            surface coordinate space of the logical center of the gesture.

            The scale factor is an absolute scale compared to the
            pointer_gesture_pinch.begin event, e.g. a scale of 2 means the fingers
            are now twice as far apart as on pointer_gesture_pinch.begin.

            The rotation is the relative angle in degrees clockwise compared to the previous
            pointer_gesture_pinch.begin or pointer_gesture_pinch.update event.

            Args:
                time: Timestamp with millisecond granularity
                dx: Delta x coordinate in surface coordinate space
                dy: Delta y coordinate in surface coordinate space
                scale: Scale relative to the initial finger position
                rotation: Angle in degrees cw relative to the previous event
            """

            ...

        def end(self, serial: int, time: int, cancelled: int) -> None:
            """
            Multi-finger pinch end

            This event is sent when a multi-finger pinch gesture ceases to
            be valid. This may happen when one or more fingers are lifted or
            the gesture is cancelled.

            When a gesture is cancelled, the client should undo state changes
            caused by this gesture. What causes a gesture to be cancelled is
            implementation-dependent.

            Args:
                time: Timestamp with millisecond granularity
                cancelled: 1 if the gesture was cancelled, 0 otherwise
            """

            ...

class zwp_pointer_gesture_hold_v1:
    """
    A hold gesture object

    A hold gesture object notifies a client about a single- or
    multi-finger hold gesture detected on an indirect input device such as
    a touchpad. The gesture is usually initiated by one or more fingers
    being held down without significant movement. The precise conditions
    of when such a gesture is detected are implementation-dependent.

    In particular, this gesture may be used to cancel kinetic scrolling.

    A hold gesture consists of two stages: begin and end. Unlike pinch and
    swipe there is no update stage.
    There cannot be multiple simultaneous hold, pinch or swipe gestures on a
    same pointer/seat, how compositors prevent these situations is
    implementation-dependent.

    A gesture may be cancelled by the compositor or the hardware.
    Clients should not consider performing permanent or irreversible
    actions until the end of a gesture has been received.
    """
    object_id = 0
    version = 3


    def destroy(self) -> None:
        """Destroy the hold gesture object"""

        ...

    def on_begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
        """
        Multi-finger hold begin.

        Override to handle [`wayland.zwp_pointer_gesture_hold_v1.events.begin`][].
        """

        ...

    def on_end(self, serial: int, time: int, cancelled: int) -> None:
        """
        Multi-finger hold end.

        Override to handle [`wayland.zwp_pointer_gesture_hold_v1.events.end`][].
        """

        ...

    class events(WaylandEvent):
        def begin(self, serial: int, time: int, surface: wl_surface, fingers: int) -> None:
            """
            Multi-finger hold begin

            This event is sent when a hold gesture is detected on the device.

            Args:
                time: Timestamp with millisecond granularity
                fingers: Number of fingers
            """

            ...

        def end(self, serial: int, time: int, cancelled: int) -> None:
            """
            Multi-finger hold end

            This event is sent when a hold gesture ceases to
            be valid. This may happen when the holding fingers are lifted or
            the gesture is cancelled, for example if the fingers move past an
            implementation-defined threshold, the finger count changes or the hold
            gesture changes into a different type of gesture.

            When a gesture is cancelled, the client may need to undo state changes
            caused by this gesture. What causes a gesture to be cancelled is
            implementation-dependent.

            Args:
                time: Timestamp with millisecond granularity
                cancelled: 1 if the gesture was cancelled, 0 otherwise
            """

            ...

class zwp_primary_selection_device_manager_v1:
    """
    X primary selection emulation

    The primary selection device manager is a singleton global object that
    provides access to the primary selection. It allows to create
    wp_primary_selection_source objects, as well as retrieving the per-seat
    wp_primary_selection_device objects.
    """
    object_id = 0
    version = 1


    def create_source(self) -> zwp_primary_selection_source_v1:
        """
        Create a new primary selection source

        Create a new primary selection source.

        Returns:
            zwp_primary_selection_source_v1: The created object
        """

        ...

    def get_device(self, seat: wl_seat) -> zwp_primary_selection_device_v1:
        """
        Create a new primary selection device

        Create a new data device for a given seat.

        Returns:
            zwp_primary_selection_device_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the primary selection device manager

        Destroy the primary selection device manager.
        """

        ...

class zwp_primary_selection_device_v1:
    """"""
    object_id = 0
    version = 1


    def set_selection(self, source: zwp_primary_selection_source_v1, serial: int) -> None:
        """
        Set the primary selection

        Replaces the current selection. The previous owner of the primary
        selection will receive a wp_primary_selection_source.cancelled event.

        To unset the selection, set the source to NULL.

        Args:
            serial: Serial of the event that triggered this request
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the primary selection device

        Destroy the primary selection device.
        """

        ...

    def on_data_offer(self, offer: zwp_primary_selection_offer_v1) -> None:
        """
        Introduce a new `wp_primary_selection_offer`.

        Override to handle [`wayland.zwp_primary_selection_device_v1.events.data_offer`][].
        """

        ...

    def on_selection(self, id: zwp_primary_selection_offer_v1) -> None:
        """
        Advertise a new primary selection.

        Override to handle [`wayland.zwp_primary_selection_device_v1.events.selection`][].
        """

        ...

    class events(WaylandEvent):
        def data_offer(self, offer: zwp_primary_selection_offer_v1) -> None:
            """
            Introduce a new `wp_primary_selection_offer`

            Introduces a new wp_primary_selection_offer object that may be used
            to receive the current primary selection. Immediately following this
            event, the new wp_primary_selection_offer object will send
            wp_primary_selection_offer.offer events to describe the offered mime
            types.
            """

            ...

        def selection(self, id: zwp_primary_selection_offer_v1) -> None:
            """
            Advertise a new primary selection

            The wp_primary_selection_device.selection event is sent to notify the
            client of a new primary selection. This event is sent after the
            wp_primary_selection.data_offer event introducing this object, and after
            the offer has announced its mimetypes through
            wp_primary_selection_offer.offer.

            The data_offer is valid until a new offer or NULL is received
            or until the client loses keyboard focus. The client must destroy the
            previous selection data_offer, if any, upon receiving this event.
            """

            ...

class zwp_primary_selection_offer_v1:
    """
    Offer to transfer primary selection contents

    A wp_primary_selection_offer represents an offer to transfer the contents
    of the primary selection clipboard to the client. Similar to
    wl_data_offer, the offer also describes the mime types that the data can
    be converted to and provides the mechanisms for transferring the data
    directly to the client.
    """
    object_id = 0
    version = 1


    def receive(self, mime_type: str, fd: fd) -> None:
        """
        Request that the data is transferred

        To transfer the contents of the primary selection clipboard, the client
        issues this request and indicates the mime type that it wants to
        receive. The transfer happens through the passed file descriptor
        (typically created with the pipe system call). The source client writes
        the data in the mime type representation requested and then closes the
        file descriptor.

        The receiving client reads from the read end of the pipe until EOF and
        closes its end, at which point the transfer is complete.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the primary selection offer

        Destroy the primary selection offer.
        """

        ...

    def on_offer(self, mime_type: str) -> None:
        """
        Advertise offered mime type.

        Override to handle [`wayland.zwp_primary_selection_offer_v1.events.offer`][].
        """

        ...

    class events(WaylandEvent):
        def offer(self, mime_type: str) -> None:
            """
            Advertise offered mime type

            Sent immediately after creating announcing the
            wp_primary_selection_offer through
            wp_primary_selection_device.data_offer. One event is sent per offered
            mime type.
            """

            ...

class zwp_primary_selection_source_v1:
    """
    Offer to replace the contents of the primary selection

    The source side of a wp_primary_selection_offer, it provides a way to
    describe the offered data and respond to requests to transfer the
    requested contents of the primary selection clipboard.
    """
    object_id = 0
    version = 1


    def offer(self, mime_type: str) -> None:
        """
        Add an offered mime type

        This request adds a mime type to the set of mime types advertised to
        targets. Can be called several times to offer multiple types.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the primary selection source

        Destroy the primary selection source.
        """

        ...

    def on_send(self, mime_type: str, fd: fd) -> None:
        """
        Send the primary selection contents.

        Override to handle [`wayland.zwp_primary_selection_source_v1.events.send`][].
        """

        ...

    def on_cancelled(self) -> None:
        """
        Request for primary selection contents was canceled.

        Override to handle [`wayland.zwp_primary_selection_source_v1.events.cancelled`][].
        """

        ...

    class events(WaylandEvent):
        def send(self, mime_type: str, fd: fd) -> None:
            """
            Send the primary selection contents

            Request for the current primary selection contents from the client.
            Send the specified mime type over the passed file descriptor, then
            close it.
            """

            ...

        def cancelled(self) -> None:
            """
            Request for primary selection contents was canceled

            This primary selection source is no longer valid. The client should
            clean up and destroy this primary selection source.
            """

            ...

class zwp_relative_pointer_manager_v1:
    """
    Get relative pointer objects

    A global interface used for getting the relative pointer object for a
    given pointer.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the relative pointer manager object

        Used by the client to notify the server that it will no longer use this
        relative pointer manager object.
        """

        ...

    def get_relative_pointer(self, pointer: wl_pointer) -> zwp_relative_pointer_v1:
        """
        Get a relative pointer object

        Create a relative pointer interface given a wl_pointer object. See the
        wp_relative_pointer interface for more details.

        Returns:
            zwp_relative_pointer_v1: The created object
        """

        ...

class zwp_relative_pointer_v1:
    """
    Relative pointer object

    A wp_relative_pointer object is an extension to the wl_pointer interface
    used for emitting relative pointer events. It shares the same focus as
    wl_pointer objects of the same seat and will only emit events when it has
    focus.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """Release the relative pointer object"""

        ...

    def on_relative_motion(self, utime_hi: int, utime_lo: int, dx: float, dy: float, dx_unaccel: float, dy_unaccel: float) -> None:
        """
        Relative pointer motion.

        Override to handle [`wayland.zwp_relative_pointer_v1.events.relative_motion`][].
        """

        ...

    class events(WaylandEvent):
        def relative_motion(self, utime_hi: int, utime_lo: int, dx: float, dy: float, dx_unaccel: float, dy_unaccel: float) -> None:
            """
            Relative pointer motion

            Relative x/y pointer motion from the pointer of the seat associated with
            this object.

            A relative motion is in the same dimension as regular wl_pointer motion
            events, except they do not represent an absolute position. For example,
            moving a pointer from (x, y) to (x', y') would have the equivalent
            relative motion (x' - x, y' - y). If a pointer motion caused the
            absolute pointer position to be clipped by for example the edge of the
            monitor, the relative motion is unaffected by the clipping and will
            represent the unclipped motion.

            This event also contains non-accelerated motion deltas. The
            non-accelerated delta is, when applicable, the regular pointer motion
            delta as it was before having applied motion acceleration and other
            transformations such as normalization.

            Note that the non-accelerated delta does not represent 'raw' events as
            they were read from some device. Pointer motion acceleration is device-
            and configuration-specific and non-accelerated deltas and accelerated
            deltas may have the same value on some devices.

            Relative motions are not coupled to wl_pointer.motion events, and can be
            sent in combination with such events, but also independently. There may
            also be scenarios where wl_pointer.motion is sent, but there is no
            relative motion. The order of an absolute and relative motion event
            originating from the same physical motion is not guaranteed.

            If the client needs button events or focus state, it can receive them
            from a wl_pointer object of the same seat that the wp_relative_pointer
            object is associated with.

            Args:
                utime_hi: High 32 bits of a 64 bit timestamp with microsecond granularity
                utime_lo: Low 32 bits of a 64 bit timestamp with microsecond granularity
                dx: The x component of the motion vector
                dy: The y component of the motion vector
                dx_unaccel: The x component of the unaccelerated motion vector
                dy_unaccel: The y component of the unaccelerated motion vector
            """

            ...

class zwp_tablet_manager_v1:
    """
    Controller object for graphic tablet devices

    An object that provides access to the graphics tablets available on this
    system. All tablets are associated with a seat, to get access to the
    actual tablets, use wp_tablet_manager.get_tablet_seat.
    """
    object_id = 0
    version = 1


    def get_tablet_seat(self, seat: wl_seat) -> zwp_tablet_seat_v1:
        """
        Get the tablet seat

        Get the wp_tablet_seat object for the given seat. This object
        provides access to all graphics tablets in this seat.

        Args:
            seat: The `wl_seat` object to retrieve the tablets for

        Returns:
            zwp_tablet_seat_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Release the memory for the tablet manager object

        Destroy the wp_tablet_manager object. Objects created from this
        object are unaffected and should be destroyed separately.
        """

        ...

class zwp_tablet_seat_v1:
    """
    Controller object for graphic tablet devices of a seat

    An object that provides access to the graphics tablets available on this
    seat. After binding to this interface, the compositor sends a set of
    wp_tablet_seat.tablet_added and wp_tablet_seat.tool_added events.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Release the memory for the tablet seat object

        Destroy the wp_tablet_seat object. Objects created from this
        object are unaffected and should be destroyed separately.
        """

        ...

    def on_tablet_added(self, id: zwp_tablet_v1) -> None:
        """
        New device notification.

        Override to handle [`wayland.zwp_tablet_seat_v1.events.tablet_added`][].
        """

        ...

    def on_tool_added(self, id: zwp_tablet_tool_v1) -> None:
        """
        A new tool has been used with a tablet.

        Override to handle [`wayland.zwp_tablet_seat_v1.events.tool_added`][].
        """

        ...

    class events(WaylandEvent):
        def tablet_added(self, id: zwp_tablet_v1) -> None:
            """
            New device notification

            This event is sent whenever a new tablet becomes available on this
            seat. This event only provides the object id of the tablet, any
            static information about the tablet (device name, vid/pid, etc.) is
            sent through the wp_tablet interface.

            Args:
                id: The newly added graphics tablet
            """

            ...

        def tool_added(self, id: zwp_tablet_tool_v1) -> None:
            """
            A new tool has been used with a tablet

            This event is sent whenever a tool that has not previously been used
            with a tablet comes into use. This event only provides the object id
            of the tool; any static information about the tool (capabilities,
            type, etc.) is sent through the wp_tablet_tool interface.

            Args:
                id: The newly added tablet tool
            """

            ...

class zwp_tablet_tool_v1:
    """
    A physical tablet tool

    An object that represents a physical tool that has been, or is
    currently in use with a tablet in this seat. Each wp_tablet_tool
    object stays valid until the client destroys it; the compositor
    reuses the wp_tablet_tool object to indicate that the object's
    respective physical tool has come into proximity of a tablet again.

    A wp_tablet_tool object's relation to a physical tool depends on the
    tablet's ability to report serial numbers. If the tablet supports
    this capability, then the object represents a specific physical tool
    and can be identified even when used on multiple tablets.

    A tablet tool has a number of static characteristics, e.g. tool type,
    hardware_serial and capabilities. These capabilities are sent in an
    event sequence after the wp_tablet_seat.tool_added event before any
    actual events from this tool. This initial event sequence is
    terminated by a wp_tablet_tool.done event.

    Tablet tool events are grouped by wp_tablet_tool.frame events.
    Any events received before a wp_tablet_tool.frame event should be
    considered part of the same hardware state change.
    """
    object_id = 0
    version = 1

    class type(Enum):
        """
        A physical tool type

        Describes the physical type of a tool. The physical type of a tool
        generally defines its base usage.

        The mouse tool represents a mouse-shaped tool that is not a relative
        device but bound to the tablet's surface, providing absolute
        coordinates.

        The lens tool is a mouse-shaped tool with an attached lens to
        provide precision focus.
        """

        pen: int
        """Pen"""

        eraser: int
        """Eraser"""

        brush: int
        """Brush"""

        pencil: int
        """Pencil"""

        airbrush: int
        """Airbrush"""

        finger: int
        """Finger"""

        mouse: int
        """Mouse"""

        lens: int
        """Lens"""



    class capability(Enum):
        """
        Capability flags for a tool

        Describes extra capabilities on a tablet.

        Any tool must provide x and y values, extra axes are
        device-specific.
        """

        tilt: int
        """Tilt axes"""

        pressure: int
        """Pressure axis"""

        distance: int
        """Distance axis"""

        rotation: int
        """Z-rotation axis"""

        slider: int
        """Slider axis"""

        wheel: int
        """Wheel axis"""



    class button_state(Enum):
        """
        Physical button state

        Describes the physical state of a button that produced the button event.
        """

        released: int
        """Button is not pressed"""

        pressed: int
        """Button is pressed"""



    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""



    def set_cursor(self, serial: int, surface: wl_surface, hotspot_x: int, hotspot_y: int) -> None:
        """
        Set the tablet tool's surface

        Sets the surface of the cursor used for this tool on the given
        tablet. This request only takes effect if the tool is in proximity
        of one of the requesting client's surfaces or the surface parameter
        is the current pointer surface. If there was a previous surface set
        with this request it is replaced. If surface is NULL, the cursor
        image is hidden.

        The parameters hotspot_x and hotspot_y define the position of the
        pointer surface relative to the pointer location. Its top-left corner
        is always at (x, y) - (hotspot_x, hotspot_y), where (x, y) are the
        coordinates of the pointer location, in surface-local coordinates.

        On surface.attach requests to the pointer surface, hotspot_x and
        hotspot_y are decremented by the x and y parameters passed to the
        request. Attach must be confirmed by wl_surface.commit as usual.

        The hotspot can also be updated by passing the currently set pointer
        surface to this request with new values for hotspot_x and hotspot_y.

        The current and pending input regions of the wl_surface are cleared,
        and wl_surface.set_input_region is ignored until the wl_surface is no
        longer used as the cursor. When the use as a cursor ends, the current
        and pending input regions become undefined, and the wl_surface is
        unmapped.

        This request gives the surface the role of a cursor. The role
        assigned by this request is the same as assigned by
        wl_pointer.set_cursor meaning the same surface can be
        used both as a wl_pointer cursor and a wp_tablet cursor. If the
        surface already has another role, it raises a protocol error.
        The surface may be used on multiple tablets and across multiple
        seats.

        Args:
            serial: Serial of the enter event
            hotspot_x: Surface-local x coordinate
            hotspot_y: Surface-local y coordinate
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the tool object

        This destroys the client's resource for this tool object.
        """

        ...

    def on_type(self, tool_type: zwp_tablet_tool_v1.type) -> None:
        """
        Tool type.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.type`][].
        """

        ...

    def on_hardware_serial(self, hardware_serial_hi: int, hardware_serial_lo: int) -> None:
        """
        Unique hardware serial number of the tool.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.hardware_serial`][].
        """

        ...

    def on_hardware_id_wacom(self, hardware_id_hi: int, hardware_id_lo: int) -> None:
        """
        Hardware id notification in wacom's format.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.hardware_id_wacom`][].
        """

        ...

    def on_capability(self, capability: zwp_tablet_tool_v1.capability) -> None:
        """
        Tool capability notification.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.capability`][].
        """

        ...

    def on_done(self) -> None:
        """
        Tool description events sequence complete.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.done`][].
        """

        ...

    def on_removed(self) -> None:
        """
        Tool removed.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.removed`][].
        """

        ...

    def on_proximity_in(self, serial: int, tablet: zwp_tablet_v1, surface: wl_surface) -> None:
        """
        Proximity in event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.proximity_in`][].
        """

        ...

    def on_proximity_out(self) -> None:
        """
        Proximity out event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.proximity_out`][].
        """

        ...

    def on_down(self, serial: int) -> None:
        """
        Tablet tool is making contact.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.down`][].
        """

        ...

    def on_up(self) -> None:
        """
        Tablet tool is no longer making contact.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.up`][].
        """

        ...

    def on_motion(self, x: float, y: float) -> None:
        """
        Motion event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.motion`][].
        """

        ...

    def on_pressure(self, pressure: int) -> None:
        """
        Pressure change event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.pressure`][].
        """

        ...

    def on_distance(self, distance: int) -> None:
        """
        Distance change event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.distance`][].
        """

        ...

    def on_tilt(self, tilt_x: int, tilt_y: int) -> None:
        """
        Tilt change event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.tilt`][].
        """

        ...

    def on_rotation(self, degrees: int) -> None:
        """
        Z-rotation change event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.rotation`][].
        """

        ...

    def on_slider(self, position: int) -> None:
        """
        Slider position change event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.slider`][].
        """

        ...

    def on_wheel(self, degrees: int, clicks: int) -> None:
        """
        Wheel delta event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.wheel`][].
        """

        ...

    def on_button(self, serial: int, button: int, state: zwp_tablet_tool_v1.button_state) -> None:
        """
        Button event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.button`][].
        """

        ...

    def on_frame(self, time: int) -> None:
        """
        Frame event.

        Override to handle [`wayland.zwp_tablet_tool_v1.events.frame`][].
        """

        ...

    class events(WaylandEvent):
        def type(self, tool_type: zwp_tablet_tool_v1.type) -> None:
            """
            Tool type

            The tool type is the high-level type of the tool and usually decides
            the interaction expected from this tool.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                tool_type: The physical tool type
            """

            ...

        def hardware_serial(self, hardware_serial_hi: int, hardware_serial_lo: int) -> None:
            """
            Unique hardware serial number of the tool

            If the physical tool can be identified by a unique 64-bit serial
            number, this event notifies the client of this serial number.

            If multiple tablets are available in the same seat and the tool is
            uniquely identifiable by the serial number, that tool may move
            between tablets.

            Otherwise, if the tool has no serial number and this event is
            missing, the tool is tied to the tablet it first comes into
            proximity with. Even if the physical tool is used on multiple
            tablets, separate wp_tablet_tool objects will be created, one per
            tablet.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                hardware_serial_hi: The unique serial number of the tool, most significant bits
                hardware_serial_lo: The unique serial number of the tool, least significant bits
            """

            ...

        def hardware_id_wacom(self, hardware_id_hi: int, hardware_id_lo: int) -> None:
            """
            Hardware id notification in wacom's format

            This event notifies the client of a hardware id available on this tool.

            The hardware id is a device-specific 64-bit id that provides extra
            information about the tool in use, beyond the wl_tool.type
            enumeration. The format of the id is specific to tablets made by
            Wacom Inc. For example, the hardware id of a Wacom Grip
            Pen (a stylus) is 0x802.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                hardware_id_hi: The hardware id, most significant bits
                hardware_id_lo: The hardware id, least significant bits
            """

            ...

        def capability(self, capability: zwp_tablet_tool_v1.capability) -> None:
            """
            Tool capability notification

            This event notifies the client of any capabilities of this tool,
            beyond the main set of x/y axes and tip up/down detection.

            One event is sent for each extra capability available on this tool.

            This event is sent in the initial burst of events before the
            wp_tablet_tool.done event.

            Args:
                capability: The capability
            """

            ...

        def done(self) -> None:
            """
            Tool description events sequence complete

            This event signals the end of the initial burst of descriptive
            events. A client may consider the static description of the tool to
            be complete and finalize initialization of the tool.
            """

            ...

        def removed(self) -> None:
            """
            Tool removed

            This event is sent when the tool is removed from the system and will
            send no further events. Should the physical tool come back into
            proximity later, a new wp_tablet_tool object will be created.

            It is compositor-dependent when a tool is removed. A compositor may
            remove a tool on proximity out, tablet removal or any other reason.
            A compositor may also keep a tool alive until shutdown.

            If the tool is currently in proximity, a proximity_out event will be
            sent before the removed event. See wp_tablet_tool.proximity_out for
            the handling of any buttons logically down.

            When this event is received, the client must wp_tablet_tool.destroy
            the object.
            """

            ...

        def proximity_in(self, serial: int, tablet: zwp_tablet_v1, surface: wl_surface) -> None:
            """
            Proximity in event

            Notification that this tool is focused on a certain surface.

            This event can be received when the tool has moved from one surface to
            another, or when the tool has come back into proximity above the
            surface.

            If any button is logically down when the tool comes into proximity,
            the respective button event is sent after the proximity_in event but
            within the same frame as the proximity_in event.

            Args:
                tablet: The tablet the tool is in proximity of
                surface: The current surface the tablet tool is over
            """

            ...

        def proximity_out(self) -> None:
            """
            Proximity out event

            Notification that this tool has either left proximity, or is no
            longer focused on a certain surface.

            When the tablet tool leaves proximity of the tablet, button release
            events are sent for each button that was held down at the time of
            leaving proximity. These events are sent before the proximity_out
            event but within the same wp_tablet.frame.

            If the tool stays within proximity of the tablet, but the focus
            changes from one surface to another, a button release event may not
            be sent until the button is actually released or the tool leaves the
            proximity of the tablet.
            """

            ...

        def down(self, serial: int) -> None:
            """
            Tablet tool is making contact

            Sent whenever the tablet tool comes in contact with the surface of the
            tablet.

            If the tool is already in contact with the tablet when entering the
            input region, the client owning said region will receive a
            wp_tablet.proximity_in event, followed by a wp_tablet.down
            event and a wp_tablet.frame event.

            Note that this event describes logical contact, not physical
            contact. On some devices, a compositor may not consider a tool in
            logical contact until a minimum physical pressure threshold is
            exceeded.
            """

            ...

        def up(self) -> None:
            """
            Tablet tool is no longer making contact

            Sent whenever the tablet tool stops making contact with the surface of
            the tablet, or when the tablet tool moves out of the input region
            and the compositor grab (if any) is dismissed.

            If the tablet tool moves out of the input region while in contact
            with the surface of the tablet and the compositor does not have an
            ongoing grab on the surface, the client owning said region will
            receive a wp_tablet.up event, followed by a wp_tablet.proximity_out
            event and a wp_tablet.frame event. If the compositor has an ongoing
            grab on this device, this event sequence is sent whenever the grab
            is dismissed in the future.

            Note that this event describes logical contact, not physical
            contact. On some devices, a compositor may not consider a tool out
            of logical contact until physical pressure falls below a specific
            threshold.
            """

            ...

        def motion(self, x: float, y: float) -> None:
            """
            Motion event

            Sent whenever a tablet tool moves.

            Args:
                x: Surface-local x coordinate
                y: Surface-local y coordinate
            """

            ...

        def pressure(self, pressure: int) -> None:
            """
            Pressure change event

            Sent whenever the pressure axis on a tool changes. The value of this
            event is normalized to a value between 0 and 65535.

            Note that pressure may be nonzero even when a tool is not in logical
            contact. See the down and up events for more details.

            Args:
                pressure: The current pressure value
            """

            ...

        def distance(self, distance: int) -> None:
            """
            Distance change event

            Sent whenever the distance axis on a tool changes. The value of this
            event is normalized to a value between 0 and 65535.

            Note that distance may be nonzero even when a tool is not in logical
            contact. See the down and up events for more details.

            Args:
                distance: The current distance value
            """

            ...

        def tilt(self, tilt_x: int, tilt_y: int) -> None:
            """
            Tilt change event

            Sent whenever one or both of the tilt axes on a tool change. Each tilt
            value is in 0.01 of a degree, relative to the z-axis of the tablet.
            The angle is positive when the top of a tool tilts along the
            positive x or y axis.

            Args:
                tilt_x: The current value of the x tilt axis
                tilt_y: The current value of the y tilt axis
            """

            ...

        def rotation(self, degrees: int) -> None:
            """
            Z-rotation change event

            Sent whenever the z-rotation axis on the tool changes. The
            rotation value is in 0.01 of a degree clockwise from the tool's
            logical neutral position.

            Args:
                degrees: The current rotation of the z axis
            """

            ...

        def slider(self, position: int) -> None:
            """
            Slider position change event

            Sent whenever the slider position on the tool changes. The
            value is normalized between -65535 and 65535, with 0 as the logical
            neutral position of the slider.

            The slider is available on e.g. the Wacom Airbrush tool.

            Args:
                position: The current position of slider
            """

            ...

        def wheel(self, degrees: int, clicks: int) -> None:
            """
            Wheel delta event

            Sent whenever the wheel on the tool emits an event. This event
            contains two values for the same axis change. The degrees value is
            in 0.01 of a degree in the same orientation as the
            wl_pointer.vertical_scroll axis. The clicks value is in discrete
            logical clicks of the mouse wheel. This value may be zero if the
            movement of the wheel was less than one logical click.

            Clients should choose either value and avoid mixing degrees and
            clicks. The compositor may accumulate values smaller than a logical
            click and emulate click events when a certain threshold is met.
            Thus, wl_tablet_tool.wheel events with non-zero clicks values may
            have different degrees values.

            Args:
                degrees: The wheel delta in 0.01 of a degree
                clicks: The wheel delta in discrete clicks
            """

            ...

        def button(self, serial: int, button: int, state: zwp_tablet_tool_v1.button_state) -> None:
            """
            Button event

            Sent whenever a button on the tool is pressed or released.

            If a button is held down when the tool moves in or out of proximity,
            button events are generated by the compositor. See
            wp_tablet_tool.proximity_in and wp_tablet_tool.proximity_out for
            details.

            Args:
                button: The button whose state has changed
                state: Whether the button was pressed or released
            """

            ...

        def frame(self, time: int) -> None:
            """
            Frame event

            Marks the end of a series of axis and/or button updates from the
            tablet. The Wayland protocol requires axis updates to be sent
            sequentially, however all events within a frame should be considered
            one hardware event.

            Args:
                time: The time of the event with millisecond granularity
            """

            ...

class zwp_tablet_v1:
    """
    Graphics tablet device

    The wp_tablet interface represents one graphics tablet device. The
    tablet interface itself does not generate events; all events are
    generated by wp_tablet_tool objects when in proximity above a tablet.

    A tablet has a number of static characteristics, e.g. device name and
    pid/vid. These capabilities are sent in an event sequence after the
    wp_tablet_seat.tablet_added event. This initial event sequence is
    terminated by a wp_tablet.done event.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the tablet object

        This destroys the client's resource for this tablet object.
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Tablet device name.

        Override to handle [`wayland.zwp_tablet_v1.events.name`][].
        """

        ...

    def on_id(self, vid: int, pid: int) -> None:
        """
        Tablet device usb vendor/product id.

        Override to handle [`wayland.zwp_tablet_v1.events.id`][].
        """

        ...

    def on_path(self, path: str) -> None:
        """
        Path to the device.

        Override to handle [`wayland.zwp_tablet_v1.events.path`][].
        """

        ...

    def on_done(self) -> None:
        """
        Tablet description events sequence complete.

        Override to handle [`wayland.zwp_tablet_v1.events.done`][].
        """

        ...

    def on_removed(self) -> None:
        """
        Tablet removed event.

        Override to handle [`wayland.zwp_tablet_v1.events.removed`][].
        """

        ...

    class events(WaylandEvent):
        def name(self, name: str) -> None:
            """
            Tablet device name

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                name: The device name
            """

            ...

        def id(self, vid: int, pid: int) -> None:
            """
            Tablet device usb vendor/product id

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                vid: Usb vendor id
                pid: Usb product id
            """

            ...

        def path(self, path: str) -> None:
            """
            Path to the device

            A system-specific device path that indicates which device is behind
            this wp_tablet. This information may be used to gather additional
            information about the device, e.g. through libwacom.

            A device may have more than one device path. If so, multiple
            wp_tablet.path events are sent. A device may be emulated and not
            have a device path, and in that case this event will not be sent.

            The format of the path is unspecified, it may be a device node, a
            sysfs path, or some other identifier. It is up to the client to
            identify the string provided.

            This event is sent in the initial burst of events before the
            wp_tablet.done event.

            Args:
                path: Path to local device
            """

            ...

        def done(self) -> None:
            """
            Tablet description events sequence complete

            This event is sent immediately to signal the end of the initial
            burst of descriptive events. A client may consider the static
            description of the tablet to be complete and finalize initialization
            of the tablet.
            """

            ...

        def removed(self) -> None:
            """
            Tablet removed event

            Sent when the tablet has been removed from the system. When a tablet
            is removed, some tools may be removed.

            When this event is received, the client must wp_tablet.destroy
            the object.
            """

            ...

class zwp_text_input_v1:
    """
    Text input

    An object used for text input. Adds support for text input and input
    methods to applications. A text_input object is created from a
    wl_text_input_manager and corresponds typically to a text entry in an
    application.

    Requests are used to activate/deactivate the text_input object and set
    state information like surrounding and selected text or the content type.
    The information about entered text is sent to the text_input object via
    the pre-edit and commit events. Using this interface removes the need
    for applications to directly process hardware key events and compose text
    out of them.

    Text is generally UTF-8 encoded, indices and lengths are in bytes.

    Serials are used to synchronize the state between the text input and
    an input method. New serials are sent by the text input in the
    commit_state request and are used by the input method to indicate
    the known text input state in events like preedit_string, commit_string,
    and keysym. The text input can then ignore events from the input method
    which are based on an outdated state (for example after a reset).

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 1

    class content_hint(IntFlag):
        """
        Content hint

        Content hint is a bitmask to allow to modify the behavior of the text
        input.
        """

        none: int
        """No special behaviour"""

        default: int
        """Auto completion, correction and capitalization"""

        password: int
        """Hidden and sensitive text"""

        auto_completion: int
        """Suggest word completions"""

        auto_correction: int
        """Suggest word corrections"""

        auto_capitalization: int
        """Switch to uppercase letters at the start of a sentence"""

        lowercase: int
        """Prefer lowercase letters"""

        uppercase: int
        """Prefer uppercase letters"""

        titlecase: int
        """Prefer casing for titles and headings (can be language dependent)"""

        hidden_text: int
        """Characters should be hidden"""

        sensitive_data: int
        """Typed text should not be stored"""

        latin: int
        """Just latin characters should be entered"""

        multiline: int
        """The text input is multiline"""



    class content_purpose(Enum):
        """
        Content purpose

        The content purpose allows to specify the primary purpose of a text
        input.

        This allows an input method to show special purpose input panels with
        extra characters or to disallow some characters.
        """

        normal: int
        """Default input, allowing all characters"""

        alpha: int
        """Allow only alphabetic characters"""

        digits: int
        """Allow only digits"""

        number: int
        """Input a number (including decimal separator and sign)"""

        phone: int
        """Input a phone number"""

        url: int
        """Input an url"""

        email: int
        """Input an email address"""

        name: int
        """Input a name of a person"""

        password: int
        """Input a password (combine with password or `sensitive_data` hint)"""

        date: int
        """Input a date"""

        time: int
        """Input a time"""

        datetime: int
        """Input a date and time"""

        terminal: int
        """Input for a terminal"""



    class preedit_style(Enum):
        default: int
        """Default style for composing text"""

        none: int
        """Style should be the same as in non-composing text"""

        active: int
        inactive: int
        highlight: int
        underline: int
        selection: int
        incorrect: int


    class text_direction(Enum):
        auto: int
        """Automatic text direction based on text and language"""

        ltr: int
        """Left-to-right"""

        rtl: int
        """Right-to-left"""



    def activate(self, seat: wl_seat, surface: wl_surface) -> None:
        """
        Request activation

        Requests the text_input object to be activated (typically when the
        text entry gets focus).

        The seat argument is a wl_seat which maintains the focus for this
        activation. The surface argument is a wl_surface assigned to the
        text_input object and tracked for focus lost. The enter event
        is emitted on successful activation.
        """

        ...

    def deactivate(self, seat: wl_seat) -> None:
        """
        Request deactivation

        Requests the text_input object to be deactivated (typically when the
        text entry lost focus). The seat argument is a wl_seat which was used
        for activation.
        """

        ...

    def show_input_panel(self) -> None:
        """
        Show input panels

        Requests input panels (virtual keyboard) to show.
        """

        ...

    def hide_input_panel(self) -> None:
        """
        Hide input panels

        Requests input panels (virtual keyboard) to hide.
        """

        ...

    def reset(self) -> None:
        """
        Reset

        Should be called by an editor widget when the input state should be
        reset, for example after the text was changed outside of the normal
        input method flow.
        """

        ...

    def set_surrounding_text(self, text: str, cursor: int, anchor: int) -> None:
        """
        Sets the surrounding text

        Sets the plain surrounding text around the input position. Text is
        UTF-8 encoded. Cursor is the byte offset within the
        surrounding text. Anchor is the byte offset of the
        selection anchor within the surrounding text. If there is no selected
        text anchor, then it is the same as cursor.
        """

        ...

    def set_content_type(self, hint: zwp_text_input_v1.content_hint, purpose: zwp_text_input_v1.content_purpose) -> None:
        """
        Set content purpose and hint

        Sets the content purpose and content hint. While the purpose is the
        basic purpose of an input field, the hint flags allow to modify some
        of the behavior.

        When no content type is explicitly set, a normal content purpose with
        default hints (auto completion, auto correction, auto capitalization)
        should be assumed.
        """

        ...

    def set_cursor_rectangle(self, x: int, y: int, width: int, height: int) -> None:
        """"""

        ...

    def set_preferred_language(self, language: str) -> None:
        """
        Sets preferred language

        Sets a specific language. This allows for example a virtual keyboard to
        show a language specific layout. The "language" argument is an RFC-3066
        format language tag.

        It could be used for example in a word processor to indicate the
        language of the currently edited document or in an instant message
        application which tracks languages of contacts.
        """

        ...

    def commit_state(self, serial: int) -> None:
        """

        Args:
            serial: Used to identify the known state
        """

        ...

    def invoke_action(self, button: int, index: int) -> None:
        """"""

        ...

    def on_enter(self, surface: wl_surface) -> None:
        """
        Enter event.

        Override to handle [`wayland.zwp_text_input_v1.events.enter`][].
        """

        ...

    def on_leave(self) -> None:
        """
        Leave event.

        Override to handle [`wayland.zwp_text_input_v1.events.leave`][].
        """

        ...

    def on_modifiers_map(self, map: list) -> None:
        """
        Modifiers map.

        Override to handle [`wayland.zwp_text_input_v1.events.modifiers_map`][].
        """

        ...

    def on_input_panel_state(self, state: int) -> None:
        """
        State of the input panel.

        Override to handle [`wayland.zwp_text_input_v1.events.input_panel_state`][].
        """

        ...

    def on_preedit_string(self, serial: int, text: str, commit: str) -> None:
        """
        Pre-edit.

        Override to handle [`wayland.zwp_text_input_v1.events.preedit_string`][].
        """

        ...

    def on_preedit_styling(self, index: int, length: int, style: zwp_text_input_v1.preedit_style) -> None:
        """
        Pre-edit styling.

        Override to handle [`wayland.zwp_text_input_v1.events.preedit_styling`][].
        """

        ...

    def on_preedit_cursor(self, index: int) -> None:
        """
        Pre-edit cursor.

        Override to handle [`wayland.zwp_text_input_v1.events.preedit_cursor`][].
        """

        ...

    def on_commit_string(self, serial: int, text: str) -> None:
        """
        Commit.

        Override to handle [`wayland.zwp_text_input_v1.events.commit_string`][].
        """

        ...

    def on_cursor_position(self, index: int, anchor: int) -> None:
        """
        Set cursor to new position.

        Override to handle [`wayland.zwp_text_input_v1.events.cursor_position`][].
        """

        ...

    def on_delete_surrounding_text(self, index: int, length: int) -> None:
        """
        Delete surrounding text.

        Override to handle [`wayland.zwp_text_input_v1.events.delete_surrounding_text`][].
        """

        ...

    def on_keysym(self, serial: int, time: int, sym: int, state: int, modifiers: int) -> None:
        """
        Keysym.

        Override to handle [`wayland.zwp_text_input_v1.events.keysym`][].
        """

        ...

    def on_language(self, serial: int, language: str) -> None:
        """
        Language.

        Override to handle [`wayland.zwp_text_input_v1.events.language`][].
        """

        ...

    def on_text_direction(self, serial: int, direction: zwp_text_input_v1.text_direction) -> None:
        """
        Text direction.

        Override to handle [`wayland.zwp_text_input_v1.events.text_direction`][].
        """

        ...

    class events(WaylandEvent):
        def enter(self, surface: wl_surface) -> None:
            """
            Enter event

            Notify the text_input object when it received focus. Typically in
            response to an activate request.
            """

            ...

        def leave(self) -> None:
            """
            Leave event

            Notify the text_input object when it lost focus. Either in response
            to a deactivate request or when the assigned surface lost focus or was
            destroyed.
            """

            ...

        def modifiers_map(self, map: list) -> None:
            """
            Modifiers map

            Transfer an array of 0-terminated modifier names. The position in
            the array is the index of the modifier as used in the modifiers
            bitmask in the keysym event.
            """

            ...

        def input_panel_state(self, state: int) -> None:
            """
            State of the input panel

            Notify when the visibility state of the input panel changed.
            """

            ...

        def preedit_string(self, serial: int, text: str, commit: str) -> None:
            """
            Pre-edit

            Notify when a new composing text (pre-edit) should be set around the
            current cursor position. Any previously set composing text should
            be removed.

            The commit text can be used to replace the preedit text on reset
            (for example on unfocus).

            The text input should also handle all preedit_style and preedit_cursor
            events occurring directly before preedit_string.

            Args:
                serial: Serial of the latest known text input state
            """

            ...

        def preedit_styling(self, index: int, length: int, style: zwp_text_input_v1.preedit_style) -> None:
            """
            Pre-edit styling

            Sets styling information on composing text. The style is applied for
            length bytes from index relative to the beginning of the composing
            text (as byte offset). Multiple styles can
            be applied to a composing text by sending multiple preedit_styling
            events.

            This event is handled as part of a following preedit_string event.
            """

            ...

        def preedit_cursor(self, index: int) -> None:
            """
            Pre-edit cursor

            Sets the cursor position inside the composing text (as byte
            offset) relative to the start of the composing text. When index is a
            negative number no cursor is shown.

            This event is handled as part of a following preedit_string event.
            """

            ...

        def commit_string(self, serial: int, text: str) -> None:
            """
            Commit

            Notify when text should be inserted into the editor widget. The text to
            commit could be either just a single character after a key press or the
            result of some composing (pre-edit). It could also be an empty text
            when some text should be removed (see delete_surrounding_text) or when
            the input cursor should be moved (see cursor_position).

            Any previously set composing text should be removed.

            Args:
                serial: Serial of the latest known text input state
            """

            ...

        def cursor_position(self, index: int, anchor: int) -> None:
            """
            Set cursor to new position

            Notify when the cursor or anchor position should be modified.

            This event should be handled as part of a following commit_string
            event.
            """

            ...

        def delete_surrounding_text(self, index: int, length: int) -> None:
            """
            Delete surrounding text

            Notify when the text around the current cursor position should be
            deleted.

            Index is relative to the current cursor (in bytes).
            Length is the length of deleted text (in bytes).

            This event should be handled as part of a following commit_string
            event.
            """

            ...

        def keysym(self, serial: int, time: int, sym: int, state: int, modifiers: int) -> None:
            """
            Keysym

            Notify when a key event was sent. Key events should not be used
            for normal text input operations, which should be done with
            commit_string, delete_surrounding_text, etc. The key event follows
            the wl_keyboard key event convention. Sym is an XKB keysym, state a
            wl_keyboard key_state. Modifiers are a mask for effective modifiers
            (where the modifier indices are set by the modifiers_map event)

            Args:
                serial: Serial of the latest known text input state
            """

            ...

        def language(self, serial: int, language: str) -> None:
            """
            Language

            Sets the language of the input text. The "language" argument is an
            RFC-3066 format language tag.

            Args:
                serial: Serial of the latest known text input state
            """

            ...

        def text_direction(self, serial: int, direction: zwp_text_input_v1.text_direction) -> None:
            """
            Text direction

            Sets the text direction of input text.

            It is mainly needed for showing an input cursor on the correct side of
            the editor when there is no input done yet and making sure neutral
            direction text is laid out properly.

            Args:
                serial: Serial of the latest known text input state
            """

            ...

class zwp_text_input_manager_v1:
    """
    Text input manager

    A factory for text_input objects. This object is a global singleton.
    """
    object_id = 0
    version = 1


    def create_text_input(self) -> zwp_text_input_v1:
        """
        Create text input

        Creates a new text_input object.

        Returns:
            zwp_text_input_v1: The created object
        """

        ...

class zwp_text_input_v3:
    """
    Text input

    The zwp_text_input_v3 interface represents text input and input methods
    associated with a seat. It provides enter/leave events to follow the
    text input focus for a seat.

    Requests are used to enable/disable the text-input object and set
    state information like surrounding and selected text or the content type.
    The information about the entered text is sent to the text-input object
    via the preedit_string and commit_string events.

    Text is valid UTF-8 encoded, indices and lengths are in bytes. Indices
    must not point to middle bytes inside a code point: they must either
    point to the first byte of a code point or to the end of the buffer.
    Lengths must be measured between two valid indices.

    Focus moving throughout surfaces will result in the emission of
    zwp_text_input_v3.enter and zwp_text_input_v3.leave events. The focused
    surface must commit zwp_text_input_v3.enable and
    zwp_text_input_v3.disable requests as the keyboard focus moves across
    editable and non-editable elements of the UI. Those two requests are not
    expected to be paired with each other, the compositor must be able to
    handle consecutive series of the same request.

    State is sent by the state requests (set_surrounding_text,
    set_content_type and set_cursor_rectangle) and a commit request. After an
    enter event or disable request all state information is invalidated and
    needs to be resent by the client.
    """
    object_id = 0
    version = 1

    class change_cause(Enum):
        """
        Text change reason

        Reason for the change of surrounding text or cursor posision.
        """

        input_method: int
        """Input method caused the change"""

        other: int
        """Something else than the input method caused the change"""



    class content_hint(IntFlag):
        """
        Content hint

        Content hint is a bitmask to allow to modify the behavior of the text
        input.
        """

        none: int
        """No special behavior"""

        completion: int
        """Suggest word completions"""

        spellcheck: int
        """Suggest word corrections"""

        auto_capitalization: int
        """Switch to uppercase letters at the start of a sentence"""

        lowercase: int
        """Prefer lowercase letters"""

        uppercase: int
        """Prefer uppercase letters"""

        titlecase: int
        """Prefer casing for titles and headings (can be language dependent)"""

        hidden_text: int
        """Characters should be hidden"""

        sensitive_data: int
        """Typed text should not be stored"""

        latin: int
        """Just latin characters should be entered"""

        multiline: int
        """The text input is multiline"""



    class content_purpose(Enum):
        """
        Content purpose

        The content purpose allows to specify the primary purpose of a text
        input.

        This allows an input method to show special purpose input panels with
        extra characters or to disallow some characters.
        """

        normal: int
        """Default input, allowing all characters"""

        alpha: int
        """Allow only alphabetic characters"""

        digits: int
        """Allow only digits"""

        number: int
        """Input a number (including decimal separator and sign)"""

        phone: int
        """Input a phone number"""

        url: int
        """Input an url"""

        email: int
        """Input an email address"""

        name: int
        """Input a name of a person"""

        password: int
        """Input a password (combine with `sensitive_data` hint)"""

        pin: int
        """Input is a numeric password (combine with `sensitive_data` hint)"""

        date: int
        """Input a date"""

        time: int
        """Input a time"""

        datetime: int
        """Input a date and time"""

        terminal: int
        """Input for a terminal"""



    def destroy(self) -> None:
        """
        Destroy the `wp_text_input`

        Destroy the wp_text_input object. Also disables all surfaces enabled
        through this wp_text_input object.
        """

        ...

    def enable(self) -> None:
        """
        Request text input to be enabled

        Requests text input on the surface previously obtained from the enter
        event.

        This request must be issued every time the focused text input changes
        to a new one, including within the current surface. Use
        zwp_text_input_v3.disable when there is no longer any input focus on
        the current surface.

        Clients must not enable more than one text input on the single seat
        and should disable the current text input before enabling the new one.
        Requests to enable a text input when another text input is enabled
        on the same seat must be ignored by compositor.

        This request resets all state associated with previous enable, disable,
        set_surrounding_text, set_text_change_cause, set_content_type, and
        set_cursor_rectangle requests, as well as the state associated with
        preedit_string, commit_string, and delete_surrounding_text events.

        The set_surrounding_text, set_content_type and set_cursor_rectangle
        requests must follow if the text input supports the necessary
        functionality.

        State set with this request is double-buffered. It will get applied on
        the next zwp_text_input_v3.commit request, and stay valid until the
        next committed enable or disable request.

        The changes must be applied by the compositor after issuing a
        zwp_text_input_v3.commit request.
        """

        ...

    def disable(self) -> None:
        """
        Disable text input on a surface

        Explicitly disable text input on the current surface (typically when
        there is no focus on any text entry inside the surface).

        State set with this request is double-buffered. It will get applied on
        the next zwp_text_input_v3.commit request.
        """

        ...

    def set_surrounding_text(self, text: str, cursor: int, anchor: int) -> None:
        """
        Sets the surrounding text

        Sets the surrounding plain text around the input, excluding the preedit
        text.

        The client should notify the compositor of any changes in any of the
        values carried with this request, including changes caused by handling
        incoming text-input events as well as changes caused by other
        mechanisms like keyboard typing.

        If the client is unaware of the text around the cursor, it should not
        issue this request, to signify lack of support to the compositor.

        Text is UTF-8 encoded, and should include the cursor position, the
        complete selection and additional characters before and after them.
        There is a maximum length of wayland messages, so text can not be
        longer than 4000 bytes.

        Cursor is the byte offset of the cursor within text buffer.

        Anchor is the byte offset of the selection anchor within text buffer.
        If there is no selected text, anchor is the same as cursor.

        If any preedit text is present, it is replaced with a cursor for the
        purpose of this event.

        Values set with this request are double-buffered. They will get applied
        on the next zwp_text_input_v3.commit request, and stay valid until the
        next committed enable or disable request.

        The initial state for affected fields is empty, meaning that the text
        input does not support sending surrounding text. If the empty values
        get applied, subsequent attempts to change them may have no effect.
        """

        ...

    def set_text_change_cause(self, cause: zwp_text_input_v3.change_cause) -> None:
        """
        Indicates the cause of surrounding text change

        Tells the compositor why the text surrounding the cursor changed.

        Whenever the client detects an external change in text, cursor, or
        anchor posision, it must issue this request to the compositor. This
        request is intended to give the input method a chance to update the
        preedit text in an appropriate way, e.g. by removing it when the user
        starts typing with a keyboard.

        cause describes the source of the change.

        The value set with this request is double-buffered. It must be applied
        and reset to initial at the next zwp_text_input_v3.commit request.

        The initial value of cause is input_method.
        """

        ...

    def set_content_type(self, hint: zwp_text_input_v3.content_hint, purpose: zwp_text_input_v3.content_purpose) -> None:
        """
        Set content purpose and hint

        Sets the content purpose and content hint. While the purpose is the
        basic purpose of an input field, the hint flags allow to modify some of
        the behavior.

        Values set with this request are double-buffered. They will get applied
        on the next zwp_text_input_v3.commit request.
        Subsequent attempts to update them may have no effect. The values
        remain valid until the next committed enable or disable request.

        The initial value for hint is none, and the initial value for purpose
        is normal.
        """

        ...

    def set_cursor_rectangle(self, x: int, y: int, width: int, height: int) -> None:
        """
        Set cursor position

        Marks an area around the cursor as a x, y, width, height rectangle in
        surface local coordinates.

        Allows the compositor to put a window with word suggestions near the
        cursor, without obstructing the text being input.

        If the client is unaware of the position of edited text, it should not
        issue this request, to signify lack of support to the compositor.

        Values set with this request are double-buffered. They will get applied
        on the next zwp_text_input_v3.commit request, and stay valid until the
        next committed enable or disable request.

        The initial values describing a cursor rectangle are empty. That means
        the text input does not support describing the cursor area. If the
        empty values get applied, subsequent attempts to change them may have
        no effect.
        """

        ...

    def commit(self) -> None:
        """
        Commit state

        Atomically applies state changes recently sent to the compositor.

        The commit request establishes and updates the state of the client, and
        must be issued after any changes to apply them.

        Text input state (enabled status, content purpose, content hint,
        surrounding text and change cause, cursor rectangle) is conceptually
        double-buffered within the context of a text input, i.e. between a
        committed enable request and the following committed enable or disable
        request.

        Protocol requests modify the pending state, as opposed to the current
        state in use by the input method. A commit request atomically applies
        all pending state, replacing the current state. After commit, the new
        pending state is as documented for each related request.

        Requests are applied in the order of arrival.

        Neither current nor pending state are modified unless noted otherwise.

        The compositor must count the number of commit requests coming from
        each zwp_text_input_v3 object and use the count as the serial in done
        events.
        """

        ...

    def on_enter(self, surface: wl_surface) -> None:
        """
        Enter event.

        Override to handle [`wayland.zwp_text_input_v3.events.enter`][].
        """

        ...

    def on_leave(self, surface: wl_surface) -> None:
        """
        Leave event.

        Override to handle [`wayland.zwp_text_input_v3.events.leave`][].
        """

        ...

    def on_preedit_string(self, text: str, cursor_begin: int, cursor_end: int) -> None:
        """
        Pre-edit.

        Override to handle [`wayland.zwp_text_input_v3.events.preedit_string`][].
        """

        ...

    def on_commit_string(self, text: str) -> None:
        """
        Text commit.

        Override to handle [`wayland.zwp_text_input_v3.events.commit_string`][].
        """

        ...

    def on_delete_surrounding_text(self, before_length: int, after_length: int) -> None:
        """
        Delete surrounding text.

        Override to handle [`wayland.zwp_text_input_v3.events.delete_surrounding_text`][].
        """

        ...

    def on_done(self, serial: int) -> None:
        """
        Apply changes.

        Override to handle [`wayland.zwp_text_input_v3.events.done`][].
        """

        ...

    class events(WaylandEvent):
        def enter(self, surface: wl_surface) -> None:
            """
            Enter event

            Notification that this seat's text-input focus is on a certain surface.

            If client has created multiple text input objects, compositor must send
            this event to all of them.

            When the seat has the keyboard capability the text-input focus follows
            the keyboard focus. This event sets the current surface for the
            text-input object.
            """

            ...

        def leave(self, surface: wl_surface) -> None:
            """
            Leave event

            Notification that this seat's text-input focus is no longer on a
            certain surface. The client should reset any preedit string previously
            set.

            The leave notification clears the current surface. It is sent before
            the enter notification for the new focus. After leave event, compositor
            must ignore requests from any text input instances until next enter
            event.

            When the seat has the keyboard capability the text-input focus follows
            the keyboard focus.
            """

            ...

        def preedit_string(self, text: str, cursor_begin: int, cursor_end: int) -> None:
            """
            Pre-edit

            Notify when a new composing text (pre-edit) should be set at the
            current cursor position. Any previously set composing text must be
            removed. Any previously existing selected text must be removed.

            The argument text contains the pre-edit string buffer.

            The parameters cursor_begin and cursor_end are counted in bytes
            relative to the beginning of the submitted text buffer. Cursor should
            be hidden when both are equal to -1.

            They could be represented by the client as a line if both values are
            the same, or as a text highlight otherwise.

            Values set with this event are double-buffered. They must be applied
            and reset to initial on the next zwp_text_input_v3.done event.

            The initial value of text is an empty string, and cursor_begin,
            cursor_end and cursor_hidden are all 0.
            """

            ...

        def commit_string(self, text: str) -> None:
            """
            Text commit

            Notify when text should be inserted into the editor widget. The text to
            commit could be either just a single character after a key press or the
            result of some composing (pre-edit).

            Values set with this event are double-buffered. They must be applied
            and reset to initial on the next zwp_text_input_v3.done event.

            The initial value of text is an empty string.
            """

            ...

        def delete_surrounding_text(self, before_length: int, after_length: int) -> None:
            """
            Delete surrounding text

            Notify when the text around the current cursor position should be
            deleted.

            Before_length and after_length are the number of bytes before and after
            the current cursor index (excluding the selection) to delete.

            If a preedit text is present, in effect before_length is counted from
            the beginning of it, and after_length from its end (see done event
            sequence).

            Values set with this event are double-buffered. They must be applied
            and reset to initial on the next zwp_text_input_v3.done event.

            The initial values of both before_length and after_length are 0.

            Args:
                before_length: Length of text before current cursor position
                after_length: Length of text after current cursor position
            """

            ...

        def done(self, serial: int) -> None:
            """
            Apply changes

            Instruct the application to apply changes to state requested by the
            preedit_string, commit_string and delete_surrounding_text events. The
            state relating to these events is double-buffered, and each one
            modifies the pending state. This event replaces the current state with
            the pending state.

            The application must proceed by evaluating the changes in the following
            order:

            1. Replace existing preedit string with the cursor.
            2. Delete requested surrounding text.
            3. Insert commit string with the cursor at its end.
            4. Calculate surrounding text to send.
            5. Insert new preedit text in cursor position.
            6. Place cursor inside preedit text.

            The serial number reflects the last state of the zwp_text_input_v3
            object known to the compositor. The value of the serial argument must
            be equal to the number of commit requests already issued on that object.

            When the client receives a done event with a serial different than the
            number of past commit requests, it must proceed with evaluating and
            applying the changes as normal, except it should not change the current
            state of the zwp_text_input_v3 object. All pending state requests
            (set_surrounding_text, set_content_type and set_cursor_rectangle) on
            the zwp_text_input_v3 object should be sent and committed after
            receiving a zwp_text_input_v3.done event with a matching serial.
            """

            ...

class zwp_text_input_manager_v3:
    """
    Text input manager

    A factory for text-input objects. This object is a global singleton.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `wp_text_input_manager`

        Destroy the wp_text_input_manager object.
        """

        ...

    def get_text_input(self, seat: wl_seat) -> zwp_text_input_v3:
        """
        Create a new text input object

        Creates a new text-input object for a given seat.

        Returns:
            zwp_text_input_v3: The created object
        """

        ...

class zxdg_decoration_manager_v1:
    """
    Window decoration manager

    This interface allows a compositor to announce support for server-side
    decorations.

    A window decoration is a set of window controls as deemed appropriate by
    the party managing them, such as user interface components used to move,
    resize and change a window's state.

    A client can use this protocol to request being decorated by a supporting
    compositor.

    If compositor and client do not negotiate the use of a server-side
    decoration using this protocol, clients continue to self-decorate as they
    see fit.

    Warning! The protocol described in this file is experimental and
    backward incompatible changes may be made. Backward compatible changes
    may be added together with the corresponding interface version bump.
    Backward incompatible changes are done by bumping the version number in
    the protocol and interface names and resetting the interface version.
    Once the protocol is to be declared stable, the 'z' prefix and the
    version number in the protocol and interface names are removed and the
    interface version number is reset.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the decoration manager object

        Destroy the decoration manager. This doesn't destroy objects created
        with the manager.
        """

        ...

    def get_toplevel_decoration(self, toplevel: xdg_toplevel) -> zxdg_toplevel_decoration_v1:
        """
        Create a new toplevel decoration object

        Create a new decoration object associated with the given toplevel.

        Creating an xdg_toplevel_decoration from an xdg_toplevel which has a
        buffer attached or committed is a client error, and any attempts by a
        client to attach or manipulate a buffer prior to the first
        xdg_toplevel_decoration.configure event must also be treated as
        errors.

        Returns:
            zxdg_toplevel_decoration_v1: The created object
        """

        ...

class zxdg_toplevel_decoration_v1:
    """
    Decoration object for a toplevel surface

    The decoration object allows the compositor to toggle server-side window
    decorations for a toplevel surface. The client can request to switch to
    another mode.

    The xdg_toplevel_decoration object must be destroyed before its
    xdg_toplevel.
    """
    object_id = 0
    version = 1

    class error(Enum):
        unconfigured_buffer: int
        """`xdg_toplevel` has a buffer attached before configure"""

        already_constructed: int
        """`xdg_toplevel` already has a decoration object"""

        orphaned: int
        """`xdg_toplevel` destroyed before the decoration object"""

        invalid_mode: int
        """Invalid mode"""



    class mode(Enum):
        """
        Window decoration modes

        These values describe window decoration modes.
        """

        client_side: int
        """No server-side window decoration"""

        server_side: int
        """Server-side window decoration"""



    def destroy(self) -> None:
        """
        Destroy the decoration object

        Switch back to a mode without any server-side decorations at the next
        commit.
        """

        ...

    def set_mode(self, mode: zxdg_toplevel_decoration_v1.mode) -> None:
        """
        Set the decoration mode

        Set the toplevel surface decoration mode. This informs the compositor
        that the client prefers the provided decoration mode.

        After requesting a decoration mode, the compositor will respond by
        emitting an xdg_surface.configure event. The client should then update
        its content, drawing it without decorations if the received mode is
        server-side decorations. The client must also acknowledge the configure
        when committing the new content (see xdg_surface.ack_configure).

        The compositor can decide not to use the client's mode and enforce a
        different mode instead.

        Clients whose decoration mode depend on the xdg_toplevel state may send
        a set_mode request in response to an xdg_surface.configure event and wait
        for the next xdg_surface.configure event to prevent unwanted state.
        Such clients are responsible for preventing configure loops and must
        make sure not to send multiple successive set_mode requests with the
        same decoration mode.

        If an invalid mode is supplied by the client, the invalid_mode protocol
        error is raised by the compositor.

        Args:
            mode: The decoration mode
        """

        ...

    def unset_mode(self) -> None:
        """
        Unset the decoration mode

        Unset the toplevel surface decoration mode. This informs the compositor
        that the client doesn't prefer a particular decoration mode.

        This request has the same semantics as set_mode.
        """

        ...

    def on_configure(self, mode: zxdg_toplevel_decoration_v1.mode) -> None:
        """
        Notify a decoration mode change.

        Override to handle [`wayland.zxdg_toplevel_decoration_v1.events.configure`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, mode: zxdg_toplevel_decoration_v1.mode) -> None:
            """
            Notify a decoration mode change

            The configure event configures the effective decoration mode. The
            configured state should not be applied immediately. Clients must send an
            ack_configure in response to this event. See xdg_surface.configure and
            xdg_surface.ack_configure for details.

            A configure event can be sent at any time. The specified mode must be
            obeyed by the client.

            Args:
                mode: The decoration mode
            """

            ...

class zxdg_exporter_v1:
    """
    Interface for exporting surfaces

    A global interface used for exporting surfaces that can later be imported
    using xdg_importer.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `xdg_exporter` object

        Notify the compositor that the xdg_exporter object will no longer be
        used.
        """

        ...

    def export(self, surface: wl_surface) -> zxdg_exported_v1:
        """
        Export a surface

        The export request exports the passed surface so that it can later be
        imported via xdg_importer. When called, a new xdg_exported object will
        be created and xdg_exported.handle will be sent immediately. See the
        corresponding interface and event for details.

        A surface may be exported multiple times, and each exported handle may
        be used to create an xdg_imported multiple times. Only xdg_surface
        surfaces may be exported.

        Args:
            surface: The surface to export

        Returns:
            zxdg_exported_v1: The created object
        """

        ...

class zxdg_importer_v1:
    """
    Interface for importing surfaces

    A global interface used for importing surfaces exported by xdg_exporter.
    With this interface, a client can create a reference to a surface of
    another client.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `xdg_importer` object

        Notify the compositor that the xdg_importer object will no longer be
        used.
        """

        ...

    def import_(self, handle: str) -> zxdg_imported_v1:
        """
        Import a surface

        The import request imports a surface from any client given a handle
        retrieved by exporting said surface using xdg_exporter.export. When
        called, a new xdg_imported object will be created. This new object
        represents the imported surface, and the importing client can
        manipulate its relationship using it. See xdg_imported for details.

        Args:
            handle: The exported surface handle

        Returns:
            zxdg_imported_v1: The created object
        """

        ...

class zxdg_exported_v1:
    """
    An exported surface handle

    An xdg_exported object represents an exported reference to a surface. The
    exported surface may be referenced as long as the xdg_exported object not
    destroyed. Destroying the xdg_exported invalidates any relationship the
    importer may have established using xdg_imported.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Unexport the exported surface

        Revoke the previously exported surface. This invalidates any
        relationship the importer may have set up using the xdg_imported created
        given the handle sent via xdg_exported.handle.
        """

        ...

    def on_handle(self, handle: str) -> None:
        """
        The exported surface handle.

        Override to handle [`wayland.zxdg_exported_v1.events.handle`][].
        """

        ...

    class events(WaylandEvent):
        def handle(self, handle: str) -> None:
            """
            The exported surface handle

            The handle event contains the unique handle of this exported surface
            reference. It may be shared with any client, which then can use it to
            import the surface by calling xdg_importer.import. A handle may be
            used to import the surface multiple times.

            Args:
                handle: The exported surface handle
            """

            ...

class zxdg_imported_v1:
    """
    An imported surface handle

    An xdg_imported object represents an imported reference to surface exported
    by some client. A client can use this interface to manipulate
    relationships between its own surfaces and the imported surface.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `xdg_imported` object

        Notify the compositor that it will no longer use the xdg_imported
        object. Any relationship that may have been set up will at this point
        be invalidated.
        """

        ...

    def set_parent_of(self, surface: wl_surface) -> None:
        """
        Set as the parent of some surface

        Set the imported surface as the parent of some surface of the client.
        The passed surface must be a toplevel xdg_surface. Calling this function
        sets up a surface to surface relation with the same stacking and positioning
        semantics as xdg_surface.set_parent.

        Args:
            surface: The child surface
        """

        ...

    def on_destroyed(self) -> None:
        """
        The imported surface handle has been destroyed.

        Override to handle [`wayland.zxdg_imported_v1.events.destroyed`][].
        """

        ...

    class events(WaylandEvent):
        def destroyed(self) -> None:
            """
            The imported surface handle has been destroyed

            The imported surface handle has been destroyed and any relationship set
            up has been invalidated. This may happen for various reasons, for
            example if the exported surface or the exported surface handle has been
            destroyed, if the handle used for importing was invalid.
            """

            ...

class zxdg_exporter_v2:
    """
    Interface for exporting surfaces

    A global interface used for exporting surfaces that can later be imported
    using xdg_importer.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        Error values

        These errors can be emitted in response to invalid xdg_exporter
        requests.
        """

        invalid_surface: int
        """Surface is not an `xdg_toplevel`"""



    def destroy(self) -> None:
        """
        Destroy the `xdg_exporter` object

        Notify the compositor that the xdg_exporter object will no longer be
        used.
        """

        ...

    def export_toplevel(self, surface: wl_surface) -> zxdg_exported_v2:
        """
        Export a toplevel surface

        The export_toplevel request exports the passed surface so that it can later be
        	imported via xdg_importer. When called, a new xdg_exported object will
        	be created and xdg_exported.handle will be sent immediately. See the
        	corresponding interface and event for details.

        	A surface may be exported multiple times, and each exported handle may
        	be used to create an xdg_imported multiple times. Only xdg_toplevel
                equivalent surfaces may be exported, otherwise an invalid_surface
                protocol error is sent.

        Args:
            surface: The surface to export

        Returns:
            zxdg_exported_v2: The created object
        """

        ...

class zxdg_importer_v2:
    """
    Interface for importing surfaces

    A global interface used for importing surfaces exported by xdg_exporter.
    With this interface, a client can create a reference to a surface of
    another client.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the `xdg_importer` object

        Notify the compositor that the xdg_importer object will no longer be
        used.
        """

        ...

    def import_toplevel(self, handle: str) -> zxdg_imported_v2:
        """
        Import a toplevel surface

        The import_toplevel request imports a surface from any client given a handle
        retrieved by exporting said surface using xdg_exporter.export_toplevel.
        When called, a new xdg_imported object will be created. This new object
        represents the imported surface, and the importing client can
        manipulate its relationship using it. See xdg_imported for details.

        Args:
            handle: The exported surface handle

        Returns:
            zxdg_imported_v2: The created object
        """

        ...

class zxdg_exported_v2:
    """
    An exported surface handle

    An xdg_exported object represents an exported reference to a surface. The
    exported surface may be referenced as long as the xdg_exported object not
    destroyed. Destroying the xdg_exported invalidates any relationship the
    importer may have established using xdg_imported.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Unexport the exported surface

        Revoke the previously exported surface. This invalidates any
        relationship the importer may have set up using the xdg_imported created
        given the handle sent via xdg_exported.handle.
        """

        ...

    def on_handle(self, handle: str) -> None:
        """
        The exported surface handle.

        Override to handle [`wayland.zxdg_exported_v2.events.handle`][].
        """

        ...

    class events(WaylandEvent):
        def handle(self, handle: str) -> None:
            """
            The exported surface handle

            The handle event contains the unique handle of this exported surface
            reference. It may be shared with any client, which then can use it to
            import the surface by calling xdg_importer.import_toplevel. A handle
            may be used to import the surface multiple times.

            Args:
                handle: The exported surface handle
            """

            ...

class zxdg_imported_v2:
    """
    An imported surface handle

    An xdg_imported object represents an imported reference to surface exported
    by some client. A client can use this interface to manipulate
    relationships between its own surfaces and the imported surface.
    """
    object_id = 0
    version = 1

    class error(Enum):
        """
        Error values

        These errors can be emitted in response to invalid xdg_imported
        requests.
        """

        invalid_surface: int
        """Surface is not an `xdg_toplevel`"""



    def destroy(self) -> None:
        """
        Destroy the `xdg_imported` object

        Notify the compositor that it will no longer use the xdg_imported
        object. Any relationship that may have been set up will at this point
        be invalidated.
        """

        ...

    def set_parent_of(self, surface: wl_surface) -> None:
        """
        Set as the parent of some surface

        Set the imported surface as the parent of some surface of the client.
        The passed surface must be an xdg_toplevel equivalent, otherwise an
        invalid_surface protocol error is sent. Calling this function sets up
        a surface to surface relation with the same stacking and positioning
        semantics as xdg_toplevel.set_parent.

        Args:
            surface: The child surface
        """

        ...

    def on_destroyed(self) -> None:
        """
        The imported surface handle has been destroyed.

        Override to handle [`wayland.zxdg_imported_v2.events.destroyed`][].
        """

        ...

    class events(WaylandEvent):
        def destroyed(self) -> None:
            """
            The imported surface handle has been destroyed

            The imported surface handle has been destroyed and any relationship set
            up has been invalidated. This may happen for various reasons, for
            example if the exported surface or the exported surface handle has been
            destroyed, if the handle used for importing was invalid.
            """

            ...

class zxdg_output_manager_v1:
    """
    Manage `xdg_output` objects

    A global factory interface for xdg_output objects.
    """
    object_id = 0
    version = 3


    def destroy(self) -> None:
        """
        Destroy the `xdg_output_manager` object

        Using this request a client can tell the server that it is not
        going to use the xdg_output_manager object anymore.

        Any objects already created through this instance are not affected.
        """

        ...

    def get_xdg_output(self, output: wl_output) -> zxdg_output_v1:
        """
        Create an xdg output from a `wl_output`

        This creates a new xdg_output object for the given wl_output.

        Returns:
            zxdg_output_v1: The created object
        """

        ...

class zxdg_output_v1:
    """
    Compositor logical output region

    An xdg_output describes part of the compositor geometry.

    This typically corresponds to a monitor that displays part of the
    compositor space.

    For objects version 3 onwards, after all xdg_output properties have been
    sent (when the object is created and when properties are updated), a
    wl_output.done event is sent. This allows changes to the output
    properties to be seen as atomic, even if they happen via multiple events.
    """
    object_id = 0
    version = 3


    def destroy(self) -> None:
        """
        Destroy the `xdg_output` object

        Using this request a client can tell the server that it is not
        going to use the xdg_output object anymore.
        """

        ...

    def on_logical_position(self, x: int, y: int) -> None:
        """
        Position of the output within the global compositor space.

        Override to handle [`wayland.zxdg_output_v1.events.logical_position`][].
        """

        ...

    def on_logical_size(self, width: int, height: int) -> None:
        """
        Size of the output in the global compositor space.

        Override to handle [`wayland.zxdg_output_v1.events.logical_size`][].
        """

        ...

    def on_done(self) -> None:
        """
        All information about the output have been sent.

        Override to handle [`wayland.zxdg_output_v1.events.done`][].
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Name of this output.

        Override to handle [`wayland.zxdg_output_v1.events.name`][].
        """

        ...

    def on_description(self, description: str) -> None:
        """
        Human-readable description of this output.

        Override to handle [`wayland.zxdg_output_v1.events.description`][].
        """

        ...

    class events(WaylandEvent):
        def logical_position(self, x: int, y: int) -> None:
            """
            Position of the output within the global compositor space

            The position event describes the location of the wl_output within
            the global compositor space.

            The logical_position event is sent after creating an xdg_output
            (see xdg_output_manager.get_xdg_output) and whenever the location
            of the output changes within the global compositor space.

            Args:
                x: X position within the global compositor space
                y: Y position within the global compositor space
            """

            ...

        def logical_size(self, width: int, height: int) -> None:
            """
            Size of the output in the global compositor space

            The logical_size event describes the size of the output in the
            global compositor space.

            Most regular Wayland clients should not pay attention to the
            logical size and would rather rely on xdg_shell interfaces.

            Some clients such as Xwayland, however, need this to configure
            their surfaces in the global compositor space as the compositor
            may apply a different scale from what is advertised by the output
            scaling property (to achieve fractional scaling, for example).

            For example, for a wl_output mode 3840×2160 and a scale factor 2:

            - A compositor not scaling the monitor viewport in its compositing space
              will advertise a logical size of 3840×2160,

            - A compositor scaling the monitor viewport with scale factor 2 will
              advertise a logical size of 1920×1080,

            - A compositor scaling the monitor viewport using a fractional scale of
              1.5 will advertise a logical size of 2560×1440.

            For example, for a wl_output mode 1920×1080 and a 90 degree rotation,
            the compositor will advertise a logical size of 1080x1920.

            The logical_size event is sent after creating an xdg_output
            (see xdg_output_manager.get_xdg_output) and whenever the logical
            size of the output changes, either as a result of a change in the
            applied scale or because of a change in the corresponding output
            mode(see wl_output.mode) or transform (see wl_output.transform).

            Args:
                width: Width in global compositor space
                height: Height in global compositor space
            """

            ...

        def done(self) -> None:
            """
            All information about the output have been sent

            This event is sent after all other properties of an xdg_output
            have been sent.

            This allows changes to the xdg_output properties to be seen as
            atomic, even if they happen via multiple events.

            For objects version 3 onwards, this event is deprecated. Compositors
            are not required to send it anymore and must send wl_output.done
            instead.
            """

            ...

        def name(self, name: str) -> None:
            """
            Name of this output

            Many compositors will assign names to their outputs, show them to the
            	user, allow them to be configured by name, etc. The client may wish to
            	know this name as well to offer the user similar behaviors.

            	The naming convention is compositor defined, but limited to
            	alphanumeric characters and dashes (-). Each name is unique among all
            	wl_output globals, but if a wl_output global is destroyed the same name
            	may be reused later. The names will also remain consistent across
            	sessions with the same hardware and software configuration.

            	Examples of names include 'HDMI-A-1', 'WL-1', 'X11-1', etc. However, do
            	not assume that the name is a reflection of an underlying DRM
            	connector, X11 connection, etc.

            	The name event is sent after creating an xdg_output (see
            	xdg_output_manager.get_xdg_output). This event is only sent once per
            	xdg_output, and the name does not change over the lifetime of the
            	wl_output global.

                    This event is deprecated, instead clients should use wl_output.name.
                    Compositors must still support this event.

            Args:
                name: Output name
            """

            ...

        def description(self, description: str) -> None:
            """
            Human-readable description of this output

            Many compositors can produce human-readable descriptions of their
            outputs.  The client may wish to know this description as well, to
            communicate the user for various purposes.

            The description is a UTF-8 string with no convention defined for its
            contents. Examples might include 'Foocorp 11" Display' or 'Virtual X11
            output via :1'.

            The description event is sent after creating an xdg_output (see
            xdg_output_manager.get_xdg_output) and whenever the description
            changes. The description is optional, and may not be sent at all.

            For objects of version 2 and lower, this event is only sent once per
            xdg_output, and the description does not change over the lifetime of
            the wl_output global.

            This event is deprecated, instead clients should use
            wl_output.description. Compositors must still support this event.

            Args:
                description: Output description
            """

            ...

class xdg_shell:
    """
    Create desktop-style surfaces

    xdg_shell allows clients to turn a wl_surface into a "real window"
    which can be dragged, resized, stacked, and moved around by the
    user. Everything about this interface is suited towards traditional
    desktop environments.
    """
    object_id = 0
    version = 1

    class version(Enum):
        """
        Latest protocol version

        The 'current' member of this enum gives the version of the
        protocol.  Implementations can compare this to the version
        they implement using static_assert to ensure the protocol and
        implementation versions match.
        """

        current: int
        """Always the latest version"""



    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""

        defunct_surfaces: int
        """`xdg_shell` was destroyed before children"""

        not_the_topmost_popup: int
        """The client tried to map or destroy a non-topmost popup"""

        invalid_popup_parent: int
        """The client specified an invalid popup parent surface"""



    def destroy(self) -> None:
        """
        Destroy `xdg_shell`

        Destroy this xdg_shell object.

        Destroying a bound xdg_shell object while there are surfaces
        still alive created by this xdg_shell object instance is illegal
        and will result in a protocol error.
        """

        ...

    def use_unstable_version(self, version: int) -> None:
        """
        Enable use of this unstable version

        Negotiate the unstable version of the interface.  This
        mechanism is in place to ensure client and server agree on the
        unstable versions of the protocol that they speak or exit
        cleanly if they don't agree.  This request will go away once
        the xdg-shell protocol is stable.
        """

        ...

    def get_xdg_surface(self, surface: wl_surface) -> xdg_surface:
        """
        Create a shell surface from a surface

        This creates an xdg_surface for the given surface and gives it the
        xdg_surface role. A wl_surface can only be given an xdg_surface role
        once. If get_xdg_surface is called with a wl_surface that already has
        an active xdg_surface associated with it, or if it had any other role,
        an error is raised.

        See the documentation of xdg_surface for more details about what an
        xdg_surface is and how it is used.

        Returns:
            xdg_surface: The created object
        """

        ...

    def get_xdg_popup(self, surface: wl_surface, parent: wl_surface, seat: wl_seat, serial: int, x: int, y: int) -> xdg_popup:
        """
        Create a popup for a surface

        This creates an xdg_popup for the given surface and gives it the
        xdg_popup role. A wl_surface can only be given an xdg_popup role
        once. If get_xdg_popup is called with a wl_surface that already has
        an active xdg_popup associated with it, or if it had any other role,
        an error is raised.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event.

        See the documentation of xdg_popup for more details about what an
        xdg_popup is and how it is used.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event

        Returns:
            xdg_popup: The created object
        """

        ...

    def pong(self, serial: int) -> None:
        """
        Respond to a ping event

        A client must respond to a ping event with a pong request or
        the client may be deemed unresponsive.

        Args:
            serial: Serial of the ping event
        """

        ...

    def on_ping(self, serial: int) -> None:
        """
        Check if the client is alive.

        Override to handle [`wayland.xdg_shell.events.ping`][].
        """

        ...

    class events(WaylandEvent):
        def ping(self, serial: int) -> None:
            """
            Check if the client is alive

            The ping event asks the client if it's still alive. Pass the
            serial specified in the event back to the compositor by sending
            a "pong" request back with the specified serial.

            Compositors can use this to determine if the client is still
            alive. It's unspecified what will happen if the client doesn't
            respond to the ping request, or in what timeframe. Clients should
            try to respond in a reasonable amount of time.

            A compositor is free to ping in any way it wants, but a client must
            always respond to any xdg_shell object it created.

            Args:
                serial: Pass this to the pong request
            """

            ...

class zxdg_shell_v6:
    """
    Create desktop-style surfaces

    xdg_shell allows clients to turn a wl_surface into a "real window"
    which can be dragged, resized, stacked, and moved around by the
    user. Everything about this interface is suited towards traditional
    desktop environments.
    """
    object_id = 0
    version = 1

    class error(Enum):
        role: int
        """Given `wl_surface` has another role"""

        defunct_surfaces: int
        """`xdg_shell` was destroyed before children"""

        not_the_topmost_popup: int
        """The client tried to map or destroy a non-topmost popup"""

        invalid_popup_parent: int
        """The client specified an invalid popup parent surface"""

        invalid_surface_state: int
        """The client provided an invalid surface state"""

        invalid_positioner: int
        """The client provided an invalid positioner"""



    def destroy(self) -> None:
        """
        Destroy `xdg_shell`

        Destroy this xdg_shell object.

        Destroying a bound xdg_shell object while there are surfaces
        still alive created by this xdg_shell object instance is illegal
        and will result in a protocol error.
        """

        ...

    def create_positioner(self) -> zxdg_positioner_v6:
        """
        Create a positioner object

        Create a positioner object. A positioner object is used to position
        surfaces relative to some parent surface. See the interface description
        and xdg_surface.get_popup for details.

        Returns:
            zxdg_positioner_v6: The created object
        """

        ...

    def get_xdg_surface(self, surface: wl_surface) -> zxdg_surface_v6:
        """
        Create a shell surface from a surface

        This creates an xdg_surface for the given surface. While xdg_surface
        itself is not a role, the corresponding surface may only be assigned
        a role extending xdg_surface, such as xdg_toplevel or xdg_popup.

        This creates an xdg_surface for the given surface. An xdg_surface is
        used as basis to define a role to a given surface, such as xdg_toplevel
        or xdg_popup. It also manages functionality shared between xdg_surface
        based surface roles.

        See the documentation of xdg_surface for more details about what an
        xdg_surface is and how it is used.

        Returns:
            zxdg_surface_v6: The created object
        """

        ...

    def pong(self, serial: int) -> None:
        """
        Respond to a ping event

        A client must respond to a ping event with a pong request or
        the client may be deemed unresponsive. See xdg_shell.ping.

        Args:
            serial: Serial of the ping event
        """

        ...

    def on_ping(self, serial: int) -> None:
        """
        Check if the client is alive.

        Override to handle [`wayland.zxdg_shell_v6.events.ping`][].
        """

        ...

    class events(WaylandEvent):
        def ping(self, serial: int) -> None:
            """
            Check if the client is alive

            The ping event asks the client if it's still alive. Pass the
            serial specified in the event back to the compositor by sending
            a "pong" request back with the specified serial. See xdg_shell.ping.

            Compositors can use this to determine if the client is still
            alive. It's unspecified what will happen if the client doesn't
            respond to the ping request, or in what timeframe. Clients should
            try to respond in a reasonable amount of time.

            A compositor is free to ping in any way it wants, but a client must
            always respond to any xdg_shell object it created.

            Args:
                serial: Pass this to the pong request
            """

            ...

class zxdg_positioner_v6:
    """
    Child surface positioner

    The xdg_positioner provides a collection of rules for the placement of a
    child surface relative to a parent surface. Rules can be defined to ensure
    the child surface remains within the visible area's borders, and to
    specify how the child surface changes its position, such as sliding along
    an axis, or flipping around a rectangle. These positioner-created rules are
    constrained by the requirement that a child surface must intersect with or
    be at least partially adjacent to its parent surface.

    See the various requests for details about possible rules.

    At the time of the request, the compositor makes a copy of the rules
    specified by the xdg_positioner. Thus, after the request is complete the
    xdg_positioner object can be destroyed or reused; further changes to the
    object will have no effect on previous usages.

    For an xdg_positioner object to be considered complete, it must have a
    non-zero size set by set_size, and a non-zero anchor rectangle set by
    set_anchor_rect. Passing an incomplete xdg_positioner object when
    positioning a surface raises an error.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_input: int
        """Invalid input provided"""



    class anchor(IntFlag):
        none: int
        """The center of the anchor rectangle"""

        top: int
        """The top edge of the anchor rectangle"""

        bottom: int
        """The bottom edge of the anchor rectangle"""

        left: int
        """The left edge of the anchor rectangle"""

        right: int
        """The right edge of the anchor rectangle"""



    class gravity(IntFlag):
        none: int
        """Center over the anchor edge"""

        top: int
        """Position above the anchor edge"""

        bottom: int
        """Position below the anchor edge"""

        left: int
        """Position to the left of the anchor edge"""

        right: int
        """Position to the right of the anchor edge"""



    class constraint_adjustment(IntFlag):
        """
        Constraint adjustments

        The constraint adjustment value define ways the compositor will adjust
        the position of the surface, if the unadjusted position would result
        in the surface being partly constrained.

        Whether a surface is considered 'constrained' is left to the compositor
        to determine. For example, the surface may be partly outside the
        compositor's defined 'work area', thus necessitating the child surface's
        position be adjusted until it is entirely inside the work area.

        The adjustments can be combined, according to a defined precedence: 1)
        Flip, 2) Slide, 3) Resize.
        """

        none: int
        """
        Don't move the child surface when constrained
        Don't alter the surface position even if it is constrained on some
        axis, for example partially outside the edge of a monitor.
        """

        slide_x: int
        """
        Move along the x axis until unconstrained
        Slide the surface along the x axis until it is no longer constrained.
        First try to slide towards the direction of the gravity on the x axis
        until either the edge in the opposite direction of the gravity is
        unconstrained or the edge in the direction of the gravity is
        constrained.
        Then try to slide towards the opposite direction of the gravity on the
        x axis until either the edge in the direction of the gravity is
        unconstrained or the edge in the opposite direction of the gravity is
        constrained.
        """

        slide_y: int
        """
        Move along the y axis until unconstrained
        Slide the surface along the y axis until it is no longer constrained.
        First try to slide towards the direction of the gravity on the y axis
        until either the edge in the opposite direction of the gravity is
        unconstrained or the edge in the direction of the gravity is
        constrained.
        Then try to slide towards the opposite direction of the gravity on the
        y axis until either the edge in the direction of the gravity is
        unconstrained or the edge in the opposite direction of the gravity is
        constrained.
        """

        flip_x: int
        """
        Invert the anchor and gravity on the x axis
        Invert the anchor and gravity on the x axis if the surface is
        constrained on the x axis. For example, if the left edge of the
        surface is constrained, the gravity is 'left' and the anchor is
        'left', change the gravity to 'right' and the anchor to 'right'.
        If the adjusted position also ends up being constrained, the resulting
        position of the flip_x adjustment will be the one before the
        adjustment.
        """

        flip_y: int
        """
        Invert the anchor and gravity on the y axis
        Invert the anchor and gravity on the y axis if the surface is
        constrained on the y axis. For example, if the bottom edge of the
        surface is constrained, the gravity is 'bottom' and the anchor is
        'bottom', change the gravity to 'top' and the anchor to 'top'.
        If the adjusted position also ends up being constrained, the resulting
        position of the flip_y adjustment will be the one before the
        adjustment.
        """

        resize_x: int
        """
        Horizontally resize the surface
        Resize the surface horizontally so that it is completely
        unconstrained.
        """

        resize_y: int
        """
        Vertically resize the surface
        Resize the surface vertically so that it is completely unconstrained.
        """



    def destroy(self) -> None:
        """
        Destroy the `xdg_positioner` object

        Notify the compositor that the xdg_positioner will no longer be used.
        """

        ...

    def set_size(self, width: int, height: int) -> None:
        """
        Set the size of the to-be positioned rectangle

        Set the size of the surface that is to be positioned with the positioner
        object. The size is in surface-local coordinates and corresponds to the
        window geometry. See xdg_surface.set_window_geometry.

        If a zero or negative size is set the invalid_input error is raised.

        Args:
            width: Width of positioned rectangle
            height: Height of positioned rectangle
        """

        ...

    def set_anchor_rect(self, x: int, y: int, width: int, height: int) -> None:
        """
        Set the anchor rectangle within the parent surface

        Specify the anchor rectangle within the parent surface that the child
        surface will be placed relative to. The rectangle is relative to the
        window geometry as defined by xdg_surface.set_window_geometry of the
        parent surface. The rectangle must be at least 1x1 large.

        When the xdg_positioner object is used to position a child surface, the
        anchor rectangle may not extend outside the window geometry of the
        positioned child's parent surface.

        If a zero or negative size is set the invalid_input error is raised.

        Args:
            x: X position of anchor rectangle
            y: Y position of anchor rectangle
            width: Width of anchor rectangle
            height: Height of anchor rectangle
        """

        ...

    def set_anchor(self, anchor: zxdg_positioner_v6.anchor) -> None:
        """
        Set anchor rectangle anchor edges

        Defines a set of edges for the anchor rectangle. These are used to
        derive an anchor point that the child surface will be positioned
        relative to. If two orthogonal edges are specified (e.g. 'top' and
        'left'), then the anchor point will be the intersection of the edges
        (e.g. the top left position of the rectangle); otherwise, the derived
        anchor point will be centered on the specified edge, or in the center of
        the anchor rectangle if no edge is specified.

        If two parallel anchor edges are specified (e.g. 'left' and 'right'),
        the invalid_input error is raised.

        Args:
            anchor: Bit mask of anchor edges
        """

        ...

    def set_gravity(self, gravity: zxdg_positioner_v6.gravity) -> None:
        """
        Set child surface gravity

        Defines in what direction a surface should be positioned, relative to
        the anchor point of the parent surface. If two orthogonal gravities are
        specified (e.g. 'bottom' and 'right'), then the child surface will be
        placed in the specified direction; otherwise, the child surface will be
        centered over the anchor point on any axis that had no gravity
        specified.

        If two parallel gravities are specified (e.g. 'left' and 'right'), the
        invalid_input error is raised.

        Args:
            gravity: Bit mask of gravity directions
        """

        ...

    def set_constraint_adjustment(self, constraint_adjustment: int) -> None:
        """
        Set the adjustment to be done when constrained

        Specify how the window should be positioned if the originally intended
        position caused the surface to be constrained, meaning at least
        partially outside positioning boundaries set by the compositor. The
        adjustment is set by constructing a bitmask describing the adjustment to
        be made when the surface is constrained on that axis.

        If no bit for one axis is set, the compositor will assume that the child
        surface should not change its position on that axis when constrained.

        If more than one bit for one axis is set, the order of how adjustments
        are applied is specified in the corresponding adjustment descriptions.

        The default adjustment is none.

        Args:
            constraint_adjustment: Bit mask of constraint adjustments
        """

        ...

    def set_offset(self, x: int, y: int) -> None:
        """
        Set surface position offset

        Specify the surface position offset relative to the position of the
        anchor on the anchor rectangle and the anchor on the surface. For
        example if the anchor of the anchor rectangle is at (x, y), the surface
        has the gravity bottom|right, and the offset is (ox, oy), the calculated
        surface position will be (x + ox, y + oy). The offset position of the
        surface is the one used for constraint testing. See
        set_constraint_adjustment.

        An example use case is placing a popup menu on top of a user interface
        element, while aligning the user interface element of the parent surface
        with some user interface element placed somewhere in the popup surface.

        Args:
            x: Surface position x offset
            y: Surface position y offset
        """

        ...

class zxdg_surface_v6:
    """
    Desktop user interface surface base interface

    An interface that may be implemented by a wl_surface, for
    implementations that provide a desktop-style user interface.

    It provides a base set of functionality required to construct user
    interface elements requiring management by the compositor, such as
    toplevel windows, menus, etc. The types of functionality are split into
    xdg_surface roles.

    Creating an xdg_surface does not set the role for a wl_surface. In order
    to map an xdg_surface, the client must create a role-specific object
    using, e.g., get_toplevel, get_popup. The wl_surface for any given
    xdg_surface can have at most one role, and may not be assigned any role
    not based on xdg_surface.

    A role must be assigned before any other requests are made to the
    xdg_surface object.

    The client must call wl_surface.commit on the corresponding wl_surface
    for the xdg_surface state to take effect.

    Creating an xdg_surface from a wl_surface which has a buffer attached or
    committed is a client error, and any attempts by a client to attach or
    manipulate a buffer prior to the first xdg_surface.configure call must
    also be treated as errors.

    For a surface to be mapped by the compositor, the following conditions
    must be met: (1) the client has assigned an xdg_surface based role to the
    surface, (2) the client has set and committed the xdg_surface state and
    the role dependent state to the surface and (3) the client has committed a
    buffer to the surface.
    """
    object_id = 0
    version = 1

    class error(Enum):
        not_constructed: int
        already_constructed: int
        unconfigured_buffer: int


    def destroy(self) -> None:
        """
        Destroy the `xdg_surface`

        Destroy the xdg_surface object. An xdg_surface must only be destroyed
        	after its role object has been destroyed. If the role object still
                exists when this request is issued, the zxdg_shell_v6.defunct_surfaces
                is raised.
        """

        ...

    def get_toplevel(self) -> zxdg_toplevel_v6:
        """
        Assign the `xdg_toplevel` surface role

        This creates an xdg_toplevel object for the given xdg_surface and gives
        	the associated wl_surface the xdg_toplevel role. If the surface already
                had a role, the zxdg_shell_v6.role error is raised.

        	See the documentation of xdg_toplevel for more details about what an
        	xdg_toplevel is and how it is used.

        Returns:
            zxdg_toplevel_v6: The created object
        """

        ...

    def get_popup(self, parent: zxdg_surface_v6, positioner: zxdg_positioner_v6) -> zxdg_popup_v6:
        """
        Assign the `xdg_popup` surface role

        This creates an xdg_popup object for the given xdg_surface and gives the
        	associated wl_surface the xdg_popup role. If the surface already
                had a role, the zxdg_shell_v6.role error is raised.

        	See the documentation of xdg_popup for more details about what an
        	xdg_popup is and how it is used.

        Returns:
            zxdg_popup_v6: The created object
        """

        ...

    def set_window_geometry(self, x: int, y: int, width: int, height: int) -> None:
        """
        Set the new window geometry

        The window geometry of a surface is its "visible bounds" from the
        user's perspective. Client-side decorations often have invisible
        portions like drop-shadows which should be ignored for the
        purposes of aligning, placing and constraining windows.

        The window geometry is double-buffered state, see wl_surface.commit.

        Once the window geometry of the surface is set, it is not possible to
        unset it, and it will remain the same until set_window_geometry is
        called again, even if a new subsurface or buffer is attached.

        If never set, the value is the full bounds of the surface,
        including any subsurfaces. This updates dynamically on every
        commit. This unset is meant for extremely simple clients.

        The arguments are given in the surface-local coordinate space of
        the wl_surface associated with this xdg_surface.

        The width and height must be greater than zero. Setting an invalid size
        will raise an error. When applied, the effective window geometry will be
        the set window geometry clamped to the bounding rectangle of the
        combined geometry of the surface of the xdg_surface and the associated
        subsurfaces.
        """

        ...

    def ack_configure(self, serial: int) -> None:
        """
        Ack a configure event

        When a configure event is received, if a client commits the
        	surface in response to the configure event, then the client
        	must make an ack_configure request sometime before the commit
        	request, passing along the serial of the configure event.

        	For instance, for toplevel surfaces the compositor might use this
        	information to move a surface to the top left only when the client has
        	drawn itself for the maximized or fullscreen state.

        	If the client receives multiple configure events before it
        	can respond to one, it only has to ack the last configure event.

        	A client is not required to commit immediately after sending
        	an ack_configure request - it may even ack_configure several times
        	before its next surface commit.

        	A client may send multiple ack_configure requests before committing, but
        	only the last request sent before a commit indicates which configure
        	event the client really is responding to.

                If an invalid serial is used, the zxdg_shell_v6.invalid_surface_state
                error is raised.

        Args:
            serial: The serial from the configure event
        """

        ...

    def on_configure(self, serial: int) -> None:
        """
        Suggest a surface change.

        Override to handle [`wayland.zxdg_surface_v6.events.configure`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, serial: int) -> None:
            """
            Suggest a surface change

            The configure event marks the end of a configure sequence. A configure
            sequence is a set of one or more events configuring the state of the
            xdg_surface, including the final xdg_surface.configure event.

            Where applicable, xdg_surface surface roles will during a configure
            sequence extend this event as a latched state sent as events before the
            xdg_surface.configure event. Such events should be considered to make up
            a set of atomically applied configuration states, where the
            xdg_surface.configure commits the accumulated state.

            Clients should arrange their surface for the new states, and then send
            an ack_configure request with the serial sent in this configure event at
            some point before committing the new surface.

            If the client receives multiple configure events before it can respond
            to one, it is free to discard all but the last event it received.

            Args:
                serial: Serial of the configure event
            """

            ...

class zxdg_toplevel_v6:
    """
    Toplevel surface

    This interface defines an xdg_surface role which allows a surface to,
    among other things, set window-like properties such as maximize,
    fullscreen, and minimize, set application-specific metadata like title and
    id, and well as trigger user interactive operations such as interactive
    resize and move.
    """
    object_id = 0
    version = 1

    class resize_edge(Enum):
        """
        Edge values for resizing

        These values are used to indicate which edge of a surface
        is being dragged in a resize operation.
        """

        none: int
        top: int
        bottom: int
        left: int
        top_left: int
        bottom_left: int
        right: int
        top_right: int
        bottom_right: int


    class state(Enum):
        """
        Types of state on the surface

        The different state values used on the surface. This is designed for
        state values like maximized, fullscreen. It is paired with the
        configure event to ensure that both the client and the compositor
        setting the state can be synchronized.

        States set in this way are double-buffered, see wl_surface.commit.
        """

        maximized: int
        """
        The surface is maximized
        The surface is maximized. The window geometry specified in the configure
        event must be obeyed by the client. If the window geometry is not obyed,
        the zxdg_shell_v6.invalid_surface_state error is raised.
        """

        fullscreen: int
        """
        The surface is fullscreen
        The surface is fullscreen. See set_fullscreen for more information.
        """

        resizing: int
        """
        The surface is being resized
        The surface is being resized. The window geometry specified in the
        configure event is a maximum; the client cannot resize beyond it. If the
        client attempts to resize above it, the zxdg_shell_v6.invalid_surface_state
        error is raised.
        Clients that have aspect ratio or cell sizing configuration can use
        a smaller size, however.
        """

        activated: int
        """
        The surface is now activated
        Client window decorations should be painted as if the window is
        active. Do not assume this means that the window actually has
        keyboard or pointer focus.
        """



    def destroy(self) -> None:
        """
        Destroy the `xdg_toplevel`

        Unmap and destroy the window. The window will be effectively
        hidden from the user's point of view, and all state like
        maximization, fullscreen, and so on, will be lost.
        """

        ...

    def set_parent(self, parent: zxdg_toplevel_v6) -> None:
        """
        Set the parent of this surface

        Set the "parent" of this surface. This window should be stacked
        above a parent. The parent surface must be mapped as long as this
        surface is mapped.

        Parent windows should be set on dialogs, toolboxes, or other
        "auxiliary" surfaces, so that the parent is raised when the dialog
        is raised.
        """

        ...

    def set_title(self, title: str) -> None:
        """
        Set surface title

        Set a short title for the surface.

        This string may be used to identify the surface in a task bar,
        window list, or other user interface elements provided by the
        compositor.

        The string must be encoded in UTF-8.
        """

        ...

    def set_app_id(self, app_id: str) -> None:
        """
        Set application id

        Set an application identifier for the surface.

        The app ID identifies the general class of applications to which
        the surface belongs. The compositor can use this to group multiple
        surfaces together, or to determine how to launch a new application.

        For D-Bus activatable applications, the app ID is used as the D-Bus
        service name.

        The compositor shell will try to group application surfaces together
        by their app ID. As a best practice, it is suggested to select app
        ID's that match the basename of the application's .desktop file.
        For example, "org.freedesktop.FooViewer" where the .desktop file is
        "org.freedesktop.FooViewer.desktop".

        See the desktop-entry specification [0] for more details on
        application identifiers and how they relate to well-known D-Bus
        names and .desktop files.

        [0] http://standards.freedesktop.org/desktop-entry-spec/
        """

        ...

    def show_window_menu(self, seat: wl_seat, serial: int, x: int, y: int) -> None:
        """
        Show the window menu

        Clients implementing client-side decorations might want to show
        a context menu when right-clicking on the decorations, giving the
        user a menu that they can use to maximize or minimize the window.

        This request asks the compositor to pop up such a window menu at
        the given position, relative to the local surface coordinates of
        the parent surface. There are no guarantees as to what menu items
        the window menu contains.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
            x: The x position to pop up the window menu at
            y: The y position to pop up the window menu at
        """

        ...

    def move(self, seat: wl_seat, serial: int) -> None:
        """
        Start an interactive move

        Start an interactive, user-driven move of the surface.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event. The passed
        serial is used to determine the type of interactive move (touch,
        pointer, etc).

        The server may ignore move requests depending on the state of
        the surface (e.g. fullscreen or maximized), or if the passed serial
        is no longer valid.

        If triggered, the surface will lose the focus of the device
        (wl_pointer, wl_touch, etc) used for the move. It is up to the
        compositor to visually indicate that the move is taking place, such as
        updating a pointer cursor, during the move. There is no guarantee
        that the device focus will return when the move is completed.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
        """

        ...

    def resize(self, seat: wl_seat, serial: int, edges: int) -> None:
        """
        Start an interactive resize

        Start a user-driven, interactive resize of the surface.

        This request must be used in response to some sort of user action
        like a button press, key press, or touch down event. The passed
        serial is used to determine the type of interactive resize (touch,
        pointer, etc).

        The server may ignore resize requests depending on the state of
        the surface (e.g. fullscreen or maximized).

        If triggered, the client will receive configure events with the
        "resize" state enum value and the expected sizes. See the "resize"
        enum value for more details about what is required. The client
        must also acknowledge configure events using "ack_configure". After
        the resize is completed, the client will receive another "configure"
        event without the resize state.

        If triggered, the surface also will lose the focus of the device
        (wl_pointer, wl_touch, etc) used for the resize. It is up to the
        compositor to visually indicate that the resize is taking place,
        such as updating a pointer cursor, during the resize. There is no
        guarantee that the device focus will return when the resize is
        completed.

        The edges parameter specifies how the surface should be resized,
        and is one of the values of the resize_edge enum. The compositor
        may use this information to update the surface position for
        example when dragging the top left corner. The compositor may also
        use this information to adapt its behavior, e.g. choose an
        appropriate cursor image.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
            edges: Which edge or corner is being dragged
        """

        ...

    def set_max_size(self, width: int, height: int) -> None:
        """
        Set the maximum size

        Set a maximum size for the window.

        	The client can specify a maximum size so that the compositor does
        	not try to configure the window beyond this size.

        	The width and height arguments are in window geometry coordinates.
        	See xdg_surface.set_window_geometry.

        	Values set in this way are double-buffered, see wl_surface.commit.

        	The compositor can use this information to allow or disallow
        	different states like maximize or fullscreen and draw accurate
        	animations.

        	Similarly, a tiling window manager may use this information to
        	place and resize client windows in a more effective way.

        	The client should not rely on the compositor to obey the maximum
        	size. The compositor may decide to ignore the values set by the
        	client and request a larger size.

        	If never set, or a value of zero in the request, means that the
        	client has no expected maximum size in the given dimension.
        	As a result, a client wishing to reset the maximum size
        	to an unspecified state can use zero for width and height in the
        	request.

        	Requesting a maximum size to be smaller than the minimum size of
        	a surface is illegal and will result in a protocol error.

        	The width and height must be greater than or equal to zero. Using
        	strictly negative values for width and height will result in the
                zxdg_shell_v6.invalid_surface_state error being raised.
        """

        ...

    def set_min_size(self, width: int, height: int) -> None:
        """
        Set the minimum size

        Set a minimum size for the window.

        	The client can specify a minimum size so that the compositor does
        	not try to configure the window below this size.

        	The width and height arguments are in window geometry coordinates.
        	See xdg_surface.set_window_geometry.

        	Values set in this way are double-buffered, see wl_surface.commit.

        	The compositor can use this information to allow or disallow
        	different states like maximize or fullscreen and draw accurate
        	animations.

        	Similarly, a tiling window manager may use this information to
        	place and resize client windows in a more effective way.

        	The client should not rely on the compositor to obey the minimum
        	size. The compositor may decide to ignore the values set by the
        	client and request a smaller size.

        	If never set, or a value of zero in the request, means that the
        	client has no expected minimum size in the given dimension.
        	As a result, a client wishing to reset the minimum size
        	to an unspecified state can use zero for width and height in the
        	request.

        	Requesting a minimum size to be larger than the maximum size of
        	a surface is illegal and will result in a protocol error.

        	The width and height must be greater than or equal to zero. Using
        	strictly negative values for width and height will result in the
                zxdg_shell_v6.invalid_surface_state error being raised.
        """

        ...

    def set_maximized(self) -> None:
        """
        Maximize the window

        Maximize the surface.

        	After requesting that the surface should be maximized, the compositor
        	will respond by emitting a configure event with the "maximized" state
        	and the required window geometry. The client should then update its
        	content, drawing it in a maximized state, i.e. without shadow or other
        	decoration outside of the window geometry. The client must also
        	acknowledge the configure when committing the new content (see
        	ack_configure).

        	It is up to the compositor to decide how and where to maximize the
        	surface, for example which output and what region of the screen should
        	be used.

        	If the surface was already maximized, the compositor will still emit
        	a configure event with the "maximized" state.

                Note that unrelated compositor side state changes may cause
                configure events to be emitted at any time, meaning trying to
                match this request to a specific future configure event is
                futile.
        """

        ...

    def unset_maximized(self) -> None:
        """
        Unmaximize the window

        Unmaximize the surface.

        	After requesting that the surface should be unmaximized, the compositor
        	will respond by emitting a configure event without the "maximized"
        	state. If available, the compositor will include the window geometry
        	dimensions the window had prior to being maximized in the configure
        	request. The client must then update its content, drawing it in a
        	regular state, i.e. potentially with shadow, etc. The client must also
        	acknowledge the configure when committing the new content (see
        	ack_configure).

        	It is up to the compositor to position the surface after it was
        	unmaximized; usually the position the surface had before maximizing, if
        	applicable.

        	If the surface was already not maximized, the compositor will still
        	emit a configure event without the "maximized" state.

                Note that unrelated changes in the state of compositor may cause
                configure events to be emitted by the compositor between processing
                this request and emitting corresponding configure event, so trying
                to match the request with the event is futile.
        """

        ...

    def set_fullscreen(self, output: wl_output) -> None:
        """
        Set the window as fullscreen on a monitor

        Make the surface fullscreen.

        You can specify an output that you would prefer to be fullscreen.
        If this value is NULL, it's up to the compositor to choose which
        display will be used to map this surface.

        If the surface doesn't cover the whole output, the compositor will
        position the surface in the center of the output and compensate with
        black borders filling the rest of the output.
        """

        ...

    def unset_fullscreen(self) -> None:
        """"""

        ...

    def set_minimized(self) -> None:
        """
        Set the window as minimized

        Request that the compositor minimize your surface. There is no
        way to know if the surface is currently minimized, nor is there
        any way to unset minimization on this surface.

        If you are looking to throttle redrawing when minimized, please
        instead use the wl_surface.frame event for this, as this will
        also work with live previews on windows in Alt-Tab, Expose or
        similar compositor features.
        """

        ...

    def on_configure(self, width: int, height: int, states: list) -> None:
        """
        Suggest a surface change.

        Override to handle [`wayland.zxdg_toplevel_v6.events.configure`][].
        """

        ...

    def on_close(self) -> None:
        """
        Surface wants to be closed.

        Override to handle [`wayland.zxdg_toplevel_v6.events.close`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, width: int, height: int, states: list) -> None:
            """
            Suggest a surface change

            This configure event asks the client to resize its toplevel surface or
            to change its state. The configured state should not be applied
            immediately. See xdg_surface.configure for details.

            The width and height arguments specify a hint to the window
            about how its surface should be resized in window geometry
            coordinates. See set_window_geometry.

            If the width or height arguments are zero, it means the client
            should decide its own window dimension. This may happen when the
            compositor needs to configure the state of the surface but doesn't
            have any information about any previous or expected dimension.

            The states listed in the event specify how the width/height
            arguments should be interpreted, and possibly how it should be
            drawn.

            Clients must send an ack_configure in response to this event. See
            xdg_surface.configure and xdg_surface.ack_configure for details.
            """

            ...

        def close(self) -> None:
            """
            Surface wants to be closed

            The close event is sent by the compositor when the user
            wants the surface to be closed. This should be equivalent to
            the user clicking the close button in client-side decorations,
            if your application has any.

            This is only a request that the user intends to close the
            window. The client may choose to ignore this request, or show
            a dialog to ask the user to save their data, etc.
            """

            ...

class zxdg_popup_v6:
    """
    Short-lived, popup surfaces for menus

    A popup surface is a short-lived, temporary surface. It can be used to
    implement for example menus, popovers, tooltips and other similar user
    interface concepts.

    A popup can be made to take an explicit grab. See xdg_popup.grab for
    details.

    When the popup is dismissed, a popup_done event will be sent out, and at
    the same time the surface will be unmapped. See the xdg_popup.popup_done
    event for details.

    Explicitly destroying the xdg_popup object will also dismiss the popup and
    unmap the surface. Clients that want to dismiss the popup when another
    surface of their own is clicked should dismiss the popup using the destroy
    request.

    The parent surface must have either the xdg_toplevel or xdg_popup surface
    role.

    A newly created xdg_popup will be stacked on top of all previously created
    xdg_popup surfaces associated with the same xdg_toplevel.

    The parent of an xdg_popup must be mapped (see the xdg_surface
    description) before the xdg_popup itself.

    The x and y arguments passed when creating the popup object specify
    where the top left of the popup should be placed, relative to the
    local surface coordinates of the parent surface. See
    xdg_surface.get_popup. An xdg_popup must intersect with or be at least
    partially adjacent to its parent surface.

    The client must call wl_surface.commit on the corresponding wl_surface
    for the xdg_popup state to take effect.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_grab: int
        """Tried to grab after being mapped"""



    def destroy(self) -> None:
        """
        Remove `xdg_popup` interface

        This destroys the popup. Explicitly destroying the xdg_popup
        object will also dismiss the popup, and unmap the surface.

        If this xdg_popup is not the "topmost" popup, a protocol error
        will be sent.
        """

        ...

    def grab(self, seat: wl_seat, serial: int) -> None:
        """
        Make the popup take an explicit grab

        This request makes the created popup take an explicit grab. An explicit
        grab will be dismissed when the user dismisses the popup, or when the
        client destroys the xdg_popup. This can be done by the user clicking
        outside the surface, using the keyboard, or even locking the screen
        through closing the lid or a timeout.

        If the compositor denies the grab, the popup will be immediately
        dismissed.

        This request must be used in response to some sort of user action like a
        button press, key press, or touch down event. The serial number of the
        event should be passed as 'serial'.

        The parent of a grabbing popup must either be an xdg_toplevel surface or
        another xdg_popup with an explicit grab. If the parent is another
        xdg_popup it means that the popups are nested, with this popup now being
        the topmost popup.

        Nested popups must be destroyed in the reverse order they were created
        in, e.g. the only popup you are allowed to destroy at all times is the
        topmost one.

        When compositors choose to dismiss a popup, they may dismiss every
        nested grabbing popup as well. When a compositor dismisses popups, it
        will follow the same dismissing order as required from the client.

        The parent of a grabbing popup must either be another xdg_popup with an
        active explicit grab, or an xdg_popup or xdg_toplevel, if there are no
        explicit grabs already taken.

        If the topmost grabbing popup is destroyed, the grab will be returned to
        the parent of the popup, if that parent previously had an explicit grab.

        If the parent is a grabbing popup which has already been dismissed, this
        popup will be immediately dismissed. If the parent is a popup that did
        not take an explicit grab, an error will be raised.

        During a popup grab, the client owning the grab will receive pointer
        and touch events for all their surfaces as normal (similar to an
        "owner-events" grab in X11 parlance), while the top most grabbing popup
        will always have keyboard focus.

        Args:
            seat: The `wl_seat` of the user event
            serial: The serial of the user event
        """

        ...

    def on_configure(self, x: int, y: int, width: int, height: int) -> None:
        """
        Configure the popup surface.

        Override to handle [`wayland.zxdg_popup_v6.events.configure`][].
        """

        ...

    def on_popup_done(self) -> None:
        """
        Popup interaction is done.

        Override to handle [`wayland.zxdg_popup_v6.events.popup_done`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, x: int, y: int, width: int, height: int) -> None:
            """
            Configure the popup surface

            This event asks the popup surface to configure itself given the
            configuration. The configured state should not be applied immediately.
            See xdg_surface.configure for details.

            The x and y arguments represent the position the popup was placed at
            given the xdg_positioner rule, relative to the upper left corner of the
            window geometry of the parent surface.

            Args:
                x: X position relative to parent surface window geometry
                y: Y position relative to parent surface window geometry
                width: Window geometry width
                height: Window geometry height
            """

            ...

        def popup_done(self) -> None:
            """
            Popup interaction is done

            The popup_done event is sent out when a popup is dismissed by the
            compositor. The client should destroy the xdg_popup object at this
            point.
            """

            ...

class zwp_xwayland_keyboard_grab_manager_v1:
    """
    Context object for keyboard grab manager

    A global interface used for grabbing the keyboard.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the keyboard grab manager

        Destroy the keyboard grab manager.
        """

        ...

    def grab_keyboard(self, surface: wl_surface, seat: wl_seat) -> zwp_xwayland_keyboard_grab_v1:
        """
        Grab the keyboard to a surface

        The grab_keyboard request asks for a grab of the keyboard, forcing
        the keyboard focus for the given seat upon the given surface.

        The protocol provides no guarantee that the grab is ever satisfied,
        and does not require the compositor to send an error if the grab
        cannot ever be satisfied. It is thus possible to request a keyboard
        grab that will never be effective.

        The protocol:

        * does not guarantee that the grab itself is applied for a surface,
          the grab request may be silently ignored by the compositor,
        * does not guarantee that any events are sent to this client even
          if the grab is applied to a surface,
        * does not guarantee that events sent to this client are exhaustive,
          a compositor may filter some events for its own consumption,
        * does not guarantee that events sent to this client are continuous,
          a compositor may change and reroute keyboard events while the grab
          is nominally active.

        Args:
            surface: Surface to report keyboard events to
            seat: The seat for which the keyboard should be grabbed

        Returns:
            zwp_xwayland_keyboard_grab_v1: The created object
        """

        ...

class zwp_xwayland_keyboard_grab_v1:
    """
    Interface for grabbing the keyboard

    A global interface used for grabbing the keyboard.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the grabbed keyboard object

        Destroy the grabbed keyboard object. If applicable, the compositor
        will ungrab the keyboard.
        """

        ...

class hyprland_ctm_control_manager_v1:
    """
    Manager to control ctms

    This object is a manager which offers requests to control CTMs.

    If any changes are done, once this object is destroyed, CTMs are reset back to
    an identity matrix.
    """
    object_id = 0
    version = 2

    class error(Enum):
        invalid_matrix: int
        """The matrix values are invalid."""



    def set_ctm_for_output(self, output: wl_output, mat0: float, mat1: float, mat2: float, mat3: float, mat4: float, mat5: float, mat6: float, mat7: float, mat8: float) -> None:
        """
        Set the ctm of an output

        Set a CTM for a wl_output.

        This state is not applied immediately; clients must call .commit to
        apply any pending changes.

        The provided values describe a 3x3 Row-Major CTM with values in the range of [0, ∞)

        Passing values outside of the range will raise an invalid_matrix error.

        The default value of the CTM is an identity matrix.

        If an output doesn't get a CTM set with set_ctm_for_output and commit is called,
        that output will get its CTM reset to an identity matrix.
        """

        ...

    def commit(self) -> None:
        """
        Commit the pending state

        Commits the pending state(s) set by set_ctm_for_output.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.

        The CTMs of all outputs will be reset to an identity matrix.
        """

        ...

    def on_blocked(self) -> None:
        """
        This event is sent if another manager was bound by any client.

        Override to handle [`wayland.hyprland_ctm_control_manager_v1.events.blocked`][].
        """

        ...

    class events(WaylandEvent):
        def blocked(self) -> None:
            """
            This event is sent if another manager was bound by any client
            at the time the current manager was bound.
            Any set_ctm_for_output requests from a blocked manager will be
            silently ignored by the compositor.

            The client should destroy the manager after receiving this event.
            """

            ...

class hyprland_focus_grab_manager_v1:
    """
    Manager for focus grab objects

    This interface allows a client to create surface grab objects.
    """
    object_id = 0
    version = 1


    def create_grab(self) -> hyprland_focus_grab_v1:
        """
        Create a focus grab object

        Create a surface grab object.

        Returns:
            hyprland_focus_grab_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the focus grab manager

        Destroy the focus grab manager.
        This doesn't destroy existing focus grab objects.
        """

        ...

class hyprland_focus_grab_v1:
    """
    Input focus limiter

    This interface restricts input focus to a specified whitelist of
    surfaces as long as the focus grab object exists and has at least
    one comitted surface.

    Mouse and touch events inside a whitelisted surface will be passed
    to the surface normally, while events outside of a whitelisted surface
    will clear the grab object. Keyboard events will be passed to the client
    and a compositor-picked surface in the whitelist will receive a
    wl_keyboard::enter event if a whitelisted surface is not already entered.

    Upon meeting implementation-defined criteria usually meaning a mouse or
    touch input outside of any whitelisted surfaces, the compositor will
    clear the whitelist, rendering the grab inert and sending the cleared
    event. The same will happen if another focus grab or similar action
    is started at the compositor's discretion.
    """
    object_id = 0
    version = 1


    def add_surface(self, surface: wl_surface) -> None:
        """
        Add a surface to the focus whitelist

        Add a surface to the whitelist. Destroying the surface is treated the
        same as an explicit call to remove_surface and duplicate additions are
        ignored.

        Does not take effect until commit is called.
        """

        ...

    def remove_surface(self, surface: wl_surface) -> None:
        """
        Remove a surface from the focus whitelist

        Remove a surface from the whitelist. Destroying the surface is treated
        the same as an explicit call to this function.

        If the grab was active and the removed surface was entered by the
        keyboard, another surface will be entered on commit.

        Does not take effect until commit is called.
        """

        ...

    def commit(self) -> None:
        """
        Commit the focus whitelist

        Commit pending changes to the surface whitelist.

        If the list previously had no entries and now has at least one, the grab
        will start. If it previously had entries and now has none, the grab will
        become inert.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the focus grab

        Destroy the grab object and remove the grab if active.
        """

        ...

    def on_cleared(self) -> None:
        """
        The focus grab was cleared.

        Override to handle [`wayland.hyprland_focus_grab_v1.events.cleared`][].
        """

        ...

    class events(WaylandEvent):
        def cleared(self) -> None:
            """
            The focus grab was cleared

            Sent when an active grab is cancelled by the compositor,
            regardless of cause.
            """

            ...

class hyprland_global_shortcuts_manager_v1:
    """
    Manager to register global shortcuts

    This object is a manager which offers requests to create global shortcuts.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_taken: int
        """The `app_id` + id combination has already been registered."""



    def register_shortcut(self, id: str, app_id: str, description: str, trigger_description: str) -> hyprland_global_shortcut_v1:
        """
        Register a shortcut

        Register a new global shortcut.

        A global shortcut is anonymous, meaning the app does not know what key(s) trigger it.

        The shortcut's keybinding shall be dealt with by the compositor.

        In the case of a duplicate app_id + id combination, the already_taken protocol error is raised.

        Args:
            id: A unique id for the shortcut
            app_id: The `app_id` of the application requesting the shortcut
            description: User-readable text describing what the shortcut does.
            trigger_description: User-readable text describing how to trigger the shortcut for the client to render.

        Returns:
            hyprland_global_shortcut_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class hyprland_global_shortcut_v1:
    """
    A shortcut

    This object represents a single shortcut.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Delete this object, used or not

        Destroys the shortcut. Can be sent at any time by the client.
        """

        ...

    def on_pressed(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Keystroke pressed.

        Override to handle [`wayland.hyprland_global_shortcut_v1.events.pressed`][].
        """

        ...

    def on_released(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Keystroke released.

        Override to handle [`wayland.hyprland_global_shortcut_v1.events.released`][].
        """

        ...

    class events(WaylandEvent):
        def pressed(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Keystroke pressed

            The keystroke was pressed.

            tv_ values hold the timestamp of the occurrence.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

        def released(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Keystroke released

            The keystroke was released.

            tv_ values hold the timestamp of the occurrence.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

class hyprland_lock_notifier_v1:
    """
    Lock notification manager

    This interface allows clients to monitor whether the wayland session is
    locked or unlocked.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the manager

        Destroy the manager object. All objects created via this interface
        remain valid.
        """

        ...

    def get_lock_notification(self) -> hyprland_lock_notification_v1:
        """
        Create a notification object

        Create a new lock notification object.

        If the session is already locked when calling this method,
        the locked event shall be sent immediately.

        Returns:
            hyprland_lock_notification_v1: The created object
        """

        ...

class hyprland_lock_notification_v1:
    """
    Lock notification

    This interface is used by the compositor to send lock notification events
    to clients.

    Typically the "locked" and "unlocked" events are emitted when a client
    locks/unlocks the session via ext-session-lock, but the compositor may
    choose to send notifications for any other locking mechanisms.

    The compositor must notfiy after possible transition periods
    between locked and unlocked states of the session.
    In the context of ext-session-lock, that means the "locked" event is
    expected to be sent after the session-lock client has presented
    a lock screen frame on every output, which corresponds to the "locked"
    event of ext-session-lock.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the notification object

        Destroy the notification object.
        """

        ...

    def on_locked(self) -> None:
        """
        Session is locked.

        Override to handle [`wayland.hyprland_lock_notification_v1.events.locked`][].
        """

        ...

    def on_unlocked(self) -> None:
        """
        Session is no longer locked.

        Override to handle [`wayland.hyprland_lock_notification_v1.events.unlocked`][].
        """

        ...

    class events(WaylandEvent):
        def locked(self) -> None:
            """
            Session is locked

            This event is sent when the wayland session is locked.

            It's a compositor protocol error to send this event twice without an
            unlock event in-between.
            """

            ...

        def unlocked(self) -> None:
            """
            Session is no longer locked

            This event is sent when the wayland session is unlocked.

            It's a compositor protocol error to send this event twice without an
            locked event in-between. It's a compositor protocol error to send this
            event prior to any locked event.
            """

            ...

class hyprland_surface_manager_v1:
    """
    Manager for hyprland surface objects

    This interface allows a client to create hyprland surface objects.
    """
    object_id = 0
    version = 2

    class error(Enum):
        already_constructed: int
        """`wl_surface` already has a hyprland surface object"""



    def get_hyprland_surface(self, surface: wl_surface) -> hyprland_surface_v1:
        """
        Create a hyprland surface object

        Create a hyprland surface object for the given wayland surface.

        If the wl_surface already has an associated hyprland_surface_v1 object,
        even from a different manager, creation is a protocol error.

        Returns:
            hyprland_surface_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the hyprland surface manager

        Destroy the surface manager.
        This does not destroy existing surface objects.
        """

        ...

class hyprland_surface_v1:
    """
    Hyprland-specific `wl_surface` properties

    This interface allows access to hyprland-specific properties of a wl_surface.

    Once the wl_surface has been destroyed, the hyprland surface object must be
    destroyed as well. All other operations are a protocol error.
    """
    object_id = 0
    version = 2

    class error(Enum):
        no_surface: int
        """`wl_surface` was destroyed"""

        out_of_range: int
        """Given opacity was not in the range 0.0 - 1.0 (inclusive)"""



    def set_opacity(self, opacity: float) -> None:
        """
        Set the overall opacity of the surface

        Sets a multiplier for the overall opacity of the surface.
        This multiplier applies to visual effects such as blur behind the surface
        in addition to the surface's content.

        The default value is 1.0.
        Setting a value outside of the range 0.0 - 1.0 (inclusive) is a protocol error.
        Does not take effect until wl_surface.commit is called.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the hyprland surface interface

        Destroy the hyprland surface object, resetting properties provided
        by this interface to their default values on the next wl_surface.commit.
        """

        ...

    def set_visible_region(self, region: wl_region) -> None:
        """
        Set the visible region of the surface

        This request sets the region of the surface that contains visible content.
        Visible content refers to content that has an alpha value greater than zero.

        The visible region is an optimization hint for the compositor that lets it
        avoid drawing parts of the surface that are not visible. Setting a visible region
        that does not contain all content in the surface may result in missing content
        not being drawn.

        The visible region is specified in buffer-local coordinates.

        The compositor ignores the parts of the visible region that fall outside of the surface.
        When all parts of the region fall outside of the buffer geometry, the compositor may
        avoid rendering the surface entirely.

        The initial value for the visible region is empty. Setting the
        visible region has copy semantics, and the wl_region object can be destroyed immediately.
        A NULL wl_region causes the visible region to be set to empty.

        Does not take effect until wl_surface.commit is called.
        """

        ...

class hyprland_toplevel_export_manager_v1:
    """
    Manager to inform clients and begin capturing

    This object is a manager which offers requests to start capturing from a
    source.
    """
    object_id = 0
    version = 2


    def capture_toplevel(self, overlay_cursor: int, handle: int) -> hyprland_toplevel_export_frame_v1:
        """
        Capture a toplevel

        Capture the next frame of a toplevel. (window)

        The captured frame will not contain any server-side decorations and will
        ignore the compositor-set geometry, like e.g. rounded corners.

        It will contain all the subsurfaces and popups, however the latter will be clipped
        to the geometry of the base surface.

        The handle parameter refers to the address of the window as seen in `hyprctl clients`.
        For example, for d161e7b0 it would be 3512854448.

        Args:
            overlay_cursor: Composite cursor onto the frame
            handle: The handle of the toplevel (window) to be captured

        Returns:
            hyprland_toplevel_export_frame_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

    def capture_toplevel_with_wlr_toplevel_handle(self, overlay_cursor: int, handle: zwlr_foreign_toplevel_handle_v1) -> hyprland_toplevel_export_frame_v1:
        """
        Capture a toplevel

        Same as capture_toplevel, but with a zwlr_foreign_toplevel_handle_v1 handle.

        Args:
            overlay_cursor: Composite cursor onto the frame
            handle: The zwlr_foreign_toplevel_handle_v1 handle of the toplevel to be captured

        Returns:
            hyprland_toplevel_export_frame_v1: The created object
        """

        ...

class hyprland_toplevel_export_frame_v1:
    """
    A frame ready for copy

    This object represents a single frame.

    When created, a series of buffer events will be sent, each representing a
    supported buffer type. The "buffer_done" event is sent afterwards to
    indicate that all supported buffer types have been enumerated. The client
    will then be able to send a "copy" request. If the capture is successful,
    the compositor will send a "flags" followed by a "ready" event.

    wl_shm buffers are always supported, ie. the "buffer" event is guaranteed to be sent.

    If the capture failed, the "failed" event is sent. This can happen anytime
    before the "ready" event.

    Once either a "ready" or a "failed" event is received, the client should
    destroy the frame.
    """
    object_id = 0
    version = 2

    class error(Enum):
        already_used: int
        """The object has already been used to copy a `wl_buffer`"""

        invalid_buffer: int
        """Buffer attributes are invalid"""



    class flags(IntFlag):
        y_invert: int
        """Contents are y-inverted"""



    def copy(self, buffer: wl_buffer, ignore_damage: int) -> None:
        """
        Copy the frame

        Copy the frame to the supplied buffer. The buffer must have the
        correct size, see hyprland_toplevel_export_frame_v1.buffer and
        hyprland_toplevel_export_frame_v1.linux_dmabuf. The buffer needs to have a
        supported format.

        If the frame is successfully copied, a "flags" and a "ready" event is
        sent. Otherwise, a "failed" event is sent.

        This event will wait for appropriate damage to be copied, unless the ignore_damage
        arg is set to a non-zero value.
        """

        ...

    def destroy(self) -> None:
        """
        Delete this object, used or not

        Destroys the frame. This request can be sent at any time by the client.
        """

        ...

    def on_buffer(self, format: wl_shm.format, width: int, height: int, stride: int) -> None:
        """
        `wl_shm` buffer information.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.buffer`][].
        """

        ...

    def on_damage(self, x: int, y: int, width: int, height: int) -> None:
        """
        Carries the coordinates of the damaged region.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.damage`][].
        """

        ...

    def on_flags(self, flags: hyprland_toplevel_export_frame_v1.flags) -> None:
        """
        Frame flags.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.flags`][].
        """

        ...

    def on_ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Indicates frame is available for reading.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.ready`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Frame copy failed.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.failed`][].
        """

        ...

    def on_linux_dmabuf(self, format: int, width: int, height: int) -> None:
        """
        Linux-dmabuf buffer information.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.linux_dmabuf`][].
        """

        ...

    def on_buffer_done(self) -> None:
        """
        All buffer types reported.

        Override to handle [`wayland.hyprland_toplevel_export_frame_v1.events.buffer_done`][].
        """

        ...

    class events(WaylandEvent):
        def buffer(self, format: wl_shm.format, width: int, height: int, stride: int) -> None:
            """
            `wl_shm` buffer information

            Provides information about wl_shm buffer parameters that need to be
            used for this frame. This event is sent once after the frame is created
            if wl_shm buffers are supported.

            Args:
                format: Buffer format
                width: Buffer width
                height: Buffer height
                stride: Buffer stride
            """

            ...

        def damage(self, x: int, y: int, width: int, height: int) -> None:
            """
            Carries the coordinates of the damaged region

            This event is sent right before the ready event when ignore_damage was
            not set. It may be generated multiple times for each copy
            request.

            The arguments describe a box around an area that has changed since the
            last copy request that was derived from the current screencopy manager
            instance.

            The union of all regions received between the call to copy
            and a ready event is the total damage since the prior ready event.

            Args:
                x: Damaged x coordinates
                y: Damaged y coordinates
                width: Current width
                height: Current height
            """

            ...

        def flags(self, flags: hyprland_toplevel_export_frame_v1.flags) -> None:
            """
            Frame flags

            Provides flags about the frame. This event is sent once before the
            "ready" event.

            Args:
                flags: Frame flags
            """

            ...

        def ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Indicates frame is available for reading

            Called as soon as the frame is copied, indicating it is available
            for reading. This event includes the time at which presentation happened
            at.

            The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples,
            each component being an unsigned 32-bit value. Whole seconds are in
            tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo,
            and the additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999]. The seconds part
            may have an arbitrary offset at start.

            After receiving this event, the client should destroy the object.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

        def failed(self) -> None:
            """
            Frame copy failed

            This event indicates that the attempted frame copy has failed.

            After receiving this event, the client should destroy the object.
            """

            ...

        def linux_dmabuf(self, format: int, width: int, height: int) -> None:
            """
            Linux-dmabuf buffer information

            Provides information about linux-dmabuf buffer parameters that need to
            be used for this frame. This event is sent once after the frame is
            created if linux-dmabuf buffers are supported.

            Args:
                format: Fourcc pixel format
                width: Buffer width
                height: Buffer height
            """

            ...

        def buffer_done(self) -> None:
            """
            All buffer types reported

            This event is sent once after all buffer events have been sent.

            The client should proceed to create a buffer of one of the supported
            types, and send a "copy" request.
            """

            ...

class hyprland_toplevel_mapping_manager_v1:
    """
    Manager to request toplevel mappings

    This object is a manager which offers requests to retrieve a window address
    for a toplevel.
    """
    object_id = 0
    version = 1


    def get_window_for_toplevel(self, toplevel: ext_foreign_toplevel_handle_v1) -> hyprland_toplevel_window_mapping_handle_v1:
        """
        Get window address for toplevel

        Get the window address for a toplevel.

        Args:
            toplevel: Toplevel to get the window address for

        Returns:
            hyprland_toplevel_window_mapping_handle_v1: The created object
        """

        ...

    def get_window_for_toplevel_wlr(self, toplevel: zwlr_foreign_toplevel_handle_v1) -> hyprland_toplevel_window_mapping_handle_v1:
        """
        Get window address for wlr toplevel

        Get the window address for a wlr toplevel.

        Args:
            toplevel: Wlr toplevel to get the window address for

        Returns:
            hyprland_toplevel_window_mapping_handle_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their appropriate destroy
        request has been called.
        """

        ...

class hyprland_toplevel_window_mapping_handle_v1:
    """
    Toplevel to window mapping

    This object represents a mapping of a (wlr) toplevel to a window address.

    Once created, the `window_address` event will be sent containing the address of the window
    associated with the toplevel.
    Should the mapping fail, the `failed` event will be sent.
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy handle

        Destroy the handle. This request can be sent at any time by the client.
        """

        ...

    def on_window_address(self, address_hi: int, address: int) -> None:
        """
        Address of the window.

        Override to handle [`wayland.hyprland_toplevel_window_mapping_handle_v1.events.window_address`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Mapping failed.

        Override to handle [`wayland.hyprland_toplevel_window_mapping_handle_v1.events.failed`][].
        """

        ...

    class events(WaylandEvent):
        def window_address(self, address_hi: int, address: int) -> None:
            """
            Address of the window

            The full 64bit window address. The `address` field contains the lower 32 bits whilst the
            `address_hi` contains the upper 32 bits

            Args:
                address_hi: Upper 32 bits of the window address
                address: Lower 32 bits of the window address
            """

            ...

        def failed(self) -> None:
            """
            Mapping failed

            The mapping of the toplevel to a window address failed. Most likely the window does not
            exist (anymore).
            """

            ...

class zwlr_data_control_manager_v1:
    """
    Manager to control data devices

    This interface is a manager that allows creating per-seat data device
    controls.
    """
    object_id = 0
    version = 2


    def create_data_source(self) -> zwlr_data_control_source_v1:
        """
        Create a new data source

        Create a new data source.

        Returns:
            zwlr_data_control_source_v1: The created object
        """

        ...

    def get_data_device(self, seat: wl_seat) -> zwlr_data_control_device_v1:
        """
        Get a data device for a seat

        Create a data device that can be used to manage a seat's selection.

        Returns:
            zwlr_data_control_device_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class zwlr_data_control_device_v1:
    """
    Manage a data device for a seat

    This interface allows a client to manage a seat's selection.

    When the seat is destroyed, this object becomes inert.
    """
    object_id = 0
    version = 2

    class error(Enum):
        used_source: int
        """Source given to `set_selection` or `set_primary_selection` was already used before"""



    def set_selection(self, source: zwlr_data_control_source_v1) -> None:
        """
        Copy data to the selection

        This request asks the compositor to set the selection to the data from
        the source on behalf of the client.

        The given source may not be used in any further set_selection or
        set_primary_selection requests. Attempting to use a previously used
        source is a protocol error.

        To unset the selection, set the source to NULL.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this data device

        Destroys the data device object.
        """

        ...

    def set_primary_selection(self, source: zwlr_data_control_source_v1) -> None:
        """
        Copy data to the primary selection

        This request asks the compositor to set the primary selection to the
        data from the source on behalf of the client.

        The given source may not be used in any further set_selection or
        set_primary_selection requests. Attempting to use a previously used
        source is a protocol error.

        To unset the primary selection, set the source to NULL.

        The compositor will ignore this request if it does not support primary
        selection.
        """

        ...

    def on_data_offer(self, id: zwlr_data_control_offer_v1) -> None:
        """
        Introduce a new `wlr_data_control_offer`.

        Override to handle [`wayland.zwlr_data_control_device_v1.events.data_offer`][].
        """

        ...

    def on_selection(self, id: zwlr_data_control_offer_v1) -> None:
        """
        Advertise new selection.

        Override to handle [`wayland.zwlr_data_control_device_v1.events.selection`][].
        """

        ...

    def on_finished(self) -> None:
        """
        This data control is no longer valid.

        Override to handle [`wayland.zwlr_data_control_device_v1.events.finished`][].
        """

        ...

    def on_primary_selection(self, id: zwlr_data_control_offer_v1) -> None:
        """
        Advertise new primary selection.

        Override to handle [`wayland.zwlr_data_control_device_v1.events.primary_selection`][].
        """

        ...

    class events(WaylandEvent):
        def data_offer(self, id: zwlr_data_control_offer_v1) -> None:
            """
            Introduce a new `wlr_data_control_offer`

            The data_offer event introduces a new wlr_data_control_offer object,
            which will subsequently be used in either the
            wlr_data_control_device.selection event (for the regular clipboard
            selections) or the wlr_data_control_device.primary_selection event (for
            the primary clipboard selections). Immediately following the
            wlr_data_control_device.data_offer event, the new data_offer object
            will send out wlr_data_control_offer.offer events to describe the MIME
            types it offers.
            """

            ...

        def selection(self, id: zwlr_data_control_offer_v1) -> None:
            """
            Advertise new selection

            The selection event is sent out to notify the client of a new
            wlr_data_control_offer for the selection for this device. The
            wlr_data_control_device.data_offer and the wlr_data_control_offer.offer
            events are sent out immediately before this event to introduce the data
            offer object. The selection event is sent to a client when a new
            selection is set. The wlr_data_control_offer is valid until a new
            wlr_data_control_offer or NULL is received. The client must destroy the
            previous selection wlr_data_control_offer, if any, upon receiving this
            event.

            The first selection event is sent upon binding the
            wlr_data_control_device object.
            """

            ...

        def finished(self) -> None:
            """
            This data control is no longer valid

            This data control object is no longer valid and should be destroyed by
            the client.
            """

            ...

        def primary_selection(self, id: zwlr_data_control_offer_v1) -> None:
            """
            Advertise new primary selection

            The primary_selection event is sent out to notify the client of a new
            wlr_data_control_offer for the primary selection for this device. The
            wlr_data_control_device.data_offer and the wlr_data_control_offer.offer
            events are sent out immediately before this event to introduce the data
            offer object. The primary_selection event is sent to a client when a
            new primary selection is set. The wlr_data_control_offer is valid until
            a new wlr_data_control_offer or NULL is received. The client must
            destroy the previous primary selection wlr_data_control_offer, if any,
            upon receiving this event.

            If the compositor supports primary selection, the first
            primary_selection event is sent upon binding the
            wlr_data_control_device object.
            """

            ...

class zwlr_data_control_source_v1:
    """
    Offer to transfer data

    The wlr_data_control_source object is the source side of a
    wlr_data_control_offer. It is created by the source client in a data
    transfer and provides a way to describe the offered data and a way to
    respond to requests to transfer the data.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_offer: int
        """Offer sent after `wlr_data_control_device`.`set_selection`"""



    def offer(self, mime_type: str) -> None:
        """
        Add an offered mime type

        This request adds a MIME type to the set of MIME types advertised to
        targets. Can be called several times to offer multiple types.

        Calling this after wlr_data_control_device.set_selection is a protocol
        error.

        Args:
            mime_type: Mime type offered by the data source
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this source

        Destroys the data source object.
        """

        ...

    def on_send(self, mime_type: str, fd: fd) -> None:
        """
        Send the data.

        Override to handle [`wayland.zwlr_data_control_source_v1.events.send`][].
        """

        ...

    def on_cancelled(self) -> None:
        """
        Selection was cancelled.

        Override to handle [`wayland.zwlr_data_control_source_v1.events.cancelled`][].
        """

        ...

    class events(WaylandEvent):
        def send(self, mime_type: str, fd: fd) -> None:
            """
            Send the data

            Request for data from the client. Send the data as the specified MIME
            type over the passed file descriptor, then close it.

            Args:
                mime_type: Mime type for the data
                fd: File descriptor for the data
            """

            ...

        def cancelled(self) -> None:
            """
            Selection was cancelled

            This data source is no longer valid. The data source has been replaced
            by another data source.

            The client should clean up and destroy this data source.
            """

            ...

class zwlr_data_control_offer_v1:
    """
    Offer to transfer data

    A wlr_data_control_offer represents a piece of data offered for transfer
    by another client (the source client). The offer describes the different
    MIME types that the data can be converted to and provides the mechanism
    for transferring the data directly from the source client.
    """
    object_id = 0
    version = 1


    def receive(self, mime_type: str, fd: fd) -> None:
        """
        Request that the data is transferred

        To transfer the offered data, the client issues this request and
        indicates the MIME type it wants to receive. The transfer happens
        through the passed file descriptor (typically created with the pipe
        system call). The source client writes the data in the MIME type
        representation requested and then closes the file descriptor.

        The receiving client reads from the read end of the pipe until EOF and
        then closes its end, at which point the transfer is complete.

        This request may happen multiple times for different MIME types.

        Args:
            mime_type: Mime type desired by receiver
            fd: File descriptor for data transfer
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this offer

        Destroys the data offer object.
        """

        ...

    def on_offer(self, mime_type: str) -> None:
        """
        Advertise offered mime type.

        Override to handle [`wayland.zwlr_data_control_offer_v1.events.offer`][].
        """

        ...

    class events(WaylandEvent):
        def offer(self, mime_type: str) -> None:
            """
            Advertise offered mime type

            Sent immediately after creating the wlr_data_control_offer object.
            One event per offered MIME type.

            Args:
                mime_type: Offered mime type
            """

            ...

class zwlr_export_dmabuf_manager_v1:
    """
    Manager to inform clients and begin capturing

    This object is a manager with which to start capturing from sources.
    """
    object_id = 0
    version = 1


    def capture_output(self, overlay_cursor: int, output: wl_output) -> zwlr_export_dmabuf_frame_v1:
        """
        Capture a frame from an output

        Capture the next frame of an entire output.

        Args:
            overlay_cursor: Include custom client hardware cursor on top of the frame

        Returns:
            zwlr_export_dmabuf_frame_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class zwlr_export_dmabuf_frame_v1:
    """
    A dma-buf frame

    This object represents a single DMA-BUF frame.

    If the capture is successful, the compositor will first send a "frame"
    event, followed by one or several "object". When the frame is available
    for readout, the "ready" event is sent.

    If the capture failed, the "cancel" event is sent. This can happen anytime
    before the "ready" event.

    Once either a "ready" or a "cancel" event is received, the client should
    destroy the frame. Once an "object" event is received, the client is
    responsible for closing the associated file descriptor.

    All frames are read-only and may not be written into or altered.
    """
    object_id = 0
    version = 1

    class flags(Enum):
        """
        Frame flags

        Special flags that should be respected by the client.
        """

        transient: int
        """Clients should copy frame before processing"""



    class cancel_reason(Enum):
        """
        Cancel reason

        Indicates reason for cancelling the frame.
        """

        temporary: int
        """Temporary error, source will produce more frames"""

        permanent: int
        """Fatal error, source will not produce frames"""

        resizing: int
        """Temporary error, source will produce more frames"""



    def destroy(self) -> None:
        """
        Delete this object, used or not

        Unreferences the frame. This request must be called as soon as its no
        longer used.

        It can be called at any time by the client. The client will still have
        to close any FDs it has been given.
        """

        ...

    def on_frame(self, width: int, height: int, offset_x: int, offset_y: int, buffer_flags: int, flags: zwlr_export_dmabuf_frame_v1.flags, format: int, mod_high: int, mod_low: int, num_objects: int) -> None:
        """
        A frame description.

        Override to handle [`wayland.zwlr_export_dmabuf_frame_v1.events.frame`][].
        """

        ...

    def on_object(self, index: int, fd: fd, size: int, offset: int, stride: int, plane_index: int) -> None:
        """
        An object description.

        Override to handle [`wayland.zwlr_export_dmabuf_frame_v1.events.object`][].
        """

        ...

    def on_ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Indicates frame is available for reading.

        Override to handle [`wayland.zwlr_export_dmabuf_frame_v1.events.ready`][].
        """

        ...

    def on_cancel(self, reason: zwlr_export_dmabuf_frame_v1.cancel_reason) -> None:
        """
        Indicates the frame is no longer valid.

        Override to handle [`wayland.zwlr_export_dmabuf_frame_v1.events.cancel`][].
        """

        ...

    class events(WaylandEvent):
        def frame(self, width: int, height: int, offset_x: int, offset_y: int, buffer_flags: int, flags: zwlr_export_dmabuf_frame_v1.flags, format: int, mod_high: int, mod_low: int, num_objects: int) -> None:
            """
            A frame description

            Main event supplying the client with information about the frame. If the
            capture didn't fail, this event is always emitted first before any other
            events.

            This event is followed by a number of "object" as specified by the
            "num_objects" argument.

            Args:
                width: Frame width in pixels
                height: Frame height in pixels
                offset_x: Crop offset for the x axis
                offset_y: Crop offset for the y axis
                buffer_flags: Flags which indicate properties (invert, interlacing),                     has the same values as zwp_linux_buffer_params_v1:flags
                flags: Indicates special frame features
                format: Format of the frame (drm_format_*)
                mod_high: Drm format modifier, high
                mod_low: Drm format modifier, low
                num_objects: Indicates how many objects (fds) the frame has (max 4)
            """

            ...

        def object(self, index: int, fd: fd, size: int, offset: int, stride: int, plane_index: int) -> None:
            """
            An object description

            Event which serves to supply the client with the file descriptors
            containing the data for each object.

            After receiving this event, the client must always close the file
            descriptor as soon as they're done with it and even if the frame fails.

            Args:
                index: Index of the current object
                fd: Fd of the current object
                size: Size in bytes for the current object
                offset: Starting point for the data in the object's fd
                stride: Line size in bytes
                plane_index: Index of the plane the data in the object applies to
            """

            ...

        def ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Indicates frame is available for reading

            This event is sent as soon as the frame is presented, indicating it is
            available for reading. This event includes the time at which
            presentation happened at.

            The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples,
            each component being an unsigned 32-bit value. Whole seconds are in
            tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo,
            and the additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999]. The seconds part
            may have an arbitrary offset at start.

            After receiving this event, the client should destroy this object.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

        def cancel(self, reason: zwlr_export_dmabuf_frame_v1.cancel_reason) -> None:
            """
            Indicates the frame is no longer valid

            If the capture failed or if the frame is no longer valid after the
            "frame" event has been emitted, this event will be used to inform the
            client to scrap the frame.

            If the failure is temporary, the client may capture again the same
            source. If the failure is permanent, any further attempts to capture the
            same source will fail again.

            After receiving this event, the client should destroy this object.

            Args:
                reason: Indicates a reason for cancelling this frame capture
            """

            ...

class zwlr_foreign_toplevel_manager_v1:
    """
    List and control opened apps

    The purpose of this protocol is to enable the creation of taskbars
    and docks by providing them with a list of opened applications and
    letting them request certain actions on them, like maximizing, etc.

    After a client binds the zwlr_foreign_toplevel_manager_v1, each opened
    toplevel window will be sent via the toplevel event
    """
    object_id = 0
    version = 3


    def stop(self) -> None:
        """
        Stop sending events

        Indicates the client no longer wishes to receive events for new toplevels.
        However the compositor may emit further toplevel_created events, until
        the finished event is emitted.

        The client must not send any more requests after this one.
        """

        ...

    def on_toplevel(self, toplevel: zwlr_foreign_toplevel_handle_v1) -> None:
        """
        A toplevel has been created.

        Override to handle [`wayland.zwlr_foreign_toplevel_manager_v1.events.toplevel`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The compositor has finished with the toplevel manager.

        Override to handle [`wayland.zwlr_foreign_toplevel_manager_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def toplevel(self, toplevel: zwlr_foreign_toplevel_handle_v1) -> None:
            """
            A toplevel has been created

            This event is emitted whenever a new toplevel window is created. It
            is emitted for all toplevels, regardless of the app that has created
            them.

            All initial details of the toplevel(title, app_id, states, etc.) will
            be sent immediately after this event via the corresponding events in
            zwlr_foreign_toplevel_handle_v1.
            """

            ...

        def finished(self) -> None:
            """
            The compositor has finished with the toplevel manager

            This event indicates that the compositor is done sending events to the
            zwlr_foreign_toplevel_manager_v1. The server will destroy the object
            immediately after sending this request, so it will become invalid and
            the client should free any resources associated with it.
            """

            ...

class zwlr_foreign_toplevel_handle_v1:
    """
    An opened toplevel

    A zwlr_foreign_toplevel_handle_v1 object represents an opened toplevel
    window. Each app may have multiple opened toplevels.

    Each toplevel has a list of outputs it is visible on, conveyed to the
    client with the output_enter and output_leave events.
    """
    object_id = 0
    version = 3

    class state(Enum):
        """
        Types of states on the toplevel

        The different states that a toplevel can have. These have the same meaning
        as the states with the same names defined in xdg-toplevel
        """

        maximized: int
        """The toplevel is maximized"""

        minimized: int
        """The toplevel is minimized"""

        activated: int
        """The toplevel is active"""

        fullscreen: int
        """The toplevel is fullscreen"""



    class error(Enum):
        invalid_rectangle: int
        """The provided rectangle is invalid"""



    def set_maximized(self) -> None:
        """
        Requests that the toplevel be maximized

        Requests that the toplevel be maximized. If the maximized state actually
        changes, this will be indicated by the state event.
        """

        ...

    def unset_maximized(self) -> None:
        """
        Requests that the toplevel be unmaximized

        Requests that the toplevel be unmaximized. If the maximized state actually
        changes, this will be indicated by the state event.
        """

        ...

    def set_minimized(self) -> None:
        """
        Requests that the toplevel be minimized

        Requests that the toplevel be minimized. If the minimized state actually
        changes, this will be indicated by the state event.
        """

        ...

    def unset_minimized(self) -> None:
        """
        Requests that the toplevel be unminimized

        Requests that the toplevel be unminimized. If the minimized state actually
        changes, this will be indicated by the state event.
        """

        ...

    def activate(self, seat: wl_seat) -> None:
        """
        Activate the toplevel

        Request that this toplevel be activated on the given seat.
        There is no guarantee the toplevel will be actually activated.
        """

        ...

    def close(self) -> None:
        """
        Request that the toplevel be closed

        Send a request to the toplevel to close itself. The compositor would
        typically use a shell-specific method to carry out this request, for
        example by sending the xdg_toplevel.close event. However, this gives
        no guarantees the toplevel will actually be destroyed. If and when
        this happens, the zwlr_foreign_toplevel_handle_v1.closed event will
        be emitted.
        """

        ...

    def set_rectangle(self, surface: wl_surface, x: int, y: int, width: int, height: int) -> None:
        """
        The rectangle which represents the toplevel

        The rectangle of the surface specified in this request corresponds to
        the place where the app using this protocol represents the given toplevel.
        It can be used by the compositor as a hint for some operations, e.g
        minimizing. The client is however not required to set this, in which
        case the compositor is free to decide some default value.

        If the client specifies more than one rectangle, only the last one is
        considered.

        The dimensions are given in surface-local coordinates.
        Setting width=height=0 removes the already-set rectangle.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the zwlr_foreign_toplevel_handle_v1 object

        Destroys the zwlr_foreign_toplevel_handle_v1 object.

        This request should be called either when the client does not want to
        use the toplevel anymore or after the closed event to finalize the
        destruction of the object.
        """

        ...

    def set_fullscreen(self, output: wl_output) -> None:
        """
        Request that the toplevel be fullscreened

        Requests that the toplevel be fullscreened on the given output. If the
        fullscreen state and/or the outputs the toplevel is visible on actually
        change, this will be indicated by the state and output_enter/leave
        events.

        The output parameter is only a hint to the compositor. Also, if output
        is NULL, the compositor should decide which output the toplevel will be
        fullscreened on, if at all.
        """

        ...

    def unset_fullscreen(self) -> None:
        """
        Request that the toplevel be unfullscreened

        Requests that the toplevel be unfullscreened. If the fullscreen state
        actually changes, this will be indicated by the state event.
        """

        ...

    def on_title(self, title: str) -> None:
        """
        Title change.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.title`][].
        """

        ...

    def on_app_id(self, app_id: str) -> None:
        """
        App-id change.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.app_id`][].
        """

        ...

    def on_output_enter(self, output: wl_output) -> None:
        """
        Toplevel entered an output.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.output_enter`][].
        """

        ...

    def on_output_leave(self, output: wl_output) -> None:
        """
        Toplevel left an output.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.output_leave`][].
        """

        ...

    def on_state(self, state: list) -> None:
        """
        The toplevel state changed.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.state`][].
        """

        ...

    def on_done(self) -> None:
        """
        All information about the toplevel has been sent.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.done`][].
        """

        ...

    def on_closed(self) -> None:
        """
        This toplevel has been destroyed.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.closed`][].
        """

        ...

    def on_parent(self, parent: zwlr_foreign_toplevel_handle_v1) -> None:
        """
        Parent change.

        Override to handle [`wayland.zwlr_foreign_toplevel_handle_v1.events.parent`][].
        """

        ...

    class events(WaylandEvent):
        def title(self, title: str) -> None:
            """
            Title change

            This event is emitted whenever the title of the toplevel changes.
            """

            ...

        def app_id(self, app_id: str) -> None:
            """
            App-id change

            This event is emitted whenever the app-id of the toplevel changes.
            """

            ...

        def output_enter(self, output: wl_output) -> None:
            """
            Toplevel entered an output

            This event is emitted whenever the toplevel becomes visible on
            the given output. A toplevel may be visible on multiple outputs.
            """

            ...

        def output_leave(self, output: wl_output) -> None:
            """
            Toplevel left an output

            This event is emitted whenever the toplevel stops being visible on
            the given output. It is guaranteed that an entered-output event
            with the same output has been emitted before this event.
            """

            ...

        def state(self, state: list) -> None:
            """
            The toplevel state changed

            This event is emitted immediately after the zlw_foreign_toplevel_handle_v1
            is created and each time the toplevel state changes, either because of a
            compositor action or because of a request in this protocol.
            """

            ...

        def done(self) -> None:
            """
            All information about the toplevel has been sent

            This event is sent after all changes in the toplevel state have been
            sent.

            This allows changes to the zwlr_foreign_toplevel_handle_v1 properties
            to be seen as atomic, even if they happen via multiple events.
            """

            ...

        def closed(self) -> None:
            """
            This toplevel has been destroyed

            This event means the toplevel has been destroyed. It is guaranteed there
            won't be any more events for this zwlr_foreign_toplevel_handle_v1. The
            toplevel itself becomes inert so any requests will be ignored except the
            destroy request.
            """

            ...

        def parent(self, parent: zwlr_foreign_toplevel_handle_v1) -> None:
            """
            Parent change

            This event is emitted whenever the parent of the toplevel changes.

            No event is emitted when the parent handle is destroyed by the client.
            """

            ...

class zwlr_gamma_control_manager_v1:
    """
    Manager to create per-output gamma controls

    This interface is a manager that allows creating per-output gamma
    controls.
    """
    object_id = 0
    version = 1


    def get_gamma_control(self, output: wl_output) -> zwlr_gamma_control_v1:
        """
        Get a gamma control for an output

        Create a gamma control that can be used to adjust gamma tables for the
        provided output.

        Returns:
            zwlr_gamma_control_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class zwlr_gamma_control_v1:
    """
    Adjust gamma tables for an output

    This interface allows a client to adjust gamma tables for a particular
    output.

    The client will receive the gamma size, and will then be able to set gamma
    tables. At any time the compositor can send a failed event indicating that
    this object is no longer valid.

    There can only be at most one gamma control object per output, which
    has exclusive access to this particular output. When the gamma control
    object is destroyed, the gamma table is restored to its original value.
    """
    object_id = 0
    version = 1

    class error(Enum):
        invalid_gamma: int
        """Invalid gamma tables"""



    def set_gamma(self, fd: fd) -> None:
        """
        Set the gamma table

        Set the gamma table. The file descriptor can be memory-mapped to provide
        the raw gamma table, which contains successive gamma ramps for the red,
        green and blue channels. Each gamma ramp is an array of 16-byte unsigned
        integers which has the same length as the gamma size.

        The file descriptor data must have the same length as three times the
        gamma size.

        Args:
            fd: Gamma table file descriptor
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this control

        Destroys the gamma control object. If the object is still valid, this
        restores the original gamma tables.
        """

        ...

    def on_gamma_size(self, size: int) -> None:
        """
        Size of gamma ramps.

        Override to handle [`wayland.zwlr_gamma_control_v1.events.gamma_size`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Object no longer valid.

        Override to handle [`wayland.zwlr_gamma_control_v1.events.failed`][].
        """

        ...

    class events(WaylandEvent):
        def gamma_size(self, size: int) -> None:
            """
            Size of gamma ramps

            Advertise the size of each gamma ramp.

            This event is sent immediately when the gamma control object is created.

            Args:
                size: Number of elements in a ramp
            """

            ...

        def failed(self) -> None:
            """
            Object no longer valid

            This event indicates that the gamma control is no longer valid. This
            can happen for a number of reasons, including:
            - The output doesn't support gamma tables
            - Setting the gamma tables failed
            - Another client already has exclusive gamma control for this output
            - The compositor has transferred gamma control to another client

            Upon receiving this event, the client should destroy this object.
            """

            ...

class zwlr_input_inhibit_manager_v1:
    """
    Inhibits input events to other clients

    Clients can use this interface to prevent input events from being sent to
    any surfaces but its own, which is useful for example in lock screen
    software. It is assumed that access to this interface will be locked down
    to whitelisted clients by the compositor.

    Note! This protocol is deprecated and not intended for production use.
    For screen lockers, use the ext-session-lock-v1 protocol.
    """
    object_id = 0
    version = 1

    class error(Enum):
        already_inhibited: int
        """An input inhibitor is already in use on the compositor"""



    def get_inhibitor(self) -> zwlr_input_inhibitor_v1:
        """
        Inhibit input to other clients

        Activates the input inhibitor. As long as the inhibitor is active, the
        compositor will not send input events to other clients.

        Returns:
            zwlr_input_inhibitor_v1: The created object
        """

        ...

class zwlr_input_inhibitor_v1:
    """
    Inhibits input to other clients

    While this resource exists, input to clients other than the owner of the
    inhibitor resource will not receive input events. Any client which
    previously had focus will receive a leave event and will not be given
    focus again. The client that owns this resource will receive all input
    events normally. The compositor will also disable all of its own input
    processing (such as keyboard shortcuts) while the inhibitor is active.

    The compositor may continue to send input events to selected clients,
    such as an on-screen keyboard (via the input-method protocol).
    """
    object_id = 0
    version = 1


    def destroy(self) -> None:
        """
        Destroy the input inhibitor object

        Destroy the inhibitor and allow other clients to receive input.
        """

        ...

class zwlr_layer_shell_v1:
    """
    Create surfaces that are layers of the desktop

    Clients can use this interface to assign the surface_layer role to
    wl_surfaces. Such surfaces are assigned to a "layer" of the output and
    rendered with a defined z-depth respective to each other. They may also be
    anchored to the edges and corners of a screen and specify input handling
    semantics. This interface should be suitable for the implementation of
    many desktop shell components, and a broad number of other applications
    that interact with the desktop.
    """
    object_id = 0
    version = 5

    class error(Enum):
        role: int
        """`wl_surface` has another role"""

        invalid_layer: int
        """Layer value is invalid"""

        already_constructed: int
        """`wl_surface` has a buffer attached or committed"""



    class layer(Enum):
        """
        Available layers for surfaces

        These values indicate which layers a surface can be rendered in. They
        are ordered by z depth, bottom-most first. Traditional shell surfaces
        will typically be rendered between the bottom and top layers.
        Fullscreen shell surfaces are typically rendered at the top layer.
        Multiple surfaces can share a single layer, and ordering within a
        single layer is undefined.
        """

        background: int
        bottom: int
        top: int
        overlay: int


    def get_layer_surface(self, surface: wl_surface, output: wl_output, layer: zwlr_layer_shell_v1.layer, namespace: str) -> zwlr_layer_surface_v1:
        """
        Create a `layer_surface` from a surface

        Create a layer surface for an existing surface. This assigns the role of
        layer_surface, or raises a protocol error if another role is already
        assigned.

        Creating a layer surface from a wl_surface which has a buffer attached
        or committed is a client error, and any attempts by a client to attach
        or manipulate a buffer prior to the first layer_surface.configure call
        must also be treated as errors.

        After creating a layer_surface object and setting it up, the client
        must perform an initial commit without any buffer attached.
        The compositor will reply with a layer_surface.configure event.
        The client must acknowledge it and is then allowed to attach a buffer
        to map the surface.

        You may pass NULL for output to allow the compositor to decide which
        output to use. Generally this will be the one that the user most
        recently interacted with.

        Clients can specify a namespace that defines the purpose of the layer
        surface.

        Args:
            layer: Layer to add this surface to
            namespace: Namespace for the layer surface

        Returns:
            zwlr_layer_surface_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the `layer_shell` object

        This request indicates that the client will not use the layer_shell
        object any more. Objects that have been created through this instance
        are not affected.
        """

        ...

class zwlr_layer_surface_v1:
    """
    Layer metadata interface

    An interface that may be implemented by a wl_surface, for surfaces that
    are designed to be rendered as a layer of a stacked desktop-like
    environment.

    Layer surface state (layer, size, anchor, exclusive zone,
    margin, interactivity) is double-buffered, and will be applied at the
    time wl_surface.commit of the corresponding wl_surface is called.

    Attaching a null buffer to a layer surface unmaps it.

    Unmapping a layer_surface means that the surface cannot be shown by the
    compositor until it is explicitly mapped again. The layer_surface
    returns to the state it had right after layer_shell.get_layer_surface.
    The client can re-map the surface by performing a commit without any
    buffer attached, waiting for a configure event and handling it as usual.
    """
    object_id = 0
    version = 5

    class keyboard_interactivity(Enum):
        """
        Types of keyboard interaction possible for a layer shell surface

        Types of keyboard interaction possible for layer shell surfaces. The
        rationale for this is twofold: (1) some applications are not interested
        in keyboard events and not allowing them to be focused can improve the
        desktop experience; (2) some applications will want to take exclusive
        keyboard focus.
        """

        none: int
        """
        No keyboard focus is possible
        This value indicates that this surface is not interested in keyboard
        events and the compositor should never assign it the keyboard focus.
        This is the default value, set for newly created layer shell surfaces.
        This is useful for e.g. desktop widgets that display information or
        only have interaction with non-keyboard input devices.
        """

        exclusive: int
        """
        Request exclusive keyboard focus
        Request exclusive keyboard focus if this surface is above the shell surface layer.
        For the top and overlay layers, the seat will always give
        exclusive keyboard focus to the top-most layer which has keyboard
        interactivity set to exclusive. If this layer contains multiple
        surfaces with keyboard interactivity set to exclusive, the compositor
        determines the one receiving keyboard events in an implementation-
        defined manner. In this case, no guarantee is made when this surface
        will receive keyboard focus (if ever).
        For the bottom and background layers, the compositor is allowed to use
        normal focus semantics.
        This setting is mainly intended for applications that need to ensure
        they receive all keyboard events, such as a lock screen or a password
        prompt.
        """

        on_demand: int
        """
        Request regular keyboard focus semantics
        This requests the compositor to allow this surface to be focused and
        unfocused by the user in an implementation-defined manner. The user
        should be able to unfocus this surface even regardless of the layer
        it is on.
        Typically, the compositor will want to use its normal mechanism to
        manage keyboard focus between layer shell surfaces with this setting
        and regular toplevels on the desktop layer (e.g. click to focus).
        Nevertheless, it is possible for a compositor to require a special
        interaction to focus or unfocus layer shell surfaces (e.g. requiring
        a click even if focus follows the mouse normally, or providing a
        keybinding to switch focus between layers).
        This setting is mainly intended for desktop shell components (e.g.
        panels) that allow keyboard interaction. Using this option can allow
        implementing a desktop shell that can be fully usable without the
        mouse.
        """



    class error(Enum):
        invalid_surface_state: int
        """Provided surface state is invalid"""

        invalid_size: int
        """Size is invalid"""

        invalid_anchor: int
        """Anchor bitfield is invalid"""

        invalid_keyboard_interactivity: int
        """Keyboard interactivity is invalid"""

        invalid_exclusive_edge: int
        """Exclusive edge is invalid given the surface anchors"""



    class anchor(IntFlag):
        top: int
        """The top edge of the anchor rectangle"""

        bottom: int
        """The bottom edge of the anchor rectangle"""

        left: int
        """The left edge of the anchor rectangle"""

        right: int
        """The right edge of the anchor rectangle"""



    def set_size(self, width: int, height: int) -> None:
        """
        Sets the size of the surface

        Sets the size of the surface in surface-local coordinates. The
        compositor will display the surface centered with respect to its
        anchors.

        If you pass 0 for either value, the compositor will assign it and
        inform you of the assignment in the configure event. You must set your
        anchor to opposite edges in the dimensions you omit; not doing so is a
        protocol error. Both values are 0 by default.

        Size is double-buffered, see wl_surface.commit.
        """

        ...

    def set_anchor(self, anchor: zwlr_layer_surface_v1.anchor) -> None:
        """
        Configures the anchor point of the surface

        Requests that the compositor anchor the surface to the specified edges
        and corners. If two orthogonal edges are specified (e.g. 'top' and
        'left'), then the anchor point will be the intersection of the edges
        (e.g. the top left corner of the output); otherwise the anchor point
        will be centered on that edge, or in the center if none is specified.

        Anchor is double-buffered, see wl_surface.commit.
        """

        ...

    def set_exclusive_zone(self, zone: int) -> None:
        """
        Configures the exclusive geometry of this surface

        Requests that the compositor avoids occluding an area with other
        surfaces. The compositor's use of this information is
        implementation-dependent - do not assume that this region will not
        actually be occluded.

        A positive value is only meaningful if the surface is anchored to one
        edge or an edge and both perpendicular edges. If the surface is not
        anchored, anchored to only two perpendicular edges (a corner), anchored
        to only two parallel edges or anchored to all edges, a positive value
        will be treated the same as zero.

        A positive zone is the distance from the edge in surface-local
        coordinates to consider exclusive.

        Surfaces that do not wish to have an exclusive zone may instead specify
        how they should interact with surfaces that do. If set to zero, the
        surface indicates that it would like to be moved to avoid occluding
        surfaces with a positive exclusive zone. If set to -1, the surface
        indicates that it would not like to be moved to accommodate for other
        surfaces, and the compositor should extend it all the way to the edges
        it is anchored to.

        For example, a panel might set its exclusive zone to 10, so that
        maximized shell surfaces are not shown on top of it. A notification
        might set its exclusive zone to 0, so that it is moved to avoid
        occluding the panel, but shell surfaces are shown underneath it. A
        wallpaper or lock screen might set their exclusive zone to -1, so that
        they stretch below or over the panel.

        The default value is 0.

        Exclusive zone is double-buffered, see wl_surface.commit.
        """

        ...

    def set_margin(self, top: int, right: int, bottom: int, left: int) -> None:
        """
        Sets a margin from the anchor point

        Requests that the surface be placed some distance away from the anchor
        point on the output, in surface-local coordinates. Setting this value
        for edges you are not anchored to has no effect.

        The exclusive zone includes the margin.

        Margin is double-buffered, see wl_surface.commit.
        """

        ...

    def set_keyboard_interactivity(self, keyboard_interactivity: zwlr_layer_surface_v1.keyboard_interactivity) -> None:
        """
        Requests keyboard events

        Set how keyboard events are delivered to this surface. By default,
        layer shell surfaces do not receive keyboard events; this request can
        be used to change this.

        This setting is inherited by child surfaces set by the get_popup
        request.

        Layer surfaces receive pointer, touch, and tablet events normally. If
        you do not want to receive them, set the input region on your surface
        to an empty region.

        Keyboard interactivity is double-buffered, see wl_surface.commit.
        """

        ...

    def get_popup(self, popup: xdg_popup) -> None:
        """
        Assign this `layer_surface` as an `xdg_popup` parent

        This assigns an xdg_popup's parent to this layer_surface.  This popup
        should have been created via xdg_surface::get_popup with the parent set
        to NULL, and this request must be invoked before committing the popup's
        initial state.

        See the documentation of xdg_popup for more details about what an
        xdg_popup is and how it is used.
        """

        ...

    def ack_configure(self, serial: int) -> None:
        """
        Ack a configure event

        When a configure event is received, if a client commits the
        surface in response to the configure event, then the client
        must make an ack_configure request sometime before the commit
        request, passing along the serial of the configure event.

        If the client receives multiple configure events before it
        can respond to one, it only has to ack the last configure event.

        A client is not required to commit immediately after sending
        an ack_configure request - it may even ack_configure several times
        before its next surface commit.

        A client may send multiple ack_configure requests before committing, but
        only the last request sent before a commit indicates which configure
        event the client really is responding to.

        Args:
            serial: The serial from the configure event
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the `layer_surface`

        This request destroys the layer surface.
        """

        ...

    def set_layer(self, layer: zwlr_layer_shell_v1.layer) -> None:
        """
        Change the layer of the surface

        Change the layer that the surface is rendered on.

        Layer is double-buffered, see wl_surface.commit.

        Args:
            layer: Layer to move this surface to
        """

        ...

    def set_exclusive_edge(self, edge: zwlr_layer_surface_v1.anchor) -> None:
        """
        Set the edge the exclusive zone will be applied to

        Requests an edge for the exclusive zone to apply. The exclusive
        edge will be automatically deduced from anchor points when possible,
        but when the surface is anchored to a corner, it will be necessary
        to set it explicitly to disambiguate, as it is not possible to deduce
        which one of the two corner edges should be used.

        The edge must be one the surface is anchored to, otherwise the
        invalid_exclusive_edge protocol error will be raised.
        """

        ...

    def on_configure(self, serial: int, width: int, height: int) -> None:
        """
        Suggest a surface change.

        Override to handle [`wayland.zwlr_layer_surface_v1.events.configure`][].
        """

        ...

    def on_closed(self) -> None:
        """
        Surface should be closed.

        Override to handle [`wayland.zwlr_layer_surface_v1.events.closed`][].
        """

        ...

    class events(WaylandEvent):
        def configure(self, serial: int, width: int, height: int) -> None:
            """
            Suggest a surface change

            The configure event asks the client to resize its surface.

            Clients should arrange their surface for the new states, and then send
            an ack_configure request with the serial sent in this configure event at
            some point before committing the new surface.

            The client is free to dismiss all but the last configure event it
            received.

            The width and height arguments specify the size of the window in
            surface-local coordinates.

            The size is a hint, in the sense that the client is free to ignore it if
            it doesn't resize, pick a smaller size (to satisfy aspect ratio or
            resize in steps of NxM pixels). If the client picks a smaller size and
            is anchored to two opposite anchors (e.g. 'top' and 'bottom'), the
            surface will be centered on this axis.

            If the width or height arguments are zero, it means the client should
            decide its own window dimension.
            """

            ...

        def closed(self) -> None:
            """
            Surface should be closed

            The closed event is sent by the compositor when the surface will no
            longer be shown. The output may have been destroyed or the user may
            have asked for it to be removed. Further changes to the surface will be
            ignored. The client should destroy the resource after receiving this
            event, and create a new surface if they so choose.
            """

            ...

class zwlr_output_manager_v1:
    """
    Output device configuration manager

    This interface is a manager that allows reading and writing the current
    output device configuration.

    Output devices that display pixels (e.g. a physical monitor or a virtual
    output in a window) are represented as heads. Heads cannot be created nor
    destroyed by the client, but they can be enabled or disabled and their
    properties can be changed. Each head may have one or more available modes.

    Whenever a head appears (e.g. a monitor is plugged in), it will be
    advertised via the head event. Immediately after the output manager is
    bound, all current heads are advertised.

    Whenever a head's properties change, the relevant wlr_output_head events
    will be sent. Not all head properties will be sent: only properties that
    have changed need to.

    Whenever a head disappears (e.g. a monitor is unplugged), a
    wlr_output_head.finished event will be sent.

    After one or more heads appear, change or disappear, the done event will
    be sent. It carries a serial which can be used in a create_configuration
    request to update heads properties.

    The information obtained from this protocol should only be used for output
    configuration purposes. This protocol is not designed to be a generic
    output property advertisement protocol for regular clients. Instead,
    protocols such as xdg-output should be used.
    """
    object_id = 0
    version = 4


    def create_configuration(self, serial: int) -> zwlr_output_configuration_v1:
        """
        Create a new output configuration object

        Create a new output configuration object. This allows to update head
        properties.

        Returns:
            zwlr_output_configuration_v1: The created object
        """

        ...

    def stop(self) -> None:
        """
        Stop sending events

        Indicates the client no longer wishes to receive events for output
        configuration changes. However the compositor may emit further events,
        until the finished event is emitted.

        The client must not send any more requests after this one.
        """

        ...

    def on_head(self, head: zwlr_output_head_v1) -> None:
        """
        Introduce a new head.

        Override to handle [`wayland.zwlr_output_manager_v1.events.head`][].
        """

        ...

    def on_done(self, serial: int) -> None:
        """
        Sent all information about current configuration.

        Override to handle [`wayland.zwlr_output_manager_v1.events.done`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The compositor has finished with the manager.

        Override to handle [`wayland.zwlr_output_manager_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def head(self, head: zwlr_output_head_v1) -> None:
            """
            Introduce a new head

            This event introduces a new head. This happens whenever a new head
            appears (e.g. a monitor is plugged in) or after the output manager is
            bound.
            """

            ...

        def done(self, serial: int) -> None:
            """
            Sent all information about current configuration

            This event is sent after all information has been sent after binding to
            the output manager object and after any subsequent changes. This applies
            to child head and mode objects as well. In other words, this event is
            sent whenever a head or mode is created or destroyed and whenever one of
            their properties has been changed. Not all state is re-sent each time
            the current configuration changes: only the actual changes are sent.

            This allows changes to the output configuration to be seen as atomic,
            even if they happen via multiple events.

            A serial is sent to be used in a future create_configuration request.

            Args:
                serial: Current configuration serial
            """

            ...

        def finished(self) -> None:
            """
            The compositor has finished with the manager

            This event indicates that the compositor is done sending manager events.
            The compositor will destroy the object immediately after sending this
            event, so it will become invalid and the client should release any
            resources associated with it.
            """

            ...

class zwlr_output_head_v1:
    """
    Output device

    A head is an output device. The difference between a wl_output object and
    a head is that heads are advertised even if they are turned off. A head
    object only advertises properties and cannot be used directly to change
    them.

    A head has some read-only properties: modes, name, description and
    physical_size. These cannot be changed by clients.

    Other properties can be updated via a wlr_output_configuration object.

    Properties sent via this interface are applied atomically via the
    wlr_output_manager.done event. No guarantees are made regarding the order
    in which properties are sent.
    """
    object_id = 0
    version = 4

    class adaptive_sync_state(Enum):
        disabled: int
        """Adaptive sync is disabled"""

        enabled: int
        """Adaptive sync is enabled"""



    def release(self) -> None:
        """
        Destroy the head object

        This request indicates that the client will no longer use this head
        object.
        """

        ...

    def on_name(self, name: str) -> None:
        """
        Head name.

        Override to handle [`wayland.zwlr_output_head_v1.events.name`][].
        """

        ...

    def on_description(self, description: str) -> None:
        """
        Head description.

        Override to handle [`wayland.zwlr_output_head_v1.events.description`][].
        """

        ...

    def on_physical_size(self, width: int, height: int) -> None:
        """
        Head physical size.

        Override to handle [`wayland.zwlr_output_head_v1.events.physical_size`][].
        """

        ...

    def on_mode(self, mode: zwlr_output_mode_v1) -> None:
        """
        Introduce a mode.

        Override to handle [`wayland.zwlr_output_head_v1.events.mode`][].
        """

        ...

    def on_enabled(self, enabled: int) -> None:
        """
        Head is enabled or disabled.

        Override to handle [`wayland.zwlr_output_head_v1.events.enabled`][].
        """

        ...

    def on_current_mode(self, mode: zwlr_output_mode_v1) -> None:
        """
        Current mode.

        Override to handle [`wayland.zwlr_output_head_v1.events.current_mode`][].
        """

        ...

    def on_position(self, x: int, y: int) -> None:
        """
        Current position.

        Override to handle [`wayland.zwlr_output_head_v1.events.position`][].
        """

        ...

    def on_transform(self, transform: wl_output.transform) -> None:
        """
        Current transformation.

        Override to handle [`wayland.zwlr_output_head_v1.events.transform`][].
        """

        ...

    def on_scale(self, scale: float) -> None:
        """
        Current scale.

        Override to handle [`wayland.zwlr_output_head_v1.events.scale`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The head has disappeared.

        Override to handle [`wayland.zwlr_output_head_v1.events.finished`][].
        """

        ...

    def on_make(self, make: str) -> None:
        """
        Head manufacturer.

        Override to handle [`wayland.zwlr_output_head_v1.events.make`][].
        """

        ...

    def on_model(self, model: str) -> None:
        """
        Head model.

        Override to handle [`wayland.zwlr_output_head_v1.events.model`][].
        """

        ...

    def on_serial_number(self, serial_number: str) -> None:
        """
        Head serial number.

        Override to handle [`wayland.zwlr_output_head_v1.events.serial_number`][].
        """

        ...

    def on_adaptive_sync(self, state: zwlr_output_head_v1.adaptive_sync_state) -> None:
        """
        Current adaptive sync state.

        Override to handle [`wayland.zwlr_output_head_v1.events.adaptive_sync`][].
        """

        ...

    class events(WaylandEvent):
        def name(self, name: str) -> None:
            """
            Head name

            This event describes the head name.

            The naming convention is compositor defined, but limited to alphanumeric
            characters and dashes (-). Each name is unique among all wlr_output_head
            objects, but if a wlr_output_head object is destroyed the same name may
            be reused later. The names will also remain consistent across sessions
            with the same hardware and software configuration.

            Examples of names include 'HDMI-A-1', 'WL-1', 'X11-1', etc. However, do
            not assume that the name is a reflection of an underlying DRM
            connector, X11 connection, etc.

            If the compositor implements the xdg-output protocol and this head is
            enabled, the xdg_output.name event must report the same name.

            The name event is sent after a wlr_output_head object is created. This
            event is only sent once per object, and the name does not change over
            the lifetime of the wlr_output_head object.
            """

            ...

        def description(self, description: str) -> None:
            """
            Head description

            This event describes a human-readable description of the head.

            The description is a UTF-8 string with no convention defined for its
            contents. Examples might include 'Foocorp 11" Display' or 'Virtual X11
            output via :1'. However, do not assume that the name is a reflection of
            the make, model, serial of the underlying DRM connector or the display
            name of the underlying X11 connection, etc.

            If the compositor implements xdg-output and this head is enabled,
            the xdg_output.description must report the same description.

            The description event is sent after a wlr_output_head object is created.
            This event is only sent once per object, and the description does not
            change over the lifetime of the wlr_output_head object.
            """

            ...

        def physical_size(self, width: int, height: int) -> None:
            """
            Head physical size

            This event describes the physical size of the head. This event is only
            sent if the head has a physical size (e.g. is not a projector or a
            virtual device).

            The physical size event is sent after a wlr_output_head object is created. This
            event is only sent once per object, and the physical size does not change over
            the lifetime of the wlr_output_head object.

            Args:
                width: Width in millimeters of the output
                height: Height in millimeters of the output
            """

            ...

        def mode(self, mode: zwlr_output_mode_v1) -> None:
            """
            Introduce a mode

            This event introduces a mode for this head. It is sent once per
            supported mode.
            """

            ...

        def enabled(self, enabled: int) -> None:
            """
            Head is enabled or disabled

            This event describes whether the head is enabled. A disabled head is not
            mapped to a region of the global compositor space.

            When a head is disabled, some properties (current_mode, position,
            transform and scale) are irrelevant.

            Args:
                enabled: Zero if disabled, non-zero if enabled
            """

            ...

        def current_mode(self, mode: zwlr_output_mode_v1) -> None:
            """
            Current mode

            This event describes the mode currently in use for this head. It is only
            sent if the output is enabled.
            """

            ...

        def position(self, x: int, y: int) -> None:
            """
            Current position

            This events describes the position of the head in the global compositor
            space. It is only sent if the output is enabled.

            Args:
                x: X position within the global compositor space
                y: Y position within the global compositor space
            """

            ...

        def transform(self, transform: wl_output.transform) -> None:
            """
            Current transformation

            This event describes the transformation currently applied to the head.
            It is only sent if the output is enabled.
            """

            ...

        def scale(self, scale: float) -> None:
            """
            Current scale

            This events describes the scale of the head in the global compositor
            space. It is only sent if the output is enabled.
            """

            ...

        def finished(self) -> None:
            """
            The head has disappeared

            This event indicates that the head is no longer available. The head
            object becomes inert. Clients should send a destroy request and release
            any resources associated with it.
            """

            ...

        def make(self, make: str) -> None:
            """
            Head manufacturer

            This event describes the manufacturer of the head.

            This must report the same make as the wl_output interface does in its
            geometry event.

            Together with the model and serial_number events the purpose is to
            allow clients to recognize heads from previous sessions and for example
            load head-specific configurations back.

            It is not guaranteed this event will be ever sent. A reason for that
            can be that the compositor does not have information about the make of
            the head or the definition of a make is not sensible in the current
            setup, for example in a virtual session. Clients can still try to
            identify the head by available information from other events but should
            be aware that there is an increased risk of false positives.

            If sent, the make event is sent after a wlr_output_head object is
            created and only sent once per object. The make does not change over
            the lifetime of the wlr_output_head object.

            It is not recommended to display the make string in UI to users. For
            that the string provided by the description event should be preferred.
            """

            ...

        def model(self, model: str) -> None:
            """
            Head model

            This event describes the model of the head.

            This must report the same model as the wl_output interface does in its
            geometry event.

            Together with the make and serial_number events the purpose is to
            allow clients to recognize heads from previous sessions and for example
            load head-specific configurations back.

            It is not guaranteed this event will be ever sent. A reason for that
            can be that the compositor does not have information about the model of
            the head or the definition of a model is not sensible in the current
            setup, for example in a virtual session. Clients can still try to
            identify the head by available information from other events but should
            be aware that there is an increased risk of false positives.

            If sent, the model event is sent after a wlr_output_head object is
            created and only sent once per object. The model does not change over
            the lifetime of the wlr_output_head object.

            It is not recommended to display the model string in UI to users. For
            that the string provided by the description event should be preferred.
            """

            ...

        def serial_number(self, serial_number: str) -> None:
            """
            Head serial number

            This event describes the serial number of the head.

            Together with the make and model events the purpose is to allow clients
            to recognize heads from previous sessions and for example load head-
            specific configurations back.

            It is not guaranteed this event will be ever sent. A reason for that
            can be that the compositor does not have information about the serial
            number of the head or the definition of a serial number is not sensible
            in the current setup. Clients can still try to identify the head by
            available information from other events but should be aware that there
            is an increased risk of false positives.

            If sent, the serial number event is sent after a wlr_output_head object
            is created and only sent once per object. The serial number does not
            change over the lifetime of the wlr_output_head object.

            It is not recommended to display the serial_number string in UI to
            users. For that the string provided by the description event should be
            preferred.
            """

            ...

        def adaptive_sync(self, state: zwlr_output_head_v1.adaptive_sync_state) -> None:
            """
            Current adaptive sync state

            This event describes whether adaptive sync is currently enabled for
            the head or not. Adaptive sync is also known as Variable Refresh
            Rate or VRR.
            """

            ...

class zwlr_output_mode_v1:
    """
    Output mode

    This object describes an output mode.

    Some heads don't support output modes, in which case modes won't be
    advertised.

    Properties sent via this interface are applied atomically via the
    wlr_output_manager.done event. No guarantees are made regarding the order
    in which properties are sent.
    """
    object_id = 0
    version = 3


    def release(self) -> None:
        """
        Destroy the mode object

        This request indicates that the client will no longer use this mode
        object.
        """

        ...

    def on_size(self, width: int, height: int) -> None:
        """
        Mode size.

        Override to handle [`wayland.zwlr_output_mode_v1.events.size`][].
        """

        ...

    def on_refresh(self, refresh: int) -> None:
        """
        Mode refresh rate.

        Override to handle [`wayland.zwlr_output_mode_v1.events.refresh`][].
        """

        ...

    def on_preferred(self) -> None:
        """
        Mode is preferred.

        Override to handle [`wayland.zwlr_output_mode_v1.events.preferred`][].
        """

        ...

    def on_finished(self) -> None:
        """
        The mode has disappeared.

        Override to handle [`wayland.zwlr_output_mode_v1.events.finished`][].
        """

        ...

    class events(WaylandEvent):
        def size(self, width: int, height: int) -> None:
            """
            Mode size

            This event describes the mode size. The size is given in physical
            hardware units of the output device. This is not necessarily the same as
            the output size in the global compositor space. For instance, the output
            may be scaled or transformed.

            Args:
                width: Width of the mode in hardware units
                height: Height of the mode in hardware units
            """

            ...

        def refresh(self, refresh: int) -> None:
            """
            Mode refresh rate

            This event describes the mode's fixed vertical refresh rate. It is only
            sent if the mode has a fixed refresh rate.

            Args:
                refresh: Vertical refresh rate in mhz
            """

            ...

        def preferred(self) -> None:
            """
            Mode is preferred

            This event advertises this mode as preferred.
            """

            ...

        def finished(self) -> None:
            """
            The mode has disappeared

            This event indicates that the mode is no longer available. The mode
            object becomes inert. Clients should send a destroy request and release
            any resources associated with it.
            """

            ...

class zwlr_output_configuration_v1:
    """
    Output configuration

    This object is used by the client to describe a full output configuration.

    First, the client needs to setup the output configuration. Each head can
    be either enabled (and configured) or disabled. It is a protocol error to
    send two enable_head or disable_head requests with the same head. It is a
    protocol error to omit a head in a configuration.

    Then, the client can apply or test the configuration. The compositor will
    then reply with a succeeded, failed or cancelled event. Finally the client
    should destroy the configuration object.
    """
    object_id = 0
    version = 4

    class error(Enum):
        already_configured_head: int
        """Head has been configured twice"""

        unconfigured_head: int
        """Head has not been configured"""

        already_used: int
        """Request sent after configuration has been applied or tested"""



    def enable_head(self, head: zwlr_output_head_v1) -> zwlr_output_configuration_head_v1:
        """
        Enable and configure a head

        Enable a head. This request creates a head configuration object that can
        be used to change the head's properties.

        Args:
            head: The head to be enabled

        Returns:
            zwlr_output_configuration_head_v1: The created object
        """

        ...

    def disable_head(self, head: zwlr_output_head_v1) -> None:
        """
        Disable a head

        Disable a head.

        Args:
            head: The head to be disabled
        """

        ...

    def apply(self) -> None:
        """
        Apply the configuration

        Apply the new output configuration.

        In case the configuration is successfully applied, there is no guarantee
        that the new output state matches completely the requested
        configuration. For instance, a compositor might round the scale if it
        doesn't support fractional scaling.

        After this request has been sent, the compositor must respond with an
        succeeded, failed or cancelled event. Sending a request that isn't the
        destructor is a protocol error.
        """

        ...

    def test(self) -> None:
        """
        Test the configuration

        Test the new output configuration. The configuration won't be applied,
        but will only be validated.

        Even if the compositor succeeds to test a configuration, applying it may
        fail.

        After this request has been sent, the compositor must respond with an
        succeeded, failed or cancelled event. Sending a request that isn't the
        destructor is a protocol error.
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the output configuration

        Using this request a client can tell the compositor that it is not going
        to use the configuration object anymore. Any changes to the outputs
        that have not been applied will be discarded.

        This request also destroys wlr_output_configuration_head objects created
        via this object.
        """

        ...

    def on_succeeded(self) -> None:
        """
        Configuration changes succeeded.

        Override to handle [`wayland.zwlr_output_configuration_v1.events.succeeded`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Configuration changes failed.

        Override to handle [`wayland.zwlr_output_configuration_v1.events.failed`][].
        """

        ...

    def on_cancelled(self) -> None:
        """
        Configuration has been cancelled.

        Override to handle [`wayland.zwlr_output_configuration_v1.events.cancelled`][].
        """

        ...

    class events(WaylandEvent):
        def succeeded(self) -> None:
            """
            Configuration changes succeeded

            Sent after the compositor has successfully applied the changes or
            tested them.

            Upon receiving this event, the client should destroy this object.

            If the current configuration has changed, events to describe the changes
            will be sent followed by a wlr_output_manager.done event.
            """

            ...

        def failed(self) -> None:
            """
            Configuration changes failed

            Sent if the compositor rejects the changes or failed to apply them. The
            compositor should revert any changes made by the apply request that
            triggered this event.

            Upon receiving this event, the client should destroy this object.
            """

            ...

        def cancelled(self) -> None:
            """
            Configuration has been cancelled

            Sent if the compositor cancels the configuration because the state of an
            output changed and the client has outdated information (e.g. after an
            output has been hotplugged).

            The client can create a new configuration with a newer serial and try
            again.

            Upon receiving this event, the client should destroy this object.
            """

            ...

class zwlr_output_configuration_head_v1:
    """
    Head configuration

    This object is used by the client to update a single head's configuration.

    It is a protocol error to set the same property twice.
    """
    object_id = 0
    version = 4

    class error(Enum):
        already_set: int
        """Property has already been set"""

        invalid_mode: int
        """Mode doesn't belong to head"""

        invalid_custom_mode: int
        """Mode is invalid"""

        invalid_transform: int
        """Transform value outside enum"""

        invalid_scale: int
        """Scale negative or zero"""

        invalid_adaptive_sync_state: int
        """Invalid enum value used in the `set_adaptive_sync` request"""



    def set_mode(self, mode: zwlr_output_mode_v1) -> None:
        """
        Set the mode

        This request sets the head's mode.
        """

        ...

    def set_custom_mode(self, width: int, height: int, refresh: int) -> None:
        """
        Set a custom mode

        This request assigns a custom mode to the head. The size is given in
        physical hardware units of the output device. If set to zero, the
        refresh rate is unspecified.

        It is a protocol error to set both a mode and a custom mode.

        Args:
            width: Width of the mode in hardware units
            height: Height of the mode in hardware units
            refresh: Vertical refresh rate in mhz or zero
        """

        ...

    def set_position(self, x: int, y: int) -> None:
        """
        Set the position

        This request sets the head's position in the global compositor space.

        Args:
            x: X position in the global compositor space
            y: Y position in the global compositor space
        """

        ...

    def set_transform(self, transform: wl_output.transform) -> None:
        """
        Set the transform

        This request sets the head's transform.
        """

        ...

    def set_scale(self, scale: float) -> None:
        """
        Set the scale

        This request sets the head's scale.
        """

        ...

    def set_adaptive_sync(self, state: zwlr_output_head_v1.adaptive_sync_state) -> None:
        """
        Enable/disable adaptive sync

        This request enables/disables adaptive sync. Adaptive sync is also
        known as Variable Refresh Rate or VRR.
        """

        ...

class zwlr_output_power_manager_v1:
    """
    Manager to create per-output power management

    This interface is a manager that allows creating per-output power
    management mode controls.
    """
    object_id = 0
    version = 1


    def get_output_power(self, output: wl_output) -> zwlr_output_power_v1:
        """
        Get a power management for an output

        Create an output power management mode control that can be used to
        adjust the power management mode for a given output.

        Returns:
            zwlr_output_power_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class zwlr_output_power_v1:
    """
    Adjust power management mode for an output

    This object offers requests to set the power management mode of
    an output.
    """
    object_id = 0
    version = 1

    class mode(Enum):
        off: int
        """Output is turned off."""

        on: int
        """Output is turned on, no power saving"""



    class error(Enum):
        invalid_mode: int
        """Nonexistent power save mode"""



    def set_mode(self, mode: zwlr_output_power_v1.mode) -> None:
        """
        Set an outputs power save mode

        Set an output's power save mode to the given mode. The mode change
        is effective immediately. If the output does not support the given
        mode a failed event is sent.

        Args:
            mode: The power save mode to set
        """

        ...

    def destroy(self) -> None:
        """
        Destroy this power management

        Destroys the output power management mode control object.
        """

        ...

    def on_mode(self, mode: zwlr_output_power_v1.mode) -> None:
        """
        Report a power management mode change.

        Override to handle [`wayland.zwlr_output_power_v1.events.mode`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Object no longer valid.

        Override to handle [`wayland.zwlr_output_power_v1.events.failed`][].
        """

        ...

    class events(WaylandEvent):
        def mode(self, mode: zwlr_output_power_v1.mode) -> None:
            """
            Report a power management mode change

            Report the power management mode change of an output.

            The mode event is sent after an output changed its power
            management mode. The reason can be a client using set_mode or the
            compositor deciding to change an output's mode.
            This event is also sent immediately when the object is created
            so the client is informed about the current power management mode.

            Args:
                mode: The output's new power management mode
            """

            ...

        def failed(self) -> None:
            """
            Object no longer valid

            This event indicates that the output power management mode control
            is no longer valid. This can happen for a number of reasons,
            including:
            - The output doesn't support power management
            - Another client already has exclusive power management mode control
              for this output
            - The output disappeared

            Upon receiving this event, the client should destroy this object.
            """

            ...

class zwlr_screencopy_manager_v1:
    """
    Manager to inform clients and begin capturing

    This object is a manager which offers requests to start capturing from a
    source.
    """
    object_id = 0
    version = 3


    def capture_output(self, overlay_cursor: int, output: wl_output) -> zwlr_screencopy_frame_v1:
        """
        Capture an output

        Capture the next frame of an entire output.

        Args:
            overlay_cursor: Composite cursor onto the frame

        Returns:
            zwlr_screencopy_frame_v1: The created object
        """

        ...

    def capture_output_region(self, overlay_cursor: int, output: wl_output, x: int, y: int, width: int, height: int) -> zwlr_screencopy_frame_v1:
        """
        Capture an output's region

        Capture the next frame of an output's region.

        The region is given in output logical coordinates, see
        xdg_output.logical_size. The region will be clipped to the output's
        extents.

        Args:
            overlay_cursor: Composite cursor onto the frame

        Returns:
            zwlr_screencopy_frame_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """
        Destroy the manager

        All objects created by the manager will still remain valid, until their
        appropriate destroy request has been called.
        """

        ...

class zwlr_screencopy_frame_v1:
    """
    A frame ready for copy

    This object represents a single frame.

    When created, a series of buffer events will be sent, each representing a
    supported buffer type. The "buffer_done" event is sent afterwards to
    indicate that all supported buffer types have been enumerated. The client
    will then be able to send a "copy" request. If the capture is successful,
    the compositor will send a "flags" event followed by a "ready" event.

    For objects version 2 or lower, wl_shm buffers are always supported, ie.
    the "buffer" event is guaranteed to be sent.

    If the capture failed, the "failed" event is sent. This can happen anytime
    before the "ready" event.

    Once either a "ready" or a "failed" event is received, the client should
    destroy the frame.
    """
    object_id = 0
    version = 3

    class error(Enum):
        already_used: int
        """The object has already been used to copy a `wl_buffer`"""

        invalid_buffer: int
        """Buffer attributes are invalid"""



    class flags(IntFlag):
        y_invert: int
        """Contents are y-inverted"""



    def copy(self, buffer: wl_buffer) -> None:
        """
        Copy the frame

        Copy the frame to the supplied buffer. The buffer must have the
        correct size, see zwlr_screencopy_frame_v1.buffer and
        zwlr_screencopy_frame_v1.linux_dmabuf. The buffer needs to have a
        supported format.

        If the frame is successfully copied, "flags" and "ready" events are
        sent. Otherwise, a "failed" event is sent.
        """

        ...

    def destroy(self) -> None:
        """
        Delete this object, used or not

        Destroys the frame. This request can be sent at any time by the client.
        """

        ...

    def copy_with_damage(self, buffer: wl_buffer) -> None:
        """
        Copy the frame when it's damaged

        Same as copy, except it waits until there is damage to copy.
        """

        ...

    def on_buffer(self, format: wl_shm.format, width: int, height: int, stride: int) -> None:
        """
        `wl_shm` buffer information.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.buffer`][].
        """

        ...

    def on_flags(self, flags: zwlr_screencopy_frame_v1.flags) -> None:
        """
        Frame flags.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.flags`][].
        """

        ...

    def on_ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
        """
        Indicates frame is available for reading.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.ready`][].
        """

        ...

    def on_failed(self) -> None:
        """
        Frame copy failed.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.failed`][].
        """

        ...

    def on_damage(self, x: int, y: int, width: int, height: int) -> None:
        """
        Carries the coordinates of the damaged region.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.damage`][].
        """

        ...

    def on_linux_dmabuf(self, format: int, width: int, height: int) -> None:
        """
        Linux-dmabuf buffer information.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.linux_dmabuf`][].
        """

        ...

    def on_buffer_done(self) -> None:
        """
        All buffer types reported.

        Override to handle [`wayland.zwlr_screencopy_frame_v1.events.buffer_done`][].
        """

        ...

    class events(WaylandEvent):
        def buffer(self, format: wl_shm.format, width: int, height: int, stride: int) -> None:
            """
            `wl_shm` buffer information

            Provides information about wl_shm buffer parameters that need to be
            used for this frame. This event is sent once after the frame is created
            if wl_shm buffers are supported.

            Args:
                format: Buffer format
                width: Buffer width
                height: Buffer height
                stride: Buffer stride
            """

            ...

        def flags(self, flags: zwlr_screencopy_frame_v1.flags) -> None:
            """
            Frame flags

            Provides flags about the frame. This event is sent once before the
            "ready" event.

            Args:
                flags: Frame flags
            """

            ...

        def ready(self, tv_sec_hi: int, tv_sec_lo: int, tv_nsec: int) -> None:
            """
            Indicates frame is available for reading

            Called as soon as the frame is copied, indicating it is available
            for reading. This event includes the time at which the presentation took place.

            The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples,
            each component being an unsigned 32-bit value. Whole seconds are in
            tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo,
            and the additional fractional part in tv_nsec as nanoseconds. Hence,
            for valid timestamps tv_nsec must be in [0, 999999999]. The seconds part
            may have an arbitrary offset at start.

            After receiving this event, the client should destroy the object.

            Args:
                tv_sec_hi: High 32 bits of the seconds part of the timestamp
                tv_sec_lo: Low 32 bits of the seconds part of the timestamp
                tv_nsec: Nanoseconds part of the timestamp
            """

            ...

        def failed(self) -> None:
            """
            Frame copy failed

            This event indicates that the attempted frame copy has failed.

            After receiving this event, the client should destroy the object.
            """

            ...

        def damage(self, x: int, y: int, width: int, height: int) -> None:
            """
            Carries the coordinates of the damaged region

            This event is sent right before the ready event when copy_with_damage is
            requested. It may be generated multiple times for each copy_with_damage
            request.

            The arguments describe a box around an area that has changed since the
            last copy request that was derived from the current screencopy manager
            instance.

            The union of all regions received between the call to copy_with_damage
            and a ready event is the total damage since the prior ready event.

            Args:
                x: Damaged x coordinates
                y: Damaged y coordinates
                width: Current width
                height: Current height
            """

            ...

        def linux_dmabuf(self, format: int, width: int, height: int) -> None:
            """
            Linux-dmabuf buffer information

            Provides information about linux-dmabuf buffer parameters that need to
            be used for this frame. This event is sent once after the frame is
            created if linux-dmabuf buffers are supported.

            Args:
                format: Fourcc pixel format
                width: Buffer width
                height: Buffer height
            """

            ...

        def buffer_done(self) -> None:
            """
            All buffer types reported

            This event is sent once after all buffer events have been sent.

            The client should proceed to create a buffer of one of the supported
            types, and send a "copy" request.
            """

            ...

class zwlr_virtual_pointer_v1:
    """
    Virtual pointer

    This protocol allows clients to emulate a physical pointer device. The
    requests are mostly mirror opposites of those specified in wl_pointer.
    """
    object_id = 0
    version = 2

    class error(Enum):
        invalid_axis: int
        """Client sent invalid axis enumeration value"""

        invalid_axis_source: int
        """Client sent invalid axis source enumeration value"""



    def motion(self, time: int, dx: float, dy: float) -> None:
        """
        Pointer relative motion event

        The pointer has moved by a relative amount to the previous request.

        Values are in the global compositor space.

        Args:
            time: Timestamp with millisecond granularity
            dx: Displacement on the x-axis
            dy: Displacement on the y-axis
        """

        ...

    def motion_absolute(self, time: int, x: int, y: int, x_extent: int, y_extent: int) -> None:
        """
        Pointer absolute motion event

        The pointer has moved in an absolute coordinate frame.

        Value of x can range from 0 to x_extent, value of y can range from 0
        to y_extent.

        Args:
            time: Timestamp with millisecond granularity
            x: Position on the x-axis
            y: Position on the y-axis
            x_extent: Extent of the x-axis
            y_extent: Extent of the y-axis
        """

        ...

    def button(self, time: int, button: int, state: wl_pointer.button_state) -> None:
        """
        Button event

        A button was pressed or released.

        Args:
            time: Timestamp with millisecond granularity
            button: Button that produced the event
            state: Physical state of the button
        """

        ...

    def axis(self, time: int, axis: wl_pointer.axis, value: float) -> None:
        """
        Axis event

        Scroll and other axis requests.

        Args:
            time: Timestamp with millisecond granularity
            axis: Axis type
            value: Length of vector in touchpad coordinates
        """

        ...

    def frame(self) -> None:
        """
        End of a pointer event sequence

        Indicates the set of events that logically belong together.
        """

        ...

    def axis_source(self, axis_source: wl_pointer.axis_source) -> None:
        """
        Axis source event

        Source information for scroll and other axis.

        Args:
            axis_source: Source of the axis event
        """

        ...

    def axis_stop(self, time: int, axis: wl_pointer.axis) -> None:
        """
        Axis stop event

        Stop notification for scroll and other axes.

        Args:
            time: Timestamp with millisecond granularity
            axis: The axis stopped with this event
        """

        ...

    def axis_discrete(self, time: int, axis: wl_pointer.axis, value: float, discrete: int) -> None:
        """
        Axis click event

        Discrete step information for scroll and other axes.

        This event allows the client to extend data normally sent using the axis
        event with discrete value.

        Args:
            time: Timestamp with millisecond granularity
            axis: Axis type
            value: Length of vector in touchpad coordinates
            discrete: Number of steps
        """

        ...

    def destroy(self) -> None:
        """Destroy the virtual pointer object"""

        ...

class zwlr_virtual_pointer_manager_v1:
    """
    Virtual pointer manager

    This object allows clients to create individual virtual pointer objects.
    """
    object_id = 0
    version = 2


    def create_virtual_pointer(self, seat: wl_seat) -> zwlr_virtual_pointer_v1:
        """
        Create a new virtual pointer

        Creates a new virtual pointer. The optional seat is a suggestion to the
        compositor.

        Returns:
            zwlr_virtual_pointer_v1: The created object
        """

        ...

    def destroy(self) -> None:
        """Destroy the virtual pointer manager"""

        ...

    def create_virtual_pointer_with_output(self, seat: wl_seat, output: wl_output) -> zwlr_virtual_pointer_v1:
        """
        Create a new virtual pointer

        Creates a new virtual pointer. The seat and the output arguments are
        optional. If the seat argument is set, the compositor should assign the
        input device to the requested seat. If the output argument is set, the
        compositor should map the input device to the requested output.

        Returns:
            zwlr_virtual_pointer_v1: The created object
        """

        ...

